.aioseo-search-statistics-seo-statistics{position:relative}.aioseo-search-statistics-site-statistics .aioseo-seo-statistics-card .header .aioseo-tooltip .popper{max-width:400px}.aioseo-search-statistics-site-statistics .aioseo-col .aioseo-card{margin:0 0 20px}.aioseo-search-statistics-site-statistics .aioseo-graph-legend-simple .apexcharts-legend{gap:40px}
