.aioseo-sa-ct-custom-fields.lite{min-height:370px}@media(max-width:598px){.aioseo-sa-ct-custom-fields.lite .aioseo-cta.floating{top:0}}@media(max-width:420px){.aioseo-sa-ct-custom-fields.lite{min-height:450px}}.aioseo-app .aioseo-sa-ct-schema-lite{min-height:580px}@media(max-width:598px){.aioseo-app .aioseo-sa-ct-schema-lite{min-height:640px}.aioseo-app .aioseo-sa-ct-schema-lite .aioseo-cta.floating{top:0}}@media(max-width:420px){.aioseo-app .aioseo-sa-ct-schema-lite{min-height:770px}}.aioseo-app .aioseo-sa-ct-schema-lite .aioseo-cta .header-text{width:100%;max-width:600px}.aioseo-app .aioseo-sa-ct-schema-lite .schema-type{max-width:250px}
