.titles-descriptions .list .aioseo-alert[data-v-8c468fbd]{margin:16px 16px 0}.titles-descriptions .list .suggestions[data-v-8c468fbd]{display:flex;flex-direction:column;gap:16px;max-height:calc(90vh - 120px);overflow-y:auto}.titles-descriptions .list .suggestions .suggestion[data-v-8c468fbd]{display:flex;align-items:center;position:relative;border-radius:3px;font-size:14px;color:#141b38;border:1px solid #E8E8EB;height:auto;min-height:42px}[dir=ltr] .titles-descriptions .list .suggestions .suggestion[data-v-8c468fbd]{padding:7px 55px 7px 10px}[dir=rtl] .titles-descriptions .list .suggestions .suggestion[data-v-8c468fbd]{padding:7px 10px 7px 55px}.titles-descriptions .list .suggestions .suggestion p[data-v-8c468fbd]{margin:0}.titles-descriptions .list .suggestions .suggestion button[data-v-8c468fbd]{display:flex;align-items:center;justify-content:center;position:absolute;top:4px;width:32px!important;height:32px!important;background-color:#f3f4f5;border:1px solid #D0D1D7;border-radius:4px;cursor:pointer;padding:0!important}[dir=ltr] .titles-descriptions .list .suggestions .suggestion button[data-v-8c468fbd]{right:4px}[dir=rtl] .titles-descriptions .list .suggestions .suggestion button[data-v-8c468fbd]{left:4px}.titles-descriptions .list .suggestions .suggestion button svg[data-v-8c468fbd]{width:14px!important;height:14px!important;color:#141b38!important}.aioseo-ai-content-loader{display:flex;margin-bottom:-20px;flex-grow:1}.aioseo-ai-content-loader .aioseo-ai-content-loader-image{flex:1 1 50%;display:flex;align-items:center;justify-content:center;background-color:#1a82ea}[dir=ltr] .aioseo-ai-content-loader .aioseo-ai-content-loader-image{margin:-20px 0 0 -20px}[dir=rtl] .aioseo-ai-content-loader .aioseo-ai-content-loader-image{margin:-20px -20px 0 0}.aioseo-ai-content-loader .aioseo-ai-content-loader-image img{max-width:400px;max-height:400px;padding:50px;height:auto}.aioseo-ai-content-loader .aioseo-ai-content-loader-text{flex:1 1 50%;display:flex;align-items:center;justify-content:center}.aioseo-ai-content-loader .aioseo-ai-content-loader-text .loading-container{display:flex;align-items:center}.aioseo-ai-content-loader .aioseo-ai-content-loader-text .loading-container .aioseo-loading-spinner{position:relative}.aioseo-ai-content-loader .aioseo-ai-content-loader-text .loading-text{font-size:16px}[dir=ltr] .aioseo-ai-content-loader .aioseo-ai-content-loader-text .loading-text{margin-left:10px}[dir=rtl] .aioseo-ai-content-loader .aioseo-ai-content-loader-text .loading-text{margin-right:10px}.aioseo-ai-content-step-header .step-header{display:flex;align-items:center;margin-bottom:20px}.aioseo-ai-content-step-header .step-header .step-header-number{position:absolute;display:flex;align-items:center;justify-content:center;width:24px;height:24px;background-color:#f0f1f2;border-radius:50%;font-weight:700}[dir=ltr] .aioseo-ai-content-step-header .step-header .step-header-number{margin-right:10px}[dir=rtl] .aioseo-ai-content-step-header .step-header .step-header-number{margin-left:10px}.aioseo-ai-content-step-header .step-header .step-header-title{font-size:16px;font-weight:700}[dir=ltr] .aioseo-ai-content-step-header .step-header .step-header-title{margin-left:40px}[dir=rtl] .aioseo-ai-content-step-header .step-header .step-header-title{margin-right:40px}.aioseo-ai-content-style-form .field-group{margin-bottom:32px}.aioseo-ai-content-style-form .field-group label{color:#141b38;display:block;font-size:14px;font-weight:600;margin-bottom:8px}.aioseo-ai-content-style-form .aioseo-alert a{text-decoration:underline}
