<?php
$ign = array(
  'able',
  'about',
  'above',
  'according',
  'accordingly',
  'acirc',
  'across',
  'actually',
  'acute',
  'aelig',
  'after',
  'afterwards',
  'again',
  'against',
  'agrave',
  'ain\'t',
  'all',
  'allow',
  'allows',
  'almost',
  'alone',
  'along',
  'already',
  'also',
  'although',
  'always',
  'am',
  'among',
  'amongst',
  'amp',
  'an',
  'and',
  'another',
  'any',
  'anybody',
  'anyhow',
  'anyone',
  'anything',
  'anyway',
  'anyways',
  'anywhere',
  'apart',
  'appear',
  'appreciate',
  'appropriate',
  'are',
  'aring',
  'around',
  'as',
  'aside',
  'ask',
  'asking',
  'associated',
  'at',
  'atilde',
  'auml',
  'available',
  'away',
  'awfully',
  'be',
  'became',
  'because',
  'become',
  'becomes',
  'becoming',
  'been',
  'before',
  'beforehand',
  'behind',
  'being',
  'believe',
  'below',
  'beside',
  'besides',
  'best',
  'better',
  'between',
  'beyond',
  'bit',
  'both',
  'brief',
  'brvbar',
  'but',
  'by',
  'c\'mon',
  'c\'s',
  'came',
  'can',
  'can\'t',
  'cannot',
  'cant',
  'cause',
  'causes',
  'ccedil',
  'cedil',
  'cent',
  'certain',
  'certainly',
  'changes',
  'clearly',
  'co',
  'com',
  'come',
  'comes',
  'como',
  'concerning',
  'consequently',
  'consider',
  'considering',
  'contain',
  'containing',
  'contains',
  'corresponding',
  'could',
  'couldn\'t',
  'course',
  'currently',
  'definitely',
  'described',
  'despite',
  'did',
  'didn\'t',
  'different',
  'dlvr',
  'do',
  'does',
  'doesn\'t',
  'doing',
  'don\'t',
  'done',
  'down',
  'downwards',
  'during',
  'each',
  'eacute',
  'edu',
  'eg',
  'egrave',
  'eight',
  'either',
  'else',
  'elsewhere',
  'enough',
  'entirely',
  'especially',
  'et',
  'etc',
  'ETH',
  'even',
  'ever',
  'every',
  'everybody',
  'everyone',
  'everything',
  'everywhere',
  'ex',
  'exactly',
  'example',
  'except',
  'far',
  'few',
  'fifth',
  'filhos',
  'first',
  'five',
  'followed',
  'following',
  'follows',
  'for',
  'former',
  'formerly',
  'forth',
  'four',
  'frac',
  'from',
  'further',
  'furthermore',
  'get',
  'gets',
  'getting',
  'given',
  'gives',
  'go',
  'goes',
  'going',
  'gone',
  'goo',
  'got',
  'gotten',
  'greetings',
  'had',
  'hadn\'t',
  'happens',
  'hardly',
  'has',
  'hasn\'t',
  'have',
  'haven\'t',
  'having',
  'he',
  'he\'s',
  'hello',
  'help',
  'hence',
  'her',
  'here',
  'here\'s',
  'hereafter',
  'hereby',
  'herein',
  'hereupon',
  'hers',
  'herself',
  'hi',
  'him',
  'himself',
  'his',
  'hither',
  'hopefully',
  'how',
  'howbeit',
  'however',
  'http',
  'https',
  'i\'d',
  'i\'ll',
  'i\'m',
  'i\'ve',
  'Icirc',
  'ie',
  'iexcl',
  'if',
  'ignored',
  'immediate',
  'in',
  'inasmuch',
  'inc',
  'indeed',
  'indicate',
  'indicated',
  'indicates',
  'inner',
  'insofar',
  'instead',
  'into',
  'inward',
  'is',
  'it',
  'it\'d',
  'it\'ll',
  'it\'s',
  'its',
  'itself',
  'iuml',
  'just',
  'keep',
  'keeps',
  'kept',
  'know',
  'known',
  'knows',
  'laquo',
  'last',
  'lately',
  'later',
  'latter',
  'latterly',
  'least',
  'less',
  'lest',
  'let',
  'let\'s',
  'liked',
  'likely',
  'little',
  'look',
  'looking',
  'looks',
  'ltd',
  'macr',
  'mainly',
  'many',
  'may',
  'maybe',
  'me',
  'mean',
  'meanwhile',
  'merely',
  'might',
  'more',
  'moreover',
  'most',
  'mostly',
  'much',
  'must',
  'my',
  'myself',
  'name',
  'namely',
  'nbsp',
  'nd',
  'near',
  'nearly',
  'necessary',
  'need',
  'needs',
  'neither',
  'never',
  'nevertheless',
  'new',
  'next',
  'nine',
  'no',
  'nobody',
  'non',
  'none',
  'noone',
  'nor',
  'normally',
  'nothing',
  'novel',
  'now',
  'nowhere',
  'ntilde',
  'obviously',
  'of',
  'off',
  'often',
  'oh',
  'ok',
  'okay',
  'old',
  'on',
  'once',
  'one',
  'ones',
  'only',
  'onto',
  'or',
  'ordf',
  'ordm',
  'other',
  'others',
  'otherwise',
  'ought',
  'our',
  'ours',
  'ourselves',
  'out',
  'outside',
  'over',
  'overall',
  'own',
  'para',
  'particular',
  'particularly',
  'per',
  'perhaps',
  'placed',
  'please',
  'plus',
  'plusmn',
  'possible',
  'presumably',
  'probably',
  'provides',
  'que',
  'quite',
  'quot',
  'qv',
  'rather',
  'rd',
  're',
  'really',
  'reg',
  'regarding',
  'regardless',
  'regards',
  'relatively',
  'respectively',
  'right',
  'said',
  'same',
  'saw',
  'say',
  'saying',
  'says',
  'second',
  'secondly',
  'sect',
  'see',
  'seeing',
  'seem',
  'seemed',
  'seeming',
  'seems',
  'seen',
  'self',
  'selves',
  'sensible',
  'sent',
  'ser',
  'serious',
  'seriously',
  'seu',
  'seven',
  'several',
  'shall',
  'she',
  'should',
  'shouldn\'t',
  'since',
  'six',
  'sLZjpNxJtx',
  'so',
  'some',
  'somebody',
  'somehow',
  'someone',
  'something',
  'sometime',
  'sometimes',
  'somewhat',
  'somewhere',
  'soon',
  'sorry',
  'specified',
  'specify',
  'specifying',
  'still',
  'sub',
  'such',
  'sup',
  'sure',
  'take',
  'taken',
  'tell',
  'tends',
  'th',
  'than',
  'thank',
  'thanks',
  'thanx',
  'that',
  'that\'s',
  'thats',
  'the',
  'their',
  'theirs',
  'them',
  'themselves',
  'then',
  'thence',
  'there',
  'there\'s',
  'thereafter',
  'thereby',
  'therefore',
  'therein',
  'theres',
  'thereupon',
  'these',
  'they',
  'they\'d',
  'they\'ll',
  'they\'re',
  'they\'ve',
  'think',
  'third',
  'this',
  'thorough',
  'thoroughly',
  'those',
  'though',
  'three',
  'through',
  'throughout',
  'thru',
  'thus',
  'to',
  'together',
  'too',
  'took',
  'toward',
  'towards',
  'tried',
  'tries',
  'truly',
  'try',
  'trying',
  'twice',
  'two',
  'Ugrave',
  'un',
  'under',
  'unfortunately',
  'unless',
  'unlikely',
  'until',
  'unto',
  'up',
  'upon',
  'us',
  'use',
  'used',
  'uses',
  'using',
  'usually',
  'value',
  'various',
  'very',
  'via',
  'viz',
  'vs',
  'want',
  'wants',
  'was',
  'wasn\'t',
  'way',
  'we',
  'we\'d',
  'we\'ll',
  'we\'re',
  'we\'ve',
  'welcome',
  'well',
  'went',
  'were',
  'weren\'t',
  'what',
  'what\'s',
  'whatever',
  'when',
  'whence',
  'whenever',
  'where',
  'where\'s',
  'whereafter',
  'whereas',
  'whereby',
  'wherein',
  'whereupon',
  'wherever',
  'whether',
  'which',
  'while',
  'whither',
  'who',
  'who\'s',
  'whoever',
  'whole',
  'whom',
  'whose',
  'why',
  'will',
  'willing',
  'wish',
  'with',
  'within',
  'without',
  'won\'t',
  'wonder',
  'would',
  'wouldn\'t',
  'www',
  'yes',
  'yet',
  'you',
  'you\'d',
  'you\'ll',
  'you\'re',
  'you\'ve',
  'your',
  'yours',
  'yourself',
  'yourselves',
  'zero',
  'zynga',
);
