#aioseo-limit-modified-date-bricks[data-v-078871ee]{display:flex;align-items:center;justify-content:center;justify-items:center;line-height:1;cursor:pointer}#aioseo-limit-modified-date-bricks .svg[data-v-078871ee]{width:12px;height:12px;flex-basis:12px}#aioseo-limit-modified-date-bricks .aioseo-options[data-v-078871ee]{position:absolute;top:100%;white-space:nowrap;background-color:#fff;border-radius:4px;padding:8px 10px;font-size:12px;font-weight:400;color:#000;-webkit-user-select:none;user-select:none}[dir=ltr] #aioseo-limit-modified-date-bricks .aioseo-options[data-v-078871ee]{right:0}[dir=rtl] #aioseo-limit-modified-date-bricks .aioseo-options[data-v-078871ee]{left:0}#aioseo-limit-modified-date-bricks .aioseo-options[data-v-078871ee]:hover{background-color:#d9d9d9}.aioseo-bricks-modal .modal-body{min-height:min(60vh,500px)}.aioseo-bricks-modal .modal-header{gap:10px}
