<?php  ?>
<h1><a href="https://app.linksgarden.com/publisher-websites.php" target="_blank">Menu de configuration Linksgarden</a></h1>
<?php if (get_option('owner_confirmed') != 1) : ?>
    <h3>Veuillez entrer votre clé publique et clé secrète, vous pouvez les retrouver sur cette page lorsque vous tentez de valider une propriété : <a href="https://app.linksgarden.com/publisher-websites.php" target="_blank">https://app.linksgarden.com/publisher-websites.php</a></h3>
<?php endif; ?>
<form name="subId" method="POST" action="">
    <?php wp_nonce_field('lg_config_save', 'lg_nonce'); ?>
    <table class="form-table">
        <span style="color: green;" <?= get_option('owner_confirmed') == 1 ? '' : 'hidden' ?>><span class="dashicons dashicons-yes"></span> Connecté</span>
        <span style="color: red;" <?= get_option('owner_confirmed') == 4 ? '' : 'hidden' ?>><span class="dashicons dashicons-no"></span> Votre site est déconnécté de Linksgarden</span>
        <span style="color: red;" <?= $code_erreur == 3 ? '' : 'hidden' ?>><span class="dashicons dashicons-no"></span> Votre site n'est pas inscrit sur Linksgarden</span>
        <tr>
            <th>Clé publique :</th>
            <td>
                <input type="text" name="api_lg_public" id="api_lg_public" <?= get_option('api_lg_public') == false ? 'placeholder="API publique"' : 'value="'.esc_attr(get_option('api_lg_public')).'"' ?>></input>
                <span  id='lg_public_missing' style="color: red; display:none"> Champ obligatoire pour se connecter</span>
                <span style="color: red;" <?= $code_erreur == 1 ? '' : 'hidden' ?>><span class="dashicons dashicons-no"></span> Clé publique incorrecte</span>
            </td>
        </tr>
        <tr>
            <th>Clé secrète :</th>
            <td>
                <input type="password" name="api_lg_secret" id="api_lg_secret" <?= get_option('api_lg_secret') == false ? 'placeholder="API secret"' : 'value="'.get_option('api_lg_secret').'"' ?>></input>
                <span id='lg_secret_missing' style="color: red; display:none"> Champ obligatoire pour se connecter</span>
                <span style="color: red;" <?= $code_erreur == 2 ? '' : 'hidden' ?>><span class="dashicons dashicons-no"></span> Clé secrète incorrecte</span>
            </td>
        </tr>
    </table>
    <input type="submit" name="submit" id="submit" class="button button-primary" value="<?= get_option('owner_confirmed') != 1 ? 'Connecter son site à Linksgarden' : 'Enregistrer les modifications'?>">
</form>
