/* dm-sans-regular - latin */
@font-face {
  font-family: "DM Sans";
  font-style: normal;
  font-weight: 400;
  src: local(""), url("../fonts/dm-sans-v11-latin-regular.woff2") format("woff2"), url("../fonts/dm-sans-v11-latin-regular.woff") format("woff"); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}
/* dm-sans-500 - latin */
@font-face {
  font-family: "DM Sans";
  font-style: normal;
  font-weight: 500;
  src: local(""), url("../fonts/dm-sans-v11-latin-500.woff2") format("woff2"), url("../fonts/dm-sans-v11-latin-500.woff") format("woff"); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}
/* dm-sans-700 - latin */
@font-face {
  font-family: "DM Sans";
  font-style: normal;
  font-weight: 700;
  src: local(""), url("../fonts/dm-sans-v11-latin-700.woff2") format("woff2"), url("../fonts/dm-sans-v11-latin-700.woff") format("woff"); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}
:root {
  --base-gutter: 30px;
  --md-gutter: 50px;
  --lg-gutter: 70px;
  --xl-gutter: 100px;
  --base-spacer-x: 16px;
  --base-spacer-y: 16px;
  --b-radius-6: 25px;
}
@media (max-width: 1599.98px) {
  :root {
    --base-gutter: 20px;
    --md-gutter: 30px;
    --lg-gutter: 50px;
    --xl-gutter: 70px;
  }
}
@media (max-width: 1399.98px) {
  :root {
    --base-gutter: 20px;
    --md-gutter: 30px;
    --lg-gutter: 40px;
    --xl-gutter: 50px;
  }
}
@media (max-width: 1199.98px) {
  :root {
    --base-spacer-x: 10px;
    --base-spacer-y: 10px;
    --md-gutter: 20px;
    --lg-gutter: 30px;
    --xl-gutter: 40px;
  }
}
@media (max-width: 991.98px) {
  :root {
    --base-spacer-x: 5px;
    --base-spacer-y: 5px;
    --md-gutter: 20px;
    --lg-gutter: 30px;
    --xl-gutter: 40px;
  }
}

.disablecommentswrap {
  font-size: 10px;
  font-family: "DM Sans", sans-serif;
  line-height: 1.7;
  font-weight: 400;
  letter-spacing: 0;
  min-height: 100vh;
  background: #ffffff;
  color: #000000;
  outline: none;
  border: none;
  box-sizing: border-box;
  overflow: hidden;
  -webkit-display: flex;
  -moz-display: flex;
  -ms-display: flex;
  -o-display: flex;
  display: flex;
  -webkit-flex-direction: column;
  -moz-flex-direction: column;
  -ms-flex-direction: column;
  -o-flex-direction: column;
  flex-direction: column;
}
.disablecommentswrap * {
  box-sizing: border-box;
}
.disablecommentswrap ::selection {
  color: #ffffff;
  background: rgba(98, 60, 234, 0.8);
}
.disablecommentswrap ul,
.disablecommentswrap li {
  list-style: none;
}
.disablecommentswrap a {
  color: initial;
  transition: all 0.3s linear;
  text-decoration: none;
  display: inline-block;
}
.disablecommentswrap label {
  margin-bottom: 0;
}
.disablecommentswrap .button {
  vertical-align: middle;
  font-family: "DM Sans", sans-serif;
  font-weight: 500;
}
.disablecommentswrap .button:hover, .disablecommentswrap .button:focus {
  outline: none;
}
.disablecommentswrap .button:not(:disabled) {
  cursor: pointer;
}
.disablecommentswrap h1,
.disablecommentswrap h2,
.disablecommentswrap h3,
.disablecommentswrap h4,
.disablecommentswrap h5,
.disablecommentswrap h6,
.disablecommentswrap p {
  margin: 0;
  padding: 0;
}
.disablecommentswrap h1,
.disablecommentswrap h2,
.disablecommentswrap h3,
.disablecommentswrap h4,
.disablecommentswrap h5,
.disablecommentswrap h6 {
  font-family: "DM Sans", sans-serif;
  font-weight: 700;
  line-height: 1.3;
  margin-top: 0;
  margin-bottom: 0;
  color: inherit;
}
.disablecommentswrap h1 a,
.disablecommentswrap h2 a,
.disablecommentswrap h3 a,
.disablecommentswrap h4 a,
.disablecommentswrap h5 a,
.disablecommentswrap h6 a {
  color: inherit;
}
.disablecommentswrap h1 a:hover,
.disablecommentswrap h2 a:hover,
.disablecommentswrap h3 a:hover,
.disablecommentswrap h4 a:hover,
.disablecommentswrap h5 a:hover,
.disablecommentswrap h6 a:hover {
  color: inherit;
}
.disablecommentswrap ul,
.disablecommentswrap ol {
  margin-bottom: 0;
}
.disablecommentswrap img,
.disablecommentswrap video {
  max-width: 100%;
}
.disablecommentswrap .pt5 {
  padding-top: 5px;
}
.disablecommentswrap .pt10 {
  padding-top: 10px;
}
.disablecommentswrap .mt5 {
  margin-top: 5px;
}
.disablecommentswrap .mt10 {
  margin-top: 10px;
}

.pt50 {
  padding-top: 50px;
}

.pb50 {
  padding-bottom: 50px;
}

.pt70 {
  padding-top: 70px;
}

.pb70 {
  padding-bottom: 70px;
}

.pt110 {
  padding-top: 110px;
}

.pb110 {
  padding-bottom: 110px;
}

.pt120 {
  padding-top: 120px;
}

.pb120 {
  padding-bottom: 120px;
}

.pt150 {
  padding-top: 150px;
}

.pb150 {
  padding-bottom: 150px;
}

.pt200 {
  padding-top: 200px;
}

.pb200 {
  padding-bottom: 200px;
}

.pt300 {
  padding-top: 300px;
}

.pb300 {
  padding-bottom: 300px;
}

.mt10 {
  margin-top: 10px;
}

.mb10 {
  margin-bottom: 10px;
}

.mt15 {
  margin-top: 15px;
}

.mb15 {
  margin-bottom: 15px;
}

.mt20 {
  margin-top: 20px;
}

.mb20 {
  margin-bottom: 20px;
}

.mt30 {
  margin-top: 30px;
}

.mb30 {
  margin-bottom: 30px;
}

.mt50 {
  margin-top: 50px;
}

.mb50 {
  margin-bottom: 50px;
}

.mt70 {
  margin-top: 70px;
}

.mb70 {
  margin-bottom: 70px;
}

.mt80 {
  margin-top: 80px;
}

.mb80 {
  margin-bottom: 80px;
}

.mt100 {
  margin-top: 100px;
}

.mb100 {
  margin-bottom: 100px;
}

.color__primary {
  color: #623cea !important;
}

a.color__primary:hover, a.color__primary:focus {
  color: rgb(66.375, 23.625, 219.375);
  box-shadow: none;
}

.color__secondary {
  color: #fa7d51 !important;
}

a.color__secondary:hover, a.color__secondary:focus {
  color: rgb(248.5754189944, 87.9608938547, 31.4245810056);
  box-shadow: none;
}

.color__success {
  color: #05cb6b !important;
}

a.color__success:hover, a.color__success:focus {
  color: rgb(3.7740384615, 153.2259615385, 80.7644230769);
  box-shadow: none;
}

.color__danger {
  color: #e0061a !important;
}

a.color__danger:hover, a.color__danger:focus {
  color: rgb(174.3304347826, 4.6695652174, 20.2347826087);
  box-shadow: none;
}

.color__info {
  color: #00b2fc !important;
}

a.color__info:hover, a.color__info:focus {
  color: rgb(0, 141.9761904762, 201);
  box-shadow: none;
}

.color__dark {
  color: #22282d !important;
}

a.color__dark:hover, a.color__dark:focus {
  color: rgb(12.0506329114, 14.1772151899, 15.9493670886);
  box-shadow: none;
}

.color__white {
  color: #ffffff !important;
}

a.color__white:hover, a.color__white:focus {
  color: rgb(229.5, 229.5, 229.5);
  box-shadow: none;
}

.color__black {
  color: #000000 !important;
}

.color__grey {
  color: #f4f6fc !important;
}

a.color__grey:hover, a.color__grey:focus {
  color: rgb(203.9285714286, 213.2142857143, 241.0714285714);
  box-shadow: none;
}

.color__grey2 {
  color: #808da1 !important;
}

a.color__grey2:hover, a.color__grey2:focus {
  color: rgb(101.2307692308, 115.2307692308, 136.7692307692);
  box-shadow: none;
}

.color__twitter {
  color: #1da1f2 !important;
}

a.color__twitter:hover, a.color__twitter:focus {
  color: rgb(11.9665271967, 133.4728033473, 208.0334728033);
  box-shadow: none;
}

.color__linkedin {
  color: #0077b5 !important;
}

a.color__linkedin:hover, a.color__linkedin:focus {
  color: rgb(0, 85.4696132597, 130);
  box-shadow: none;
}

.color__instagram {
  color: #e1306c !important;
}

a.color__instagram:hover, a.color__instagram:focus {
  color: rgb(193.8987341772, 28.1012658228, 84.3037974684);
  box-shadow: none;
}

.background__primary {
  background-color: #623cea !important;
}

.background__secondary {
  background-color: #fa7d51 !important;
}

.background__success {
  background-color: #05cb6b !important;
}

.background__danger {
  background-color: #e0061a !important;
}

.background__info {
  background-color: #00b2fc !important;
}

.background__dark {
  background-color: #22282d !important;
}

.background__white {
  background-color: #ffffff !important;
}

.background__black {
  background-color: #000000 !important;
}

.background__grey {
  background-color: #f4f6fc !important;
}

.background__grey2 {
  background-color: #808da1 !important;
}

.background__twitter {
  background-color: #1da1f2 !important;
}

.background__linkedin {
  background-color: #0077b5 !important;
}

.background__instagram {
  background-color: #e1306c !important;
}

.gradient__primary {
  background-image: linear-gradient(180deg, rgba(98, 60, 234, 0.3), rgba(98, 60, 234, 0.05));
  color: #623cea;
}

.gradient__secondary {
  background-image: linear-gradient(180deg, rgba(250, 125, 81, 0.3), rgba(250, 125, 81, 0.05));
  color: #fa7d51;
}

.gradient__success {
  background-image: linear-gradient(180deg, rgba(5, 203, 107, 0.3), rgba(5, 203, 107, 0.05));
  color: #05cb6b;
}

.gradient__danger {
  background-image: linear-gradient(180deg, rgba(224, 6, 26, 0.3), rgba(224, 6, 26, 0.05));
  color: #e0061a;
}

.gradient__info {
  background-image: linear-gradient(180deg, rgba(0, 178, 252, 0.3), rgba(0, 178, 252, 0.05));
  color: #00b2fc;
}

.gradient__dark {
  background-image: linear-gradient(180deg, rgba(34, 40, 45, 0.3), rgba(34, 40, 45, 0.05));
  color: #22282d;
}

.gradient__white {
  background-image: linear-gradient(180deg, rgba(255, 255, 255, 0.3), rgba(255, 255, 255, 0.05));
  color: #ffffff;
}

.gradient__black {
  background-image: linear-gradient(180deg, rgba(0, 0, 0, 0.3), rgba(0, 0, 0, 0.05));
  color: #000000;
}

.gradient__grey {
  background-image: linear-gradient(180deg, rgba(244, 246, 252, 0.3), rgba(244, 246, 252, 0.05));
  color: #f4f6fc;
}

.gradient__grey2 {
  background-image: linear-gradient(180deg, rgba(128, 141, 161, 0.3), rgba(128, 141, 161, 0.05));
  color: #808da1;
}

.gradient__twitter {
  background-image: linear-gradient(180deg, rgba(29, 161, 242, 0.3), rgba(29, 161, 242, 0.05));
  color: #1da1f2;
}

.gradient__linkedin {
  background-image: linear-gradient(180deg, rgba(0, 119, 181, 0.3), rgba(0, 119, 181, 0.05));
  color: #0077b5;
}

.gradient__instagram {
  background-image: linear-gradient(180deg, rgba(225, 48, 108, 0.3), rgba(225, 48, 108, 0.05));
  color: #e1306c;
}

.cloud__info__card__icon__primary {
  background-image: linear-gradient(180deg, rgba(98, 60, 234, 0.3), rgba(98, 60, 234, 0.05));
  color: #623cea;
}

.cloud__info__card__icon__secondary {
  background-image: linear-gradient(180deg, rgba(250, 125, 81, 0.3), rgba(250, 125, 81, 0.05));
  color: #fa7d51;
}

.cloud__info__card__icon__success {
  background-image: linear-gradient(180deg, rgba(5, 203, 107, 0.3), rgba(5, 203, 107, 0.05));
  color: #05cb6b;
}

.cloud__info__card__icon__danger {
  background-image: linear-gradient(180deg, rgba(224, 6, 26, 0.3), rgba(224, 6, 26, 0.05));
  color: #e0061a;
}

.cloud__info__card__icon__info {
  background-image: linear-gradient(180deg, rgba(0, 178, 252, 0.3), rgba(0, 178, 252, 0.05));
  color: #00b2fc;
}

.cloud__info__card__icon__dark {
  background-image: linear-gradient(180deg, rgba(34, 40, 45, 0.3), rgba(34, 40, 45, 0.05));
  color: #22282d;
}

.cloud__info__card__icon__white {
  background-image: linear-gradient(180deg, rgba(255, 255, 255, 0.3), rgba(255, 255, 255, 0.05));
  color: #ffffff;
}

.cloud__info__card__icon__black {
  background-image: linear-gradient(180deg, rgba(0, 0, 0, 0.3), rgba(0, 0, 0, 0.05));
  color: #000000;
}

.cloud__info__card__icon__grey {
  background-image: linear-gradient(180deg, rgba(244, 246, 252, 0.3), rgba(244, 246, 252, 0.05));
  color: #f4f6fc;
}

.cloud__info__card__icon__grey2 {
  background-image: linear-gradient(180deg, rgba(128, 141, 161, 0.3), rgba(128, 141, 161, 0.05));
  color: #808da1;
}

.cloud__info__card__icon__twitter {
  background-image: linear-gradient(180deg, rgba(29, 161, 242, 0.3), rgba(29, 161, 242, 0.05));
  color: #1da1f2;
}

.cloud__info__card__icon__linkedin {
  background-image: linear-gradient(180deg, rgba(0, 119, 181, 0.3), rgba(0, 119, 181, 0.05));
  color: #0077b5;
}

.cloud__info__card__icon__instagram {
  background-image: linear-gradient(180deg, rgba(225, 48, 108, 0.3), rgba(225, 48, 108, 0.05));
  color: #e1306c;
}

.counter__card__primary .counter__card--icon {
  color: white;
  background: #623cea;
}
.counter__card__primary .counter__card--icon:before {
  background: #623cea;
}
.counter__card__primary .counter__card--content .count__number {
  color: #623cea;
}

.counter__card__secondary .counter__card--icon {
  color: white;
  background: #fa7d51;
}
.counter__card__secondary .counter__card--icon:before {
  background: #fa7d51;
}
.counter__card__secondary .counter__card--content .count__number {
  color: #fa7d51;
}

.counter__card__success .counter__card--icon {
  color: white;
  background: #05cb6b;
}
.counter__card__success .counter__card--icon:before {
  background: #05cb6b;
}
.counter__card__success .counter__card--content .count__number {
  color: #05cb6b;
}

.counter__card__danger .counter__card--icon {
  color: white;
  background: #e0061a;
}
.counter__card__danger .counter__card--icon:before {
  background: #e0061a;
}
.counter__card__danger .counter__card--content .count__number {
  color: #e0061a;
}

.counter__card__info .counter__card--icon {
  color: white;
  background: #00b2fc;
}
.counter__card__info .counter__card--icon:before {
  background: #00b2fc;
}
.counter__card__info .counter__card--content .count__number {
  color: #00b2fc;
}

.counter__card__dark .counter__card--icon {
  color: white;
  background: #22282d;
}
.counter__card__dark .counter__card--icon:before {
  background: #22282d;
}
.counter__card__dark .counter__card--content .count__number {
  color: #22282d;
}

.counter__card__white .counter__card--icon {
  color: #22282d;
  background: #ffffff;
}
.counter__card__white .counter__card--icon:before {
  background: #ffffff;
}
.counter__card__white .counter__card--content .count__number {
  color: #ffffff;
}

.counter__card__black .counter__card--icon {
  color: white;
  background: #000000;
}
.counter__card__black .counter__card--icon:before {
  background: #000000;
}
.counter__card__black .counter__card--content .count__number {
  color: #000000;
}

.counter__card__grey .counter__card--icon {
  color: #22282d;
  background: #f4f6fc;
}
.counter__card__grey .counter__card--icon:before {
  background: #f4f6fc;
}
.counter__card__grey .counter__card--content .count__number {
  color: #f4f6fc;
}

.counter__card__grey2 .counter__card--icon {
  color: white;
  background: #808da1;
}
.counter__card__grey2 .counter__card--icon:before {
  background: #808da1;
}
.counter__card__grey2 .counter__card--content .count__number {
  color: #808da1;
}

.counter__card__twitter .counter__card--icon {
  color: white;
  background: #1da1f2;
}
.counter__card__twitter .counter__card--icon:before {
  background: #1da1f2;
}
.counter__card__twitter .counter__card--content .count__number {
  color: #1da1f2;
}

.counter__card__linkedin .counter__card--icon {
  color: white;
  background: #0077b5;
}
.counter__card__linkedin .counter__card--icon:before {
  background: #0077b5;
}
.counter__card__linkedin .counter__card--content .count__number {
  color: #0077b5;
}

.counter__card__instagram .counter__card--icon {
  color: white;
  background: #e1306c;
}
.counter__card__instagram .counter__card--icon:before {
  background: #e1306c;
}
.counter__card__instagram .counter__card--content .count__number {
  color: #e1306c;
}

.m-0-5 {
  margin: calc(0.5 * var(--base-spacer-x)) calc(0.5 * var(--base-spacer-x));
}

.mt-0-5 {
  margin-top: calc(0.5 * var(--base-spacer-x));
}

.mr-0-5 {
  margin-right: calc(0.5 * var(--base-spacer-x));
}

.mb-0-5 {
  margin-bottom: calc(0.5 * var(--base-spacer-x));
}

.ml-0-5 {
  margin-left: calc(0.5 * var(--base-spacer-x));
}

.my-0-5 {
  margin-top: calc(0.5 * var(--base-spacer-x));
  margin-bottom: calc(0.5 * var(--base-spacer-x));
}

.m-1 {
  margin: calc(1 * var(--base-spacer-x)) calc(1 * var(--base-spacer-x));
}

.mt-1 {
  margin-top: calc(1 * var(--base-spacer-x));
}

.mr-1 {
  margin-right: calc(1 * var(--base-spacer-x));
}

.mb-1 {
  margin-bottom: calc(1 * var(--base-spacer-x));
}

.ml-1 {
  margin-left: calc(1 * var(--base-spacer-x));
}

.my-1 {
  margin-top: calc(1 * var(--base-spacer-x));
  margin-bottom: calc(1 * var(--base-spacer-x));
}

.m-1-5 {
  margin: calc(1.5 * var(--base-spacer-x)) calc(1.5 * var(--base-spacer-x));
}

.mt-1-5 {
  margin-top: calc(1.5 * var(--base-spacer-x));
}

.mr-1-5 {
  margin-right: calc(1.5 * var(--base-spacer-x));
}

.mb-1-5 {
  margin-bottom: calc(1.5 * var(--base-spacer-x));
}

.ml-1-5 {
  margin-left: calc(1.5 * var(--base-spacer-x));
}

.my-1-5 {
  margin-top: calc(1.5 * var(--base-spacer-x));
  margin-bottom: calc(1.5 * var(--base-spacer-x));
}

.m-2 {
  margin: calc(2 * var(--base-spacer-y)) calc(2 * var(--base-spacer-x));
}

.mt-2 {
  margin-top: calc(2 * var(--base-spacer-y));
}

.mr-2 {
  margin-right: calc(2 * var(--base-spacer-x));
}

.mb-2 {
  margin-bottom: calc(2 * var(--base-spacer-y));
}

.ml-2 {
  margin-left: calc(2 * var(--base-spacer-x));
}

.my-2 {
  margin-top: calc(2 * var(--base-spacer-y));
  margin-bottom: calc(2 * var(--base-spacer-y));
}

.m-2-5 {
  margin: calc(2.5 * var(--base-spacer-y)) calc(2.5 * var(--base-spacer-x));
}

.mt-2-5 {
  margin-top: calc(2.5 * var(--base-spacer-y));
}

.mr-2-5 {
  margin-right: calc(2.5 * var(--base-spacer-x));
}

.mb-2-5 {
  margin-bottom: calc(2.5 * var(--base-spacer-y));
}

.ml-2-5 {
  margin-left: calc(2.5 * var(--base-spacer-x));
}

.my-2-5 {
  margin-top: calc(2.5 * var(--base-spacer-y));
  margin-bottom: calc(2.5 * var(--base-spacer-y));
}

.m-3 {
  margin: calc(3 * var(--base-spacer-y)) calc(3 * var(--base-spacer-x));
}

.mt-3 {
  margin-top: calc(3 * var(--base-spacer-y));
}

.mr-3 {
  margin-right: calc(3 * var(--base-spacer-x));
}

.mb-3 {
  margin-bottom: calc(3 * var(--base-spacer-y));
}

.ml-3 {
  margin-left: calc(3 * var(--base-spacer-x));
}

.my-3 {
  margin-top: calc(3 * var(--base-spacer-y));
  margin-bottom: calc(3 * var(--base-spacer-y));
}

.m-3-5 {
  margin: calc(3.5 * var(--base-spacer-y)) calc(3.5 * var(--base-spacer-x));
}

.mt-3-5 {
  margin-top: calc(3.5 * var(--base-spacer-y));
}

.mr-3-5 {
  margin-right: calc(3.5 * var(--base-spacer-x));
}

.mb-3-5 {
  margin-bottom: calc(3.5 * var(--base-spacer-y));
}

.ml-3-5 {
  margin-left: calc(3.5 * var(--base-spacer-x));
}

.my-3-5 {
  margin-top: calc(3.5 * var(--base-spacer-y));
  margin-bottom: calc(3.5 * var(--base-spacer-y));
}

.m-4 {
  margin: calc(4 * var(--base-spacer-x)) calc(4 * var(--base-spacer-x));
}

.mt-4 {
  margin-top: calc(4 * var(--base-spacer-x));
}

.mr-4 {
  margin-right: calc(4 * var(--base-spacer-x));
}

.mb-4 {
  margin-bottom: calc(4 * var(--base-spacer-x));
}

.ml-4 {
  margin-left: calc(4 * var(--base-spacer-x));
}

.my-4 {
  margin-top: calc(4 * var(--base-spacer-x));
  margin-bottom: calc(4 * var(--base-spacer-x));
}

.m-5 {
  margin: calc(5 * var(--base-spacer-x)) calc(5 * var(--base-spacer-x));
}

.mt-5 {
  margin-top: calc(5 * var(--base-spacer-x));
}

.mr-5 {
  margin-right: calc(5 * var(--base-spacer-x));
}

.mb-5 {
  margin-bottom: calc(5 * var(--base-spacer-x));
}

.ml-5 {
  margin-left: calc(5 * var(--base-spacer-x));
}

.my-5 {
  margin-top: calc(5 * var(--base-spacer-x));
  margin-bottom: calc(5 * var(--base-spacer-x));
}

.mx-auto {
  margin-left: auto;
  margin-right: auto;
}

.p-0-5 {
  padding: calc(0.5 * var(--base-spacer-x)) calc(0.5 * var(--base-spacer-x));
}

.pt-0-5 {
  padding-top: calc(0.5 * var(--base-spacer-x));
}

.pr-0-5 {
  padding-right: calc(0.5 * var(--base-spacer-x));
}

.pb-0-5 {
  padding-bottom: calc(0.5 * var(--base-spacer-x));
}

.pl-0-5 {
  padding-left: calc(0.5 * var(--base-spacer-x));
}

.py-0-5 {
  padding-top: calc(0.5 * var(--base-spacer-x));
  padding-bottom: calc(0.5 * var(--base-spacer-x));
}

.p-1 {
  padding: calc(1 * var(--base-spacer-x)) calc(1 * var(--base-spacer-x));
}

.pt-1 {
  padding-top: calc(1 * var(--base-spacer-x));
}

.pr-1 {
  padding-right: calc(1 * var(--base-spacer-x));
}

.pb-1 {
  padding-bottom: calc(1 * var(--base-spacer-x));
}

.pl-1 {
  padding-left: calc(1 * var(--base-spacer-x));
}

.py-1 {
  padding-top: calc(1 * var(--base-spacer-x));
  padding-bottom: calc(1 * var(--base-spacer-x));
}

.p-1-5 {
  padding: calc(1.5 * var(--base-spacer-x)) calc(1.5 * var(--base-spacer-x));
}

.pt-1-5 {
  padding-top: calc(1.5 * var(--base-spacer-x));
}

.pr-1-5 {
  padding-right: calc(1.5 * var(--base-spacer-x));
}

.pb-1-5 {
  padding-bottom: calc(1.5 * var(--base-spacer-x));
}

.pl-1-5 {
  padding-left: calc(1.5 * var(--base-spacer-x));
}

.py-1-5 {
  padding-top: calc(1.5 * var(--base-spacer-x));
  padding-bottom: calc(1.5 * var(--base-spacer-x));
}

.p-2 {
  padding: calc(2 * var(--base-spacer-y)) calc(2 * var(--base-spacer-x));
}

.pt-2 {
  padding-top: calc(2 * var(--base-spacer-y));
}

.pr-2 {
  padding-right: calc(2 * var(--base-spacer-x));
}

.pb-2 {
  padding-bottom: calc(2 * var(--base-spacer-y));
}

.pl-2 {
  padding-left: calc(2 * var(--base-spacer-x));
}

.py-2 {
  padding-top: calc(2 * var(--base-spacer-y));
  padding-bottom: calc(2 * var(--base-spacer-y));
}

.p-2-5 {
  padding: calc(2.5 * var(--base-spacer-y)) calc(2.5 * var(--base-spacer-x));
}

.pt-2-5 {
  padding-top: calc(2.5 * var(--base-spacer-y));
}

.pr-2-5 {
  padding-right: calc(2.5 * var(--base-spacer-x));
}

.pb-2-5 {
  padding-bottom: calc(2.5 * var(--base-spacer-y));
}

.pl-2-5 {
  padding-left: calc(2.5 * var(--base-spacer-x));
}

.py-2-5 {
  padding-top: calc(2.5 * var(--base-spacer-y));
  padding-bottom: calc(2.5 * var(--base-spacer-y));
}

.p-3 {
  padding: calc(3 * var(--base-spacer-y)) calc(3 * var(--base-spacer-x));
}

.pt-3 {
  padding-top: calc(3 * var(--base-spacer-y));
}

.pr-3 {
  padding-right: calc(3 * var(--base-spacer-x));
}

.pb-3 {
  padding-bottom: calc(3 * var(--base-spacer-y));
}

.pl-3 {
  padding-left: calc(3 * var(--base-spacer-x));
}

.py-3 {
  padding-top: calc(3 * var(--base-spacer-y));
  padding-bottom: calc(3 * var(--base-spacer-y));
}

.p-3-5 {
  padding: calc(3.5 * var(--base-spacer-y)) calc(3.5 * var(--base-spacer-x));
}

.pt-3-5 {
  padding-top: calc(3.5 * var(--base-spacer-y));
}

.pr-3-5 {
  padding-right: calc(3.5 * var(--base-spacer-x));
}

.pb-3-5 {
  padding-bottom: calc(3.5 * var(--base-spacer-y));
}

.pl-3-5 {
  padding-left: calc(3.5 * var(--base-spacer-x));
}

.py-3-5 {
  padding-top: calc(3.5 * var(--base-spacer-y));
  padding-bottom: calc(3.5 * var(--base-spacer-y));
}

.p-4 {
  padding: calc(4 * var(--base-spacer-x)) calc(4 * var(--base-spacer-x));
}

.pt-4 {
  padding-top: calc(4 * var(--base-spacer-x));
}

.pr-4 {
  padding-right: calc(4 * var(--base-spacer-x));
}

.pb-4 {
  padding-bottom: calc(4 * var(--base-spacer-x));
}

.pl-4 {
  padding-left: calc(4 * var(--base-spacer-x));
}

.py-4 {
  padding-top: calc(4 * var(--base-spacer-x));
  padding-bottom: calc(4 * var(--base-spacer-x));
}

.p-5 {
  padding: calc(5 * var(--base-spacer-x)) calc(5 * var(--base-spacer-x));
}

.pt-5 {
  padding-top: calc(5 * var(--base-spacer-x));
}

.pr-5 {
  padding-right: calc(5 * var(--base-spacer-x));
}

.pb-5 {
  padding-bottom: calc(5 * var(--base-spacer-x));
}

.pl-5 {
  padding-left: calc(5 * var(--base-spacer-x));
}

.py-5 {
  padding-top: calc(5 * var(--base-spacer-x));
  padding-bottom: calc(5 * var(--base-spacer-x));
}

.px-auto {
  padding-left: auto;
  padding-right: auto;
}

.disablecommentswrap {
  padding: 30px;
}
@media (max-width: 575.98px) {
  .disablecommentswrap {
    padding: 30px;
  }
}
.disablecommentswrap .delete-comments-not-found {
  width: 60%;
  margin: 0 auto;
  text-align: center;
}
.disablecommentswrap .delete-comments-not-found .error-message {
  margin-top: 30px;
  color: #444;
}

@media (max-width: 1199.98px) {
  .sidebar__widget__wrap {
    margin-top: 50px;
  }
}

.dc-text__block {
  background: #ffffff;
  padding: 20px;
  border-radius: 10px;
}
.dc-text__block__big__pad {
  padding: 40px 50px;
  background: #ffffff;
  border-radius: 10px;
}
@media (max-width: 767.98px) {
  .dc-text__block__big__pad {
    padding: 40px 25px;
  }
}

.dc-container {
  width: 100%;
  max-width: 1200px;
  margin: 0 auto;
}

.dc-row {
  display: flex;
  flex-wrap: wrap;
  margin-right: -15px;
  margin-left: -15px;
}

.dc-col {
  flex-basis: 0;
  flex-grow: 1;
  max-width: 100%;
}

.dc-col,
.dc-col-xs-6,
.dc-col-sm-6,
.dc-col-md-6,
.dc-col-lg-4,
.dc-col-lg-3,
.dc-col-lg-9 {
  padding-left: 15px;
  padding-right: 15px;
  width: 100%;
}

@media (min-width: 576px) {
  .dc-col-xs-6 {
    flex: 0 0 50%;
    max-width: 50%;
  }
}
@media (min-width: 768px) {
  .dc-col-sm-6 {
    flex: 0 0 50%;
    max-width: 50%;
  }
}
@media (min-width: 992px) {
  .dc-col-md-6 {
    flex: 0 0 50%;
    max-width: 50%;
  }
}
@media (min-width: 1200px) {
  .dc-col-lg-3 {
    flex: 0 0 25%;
    max-width: 25%;
  }
  .dc-col-lg-4 {
    flex: 0 0 33.33%;
    max-width: 33.33%;
  }
  .dc-col-lg-9 {
    flex: 0 0 75%;
    max-width: 75%;
  }
}
.form__control {
  border: 1px solid rgba(0, 0, 0, 0.15) !important;
}
.form__control.w-100 {
  width: 100%;
}

.d__flex {
  display: flex;
}

.space__between {
  justify-content: space-between;
  align-items: center;
}
.icon__input {
  position: relative;
}
.icon__input .icon {
  position: absolute;
  top: 7px;
  right: 12px;
  pointer-events: none;
}

.button__primary:not(.hover__highlight) {
  background: #623cea;
  color: white;
  border-color: #623cea;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__primary:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__primary:not(.hover__highlight) .icon {
  color: #623cea;
  background: white;
}
.button__primary.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__primary.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__primary.active:disabled, a.button__primary:hover:disabled,
button.button__primary.active:disabled,
button.button__primary:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__primary.active, a.button__primary:hover,
button.button__primary.active,
button.button__primary:hover {
  background: rgb(79.4652777778, 36.9791666667, 231.5208333333);
  color: white;
  border-color: rgb(79.4652777778, 36.9791666667, 231.5208333333);
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.3);
}
a.button__primary.hover__highlight:hover .icon,
button.button__primary.hover__highlight:hover .icon {
  background: white;
  color: #623cea;
}

.button__secondary:not(.hover__highlight) {
  background: #fa7d51;
  color: white;
  border-color: #fa7d51;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__secondary:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__secondary:not(.hover__highlight) .icon {
  color: #fa7d51;
  background: white;
}
.button__secondary.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__secondary.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__secondary.active:disabled, a.button__secondary:hover:disabled,
button.button__secondary.active:disabled,
button.button__secondary:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__secondary.active, a.button__secondary:hover,
button.button__secondary.active,
button.button__secondary:hover {
  background: rgb(249.2877094972, 106.4804469274, 56.2122905028);
  color: white;
  border-color: rgb(249.2877094972, 106.4804469274, 56.2122905028);
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.3);
}
a.button__secondary.hover__highlight:hover .icon,
button.button__secondary.hover__highlight:hover .icon {
  background: white;
  color: #fa7d51;
}

.button__success:not(.hover__highlight) {
  background: #05cb6b;
  color: white;
  border-color: #05cb6b;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__success:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__success:not(.hover__highlight) .icon {
  color: #05cb6b;
  background: white;
}
.button__success.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__success.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__success.active:disabled, a.button__success:hover:disabled,
button.button__success.active:disabled,
button.button__success:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__success.active, a.button__success:hover,
button.button__success.active,
button.button__success:hover {
  background: rgb(4.3870192308, 178.1129807692, 93.8822115385);
  color: white;
  border-color: rgb(4.3870192308, 178.1129807692, 93.8822115385);
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.3);
}
a.button__success.hover__highlight:hover .icon,
button.button__success.hover__highlight:hover .icon {
  background: white;
  color: #05cb6b;
}

.button__danger:not(.hover__highlight) {
  background: #e0061a;
  color: white;
  border-color: #e0061a;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__danger:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__danger:not(.hover__highlight) .icon {
  color: #e0061a;
  background: white;
}
.button__danger.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__danger.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__danger.active:disabled, a.button__danger:hover:disabled,
button.button__danger.active:disabled,
button.button__danger:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__danger.active, a.button__danger:hover,
button.button__danger.active,
button.button__danger:hover {
  background: rgb(199.1652173913, 5.3347826087, 23.1173913043);
  color: white;
  border-color: rgb(199.1652173913, 5.3347826087, 23.1173913043);
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.3);
}
a.button__danger.hover__highlight:hover .icon,
button.button__danger.hover__highlight:hover .icon {
  background: white;
  color: #e0061a;
}

.button__info:not(.hover__highlight) {
  background: #00b2fc;
  color: white;
  border-color: #00b2fc;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__info:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__info:not(.hover__highlight) .icon {
  color: #00b2fc;
  background: white;
}
.button__info.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__info.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__info.active:disabled, a.button__info:hover:disabled,
button.button__info.active:disabled,
button.button__info:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__info.active, a.button__info:hover,
button.button__info.active,
button.button__info:hover {
  background: rgb(0, 159.9880952381, 226.5);
  color: white;
  border-color: rgb(0, 159.9880952381, 226.5);
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.3);
}
a.button__info.hover__highlight:hover .icon,
button.button__info.hover__highlight:hover .icon {
  background: white;
  color: #00b2fc;
}

.button__dark:not(.hover__highlight) {
  background: #22282d;
  color: white;
  border-color: #22282d;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__dark:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__dark:not(.hover__highlight) .icon {
  color: #22282d;
  background: white;
}
.button__dark.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__dark.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__dark.active:disabled, a.button__dark:hover:disabled,
button.button__dark.active:disabled,
button.button__dark:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__dark.active, a.button__dark:hover,
button.button__dark.active,
button.button__dark:hover {
  background: rgb(23.0253164557, 27.0886075949, 30.4746835443);
  color: white;
  border-color: rgb(23.0253164557, 27.0886075949, 30.4746835443);
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.3);
}
a.button__dark.hover__highlight:hover .icon,
button.button__dark.hover__highlight:hover .icon {
  background: white;
  color: #22282d;
}

.button__white:not(.hover__highlight) {
  background: #ffffff;
  color: #623cea;
  border-color: #ffffff;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__white:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__white:not(.hover__highlight) .icon {
  color: #ffffff;
  background: #623cea;
}
.button__white.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__white.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__white.active:disabled, a.button__white:hover:disabled,
button.button__white.active:disabled,
button.button__white:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__white.active, a.button__white:hover,
button.button__white.active,
button.button__white:hover {
  background: rgb(242.25, 242.25, 242.25);
  color: #623cea;
  border-color: rgb(242.25, 242.25, 242.25);
  text-shadow: 0 1px 1px rgba(98, 60, 234, 0.3);
}
a.button__white.hover__highlight:hover .icon,
button.button__white.hover__highlight:hover .icon {
  background: #623cea;
  color: #ffffff;
}

.button__black:not(.hover__highlight) {
  background: #000000;
  color: white;
  border-color: #000000;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__black:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__black:not(.hover__highlight) .icon {
  color: #000000;
  background: white;
}
.button__black.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__black.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__black.active:disabled, a.button__black:hover:disabled,
button.button__black.active:disabled,
button.button__black:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__black.hover__highlight:hover .icon,
button.button__black.hover__highlight:hover .icon {
  background: white;
  color: #000000;
}

.button__grey:not(.hover__highlight) {
  background: #f4f6fc;
  color: #623cea;
  border-color: #f4f6fc;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__grey:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__grey:not(.hover__highlight) .icon {
  color: #f4f6fc;
  background: #623cea;
}
.button__grey.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__grey.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__grey.active:disabled, a.button__grey:hover:disabled,
button.button__grey.active:disabled,
button.button__grey:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__grey.active, a.button__grey:hover,
button.button__grey.active,
button.button__grey:hover {
  background: rgb(223.9642857143, 229.6071428571, 246.5357142857);
  color: #623cea;
  border-color: rgb(223.9642857143, 229.6071428571, 246.5357142857);
  text-shadow: 0 1px 1px rgba(98, 60, 234, 0.3);
}
a.button__grey.hover__highlight:hover .icon,
button.button__grey.hover__highlight:hover .icon {
  background: #623cea;
  color: #f4f6fc;
}

.button__grey2:not(.hover__highlight) {
  background: #808da1;
  color: white;
  border-color: #808da1;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__grey2:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__grey2:not(.hover__highlight) .icon {
  color: #808da1;
  background: white;
}
.button__grey2.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__grey2.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__grey2.active:disabled, a.button__grey2:hover:disabled,
button.button__grey2.active:disabled,
button.button__grey2:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__grey2.active, a.button__grey2:hover,
button.button__grey2.active,
button.button__grey2:hover {
  background: rgb(113.3461538462, 127.8461538462, 150.1538461538);
  color: white;
  border-color: rgb(113.3461538462, 127.8461538462, 150.1538461538);
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.3);
}
a.button__grey2.hover__highlight:hover .icon,
button.button__grey2.hover__highlight:hover .icon {
  background: white;
  color: #808da1;
}

.button__twitter:not(.hover__highlight) {
  background: #1da1f2;
  color: white;
  border-color: #1da1f2;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__twitter:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__twitter:not(.hover__highlight) .icon {
  color: #1da1f2;
  background: white;
}
.button__twitter.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__twitter.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__twitter.active:disabled, a.button__twitter:hover:disabled,
button.button__twitter.active:disabled,
button.button__twitter:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__twitter.active, a.button__twitter:hover,
button.button__twitter.active,
button.button__twitter:hover {
  background: rgb(13.3535564854, 148.9435146444, 232.1464435146);
  color: white;
  border-color: rgb(13.3535564854, 148.9435146444, 232.1464435146);
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.3);
}
a.button__twitter.hover__highlight:hover .icon,
button.button__twitter.hover__highlight:hover .icon {
  background: white;
  color: #1da1f2;
}

.button__linkedin:not(.hover__highlight) {
  background: #0077b5;
  color: white;
  border-color: #0077b5;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__linkedin:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__linkedin:not(.hover__highlight) .icon {
  color: #0077b5;
  background: white;
}
.button__linkedin.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__linkedin.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__linkedin.active:disabled, a.button__linkedin:hover:disabled,
button.button__linkedin.active:disabled,
button.button__linkedin:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__linkedin.active, a.button__linkedin:hover,
button.button__linkedin.active,
button.button__linkedin:hover {
  background: rgb(0, 102.2348066298, 155.5);
  color: white;
  border-color: rgb(0, 102.2348066298, 155.5);
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.3);
}
a.button__linkedin.hover__highlight:hover .icon,
button.button__linkedin.hover__highlight:hover .icon {
  background: white;
  color: #0077b5;
}

.button__instagram:not(.hover__highlight) {
  background: #e1306c;
  color: white;
  border-color: #e1306c;
  -webkit-transition: all 0.3s ease-in-out 0s;
  -moz-transition: all 0.3s ease-in-out 0s;
  -ms-transition: all 0.3s ease-in-out 0s;
  -o-transition: all 0.3s ease-in-out 0s;
  transition: all 0.3s ease-in-out 0s;
  -webkit-transition-property: background, color, box-shadow, border;
  -moz-transition-property: background, color, box-shadow, border;
  -ms-transition-property: background, color, box-shadow, border;
  -o-transition-property: background, color, box-shadow, border;
  transition-property: background, color, box-shadow, border;
}
.button__instagram:not(.hover__highlight):disabled {
  cursor: not-allowed;
  background: #fa7d51;
}
.button__instagram:not(.hover__highlight) .icon {
  color: #e1306c;
  background: white;
}
.button__instagram.hover__highlight {
  color: #623cea;
  border-color: rgba(98, 60, 234, 0.2);
}
.button__instagram.hover__highlight .icon {
  background: #623cea;
  color: #ffffff;
}

a.button__instagram.active:disabled, a.button__instagram:hover:disabled,
button.button__instagram.active:disabled,
button.button__instagram:hover:disabled {
  cursor: not-allowed;
  background: #fa7d51;
  box-shadow: none;
}
a.button__instagram.active, a.button__instagram:hover,
button.button__instagram.active,
button.button__instagram:hover {
  background: rgb(216.1708860759, 31.3291139241, 93.9873417722);
  color: white;
  border-color: rgb(216.1708860759, 31.3291139241, 93.9873417722);
  text-shadow: 0 1px 1px rgba(255, 255, 255, 0.3);
}
a.button__instagram.hover__highlight:hover .icon,
button.button__instagram.hover__highlight:hover .icon {
  background: white;
  color: #e1306c;
}

.disablecommentswrap .button {
  height: 50px;
  line-height: 50px;
  padding: 0;
  border-radius: 5px;
  color: #808da1;
  font-size: 15px;
  border: 0;
  font-weight: 700;
  padding: 0 20px;
  box-shadow: none;
  font-family: "DM Sans", sans-serif;
  background: #f4f6fc;
}
.disablecommentswrap .button:hover, .disablecommentswrap .button:focus {
  box-shadow: none;
  border: 0;
  color: #ffffff;
  background: #05cb6b;
}
.disablecommentswrap .button:focus-visible {
  outline: 2px solid #00b2fc;
}
.disablecommentswrap .button.button__fade {
  display: flex;
  align-items: center;
  min-width: 190px;
  justify-content: center;
}
@media (max-width: 991.98px) {
  .disablecommentswrap .button {
    height: 50px;
    line-height: 46px;
    font-size: 13px;
  }
}
.disablecommentswrap .button__delete {
  color: #ffffff;
  background: #e0061a;
}
.disablecommentswrap .button__delete:hover, .disablecommentswrap .button__delete:focus {
  background: rgb(255, 0, 0);
  color: #ffffff;
}
.disablecommentswrap .button__success {
  color: #ffffff;
  background: #05cb6b;
}
.disablecommentswrap .button__success:hover, .disablecommentswrap .button__success:focus {
  background: rgba(5, 203, 107, 0.9);
  color: #ffffff;
}
.disablecommentswrap .button__success.button__fade {
  opacity: 0.6;
}
.disablecommentswrap .button__success.button__fade:disabled, .disablecommentswrap .button__success.button__fade[disabled] {
  color: #ffffff !important;
  background: #05cb6b !important;
  opacity: 0.6 !important;
}
.disablecommentswrap .button__success.form-dirty {
  opacity: 1;
}
.disablecommentswrap .button--sm {
  height: 40px;
  line-height: 40px;
}
.disablecommentswrap .button__group .button:not(:last-child) {
  margin-right: 15px;
}

.cancelButton {
  padding: 0;
  border-radius: 5px;
  color: #808da1 !important;
  font-size: 15px;
  border: 0;
  font-weight: 700;
  padding: 0 20px;
  -webkit-box-shadow: none;
  box-shadow: none;
  outline: none;
  background: #f4f6fc !important;
}

.confirmButton {
  padding: 0;
  border-radius: 5px;
  color: #fff !important;
  font-size: 15px;
  border: 0;
  font-weight: 700;
  padding: 0 20px;
  -webkit-box-shadow: none;
  box-shadow: none;
  outline: none;
  background: #e0061a !important;
}
.confirmButton:focus {
  outline: none !important;
  box-shadow: none !important;
}

#eael-spinner {
  width: 18px;
  display: inline-block;
  float: left;
  margin: 0 5px 0 0;
  -webkit-transition-property: -webkit-transform;
  -webkit-transition-duration: 1.2s;
  -webkit-animation-name: rotate;
  -webkit-animation-iteration-count: infinite;
  -webkit-animation-timing-function: linear;
  -moz-transition-property: -moz-transform;
  -moz-animation-name: rotate;
  -moz-animation-duration: 1.2s;
  -moz-animation-iteration-count: infinite;
  -moz-animation-timing-function: linear;
  transition-property: transform;
  animation-name: rotate;
  animation-duration: 1.2s;
  animation-iteration-count: infinite;
  animation-timing-function: linear;
}

@-webkit-keyframes rotate {
  from {
    -webkit-transform: rotate(0deg);
  }
  to {
    -webkit-transform: rotate(360deg);
  }
}
@-moz-keyframes rotate {
  from {
    -moz-transform: rotate(0deg);
  }
  to {
    -moz-transform: rotate(360deg);
  }
}
@keyframes rotate {
  from {
    transform: rotate(0deg);
  }
  to {
    transform: rotate(360deg);
  }
}
.disable__comment__alert {
  display: flex;
  align-items: center;
  padding: 10px 20px;
  border: 0;
}
@media (max-width: 767.98px) {
  .disable__comment__alert {
    display: block;
  }
  .disable__comment__alert .button__group {
    margin-top: 20px;
  }
}
.disable__comment__alert .alert__content {
  display: flex;
  align-items: center;
  padding-right: 20px;
  flex-wrap: wrap;
  flex: 1;
}
@media (max-width: 767.98px) {
  .disable__comment__alert .alert__content {
    padding-right: 0;
  }
}
@media (max-width: 575.98px) {
  .disable__comment__alert .alert__content {
    display: block;
  }
}
.disable__comment__alert .alert__content img {
  margin-right: 15px;
  height: 30px;
}
@media (max-width: 575.98px) {
  .disable__comment__alert .alert__content img {
    margin-bottom: 10px;
  }
}
.disable__comment__alert .alert__content p {
  font-size: 18px;
  font-weight: 500;
  color: #22282d;
  font-family: "DM Sans", sans-serif;
}
.disable__comment__alert .alert__content a.wpinsights-disable-comments-collect {
  color: #05cb6b;
}
.disable__comment__alert .alert__content a.wpinsights-disable-comments-collect:hover,
.disable__comment__alert .alert__content a.wpinsights-disable-comments-collect:visited,
.disable__comment__alert .alert__content a.wpinsights-disable-comments-collect:focus {
  outline: none;
  border: none;
  box-shadow: none;
}
.disable__comment__alert .alert__content .wpinsights-data {
  margin-top: 10px;
}
.disable__comment__alert .alert__content .wpinsights-data p {
  font-size: 13px;
}
.disable__comment__alert .button__group {
  text-align: right;
}
@media (max-width: 767.98px) {
  .disable__comment__alert .button__group {
    text-align: left;
  }
}
.disable__comment__alert .button__group .button {
  margin-right: 0;
  margin-top: 5px;
  margin-bottom: 5px;
}
.disable__comment__alert .button__group .button:not(:last-child) {
  margin-right: 0;
}
.disable__comment__alert .button__group .button:not(:first-child) {
  margin-left: 15px;
}
@media (max-width: 767.98px) {
  .disable__comment__alert .button__group .button {
    margin-right: 10px;
  }
  .disable__comment__alert .button__group .button:not(:last-child) {
    margin-right: 10px;
  }
  .disable__comment__alert .button__group .button:not(:first-child) {
    margin-left: 0;
  }
}

.section__header {
  text-align: center;
  margin-bottom: 50px;
}
.section__header h2 {
  font-size: 24px;
  font-weight: 700;
  color: #22282d;
  font-family: "DM Sans", sans-serif;
}

.disable__comment__nav__wrap {
  background: #ffffff;
  border-radius: 5px;
  position: relative;
}
.disable__comment__nav__wrap .plugin__version {
  position: absolute;
  font-size: 16px;
  font-weight: 500;
  color: #687b95;
  font-family: "DM Sans", sans-serif;
  top: 50%;
  right: 30px;
  transform: translateY(-50%);
}
@media (max-width: 767.98px) {
  .disable__comment__nav__wrap .plugin__version {
    position: static;
    top: 0;
    transform: translateY(0);
    padding: 10px 10px 10px 20px;
  }
}
.disable__comment__nav__wrap .disable__comment__nav {
  display: flex;
  flex-wrap: wrap;
  margin-top: 0;
}
.disable__comment__nav__wrap .disable__comment__nav .disable__comment__nav__item {
  margin-bottom: 0;
}
.disable__comment__nav__wrap .disable__comment__nav .disable__comment__nav__item .disable__comment__nav__link {
  font-size: 16px;
  font-weight: 700;
  color: #687b95;
  text-transform: uppercase;
  font-family: "DM Sans", sans-serif;
  padding: 17px 20px;
  outline: none;
  box-shadow: none;
}
.disable__comment__nav__wrap .disable__comment__nav .disable__comment__nav__item .disable__comment__nav__link.active {
  color: #22282d;
  position: relative;
}
.disable__comment__nav__wrap .disable__comment__nav .disable__comment__nav__item .disable__comment__nav__link.active:before {
  position: absolute;
  left: 0;
  right: 0;
  bottom: 0;
  height: 2px;
  background: #e0061a;
  content: "";
}
.disable__comment__nav__wrap .disable__comment__nav .disable__comment__nav__item .disable__comment__nav__link:focus {
  transition: unset;
}
@media (max-width: 991.98px) {
  .disable__comment__nav__wrap .disable__comment__nav .disable__comment__nav__item .disable__comment__nav__link {
    font-size: 18px;
  }
}
@media (max-width: 575.98px) {
  .disable__comment__nav__wrap .disable__comment__nav .disable__comment__nav__item .disable__comment__nav__link {
    font-size: 16px;
  }
}

.disable__comment__tab {
  padding-top: 25px;
}

.disable__comment__tab__item {
  display: none;
}
.disable__comment__tab__item.show {
  display: block;
}

.sites_list_wrapper .sites_list {
  display: flex;
  width: 100%;
  flex-wrap: wrap;
}
.sites_list_wrapper .sites_list .subsite__checklist__item {
  flex: 0 0 285px;
}
.sites_list_wrapper .sites_list .subsite__checklist__item label {
  word-break: break-word;
}

.disable__comment__option .title {
  font-size: 22px;
  font-weight: 500;
  color: #22282d;
  margin-bottom: 5px;
}
.disable__comment__option .subtitle {
  color: #687b95;
  font-size: 14px;
  font-family: "DM Sans", sans-serif;
  font-weight: 400;
  padding-left: 0;
  line-height: 1.5;
}
.disable__comment__option .subtitle .danger {
  color: #e0061a;
  font-weight: 500;
}
.disable__comment__option .radio-style input[type=radio] {
  display: none;
}
.disable__comment__option .radio-style input[type=radio]:checked ~ label .icon {
  border-color: #05cb6b;
}
.disable__comment__option .radio-style input[type=radio]:checked ~ label .icon:after {
  opacity: 1;
}
.disable__comment__option .radio-style label {
  font-size: 16px;
  font-weight: 500;
  color: #22282d;
  font-family: "DM Sans", sans-serif;
  position: relative;
  line-height: 1.3;
  padding-left: 20px;
  display: block;
  margin-bottom: 15px;
}
.disable__comment__option .radio-style label .icon {
  position: absolute;
  top: 2px;
  left: 0;
  height: 14px;
  width: 14px;
  border-radius: 50%;
  border: 1px solid #687b95;
}
.disable__comment__option .radio-style label .icon:after {
  position: absolute;
  top: 2px;
  left: 2px;
  height: 8px;
  width: 8px;
  border-radius: 50%;
  border: 0;
  background: #05cb6b;
  content: "";
  opacity: 0;
  transition: all 0.3s ease;
}
.disable__comment__option .checkbox-style input[type=checkbox] {
  display: none;
}
.disable__comment__option .checkbox-style input[type=checkbox]:checked ~ label .icon {
  border-color: #00b2fc;
  background: #00b2fc;
}
.disable__comment__option .checkbox-style input[type=checkbox]:checked ~ label .icon:after {
  opacity: 1;
}
.disable__comment__option .checkbox-style label {
  font-size: 16px;
  font-weight: 500;
  color: #687b95;
  font-family: "DM Sans", sans-serif;
  position: relative;
  line-height: 1.3;
  padding-left: 20px;
  display: block;
}
.disable__comment__option .checkbox-style label:focus-visible {
  box-shadow: none;
  outline: none;
}
.disable__comment__option .checkbox-style label .icon {
  position: absolute;
  top: 2px;
  left: 0;
  height: 14px;
  width: 14px;
  border: 1px solid #687b95;
}
.disable__comment__option .checkbox-style label .icon:after {
  position: absolute;
  top: -4px;
  left: 1px;
  content: url(../img/check.png);
  opacity: 0;
  transition: all 0.3s ease;
}
.disable__comment__option .dissable__switch__item {
  margin-bottom: 10px;
}
.disable__comment__option .dissable__switch__item input {
  display: none;
}
.disable__comment__option .dissable__switch__item input:checked ~ label {
  color: #22282d;
}
.disable__comment__option .dissable__switch__item input:checked ~ label .switch {
  background: #05cb6b;
}
.disable__comment__option .dissable__switch__item input:checked ~ label .switch:before {
  left: 28px;
}
.disable__comment__option .dissable__switch__item input:checked ~ label .switch .switch__text {
  left: 5px;
}
.disable__comment__option .dissable__switch__item input:checked ~ label .switch .switch__text.on {
  display: block;
}
.disable__comment__option .dissable__switch__item input:checked ~ label .switch .switch__text.off {
  display: none;
}
.disable__comment__option .dissable__switch__item label {
  font-size: 16px;
  font-weight: 500;
  color: #687b95;
  font-family: "DM Sans", sans-serif;
  display: inline-flex;
  align-items: center;
}
@media (max-width: 479.98px) {
  .disable__comment__option .dissable__switch__item label {
    font-size: 14px;
  }
}
.disable__comment__option .dissable__switch__item label .switch {
  height: 20px;
  width: 40px;
  margin-right: 16px;
  border-radius: 10px;
  background: #99a6b8;
  display: inline-block;
  font-size: 10px;
  text-transform: uppercase;
  font-weight: 500;
  color: #ffffff;
  font-family: "DM Sans", sans-serif;
  position: relative;
  transition: all 0.3s ease;
}
@media (max-width: 479.98px) {
  .disable__comment__option .dissable__switch__item label .switch {
    font-size: 10px;
  }
}
.disable__comment__option .dissable__switch__item label .switch:before {
  position: absolute;
  top: 6px;
  left: 4px;
  border-radius: 50%;
  background: #ffffff;
  height: 8px;
  width: 8px;
  content: "";
  transition: all 0.3s ease;
}
.disable__comment__option .dissable__switch__item label .switch .switch__text {
  position: absolute;
  top: 2px;
  left: 16px;
  transition: all 0.3s ease;
}
.disable__comment__option .dissable__switch__item label .switch .switch__text.on {
  display: none;
}
.disable__comment__option .disable_option {
  border-radius: 5px;
}
.disable__comment__option .disable_option h3 {
  font-size: 18px;
  font-weight: 500;
  color: #22282d;
  font-family: "DM Sans", sans-serif;
  position: relative;
  line-height: 1.3;
  display: block;
  margin-bottom: 15px;
}
.disable__comment__option .disable_option .disable__checklist,
.disable__comment__option .disable_option .delete__feedback {
  display: flex;
  flex-wrap: wrap;
  gap: 16px;
}
.disable__comment__option .disable_option .delete__checklist {
  display: flex;
  flex-wrap: wrap;
  gap: 16px;
  margin-bottom: 10px;
  padding-left: 1.5em;
}
.disable__comment__option .disable_option .remove__checklist {
  display: flex;
  flex-wrap: wrap;
  gap: 16px;
  margin-bottom: 10px;
}
.disable__comment__option .disable_option .delete__feedback {
  margin-bottom: 10px;
  padding-left: 1.5em;
}
.disable__comment__option .disable_option .delete__feedback label {
  font-size: 14px;
}
.disable__comment__option .disable_option .delete__feedback .delete__feedback__item {
  position: relative;
  display: inline-block;
  padding-right: 8px;
}
.disable__comment__option .disable_option .delete__feedback .delete__feedback__item:not(:last-child):before {
  position: absolute;
  top: 7px;
  right: -2px;
  bottom: 7px;
  width: 2px;
  background: #687b95;
  content: "";
}
.disable__comment__option .disable_option .delete__feedback .delete__feedback__item:last-child {
  padding-left: 8px;
}
.disable__comment__option .disable_option .delete__feedback .delete__feedback__item a {
  font-size: 18px;
  font-weight: 500;
  color: #687b95;
  outline: none;
  box-shadow: none;
}
.disable__comment__option .disable_option .disable__option__description {
  font-size: 15px;
  font-weight: 400;
  line-height: 1.8;
  color: #687b95;
  font-family: "DM Sans", sans-serif;
}
.disable__comment__option .disable_option .disable__option__description .danger {
  color: #e0061a;
  font-weight: 500;
}
.disable__comment__option .total-comments {
  font-size: 16px;
  line-height: 26px;
  margin-top: 20px;
  color: #687b95;
}

.subsite__checklist__item {
  flex: 0 0 130px;
  margin-right: 10px;
  margin-bottom: 10px;
}

.paginationjs-pages ul {
  margin-top: 0;
  display: flex;
  align-items: center;
}
.paginationjs-pages ul li a {
  font-size: 20px;
  border: 1px solid rgba(0, 0, 0, 0.1);
  padding: 0 20px;
  cursor: pointer;
  color: #687b95;
}
.paginationjs-pages ul li a:hover {
  color: #05cb6b;
}
.paginationjs-pages ul li.paginationjs-next a {
  border-top-right-radius: 8px;
  border-bottom-right-radius: 8px;
}
.paginationjs-pages ul li.paginationjs-prev a {
  border-top-left-radius: 8px;
  border-bottom-left-radius: 8px;
}
.paginationjs-pages ul li.disabled a {
  cursor: not-allowed;
  background-color: rgba(0, 0, 0, 0.05);
}
.paginationjs-pages ul li.disabled a:hover {
  color: #687b95;
}

.disable__comment__nav__wrap .disable__comment__nav .disable__comment__nav__item .disable__comment__nav__link:focus-visible {
  box-shadow: 0 0 0 2px #2271b1;
  outline: none;
}

.dc-tutorials .tutorial__list .tutorial__item h4 a:focus-visible {
  box-shadow: 0 0 0 2px #2271b1;
}

.has-pagination.disabled .paginationjs-pages li a {
  opacity: 0.3;
}
.has-pagination.disabled .paginationjs-pages li a:hover {
  color: #687b95;
}

.item__number__controller {
  align-items: center;
}
.item__number__controller p {
  margin-right: 10px;
}

.dc-select {
  position: relative;
}
.dc-select .icon {
  position: absolute;
}
.dc-select select {
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
}

.nothing-found {
  text-align: center;
  flex: 1;
}
.nothing-found p {
  font-size: 16px;
  font-weight: 400;
  color: #808da1;
  margin-bottom: 15px;
}

.disable__switch {
  display: flex;
  flex-wrap: wrap;
}
.disable__switch .avatar__status {
  flex: 0 0 170px;
}
.disable__switch .avatar__status label {
  color: #687b95 !important;
  display: inline-block !important;
}

.dc-item__card_wrap {
  height: 100%;
  display: flex;
}

.dc-item__card {
  background: #ffffff;
  padding: 10px;
  border-radius: 5px;
  margin-bottom: 30px;
  flex-grow: 1;
}
.dc-item__card .thumb img {
  vertical-align: middle;
  border-style: none;
}
.dc-item__card .card__content {
  padding: 25px 10px;
  text-align: center;
}
.dc-item__card .card__content h3 {
  font-size: 20px;
  font-weight: 500;
  font-family: "DM Sans", sans-serif;
  color: #22282d;
  margin-bottom: 10px;
}
.dc-item__card .card__content p {
  font-size: 14px;
  font-weight: 400;
  color: #687b95;
  line-height: 2.14;
  margin-bottom: 20px;
}

.dc-tutorials {
  border-radius: 5px;
  max-width: 450px;
  padding-bottom: 25px;
}
.dc-tutorials h3 {
  font-size: 20px;
  font-weight: 500;
  color: #22282d;
  font-family: "DM Sans", sans-serif;
  margin-bottom: 20px;
}
@media (max-width: 479.98px) {
  .dc-tutorials h3 {
    font-size: 20px;
  }
}
.dc-tutorials .tutorial__list .tutorial__item {
  display: flex;
}
.dc-tutorials .tutorial__list .tutorial__item:not(:last-child) {
  margin-bottom: 20px;
}
.dc-tutorials .tutorial__list .tutorial__item .icon {
  flex: 0 0 50px;
  max-width: 50px;
  height: 50px;
  border-radius: 5px;
  background: #f4f6fc;
  padding: 14px;
  margin-right: 15px;
}
.dc-tutorials .tutorial__list .tutorial__item .icon svg path {
  fill: #808da1;
  transition: all 0.3s ease;
}
.dc-tutorials .tutorial__list .tutorial__item h4 {
  font-size: 15px;
  line-height: 1.6;
  font-weight: 500;
  color: #687b95;
  font-family: "DM Sans", sans-serif;
  transition: all 0.3s ease;
}
@media (max-width: 1599.98px) {
  .dc-tutorials .tutorial__list .tutorial__item h4 {
    font-size: 14px;
  }
}
.dc-tutorials .tutorial__list .tutorial__item h4 a {
  outline: none;
  box-shadow: none;
}
.dc-tutorials .tutorial__list .tutorial__item:hover .icon svg path {
  fill: #05cb6b;
}
.dc-tutorials .tutorial__list .tutorial__item:hover h4 {
  color: #22282d;
}

.blog__post {
  padding: 5px;
  border-radius: 5px;
  background: #ffffff;
  max-width: 450px;
}
.blog__post .thumb {
  position: relative;
}
.blog__post .thumb img {
  width: 100%;
}
.blog__post .thumb .play__btn {
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  height: 50px;
  width: 50px;
  border-radius: 50%;
  background: #05cb6b;
  display: flex;
  justify-content: center;
  align-items: center;
  outline: none;
  box-shadow: none;
}
.blog__post .thumb .play__btn:focus-visible {
  box-shadow: 0 0 0 2px #2271b1;
}
.blog__post .thumb .play__btn span {
  width: 0;
  height: 0;
  border-top: 8px solid transparent;
  border-bottom: 8px solid transparent;
  border-left: 10px solid #ffffff;
}
.blog__post .blog__post__content {
  padding: 5px 10px;
}
.blog__post .blog__post__content h4 {
  font-size: 16px;
  font-weight: 500;
  color: #22282d;
  line-height: 1.8;
  font-family: "DM Sans", sans-serif;
}
.blog__post .blog__post__content h4 a:focus-visible {
  box-shadow: 0 0 0 2px #2271b1;
}

.footer {
  width: 100%;
  text-align: center;
}

.footer__content {
  text-align: center;
}
.footer__content .footer__nav ul {
  display: flex;
  flex-wrap: wrap;
  justify-content: center;
}
.footer__content .footer__nav ul li {
  margin-bottom: 15px;
  padding: 0 10px;
  position: relative;
  line-height: 1;
}
.footer__content .footer__nav ul li:not(:last-child):before {
  position: absolute;
  top: 2px;
  bottom: 2px;
  right: 0;
  width: 1px;
  background: #687b95;
  content: "";
}
.footer__content .footer__nav ul li a {
  font-size: 16px;
  font-weight: 400;
  color: #687b95;
  line-height: inherit;
  outline: none;
  box-shadow: none;
}
@media (max-width: 767.98px) {
  .footer__content .footer__nav ul li a {
    font-size: 14px;
  }
}
.footer__content .footer__nav ul li a:focus-visible {
  box-shadow: 0 0 0 2px #2271b1;
}

.cancel-dc-setup {
  text-align: right;
  margin-bottom: 20px;
  font-size: 13px;
}

.dc-quick__setup__wrap {
  padding: 50px 30px 50px;
}

.dc-logo img {
  max-width: 100%;
  max-height: 80px;
}

.dc-logo__center {
  text-align: center;
}

.dc-quick__setup__nav {
  display: flex;
  justify-content: center;
  align-items: center;
  padding: 0;
  margin: 0;
}
@media (max-width: 767.98px) {
  .dc-quick__setup__nav {
    flex-wrap: wrap;
  }
}
.dc-quick__setup__nav .quick__setup__item {
  padding: 0 25px;
  position: relative;
}
.dc-quick__setup__nav .quick__setup__item:not(:last-child):before {
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translateY(-50%);
  height: 3px;
  width: 100%;
  content: "";
  background: #d8dde7;
}
@media (max-width: 767.98px) {
  .dc-quick__setup__nav .quick__setup__item:not(:last-child):before {
    height: 0;
    width: 0;
  }
}
@media (max-width: 1199.98px) {
  .dc-quick__setup__nav .quick__setup__item {
    padding: 0 15px;
  }
}
.dc-quick__setup__nav .quick__setup__item .quick__setup__link {
  text-transform: uppercase;
  font-size: 14px;
  font-weight: 500;
  color: #22282d;
  width: 200px;
  text-align: center;
  padding: 13px 0;
  background: #ffffff;
  border-radius: 5px;
  position: relative;
  z-index: 1;
  outline: none;
  box-shadow: none;
}
@media (max-width: 1199.98px) {
  .dc-quick__setup__nav .quick__setup__item .quick__setup__link {
    width: auto;
    padding: 13px 20px;
  }
}
@media (max-width: 767.98px) {
  .dc-quick__setup__nav .quick__setup__item .quick__setup__link {
    font-size: 12px;
  }
}
.dc-quick__setup__nav .quick__setup__item.active:not(:last-child):before {
  background: #e10619;
}
.dc-quick__setup__nav .quick__setup__item.active .quick__setup__link {
  background: #e10619;
  color: #ffffff;
}

.dc-quick__step__item {
  display: none;
}
.dc-quick__step__item.active {
  display: block;
}
.dc-quick__step__item .button {
  display: none;
}

.dc-quick__step__item .quick__setup__item__header h2 {
  font-size: 32px;
  font-weight: 700;
  color: #22282d;
  font-family: "DM Sans", sans-serif;
  text-align: center;
  margin-bottom: 16px;
}
@media (max-width: 767.98px) {
  .dc-quick__step__item .quick__setup__item__header h2 {
    font-size: 28px;
  }
}
@media (max-width: 575.98px) {
  .dc-quick__step__item .quick__setup__item__header h2 {
    font-size: 24px;
  }
}
.dc-quick__step__item .quick__setup__item__header p {
  text-align: center;
  font-size: 16px;
  color: #687b95;
  max-width: 780px;
  margin: 0 auto;
}
@media (max-width: 767.98px) {
  .dc-quick__step__item .quick__setup__item__header p {
    font-size: 14px;
  }
}
.dc-quick__step__item .dc-video__area {
  text-align: center;
  margin: 0 auto;
  position: relative;
}
@media (max-width: 1199.98px) {
  .dc-quick__step__item .dc-video__area {
    min-height: 300px;
  }
}
.dc-quick__step__item .dc-video__area .play__btn {
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  height: 70px;
  width: 70px;
  border-radius: 50%;
  background: #05cb6b;
  display: flex;
  justify-content: center;
  align-items: center;
  outline: none;
  box-shadow: none;
}
.dc-quick__step__item .dc-video__area .play__btn span {
  width: 0;
  height: 0;
  border-top: 8px solid transparent;
  border-bottom: 8px solid transparent;
  border-left: 10px solid #ffffff;
}
@media (max-width: 767.98px) {
  .dc-quick__step__item .dc-video__area .play__btn {
    height: 50px;
    width: 50px;
  }
}
.dc-quick__step__item .dc-form__group {
  padding-left: 27px;
  text-align: center;
  border-radius: 10px;
  margin: 15px auto 0;
  max-width: 800px;
}
@media (max-width: 575.98px) {
  .dc-quick__step__item .dc-form__group {
    text-align: left;
  }
}
.dc-quick__step__item .dc-form__group input {
  display: none;
}
.dc-quick__step__item .dc-form__group input:checked ~ label:before {
  border-color: #00b2fc;
  background: #00b2fc;
}
.dc-quick__step__item .dc-form__group input:checked ~ label:after {
  opacity: 1;
}
.dc-quick__step__item .dc-form__group label {
  font-size: 18px;
  font-weight: 500;
  color: #22282d;
  font-family: "DM Sans", sans-serif;
  position: relative;
}
@media (max-width: 767.98px) {
  .dc-quick__step__item .dc-form__group label {
    font-size: 16px;
  }
}
.dc-quick__step__item .dc-form__group label:before {
  position: absolute;
  top: 5px;
  left: -27px;
  height: 12px;
  width: 12px;
  border: 1px solid #687b95;
  content: "";
}
@media (max-width: 767.98px) {
  .dc-quick__step__item .dc-form__group label:before {
    top: 4px;
  }
}
.dc-quick__step__item .dc-form__group label:after {
  position: absolute;
  top: -5px;
  left: -26px;
  height: 13px;
  width: 13px;
  border: 0;
  content: url(../img/check.png);
  opacity: 0;
  transition: all 0.3s ease;
}
.dc-quick__step__item .disable_option {
  border-radius: 5px;
}
.dc-quick__step__item .disable_option.dc-text__block {
  background: #f4f6fc;
}
.dc-quick__step__item .disable_option input[type=radio] {
  display: none;
}
.dc-quick__step__item .disable_option input[type=radio]:checked ~ label:before {
  border-color: #05cb6b;
}
.dc-quick__step__item .disable_option input[type=radio]:checked ~ label:after {
  opacity: 1;
}
.dc-quick__step__item .disable_option input[type=radio] ~ label {
  font-size: 18px;
  font-weight: 500;
  color: #22282d;
  font-family: "DM Sans", sans-serif;
  position: relative;
  line-height: 1.3;
  padding-left: 25px;
  display: block;
  margin-bottom: 15px;
}
.dc-quick__step__item .disable_option input[type=radio] ~ label:before {
  position: absolute;
  top: 4px;
  left: 0;
  height: 12px;
  width: 12px;
  border-radius: 50%;
  border: 1px solid #687b95;
  content: "";
}
.dc-quick__step__item .disable_option input[type=radio] ~ label:after {
  position: absolute;
  top: 7px;
  left: 3px;
  height: 8px;
  width: 8px;
  border-radius: 50%;
  border: 0;
  background: #05cb6b;
  content: "";
  opacity: 0;
  transition: all 0.3s ease;
}
.dc-quick__step__item .disable_option input[type=radio] ~ label span {
  font-size: 16px;
  font-weight: 400;
  color: #687b95;
}
.dc-quick__step__item .disable_option .disable__checklist {
  display: flex;
  flex-wrap: wrap;
  margin-bottom: 10px;
}
.dc-quick__step__item .disable_option .disable__checklist .disable__checklist__item {
  flex: 0 0 140px;
  margin-right: 10px;
}
.dc-quick__step__item .disable_option .disable__checklist .disable__checklist__item input {
  display: none;
}
.dc-quick__step__item .disable_option .disable__checklist .disable__checklist__item input:checked ~ label:before {
  border-color: #00b2fc;
  background: #00b2fc;
}
.dc-quick__step__item .disable_option .disable__checklist .disable__checklist__item input:checked ~ label:after {
  opacity: 1;
}
.dc-quick__step__item .disable_option .disable__checklist .disable__checklist__item label {
  font-size: 16px;
  font-weight: 500;
  color: #687b95;
  font-family: "DM Sans", sans-serif;
  position: relative;
  line-height: 1.3;
  padding-left: 25px;
  display: block;
}
.dc-quick__step__item .disable_option .disable__checklist .disable__checklist__item label:before {
  position: absolute;
  top: 4px;
  left: 0;
  height: 10px;
  width: 10px;
  border: 1px solid #687b95;
  content: "";
}
.dc-quick__step__item .disable_option .disable__checklist .disable__checklist__item label:after {
  position: absolute;
  top: -2px;
  left: 2px;
  height: 11px;
  width: 11px;
  border: 0;
  content: url(../img/check.png);
  opacity: 0;
  transition: all 0.3s ease;
}
.dc-quick__step__item .disable_option .disable__option__description {
  font-size: 15px;
  font-weight: 400;
  color: #687b95;
  font-family: "DM Sans", sans-serif;
}
.dc-quick__step__item .disable_option .disable__option__description .danger {
  color: #e0061a;
  font-weight: 500;
}
.dc-quick__step__item .finalize-thumb {
  text-align: center;
  padding: 0 0 30px;
}
.dc-quick__step__item .finalize-thumb img {
  max-height: 220px;
}
.dc-quick__step__item .doc__button__wrap {
  text-align: center;
}
.dc-quick__step__item .doc__button__wrap .doc__button {
  font-size: 16px;
  font-weight: 500;
  font-family: "DM Sans", sans-serif;
  color: #22282d;
  text-transform: uppercase;
  border: 1px solid #e10619;
  border-radius: 5px;
  padding: 10px 35px;
  outline: none;
  box-shadow: none;
}
.dc-quick__step__item .doc__button__wrap .doc__button:hover {
  background: #e10619;
  color: #ffffff;
}
.dc-quick__step__item #whatWeCollect {
  color: #05cb6b;
  outline: 0;
  box-shadow: none;
}
.dc-quick__step__item #whatWeCollectMessage {
  display: none;
}

.dc-quick__setup__wrap .button__group {
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  align-items: center;
}
.dc-quick__setup__wrap .button__group .button {
  width: 160px;
  text-align: center;
}
.dc-quick__setup__wrap .button__group .button.button--sm {
  width: 110px;
}
@media (max-width: 767.98px) {
  .dc-quick__setup__wrap .button__group .button {
    width: unset;
  }
  .dc-quick__setup__wrap .button__group .button.button--sm {
    width: unset;
  }
}

.disable_option .select2-container--default .select2-selection--multiple {
  min-height: 30px;
  padding: 0;
  min-width: 290px;
  width: 100%;
  display: flex;
  border: 1px solid rgba(0, 0, 0, 0.15);
}
.disable_option .select2-container--default.select2-container--focus .select2-selection--multiple {
  border-color: rgba(0, 0, 0, 0.15);
}
.disable_option .select2-container {
  min-width: 290px;
  width: auto !important;
}
.disable_option .select2-container .select2-search--inline {
  float: none;
}
.disable_option .select2-container--default .select2-selection--multiple .select2-selection__rendered {
  width: auto;
  display: inline-flex;
  flex-wrap: wrap;
  gap: 0 5px;
  margin-top: 0;
  padding: 0 8px;
  align-items: center;
}
.disable_option .select2-container--default .select2-selection--multiple .select2-selection__choice__remove {
  position: static;
  border-right: 0;
  line-height: 1;
  font-size: 16px;
  margin-right: 3px;
}
.disable_option .select2-container--default .select2-selection--multiple .select2-selection__choice__remove span {
  line-height: 1;
}
.disable_option .select2-container--default .select2-selection--multiple .select2-selection__choice {
  float: none;
  display: flex;
  align-items: stretch;
  margin-left: 0;
  margin-right: 0;
  padding-left: 0;
  padding-right: 3px;
  border: 1px solid rgba(0, 0, 0, 0.15);
}
.disable_option .select2-container--default .select2-selection--multiple .select2-selection__choice__display {
  padding-left: 5px;
  border-left: 1px solid rgba(0, 0, 0, 0.15);
}
.disable_option .select2-container--default .select2-search--inline .select2-search__field {
  margin-top: 0px;
  margin-left: 0px;
  height: 30px;
  padding-top: 7px;
  width: auto !important;
  font-size: 12px;
}
.disable_option .select2-container--default .select2-search--inline .select2-search__field::-webkit-input-placeholder { /* Chrome/Opera/Safari */
  color: #687b95;
}
.disable_option .select2-container--default .select2-search--inline .select2-search__field::-moz-placeholder { /* Firefox 19+ */
  color: #687b95;
}
.disable_option .select2-container--default .select2-search--inline .select2-search__field:-ms-input-placeholder { /* IE 10+ */
  color: #687b95;
}
.disable_option .select2-container--default .select2-search--inline .select2-search__field:-moz-placeholder { /* Firefox 18- */
  color: #687b95;
}
.disable_option .select2-container--default .select2-selection--multiple .select2-selection__choice {
  margin-top: 0 !important;
  margin-bottom: 0 !important;
}
.disable_option .select2-container .select2-search--inline .select2-search__field {
  margin-top: 0 !important;
  margin-bottom: 0 !important;
  min-height: 38px !important;
  padding-top: 11px !important;
}
.disable_option .visually-hidden {
  clip: rect(0 0 0 0);
  clip-path: inset(50%);
  height: 1px;
  overflow: hidden;
  position: absolute;
  white-space: nowrap;
  width: 1px;
}
.disable_option {
  /* Focus styles */
}
.disable_option input[type=radio]:focus,
.disable_option input[type=checkbox]:focus {
  outline: 2px solid #007cba;
  outline-offset: 2px;
}
.disable_option {
  /* Switch focus styles */
}
.disable_option .dissable__switch__item input:focus + label .switch {
  outline: 2px solid #007cba;
  outline-offset: 2px;
}
.disable_option {
  /* Form groups spacing */
}
.disable_option [role=group] {
  margin-bottom: 2rem;
}
.disable_option {
  /* Description text */
}
.disable_option .disable__option__description {
  margin-top: 0.5rem;
  color: #555;
}
.disable_option {
  /* Focus styles */
}
.disable_option .form__control:focus {
  outline: 2px solid #007cba;
  outline-offset: 1px;
}
.disable_option .check-all:focus + label {
  outline: 2px solid #007cba;
  outline-offset: 2px;
}
.disable_option .radio-option {
  margin-bottom: 1rem;
}
.disable_option .radio-option input[type=radio]:focus {
  outline: 2px solid #007cba;
  outline-offset: 2px;
}
.disable_option .radio-option label {
  display: inline-block;
}
.disable_option .radio-option .description {
  display: block;
  font-size: 16px;
  margin-top: -12px;
  padding-left: 20px;
  color: #555;
}
.disable_option .remove__checklist {
  margin: 1rem 0;
  padding-left: 1.5rem;
}
.disable_option .remove__checklist__item {
  margin-bottom: 0.5rem;
}
.disable_option .remove__checklist__item input[type=checkbox]:focus,
.disable_option .radio-option input[type=radio]:focus {
  outline: 2px solid #007cba;
  outline-offset: 2px;
}
.disable_option .form-field {
  margin-top: 1rem;
}
.disable_option .form-field input[type=text]:focus {
  outline: 2px solid #007cba;
  border-color: #007cba;
}
.disable_option .custom-types-input {
  margin-top: 1.5rem;
  padding: 1rem;
  background: #f8f9fa;
  border-radius: 4px;
}
.disable_option .roles-selection-wrapper {
  margin-top: 1rem;
  padding-left: 2rem;
}
.disable_option .allowed-comment-types-wrapper {
  margin-top: 1rem;
  padding-left: 2rem;
}
.disable_option .allowed-comment-types-wrapper .checkbox-list {
  display: flex;
  flex-direction: column;
  gap: 0.75rem;
}
.disable_option .allowed-comment-types-wrapper .checkbox-item {
  display: flex;
  align-items: center;
}
.disable_option .allowed-comment-types-wrapper .checkbox-item input[type=checkbox] {
  margin-right: 0.5rem;
  width: 16px;
  height: 16px;
  cursor: pointer;
}
.disable_option .allowed-comment-types-wrapper .checkbox-item label {
  font-size: 16px;
  font-weight: 500;
  color: #687b95;
  cursor: pointer;
  margin: 0;
}
.disable_option .allowed-comment-types-wrapper .checkbox-item input[type=checkbox]:focus {
  outline: 2px solid #007cba;
  outline-offset: 2px;
}
.disable_option .dc-select2:focus {
  outline: 2px solid #007cba;
  outline-offset: 2px;
}
.disable_option .disable__switchs input[type=checkbox]:focus + label .switch {
  outline: 2px solid #007cba;
  outline-offset: 2px;
}
.disable_option .roles-status {
  margin-top: 0.5rem;
}
.disable_option [aria-live=polite] {
  min-height: 1rem;
}
.disable_option .disable__switch[role=radiogroup] {
  margin: 1rem 0;
}
.disable_option .avatar__status {
  margin-bottom: 0.5rem;
}
.disable_option .avatar__status input[type=radio]:focus {
  outline: 2px solid #007cba;
  outline-offset: 2px;
}
.disable_option .avatar__status input[type=radio]:focus + label {
  outline: 2px solid #007cba;
  outline-offset: 1px;
}
.disable_option .avatar__status label {
  display: inline-block;
  margin-left: 0.5rem;
}
.disable_option .disable__switchs {
  margin: 1rem 0;
}
.disable_option .dissable__switch__item {
  margin-bottom: 1rem;
}
.disable_option .dissable__switch__item input[type=checkbox]:focus + label .switch {
  outline: 2px solid #007cba;
  outline-offset: 2px;
}
.disable_option .button__success:focus {
  outline: 2px solid #007cba;
  outline-offset: 2px;
  box-shadow: 0 0 0 1px #007cba;
}
.disable_option .api-descriptions {
  margin-top: 1rem;
}
.disable_option .button__delete {
  background-color: #d63638;
  border-color: #d63638;
  color: #fff;
}
.disable_option .button__delete:focus {
  outline: 2px solid #d63638;
  outline-offset: 2px;
  box-shadow: 0 0 0 1px #fff, 0 0 0 3px #d63638;
}
.disable_option .delete-comments-not-found {
  display: flex;
  align-items: center;
  gap: 1rem;
  padding: 1rem;
  border-left: 4px solid #d63638;
  background: #fff;
}
/*# sourceMappingURL=style.css.map */