.aioseo-video-sitemap-lite .aioseo-card .content{min-height:600px}.aioseo-video-sitemap-lite .aioseo-sitemap-preview{display:flex;align-items:center;margin-bottom:10px}[dir=ltr] .aioseo-video-sitemap-lite .aioseo-sitemap-preview{margin-right:10px}[dir=rtl] .aioseo-video-sitemap-lite .aioseo-sitemap-preview{margin-left:10px}.aioseo-video-sitemap-lite .aioseo-sitemap-preview .aioseo-select{max-width:180px}[dir=ltr] .aioseo-video-sitemap-lite .aioseo-sitemap-preview .aioseo-select{margin-right:10px}[dir=rtl] .aioseo-video-sitemap-lite .aioseo-sitemap-preview .aioseo-select{margin-left:10px}.aioseo-video-sitemap-lite .aioseo-sitemap-preview svg.aioseo-external{width:14px;height:14px}[dir=ltr] .aioseo-video-sitemap-lite .aioseo-sitemap-preview svg.aioseo-external{margin-right:10px}[dir=rtl] .aioseo-video-sitemap-lite .aioseo-sitemap-preview svg.aioseo-external{margin-left:10px}.aioseo-video-sitemap .aioseo-content-width,.aioseo-video-sitemap .aioseo-links-per-site{max-width:110px}.aioseo-video-sitemap .aioseo-sitemap-preview{display:flex;align-items:center;margin-bottom:10px}[dir=ltr] .aioseo-video-sitemap .aioseo-sitemap-preview{margin-right:10px}[dir=rtl] .aioseo-video-sitemap .aioseo-sitemap-preview{margin-left:10px}.aioseo-video-sitemap .aioseo-sitemap-preview .aioseo-select{max-width:180px}[dir=ltr] .aioseo-video-sitemap .aioseo-sitemap-preview .aioseo-select{margin-right:10px}[dir=rtl] .aioseo-video-sitemap .aioseo-sitemap-preview .aioseo-select{margin-left:10px}.aioseo-video-sitemap .aioseo-sitemap-preview svg.aioseo-external{width:14px;height:14px}[dir=ltr] .aioseo-video-sitemap .aioseo-sitemap-preview svg.aioseo-external{margin-right:10px}[dir=rtl] .aioseo-video-sitemap .aioseo-sitemap-preview svg.aioseo-external{margin-left:10px}.aioseo-video-sitemap .aioseo-exclude-pages-posts .aioseo-select{max-width:600px;display:inline-block}[dir=ltr] .aioseo-video-sitemap .aioseo-exclude-pages-posts .aioseo-select{margin-right:16px}[dir=rtl] .aioseo-video-sitemap .aioseo-exclude-pages-posts .aioseo-select{margin-left:16px}.aioseo-video-sitemap .aioseo-exclude-pages-posts .aioseo-select .multiselect__option{display:flex}.aioseo-video-sitemap .aioseo-exclude-pages-posts .aioseo-select .multiselect__option--highlight .option-title{color:#005ae0}.aioseo-video-sitemap .aioseo-exclude-pages-posts .option{flex:1 0 auto}.aioseo-video-sitemap .aioseo-exclude-pages-posts .option .option-title{font-weight:500;font-size:16px;color:#141b38}.aioseo-video-sitemap .aioseo-exclude-pages-posts .option .option-title .search-term{font-weight:700}.aioseo-video-sitemap .aioseo-exclude-pages-posts .option .option-details{display:flex;align-items:center;font-size:14px;color:#8c8f9a}[dir=ltr] .aioseo-video-sitemap .aioseo-exclude-pages-posts .option .option-details span{margin-right:15px}[dir=rtl] .aioseo-video-sitemap .aioseo-exclude-pages-posts .option .option-details span{margin-left:15px}.aioseo-video-sitemap .aioseo-exclude-pages-posts .option-permalink{display:flex;align-items:center}.aioseo-video-sitemap .aioseo-exclude-pages-posts .option-permalink svg.aioseo-external{width:15px;height:15px;color:#434960}.aioseo-video-sitemap .aioseo-exclude-pages-posts .multiselect-toggle{padding:10px 13px;width:40px;position:absolute;height:36px;top:2px;text-align:center;z-index:1}[dir=ltr] .aioseo-video-sitemap .aioseo-exclude-pages-posts .multiselect-toggle{right:2px}[dir=rtl] .aioseo-video-sitemap .aioseo-exclude-pages-posts .multiselect-toggle{left:2px}.aioseo-video-sitemap .aioseo-exclude-pages-posts .multiselect-toggle svg.aioseo-add-plus{width:14px;height:14px;color:#000}.aioseo-video-sitemap .aioseo-video-embed .aioseo-checkbox:first-child{margin-bottom:10px}
