<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
?>
<div class="wpforms-builder-provider-connections-error wpforms-hidden">
	<span class="wpforms-builder-provider-connections-error-message">
		<?php esc_html_e( 'Something went wrong while performing an AJAX request.', 'wpforms-lite' ); ?>
	</span>
</div>
