.aioseo-seo-checklist-progress-bar .checklist-count{font-size:14px;font-weight:600;color:#141b38;margin-bottom:8px}.aioseo-seo-checklist-progress-bar .aioseo-loading-bar .aioseo-loading-bar__bar{background-color:#d1d5db;height:12px}.aioseo-seo-checklist-progress-bar .aioseo-loading-bar .aioseo-loading-bar__progress{height:12px;background:var(--progress-color, #22C55E);transition:background-color .3s ease}.aioseo-seo-checklist-progress-bar.inline-layout{display:flex;align-items:center;gap:16px}.aioseo-seo-checklist-progress-bar.inline-layout .checklist-count{white-space:nowrap;margin-bottom:0;order:2}.aioseo-seo-checklist-progress-bar.inline-layout .aioseo-loading-bar{flex:1;order:1}
