<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit8a081da25031c092fc2baa55d98421f8
{
    public static $prefixLengthsPsr4 = array (
        'L' => 
        array (
            'League\\HTMLToMarkdown\\' => 22,
        ),
        'A' => 
        array (
            'AIOSEO\\Plugin\\' => 14,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'League\\HTMLToMarkdown\\' => 
        array (
            0 => __DIR__ . '/..' . '/league/html-to-markdown/src',
        ),
        'AIOSEO\\Plugin\\' => 
        array (
            0 => __DIR__ . '/../..' . '/app',
        ),
    );

    public static $prefixesPsr0 = array (
        'P' => 
        array (
            'PHPInsight' => 
            array (
                0 => __DIR__ . '/..' . '/jwhennessey/phpinsight/lib',
            ),
        ),
    );

    public static $classMap = array (
        'AIOSEO\\Plugin\\AIOSEO' => __DIR__ . '/../..' . '/app/AIOSEO.php',
        'AIOSEO\\Plugin\\Common\\Abilities\\Abilities' => __DIR__ . '/../..' . '/app/Common/Abilities/Abilities.php',
        'AIOSEO\\Plugin\\Common\\Admin\\Admin' => __DIR__ . '/../..' . '/app/Common/Admin/Admin.php',
        'AIOSEO\\Plugin\\Common\\Admin\\ConflictingPlugins' => __DIR__ . '/../..' . '/app/Common/Admin/ConflictingPlugins.php',
        'AIOSEO\\Plugin\\Common\\Admin\\Dashboard' => __DIR__ . '/../..' . '/app/Common/Admin/Dashboard.php',
        'AIOSEO\\Plugin\\Common\\Admin\\DeactivationSurvey' => __DIR__ . '/../..' . '/app/Common/Admin/DeactivationSurvey.php',
        'AIOSEO\\Plugin\\Common\\Admin\\NetworkAdmin' => __DIR__ . '/../..' . '/app/Common/Admin/NetworkAdmin.php',
        'AIOSEO\\Plugin\\Common\\Admin\\Notices\\ConflictingPlugins' => __DIR__ . '/../..' . '/app/Common/Admin/Notices/ConflictingPlugins.php',
        'AIOSEO\\Plugin\\Common\\Admin\\Notices\\DeprecatedWordPress' => __DIR__ . '/../..' . '/app/Common/Admin/Notices/DeprecatedWordPress.php',
        'AIOSEO\\Plugin\\Common\\Admin\\Notices\\Import' => __DIR__ . '/../..' . '/app/Common/Admin/Notices/Import.php',
        'AIOSEO\\Plugin\\Common\\Admin\\Notices\\Migration' => __DIR__ . '/../..' . '/app/Common/Admin/Notices/Migration.php',
        'AIOSEO\\Plugin\\Common\\Admin\\Notices\\Notices' => __DIR__ . '/../..' . '/app/Common/Admin/Notices/Notices.php',
        'AIOSEO\\Plugin\\Common\\Admin\\Notices\\Review' => __DIR__ . '/../..' . '/app/Common/Admin/Notices/Review.php',
        'AIOSEO\\Plugin\\Common\\Admin\\Notices\\WpNotices' => __DIR__ . '/../..' . '/app/Common/Admin/Notices/WpNotices.php',
        'AIOSEO\\Plugin\\Common\\Admin\\Pointers' => __DIR__ . '/../..' . '/app/Common/Admin/Pointers.php',
        'AIOSEO\\Plugin\\Common\\Admin\\PostSettings' => __DIR__ . '/../..' . '/app/Common/Admin/PostSettings.php',
        'AIOSEO\\Plugin\\Common\\Admin\\SeoAnalysis' => __DIR__ . '/../..' . '/app/Common/Admin/SeoAnalysis.php',
        'AIOSEO\\Plugin\\Common\\Admin\\SiteHealth' => __DIR__ . '/../..' . '/app/Common/Admin/SiteHealth.php',
        'AIOSEO\\Plugin\\Common\\Admin\\SlugMonitor' => __DIR__ . '/../..' . '/app/Common/Admin/SlugMonitor.php',
        'AIOSEO\\Plugin\\Common\\Admin\\Usage' => __DIR__ . '/../..' . '/app/Common/Admin/Usage.php',
        'AIOSEO\\Plugin\\Common\\Admin\\WritingAssistant' => __DIR__ . '/../..' . '/app/Common/Admin/WritingAssistant.php',
        'AIOSEO\\Plugin\\Common\\Ai\\Ai' => __DIR__ . '/../..' . '/app/Common/Ai/Ai.php',
        'AIOSEO\\Plugin\\Common\\Ai\\Assistant' => __DIR__ . '/../..' . '/app/Common/Ai/Assistant.php',
        'AIOSEO\\Plugin\\Common\\Ai\\BulkActions' => __DIR__ . '/../..' . '/app/Common/Ai/BulkActions.php',
        'AIOSEO\\Plugin\\Common\\Ai\\Image' => __DIR__ . '/../..' . '/app/Common/Ai/Image.php',
        'AIOSEO\\Plugin\\Common\\Api\\Ai' => __DIR__ . '/../..' . '/app/Common/Api/Ai.php',
        'AIOSEO\\Plugin\\Common\\Api\\AiAgents' => __DIR__ . '/../..' . '/app/Common/Api/AiAgents.php',
        'AIOSEO\\Plugin\\Common\\Api\\AiInsights' => __DIR__ . '/../..' . '/app/Common/Api/AiInsights.php',
        'AIOSEO\\Plugin\\Common\\Api\\Analyze' => __DIR__ . '/../..' . '/app/Common/Api/Analyze.php',
        'AIOSEO\\Plugin\\Common\\Api\\Api' => __DIR__ . '/../..' . '/app/Common/Api/Api.php',
        'AIOSEO\\Plugin\\Common\\Api\\ApiException' => __DIR__ . '/../..' . '/app/Common/Api/ApiException.php',
        'AIOSEO\\Plugin\\Common\\Api\\Connect' => __DIR__ . '/../..' . '/app/Common/Api/Connect.php',
        'AIOSEO\\Plugin\\Common\\Api\\EmailSummary' => __DIR__ . '/../..' . '/app/Common/Api/EmailSummary.php',
        'AIOSEO\\Plugin\\Common\\Api\\Integrations\\Semrush' => __DIR__ . '/../..' . '/app/Common/Api/Integrations/Semrush.php',
        'AIOSEO\\Plugin\\Common\\Api\\Integrations\\WpCode' => __DIR__ . '/../..' . '/app/Common/Api/Integrations/WpCode.php',
        'AIOSEO\\Plugin\\Common\\Api\\Network' => __DIR__ . '/../..' . '/app/Common/Api/Network.php',
        'AIOSEO\\Plugin\\Common\\Api\\Notifications' => __DIR__ . '/../..' . '/app/Common/Api/Notifications.php',
        'AIOSEO\\Plugin\\Common\\Api\\Ping' => __DIR__ . '/../..' . '/app/Common/Api/Ping.php',
        'AIOSEO\\Plugin\\Common\\Api\\Plugins' => __DIR__ . '/../..' . '/app/Common/Api/Plugins.php',
        'AIOSEO\\Plugin\\Common\\Api\\PostsTerms' => __DIR__ . '/../..' . '/app/Common/Api/PostsTerms.php',
        'AIOSEO\\Plugin\\Common\\Api\\SearchStatistics' => __DIR__ . '/../..' . '/app/Common/Api/SearchStatistics.php',
        'AIOSEO\\Plugin\\Common\\Api\\SeoChecklist' => __DIR__ . '/../..' . '/app/Common/Api/SeoChecklist.php',
        'AIOSEO\\Plugin\\Common\\Api\\Settings' => __DIR__ . '/../..' . '/app/Common/Api/Settings.php',
        'AIOSEO\\Plugin\\Common\\Api\\Sitemaps' => __DIR__ . '/../..' . '/app/Common/Api/Sitemaps.php',
        'AIOSEO\\Plugin\\Common\\Api\\Tags' => __DIR__ . '/../..' . '/app/Common/Api/Tags.php',
        'AIOSEO\\Plugin\\Common\\Api\\Tools' => __DIR__ . '/../..' . '/app/Common/Api/Tools.php',
        'AIOSEO\\Plugin\\Common\\Api\\User' => __DIR__ . '/../..' . '/app/Common/Api/User.php',
        'AIOSEO\\Plugin\\Common\\Api\\Wizard' => __DIR__ . '/../..' . '/app/Common/Api/Wizard.php',
        'AIOSEO\\Plugin\\Common\\Api\\WritingAssistant' => __DIR__ . '/../..' . '/app/Common/Api/WritingAssistant.php',
        'AIOSEO\\Plugin\\Common\\Breadcrumbs\\Block' => __DIR__ . '/../..' . '/app/Common/Breadcrumbs/Block.php',
        'AIOSEO\\Plugin\\Common\\Breadcrumbs\\Breadcrumbs' => __DIR__ . '/../..' . '/app/Common/Breadcrumbs/Breadcrumbs.php',
        'AIOSEO\\Plugin\\Common\\Breadcrumbs\\Frontend' => __DIR__ . '/../..' . '/app/Common/Breadcrumbs/Frontend.php',
        'AIOSEO\\Plugin\\Common\\Breadcrumbs\\Shortcode' => __DIR__ . '/../..' . '/app/Common/Breadcrumbs/Shortcode.php',
        'AIOSEO\\Plugin\\Common\\Breadcrumbs\\Tags' => __DIR__ . '/../..' . '/app/Common/Breadcrumbs/Tags.php',
        'AIOSEO\\Plugin\\Common\\Breadcrumbs\\Widget' => __DIR__ . '/../..' . '/app/Common/Breadcrumbs/Widget.php',
        'AIOSEO\\Plugin\\Common\\Core\\Core' => __DIR__ . '/../..' . '/app/Common/Core/Core.php',
        'AIOSEO\\Plugin\\Common\\Db\\Schema' => __DIR__ . '/../..' . '/app/Common/Db/Schema.php',
        'AIOSEO\\Plugin\\Common\\EmailReports\\EmailReports' => __DIR__ . '/../..' . '/app/Common/EmailReports/EmailReports.php',
        'AIOSEO\\Plugin\\Common\\EmailReports\\Mail' => __DIR__ . '/../..' . '/app/Common/EmailReports/Mail.php',
        'AIOSEO\\Plugin\\Common\\EmailReports\\Summary\\Content' => __DIR__ . '/../..' . '/app/Common/EmailReports/Summary/Content.php',
        'AIOSEO\\Plugin\\Common\\EmailReports\\Summary\\Summary' => __DIR__ . '/../..' . '/app/Common/EmailReports/Summary/Summary.php',
        'AIOSEO\\Plugin\\Common\\Help\\Help' => __DIR__ . '/../..' . '/app/Common/Help/Help.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\Helpers' => __DIR__ . '/../..' . '/app/Common/ImportExport/Helpers.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\ImportExport' => __DIR__ . '/../..' . '/app/Common/ImportExport/ImportExport.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\Importer' => __DIR__ . '/../..' . '/app/Common/ImportExport/Importer.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\RankMath\\GeneralSettings' => __DIR__ . '/../..' . '/app/Common/ImportExport/RankMath/GeneralSettings.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\RankMath\\Helpers' => __DIR__ . '/../..' . '/app/Common/ImportExport/RankMath/Helpers.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\RankMath\\PostMeta' => __DIR__ . '/../..' . '/app/Common/ImportExport/RankMath/PostMeta.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\RankMath\\RankMath' => __DIR__ . '/../..' . '/app/Common/ImportExport/RankMath/RankMath.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\RankMath\\Sitemap' => __DIR__ . '/../..' . '/app/Common/ImportExport/RankMath/Sitemap.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\RankMath\\TitleMeta' => __DIR__ . '/../..' . '/app/Common/ImportExport/RankMath/TitleMeta.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\SearchAppearance' => __DIR__ . '/../..' . '/app/Common/ImportExport/SearchAppearance.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\Analytics' => __DIR__ . '/../..' . '/app/Common/ImportExport/SeoPress/Analytics.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\Breadcrumbs' => __DIR__ . '/../..' . '/app/Common/ImportExport/SeoPress/Breadcrumbs.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\GeneralSettings' => __DIR__ . '/../..' . '/app/Common/ImportExport/SeoPress/GeneralSettings.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\Helpers' => __DIR__ . '/../..' . '/app/Common/ImportExport/SeoPress/Helpers.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\PostMeta' => __DIR__ . '/../..' . '/app/Common/ImportExport/SeoPress/PostMeta.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\RobotsTxt' => __DIR__ . '/../..' . '/app/Common/ImportExport/SeoPress/RobotsTxt.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\Rss' => __DIR__ . '/../..' . '/app/Common/ImportExport/SeoPress/Rss.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\SeoPress' => __DIR__ . '/../..' . '/app/Common/ImportExport/SeoPress/SeoPress.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\Sitemap' => __DIR__ . '/../..' . '/app/Common/ImportExport/SeoPress/Sitemap.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\SocialMeta' => __DIR__ . '/../..' . '/app/Common/ImportExport/SeoPress/SocialMeta.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\Titles' => __DIR__ . '/../..' . '/app/Common/ImportExport/SeoPress/Titles.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\GeneralSettings' => __DIR__ . '/../..' . '/app/Common/ImportExport/YoastSeo/GeneralSettings.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\Helpers' => __DIR__ . '/../..' . '/app/Common/ImportExport/YoastSeo/Helpers.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\PostMeta' => __DIR__ . '/../..' . '/app/Common/ImportExport/YoastSeo/PostMeta.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\SearchAppearance' => __DIR__ . '/../..' . '/app/Common/ImportExport/YoastSeo/SearchAppearance.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\SocialMeta' => __DIR__ . '/../..' . '/app/Common/ImportExport/YoastSeo/SocialMeta.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\UserMeta' => __DIR__ . '/../..' . '/app/Common/ImportExport/YoastSeo/UserMeta.php',
        'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\YoastSeo' => __DIR__ . '/../..' . '/app/Common/ImportExport/YoastSeo/YoastSeo.php',
        'AIOSEO\\Plugin\\Common\\Integrations\\BbPress' => __DIR__ . '/../..' . '/app/Common/Integrations/BbPress.php',
        'AIOSEO\\Plugin\\Common\\Integrations\\BuddyPress' => __DIR__ . '/../..' . '/app/Common/Integrations/BuddyPress.php',
        'AIOSEO\\Plugin\\Common\\Integrations\\Semrush' => __DIR__ . '/../..' . '/app/Common/Integrations/Semrush.php',
        'AIOSEO\\Plugin\\Common\\Integrations\\WpCode' => __DIR__ . '/../..' . '/app/Common/Integrations/WpCode.php',
        'AIOSEO\\Plugin\\Common\\Llms\\Llms' => __DIR__ . '/../..' . '/app/Common/Llms/Llms.php',
        'AIOSEO\\Plugin\\Common\\Main\\Activate' => __DIR__ . '/../..' . '/app/Common/Main/Activate.php',
        'AIOSEO\\Plugin\\Common\\Main\\CategoryBase' => __DIR__ . '/../..' . '/app/Common/Main/CategoryBase.php',
        'AIOSEO\\Plugin\\Common\\Main\\Filters' => __DIR__ . '/../..' . '/app/Common/Main/Filters.php',
        'AIOSEO\\Plugin\\Common\\Main\\Head' => __DIR__ . '/../..' . '/app/Common/Main/Head.php',
        'AIOSEO\\Plugin\\Common\\Main\\Main' => __DIR__ . '/../..' . '/app/Common/Main/Main.php',
        'AIOSEO\\Plugin\\Common\\Main\\Media' => __DIR__ . '/../..' . '/app/Common/Main/Media.php',
        'AIOSEO\\Plugin\\Common\\Main\\Migrations\\Definitions\\DropLegacyCacheIndexes' => __DIR__ . '/../..' . '/app/Common/Main/Migrations/Definitions/DropLegacyCacheIndexes.php',
        'AIOSEO\\Plugin\\Common\\Main\\Migrations\\Migration' => __DIR__ . '/../..' . '/app/Common/Main/Migrations/Migration.php',
        'AIOSEO\\Plugin\\Common\\Main\\Migrations\\MigrationLog' => __DIR__ . '/../..' . '/app/Common/Main/Migrations/MigrationLog.php',
        'AIOSEO\\Plugin\\Common\\Main\\Migrations\\MigrationRunner' => __DIR__ . '/../..' . '/app/Common/Main/Migrations/MigrationRunner.php',
        'AIOSEO\\Plugin\\Common\\Main\\PreUpdates' => __DIR__ . '/../..' . '/app/Common/Main/PreUpdates.php',
        'AIOSEO\\Plugin\\Common\\Main\\QueryArgs' => __DIR__ . '/../..' . '/app/Common/Main/QueryArgs.php',
        'AIOSEO\\Plugin\\Common\\Main\\Title' => __DIR__ . '/../..' . '/app/Common/Main/Title.php',
        'AIOSEO\\Plugin\\Common\\Main\\Uninstall' => __DIR__ . '/../..' . '/app/Common/Main/Uninstall.php',
        'AIOSEO\\Plugin\\Common\\Main\\Updates' => __DIR__ . '/../..' . '/app/Common/Main/Updates.php',
        'AIOSEO\\Plugin\\Common\\Meta\\Amp' => __DIR__ . '/../..' . '/app/Common/Meta/Amp.php',
        'AIOSEO\\Plugin\\Common\\Meta\\Description' => __DIR__ . '/../..' . '/app/Common/Meta/Description.php',
        'AIOSEO\\Plugin\\Common\\Meta\\Helpers' => __DIR__ . '/../..' . '/app/Common/Meta/Helpers.php',
        'AIOSEO\\Plugin\\Common\\Meta\\Included' => __DIR__ . '/../..' . '/app/Common/Meta/Included.php',
        'AIOSEO\\Plugin\\Common\\Meta\\Keywords' => __DIR__ . '/../..' . '/app/Common/Meta/Keywords.php',
        'AIOSEO\\Plugin\\Common\\Meta\\Links' => __DIR__ . '/../..' . '/app/Common/Meta/Links.php',
        'AIOSEO\\Plugin\\Common\\Meta\\Meta' => __DIR__ . '/../..' . '/app/Common/Meta/Meta.php',
        'AIOSEO\\Plugin\\Common\\Meta\\MetaData' => __DIR__ . '/../..' . '/app/Common/Meta/MetaData.php',
        'AIOSEO\\Plugin\\Common\\Meta\\Robots' => __DIR__ . '/../..' . '/app/Common/Meta/Robots.php',
        'AIOSEO\\Plugin\\Common\\Meta\\SiteVerification' => __DIR__ . '/../..' . '/app/Common/Meta/SiteVerification.php',
        'AIOSEO\\Plugin\\Common\\Meta\\Title' => __DIR__ . '/../..' . '/app/Common/Meta/Title.php',
        'AIOSEO\\Plugin\\Common\\Meta\\Traits\\Helpers\\BuddyPress' => __DIR__ . '/../..' . '/app/Common/Meta/Traits/Helpers/BuddyPress.php',
        'AIOSEO\\Plugin\\Common\\Migration\\GeneralSettings' => __DIR__ . '/../..' . '/app/Common/Migration/GeneralSettings.php',
        'AIOSEO\\Plugin\\Common\\Migration\\Helpers' => __DIR__ . '/../..' . '/app/Common/Migration/Helpers.php',
        'AIOSEO\\Plugin\\Common\\Migration\\Meta' => __DIR__ . '/../..' . '/app/Common/Migration/Meta.php',
        'AIOSEO\\Plugin\\Common\\Migration\\Migration' => __DIR__ . '/../..' . '/app/Common/Migration/Migration.php',
        'AIOSEO\\Plugin\\Common\\Migration\\OldOptions' => __DIR__ . '/../..' . '/app/Common/Migration/OldOptions.php',
        'AIOSEO\\Plugin\\Common\\Migration\\RobotsTxt' => __DIR__ . '/../..' . '/app/Common/Migration/RobotsTxt.php',
        'AIOSEO\\Plugin\\Common\\Migration\\Sitemap' => __DIR__ . '/../..' . '/app/Common/Migration/Sitemap.php',
        'AIOSEO\\Plugin\\Common\\Migration\\SocialMeta' => __DIR__ . '/../..' . '/app/Common/Migration/SocialMeta.php',
        'AIOSEO\\Plugin\\Common\\Migration\\Wpml' => __DIR__ . '/../..' . '/app/Common/Migration/Wpml.php',
        'AIOSEO\\Plugin\\Common\\Models\\AiInsightsKeywordReport' => __DIR__ . '/../..' . '/app/Common/Models/AiInsightsKeywordReport.php',
        'AIOSEO\\Plugin\\Common\\Models\\CrawlCleanupBlockedArg' => __DIR__ . '/../..' . '/app/Common/Models/CrawlCleanupBlockedArg.php',
        'AIOSEO\\Plugin\\Common\\Models\\CrawlCleanupLog' => __DIR__ . '/../..' . '/app/Common/Models/CrawlCleanupLog.php',
        'AIOSEO\\Plugin\\Common\\Models\\Model' => __DIR__ . '/../..' . '/app/Common/Models/Model.php',
        'AIOSEO\\Plugin\\Common\\Models\\Notification' => __DIR__ . '/../..' . '/app/Common/Models/Notification.php',
        'AIOSEO\\Plugin\\Common\\Models\\Post' => __DIR__ . '/../..' . '/app/Common/Models/Post.php',
        'AIOSEO\\Plugin\\Common\\Models\\SeoAnalyzerResult' => __DIR__ . '/../..' . '/app/Common/Models/SeoAnalyzerResult.php',
        'AIOSEO\\Plugin\\Common\\Models\\WritingAssistantKeyword' => __DIR__ . '/../..' . '/app/Common/Models/WritingAssistantKeyword.php',
        'AIOSEO\\Plugin\\Common\\Models\\WritingAssistantPost' => __DIR__ . '/../..' . '/app/Common/Models/WritingAssistantPost.php',
        'AIOSEO\\Plugin\\Common\\Options\\Cache' => __DIR__ . '/../..' . '/app/Common/Options/Cache.php',
        'AIOSEO\\Plugin\\Common\\Options\\DynamicBackup' => __DIR__ . '/../..' . '/app/Common/Options/DynamicBackup.php',
        'AIOSEO\\Plugin\\Common\\Options\\DynamicOptions' => __DIR__ . '/../..' . '/app/Common/Options/DynamicOptions.php',
        'AIOSEO\\Plugin\\Common\\Options\\InternalNetworkOptions' => __DIR__ . '/../..' . '/app/Common/Options/InternalNetworkOptions.php',
        'AIOSEO\\Plugin\\Common\\Options\\InternalOptions' => __DIR__ . '/../..' . '/app/Common/Options/InternalOptions.php',
        'AIOSEO\\Plugin\\Common\\Options\\NetworkOptions' => __DIR__ . '/../..' . '/app/Common/Options/NetworkOptions.php',
        'AIOSEO\\Plugin\\Common\\Options\\Options' => __DIR__ . '/../..' . '/app/Common/Options/Options.php',
        'AIOSEO\\Plugin\\Common\\Options\\SensitiveOptions' => __DIR__ . '/../..' . '/app/Common/Options/SensitiveOptions.php',
        'AIOSEO\\Plugin\\Common\\QueryArgs\\CrawlCleanup' => __DIR__ . '/../..' . '/app/Common/QueryArgs/CrawlCleanup.php',
        'AIOSEO\\Plugin\\Common\\RestApi\\Controllers\\Base' => __DIR__ . '/../..' . '/app/Common/RestApi/Controllers/Base.php',
        'AIOSEO\\Plugin\\Common\\RestApi\\Controllers\\Post' => __DIR__ . '/../..' . '/app/Common/RestApi/Controllers/Post.php',
        'AIOSEO\\Plugin\\Common\\RestApi\\Controllers\\Term' => __DIR__ . '/../..' . '/app/Common/RestApi/Controllers/Term.php',
        'AIOSEO\\Plugin\\Common\\RestApi\\RestApi' => __DIR__ . '/../..' . '/app/Common/RestApi/RestApi.php',
        'AIOSEO\\Plugin\\Common\\Rss' => __DIR__ . '/../..' . '/app/Common/Rss.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Breadcrumb' => __DIR__ . '/../..' . '/app/Common/Schema/Breadcrumb.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Context' => __DIR__ . '/../..' . '/app/Common/Schema/Context.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\AmpStory' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/AmpStory.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\Article\\Article' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/Article/Article.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\Article\\BlogPosting' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/Article/BlogPosting.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\Article\\NewsArticle' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/Article/NewsArticle.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\BreadcrumbList' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/BreadcrumbList.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\Graph' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/Graph.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\KnowledgeGraph\\KgOrganization' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/KnowledgeGraph/KgOrganization.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\KnowledgeGraph\\KgPerson' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/KnowledgeGraph/KgPerson.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\Traits\\Image' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/Traits/Image.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\AboutPage' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebPage/AboutPage.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\CheckoutPage' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebPage/CheckoutPage.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\CollectionPage' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebPage/CollectionPage.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\ContactPage' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebPage/ContactPage.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\FAQPage' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebPage/FAQPage.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\ItemPage' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebPage/ItemPage.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\MedicalWebPage' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebPage/MedicalWebPage.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\PersonAuthor' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebPage/PersonAuthor.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\ProfilePage' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebPage/ProfilePage.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\RealEstateListing' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebPage/RealEstateListing.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\SearchResultsPage' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebPage/SearchResultsPage.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\WebPage' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebPage/WebPage.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebSite' => __DIR__ . '/../..' . '/app/Common/Schema/Graphs/WebSite.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Helpers' => __DIR__ . '/../..' . '/app/Common/Schema/Helpers.php',
        'AIOSEO\\Plugin\\Common\\Schema\\Schema' => __DIR__ . '/../..' . '/app/Common/Schema/Schema.php',
        'AIOSEO\\Plugin\\Common\\SearchCleanup\\SearchCleanup' => __DIR__ . '/../..' . '/app/Common/SearchCleanup/SearchCleanup.php',
        'AIOSEO\\Plugin\\Common\\SearchStatistics\\Api\\Api' => __DIR__ . '/../..' . '/app/Common/SearchStatistics/Api/Api.php',
        'AIOSEO\\Plugin\\Common\\SearchStatistics\\Api\\Auth' => __DIR__ . '/../..' . '/app/Common/SearchStatistics/Api/Auth.php',
        'AIOSEO\\Plugin\\Common\\SearchStatistics\\Api\\Listener' => __DIR__ . '/../..' . '/app/Common/SearchStatistics/Api/Listener.php',
        'AIOSEO\\Plugin\\Common\\SearchStatistics\\Api\\Request' => __DIR__ . '/../..' . '/app/Common/SearchStatistics/Api/Request.php',
        'AIOSEO\\Plugin\\Common\\SearchStatistics\\Api\\TrustToken' => __DIR__ . '/../..' . '/app/Common/SearchStatistics/Api/TrustToken.php',
        'AIOSEO\\Plugin\\Common\\SearchStatistics\\IndexStatus' => __DIR__ . '/../..' . '/app/Common/SearchStatistics/IndexStatus.php',
        'AIOSEO\\Plugin\\Common\\SearchStatistics\\KeywordRankTracker' => __DIR__ . '/../..' . '/app/Common/SearchStatistics/KeywordRankTracker.php',
        'AIOSEO\\Plugin\\Common\\SearchStatistics\\Notices' => __DIR__ . '/../..' . '/app/Common/SearchStatistics/Notices.php',
        'AIOSEO\\Plugin\\Common\\SearchStatistics\\SearchStatistics' => __DIR__ . '/../..' . '/app/Common/SearchStatistics/SearchStatistics.php',
        'AIOSEO\\Plugin\\Common\\SearchStatistics\\Site' => __DIR__ . '/../..' . '/app/Common/SearchStatistics/Site.php',
        'AIOSEO\\Plugin\\Common\\SearchStatistics\\Sitemap' => __DIR__ . '/../..' . '/app/Common/SearchStatistics/Sitemap.php',
        'AIOSEO\\Plugin\\Common\\SeoAnalysis\\SeoAnalysis' => __DIR__ . '/../..' . '/app/Common/SeoAnalysis/SeoAnalysis.php',
        'AIOSEO\\Plugin\\Common\\SeoChecklist\\SeoChecklist' => __DIR__ . '/../..' . '/app/Common/SeoChecklist/SeoChecklist.php',
        'AIOSEO\\Plugin\\Common\\SeoRevisions\\SeoRevisions' => __DIR__ . '/../..' . '/app/Common/SeoRevisions/SeoRevisions.php',
        'AIOSEO\\Plugin\\Common\\Services\\AuditService' => __DIR__ . '/../..' . '/app/Common/Services/AuditService.php',
        'AIOSEO\\Plugin\\Common\\Services\\NotificationsService' => __DIR__ . '/../..' . '/app/Common/Services/NotificationsService.php',
        'AIOSEO\\Plugin\\Common\\Services\\PostSeoService' => __DIR__ . '/../..' . '/app/Common/Services/PostSeoService.php',
        'AIOSEO\\Plugin\\Common\\Services\\RobotsService' => __DIR__ . '/../..' . '/app/Common/Services/RobotsService.php',
        'AIOSEO\\Plugin\\Common\\Services\\SettingsService' => __DIR__ . '/../..' . '/app/Common/Services/SettingsService.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Content' => __DIR__ . '/../..' . '/app/Common/Sitemap/Content.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\File' => __DIR__ . '/../..' . '/app/Common/Sitemap/File.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Helpers' => __DIR__ . '/../..' . '/app/Common/Sitemap/Helpers.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\Block' => __DIR__ . '/../..' . '/app/Common/Sitemap/Html/Block.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\CompactArchive' => __DIR__ . '/../..' . '/app/Common/Sitemap/Html/CompactArchive.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\Frontend' => __DIR__ . '/../..' . '/app/Common/Sitemap/Html/Frontend.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\Query' => __DIR__ . '/../..' . '/app/Common/Sitemap/Html/Query.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\Shortcode' => __DIR__ . '/../..' . '/app/Common/Sitemap/Html/Shortcode.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\Sitemap' => __DIR__ . '/../..' . '/app/Common/Sitemap/Html/Sitemap.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\Widget' => __DIR__ . '/../..' . '/app/Common/Sitemap/Html/Widget.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Image\\Image' => __DIR__ . '/../..' . '/app/Common/Sitemap/Image/Image.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Image\\ThirdParty' => __DIR__ . '/../..' . '/app/Common/Sitemap/Image/ThirdParty.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Localization' => __DIR__ . '/../..' . '/app/Common/Sitemap/Localization.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Output' => __DIR__ . '/../..' . '/app/Common/Sitemap/Output.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Priority' => __DIR__ . '/../..' . '/app/Common/Sitemap/Priority.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Query' => __DIR__ . '/../..' . '/app/Common/Sitemap/Query.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\RequestParser' => __DIR__ . '/../..' . '/app/Common/Sitemap/RequestParser.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Root' => __DIR__ . '/../..' . '/app/Common/Sitemap/Root.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Sitemap' => __DIR__ . '/../..' . '/app/Common/Sitemap/Sitemap.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\SitemapAbstract' => __DIR__ . '/../..' . '/app/Common/Sitemap/SitemapAbstract.php',
        'AIOSEO\\Plugin\\Common\\Sitemap\\Xsl' => __DIR__ . '/../..' . '/app/Common/Sitemap/Xsl.php',
        'AIOSEO\\Plugin\\Common\\Social\\Facebook' => __DIR__ . '/../..' . '/app/Common/Social/Facebook.php',
        'AIOSEO\\Plugin\\Common\\Social\\Image' => __DIR__ . '/../..' . '/app/Common/Social/Image.php',
        'AIOSEO\\Plugin\\Common\\Social\\Output' => __DIR__ . '/../..' . '/app/Common/Social/Output.php',
        'AIOSEO\\Plugin\\Common\\Social\\Social' => __DIR__ . '/../..' . '/app/Common/Social/Social.php',
        'AIOSEO\\Plugin\\Common\\Social\\Twitter' => __DIR__ . '/../..' . '/app/Common/Social/Twitter.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\AdminBarNoindexWarning' => __DIR__ . '/../..' . '/app/Common/Standalone/AdminBarNoindexWarning.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\BbPress\\BbPress' => __DIR__ . '/../..' . '/app/Common/Standalone/BbPress/BbPress.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\BbPress\\Component' => __DIR__ . '/../..' . '/app/Common/Standalone/BbPress/Component.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\Blocks\\AiAssistant' => __DIR__ . '/../..' . '/app/Common/Standalone/Blocks/AiAssistant.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\Blocks\\Blocks' => __DIR__ . '/../..' . '/app/Common/Standalone/Blocks/Blocks.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\Blocks\\FaqPage' => __DIR__ . '/../..' . '/app/Common/Standalone/Blocks/FaqPage.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\Blocks\\KeyPoints' => __DIR__ . '/../..' . '/app/Common/Standalone/Blocks/KeyPoints.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\Blocks\\TableOfContents' => __DIR__ . '/../..' . '/app/Common/Standalone/Blocks/TableOfContents.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\BuddyPress\\BuddyPress' => __DIR__ . '/../..' . '/app/Common/Standalone/BuddyPress/BuddyPress.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\BuddyPress\\Component' => __DIR__ . '/../..' . '/app/Common/Standalone/BuddyPress/Component.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\BuddyPress\\Sitemap' => __DIR__ . '/../..' . '/app/Common/Standalone/BuddyPress/Sitemap.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\BuddyPress\\Tags' => __DIR__ . '/../..' . '/app/Common/Standalone/BuddyPress/Tags.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\DetailsColumn' => __DIR__ . '/../..' . '/app/Common/Standalone/DetailsColumn.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\FlyoutMenu' => __DIR__ . '/../..' . '/app/Common/Standalone/FlyoutMenu.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\HeadlineAnalyzer' => __DIR__ . '/../..' . '/app/Common/Standalone/HeadlineAnalyzer.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\LimitModifiedDate' => __DIR__ . '/../..' . '/app/Common/Standalone/LimitModifiedDate.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\Notifications' => __DIR__ . '/../..' . '/app/Common/Standalone/Notifications.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\Avada' => __DIR__ . '/../..' . '/app/Common/Standalone/PageBuilders/Avada.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\Base' => __DIR__ . '/../..' . '/app/Common/Standalone/PageBuilders/Base.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\Bricks' => __DIR__ . '/../..' . '/app/Common/Standalone/PageBuilders/Bricks.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\Divi' => __DIR__ . '/../..' . '/app/Common/Standalone/PageBuilders/Divi.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\Elementor' => __DIR__ . '/../..' . '/app/Common/Standalone/PageBuilders/Elementor.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\Oxygen' => __DIR__ . '/../..' . '/app/Common/Standalone/PageBuilders/Oxygen.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\SeedProd' => __DIR__ . '/../..' . '/app/Common/Standalone/PageBuilders/SeedProd.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\SiteOrigin' => __DIR__ . '/../..' . '/app/Common/Standalone/PageBuilders/SiteOrigin.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\ThriveArchitect' => __DIR__ . '/../..' . '/app/Common/Standalone/PageBuilders/ThriveArchitect.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\WPBakery' => __DIR__ . '/../..' . '/app/Common/Standalone/PageBuilders/WPBakery.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\PrimaryTerm' => __DIR__ . '/../..' . '/app/Common/Standalone/PrimaryTerm.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\PublishPanel' => __DIR__ . '/../..' . '/app/Common/Standalone/PublishPanel.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\SeoPreview' => __DIR__ . '/../..' . '/app/Common/Standalone/SeoPreview.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\SetupWizard' => __DIR__ . '/../..' . '/app/Common/Standalone/SetupWizard.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\Standalone' => __DIR__ . '/../..' . '/app/Common/Standalone/Standalone.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\UserProfileTab' => __DIR__ . '/../..' . '/app/Common/Standalone/UserProfileTab.php',
        'AIOSEO\\Plugin\\Common\\Standalone\\WpCode' => __DIR__ . '/../..' . '/app/Common/Standalone/WpCode.php',
        'AIOSEO\\Plugin\\Common\\ThirdParty\\ThirdParty' => __DIR__ . '/../..' . '/app/Common/ThirdParty/ThirdParty.php',
        'AIOSEO\\Plugin\\Common\\ThirdParty\\WebStories' => __DIR__ . '/../..' . '/app/Common/ThirdParty/WebStories.php',
        'AIOSEO\\Plugin\\Common\\Tools\\Htaccess' => __DIR__ . '/../..' . '/app/Common/Tools/Htaccess.php',
        'AIOSEO\\Plugin\\Common\\Tools\\RobotsTxt' => __DIR__ . '/../..' . '/app/Common/Tools/RobotsTxt.php',
        'AIOSEO\\Plugin\\Common\\Tools\\SystemStatus' => __DIR__ . '/../..' . '/app/Common/Tools/SystemStatus.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Assets' => __DIR__ . '/../..' . '/app/Common/Traits/Assets.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Api' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Api.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Arrays' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Arrays.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Blocks' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Blocks.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Buffer' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Buffer.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Constants' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Constants.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\DateTime' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/DateTime.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Deprecated' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Deprecated.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Images' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Images.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Language' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Language.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Numbers' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Numbers.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\PostType' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/PostType.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Request' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Request.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Shortcodes' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Shortcodes.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Strings' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Strings.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Svg' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Svg.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\ThirdParty' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/ThirdParty.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Url' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Url.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Vue' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Vue.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Wp' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/Wp.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\WpContext' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/WpContext.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\WpMultisite' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/WpMultisite.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\WpUri' => __DIR__ . '/../..' . '/app/Common/Traits/Helpers/WpUri.php',
        'AIOSEO\\Plugin\\Common\\Traits\\NetworkOptions' => __DIR__ . '/../..' . '/app/Common/Traits/NetworkOptions.php',
        'AIOSEO\\Plugin\\Common\\Traits\\Options' => __DIR__ . '/../..' . '/app/Common/Traits/Options.php',
        'AIOSEO\\Plugin\\Common\\Traits\\SocialProfiles' => __DIR__ . '/../..' . '/app/Common/Traits/SocialProfiles.php',
        'AIOSEO\\Plugin\\Common\\Utils\\Access' => __DIR__ . '/../..' . '/app/Common/Utils/Access.php',
        'AIOSEO\\Plugin\\Common\\Utils\\ActionScheduler' => __DIR__ . '/../..' . '/app/Common/Utils/ActionScheduler.php',
        'AIOSEO\\Plugin\\Common\\Utils\\Addons' => __DIR__ . '/../..' . '/app/Common/Utils/Addons.php',
        'AIOSEO\\Plugin\\Common\\Utils\\Assets' => __DIR__ . '/../..' . '/app/Common/Utils/Assets.php',
        'AIOSEO\\Plugin\\Common\\Utils\\Backup' => __DIR__ . '/../..' . '/app/Common/Utils/Backup.php',
        'AIOSEO\\Plugin\\Common\\Utils\\Blocks' => __DIR__ . '/../..' . '/app/Common/Utils/Blocks.php',
        'AIOSEO\\Plugin\\Common\\Utils\\Cache' => __DIR__ . '/../..' . '/app/Common/Utils/Cache.php',
        'AIOSEO\\Plugin\\Common\\Utils\\Database' => __DIR__ . '/../..' . '/app/Common/Utils/Database.php',
        'AIOSEO\\Plugin\\Common\\Utils\\Features' => __DIR__ . '/../..' . '/app/Common/Utils/Features.php',
        'AIOSEO\\Plugin\\Common\\Utils\\Filesystem' => __DIR__ . '/../..' . '/app/Common/Utils/Filesystem.php',
        'AIOSEO\\Plugin\\Common\\Utils\\Helpers' => __DIR__ . '/../..' . '/app/Common/Utils/Helpers.php',
        'AIOSEO\\Plugin\\Common\\Utils\\NetworkCache' => __DIR__ . '/../..' . '/app/Common/Utils/NetworkCache.php',
        'AIOSEO\\Plugin\\Common\\Utils\\PluginUpgraderSilentAjax' => __DIR__ . '/../..' . '/app/Common/Utils/PluginUpgraderSilentAjax.php',
        'AIOSEO\\Plugin\\Common\\Utils\\PluginUpgraderSkin' => __DIR__ . '/../..' . '/app/Common/Utils/PluginUpgraderSkin.php',
        'AIOSEO\\Plugin\\Common\\Utils\\Tags' => __DIR__ . '/../..' . '/app/Common/Utils/Tags.php',
        'AIOSEO\\Plugin\\Common\\Utils\\Templates' => __DIR__ . '/../..' . '/app/Common/Utils/Templates.php',
        'AIOSEO\\Plugin\\Common\\Utils\\VueSettings' => __DIR__ . '/../..' . '/app/Common/Utils/VueSettings.php',
        'AIOSEO\\Plugin\\Common\\WritingAssistant\\SeoBoost\\SeoBoost' => __DIR__ . '/../..' . '/app/Common/WritingAssistant/SeoBoost/SeoBoost.php',
        'AIOSEO\\Plugin\\Common\\WritingAssistant\\SeoBoost\\Service' => __DIR__ . '/../..' . '/app/Common/WritingAssistant/SeoBoost/Service.php',
        'AIOSEO\\Plugin\\Common\\WritingAssistant\\Utils\\Helpers' => __DIR__ . '/../..' . '/app/Common/WritingAssistant/Utils/Helpers.php',
        'AIOSEO\\Plugin\\Common\\WritingAssistant\\WritingAssistant' => __DIR__ . '/../..' . '/app/Common/WritingAssistant/WritingAssistant.php',
        'AIOSEO\\Plugin\\Lite\\Admin\\Admin' => __DIR__ . '/../..' . '/app/Lite/Admin/Admin.php',
        'AIOSEO\\Plugin\\Lite\\Admin\\Connect' => __DIR__ . '/../..' . '/app/Lite/Admin/Connect.php',
        'AIOSEO\\Plugin\\Lite\\Admin\\Notices\\Notices' => __DIR__ . '/../..' . '/app/Lite/Admin/Notices/Notices.php',
        'AIOSEO\\Plugin\\Lite\\Admin\\PostSettings' => __DIR__ . '/../..' . '/app/Lite/Admin/PostSettings.php',
        'AIOSEO\\Plugin\\Lite\\Admin\\Usage' => __DIR__ . '/../..' . '/app/Lite/Admin/Usage.php',
        'AIOSEO\\Plugin\\Lite\\Api\\Api' => __DIR__ . '/../..' . '/app/Lite/Api/Api.php',
        'AIOSEO\\Plugin\\Lite\\Api\\Wizard' => __DIR__ . '/../..' . '/app/Lite/Api/Wizard.php',
        'AIOSEO\\Plugin\\Lite\\Main\\Filters' => __DIR__ . '/../..' . '/app/Lite/Main/Filters.php',
        'AIOSEO\\Plugin\\Lite\\Options\\InternalOptions' => __DIR__ . '/../..' . '/app/Lite/Options/InternalOptions.php',
        'AIOSEO\\Plugin\\Lite\\Options\\Options' => __DIR__ . '/../..' . '/app/Lite/Options/Options.php',
        'AIOSEO\\Plugin\\Lite\\Options\\SensitiveOptions' => __DIR__ . '/../..' . '/app/Lite/Options/SensitiveOptions.php',
        'AIOSEO\\Plugin\\Lite\\Traits\\Helpers\\Vue' => __DIR__ . '/../..' . '/app/Lite/Traits/Helpers/Vue.php',
        'AIOSEO\\Plugin\\Lite\\Traits\\Options' => __DIR__ . '/../..' . '/app/Lite/Traits/Options.php',
        'AIOSEO\\Plugin\\Lite\\Utils\\Helpers' => __DIR__ . '/../..' . '/app/Lite/Utils/Helpers.php',
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
        'League\\HTMLToMarkdown\\Coerce' => __DIR__ . '/..' . '/league/html-to-markdown/src/Coerce.php',
        'League\\HTMLToMarkdown\\Configuration' => __DIR__ . '/..' . '/league/html-to-markdown/src/Configuration.php',
        'League\\HTMLToMarkdown\\ConfigurationAwareInterface' => __DIR__ . '/..' . '/league/html-to-markdown/src/ConfigurationAwareInterface.php',
        'League\\HTMLToMarkdown\\Converter\\BlockquoteConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/BlockquoteConverter.php',
        'League\\HTMLToMarkdown\\Converter\\CodeConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/CodeConverter.php',
        'League\\HTMLToMarkdown\\Converter\\CommentConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/CommentConverter.php',
        'League\\HTMLToMarkdown\\Converter\\ConverterInterface' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/ConverterInterface.php',
        'League\\HTMLToMarkdown\\Converter\\DefaultConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/DefaultConverter.php',
        'League\\HTMLToMarkdown\\Converter\\DivConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/DivConverter.php',
        'League\\HTMLToMarkdown\\Converter\\EmphasisConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/EmphasisConverter.php',
        'League\\HTMLToMarkdown\\Converter\\HardBreakConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/HardBreakConverter.php',
        'League\\HTMLToMarkdown\\Converter\\HeaderConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/HeaderConverter.php',
        'League\\HTMLToMarkdown\\Converter\\HorizontalRuleConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/HorizontalRuleConverter.php',
        'League\\HTMLToMarkdown\\Converter\\ImageConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/ImageConverter.php',
        'League\\HTMLToMarkdown\\Converter\\LinkConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/LinkConverter.php',
        'League\\HTMLToMarkdown\\Converter\\ListBlockConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/ListBlockConverter.php',
        'League\\HTMLToMarkdown\\Converter\\ListItemConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/ListItemConverter.php',
        'League\\HTMLToMarkdown\\Converter\\ParagraphConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/ParagraphConverter.php',
        'League\\HTMLToMarkdown\\Converter\\PreformattedConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/PreformattedConverter.php',
        'League\\HTMLToMarkdown\\Converter\\TableConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/TableConverter.php',
        'League\\HTMLToMarkdown\\Converter\\TextConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/Converter/TextConverter.php',
        'League\\HTMLToMarkdown\\Element' => __DIR__ . '/..' . '/league/html-to-markdown/src/Element.php',
        'League\\HTMLToMarkdown\\ElementInterface' => __DIR__ . '/..' . '/league/html-to-markdown/src/ElementInterface.php',
        'League\\HTMLToMarkdown\\Environment' => __DIR__ . '/..' . '/league/html-to-markdown/src/Environment.php',
        'League\\HTMLToMarkdown\\HtmlConverter' => __DIR__ . '/..' . '/league/html-to-markdown/src/HtmlConverter.php',
        'League\\HTMLToMarkdown\\HtmlConverterInterface' => __DIR__ . '/..' . '/league/html-to-markdown/src/HtmlConverterInterface.php',
        'League\\HTMLToMarkdown\\PreConverterInterface' => __DIR__ . '/..' . '/league/html-to-markdown/src/PreConverterInterface.php',
        'PHPInsight\\Autoloader' => __DIR__ . '/..' . '/jwhennessey/phpinsight/lib/PHPInsight/Autoloader.php',
        'PHPInsight\\Sentiment' => __DIR__ . '/..' . '/jwhennessey/phpinsight/lib/PHPInsight/Sentiment.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit8a081da25031c092fc2baa55d98421f8::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit8a081da25031c092fc2baa55d98421f8::$prefixDirsPsr4;
            $loader->prefixesPsr0 = ComposerStaticInit8a081da25031c092fc2baa55d98421f8::$prefixesPsr0;
            $loader->classMap = ComposerStaticInit8a081da25031c092fc2baa55d98421f8::$classMap;

        }, null, ClassLoader::class);
    }
}
