.aioseo-ai-content-settings__disconnect-modal .aioseo-modal-body{padding:20px 40px 40px;display:flex;align-items:center;justify-content:center;flex-direction:column;position:relative}.aioseo-ai-content-settings__disconnect-modal .aioseo-modal-body h3{font-size:20px;margin-bottom:16px}.aioseo-ai-content-settings__disconnect-modal .aioseo-modal-body .reset-description{font-size:16px;color:#141b38;margin-bottom:16px;text-align:center;max-width:515px;line-height:1.6}.aioseo-ai-content-settings__disconnect-modal .aioseo-modal-body button.close{position:absolute;top:11px;width:24px;height:24px;background-color:#fff;border:none;display:flex;align-items:center}[dir=ltr] .aioseo-ai-content-settings__disconnect-modal .aioseo-modal-body button.close{right:11px}[dir=rtl] .aioseo-ai-content-settings__disconnect-modal .aioseo-modal-body button.close{left:11px}.aioseo-ai-content-settings__disconnect-modal .aioseo-modal-body button.close svg.aioseo-close{cursor:pointer;width:14px;height:14px}.aioseo-ai-content-settings__disconnect-modal .aioseo-modal-body .aioseo-description{max-width:510px;text-align:center}.aioseo-ai-content-settings__disconnect-modal .aioseo-modal-body .aioseo-button:not(.close){margin-top:16px}.aioseo-buy-or-connect[data-v-d58bd455]{display:block}.aioseo-buy-or-connect__connected .credits-display[data-v-d58bd455]{margin-bottom:8px}.aioseo-buy-or-connect__connected .credits-display[data-v-d58bd455] .aioseo-ai-credit-counter .purchase-credits{display:none}.aioseo-buy-or-connect__connected .credits-description[data-v-d58bd455]{font-size:14px;color:#434960;margin-bottom:8px}.aioseo-buy-or-connect__connected .credits-description a[data-v-d58bd455]{color:#005ae0;text-decoration:none}.aioseo-buy-or-connect__connected .credits-description a[data-v-d58bd455]:hover{text-decoration:underline}.aioseo-buy-or-connect__connected .credits-actions[data-v-d58bd455]{font-size:13px;color:#8c8f9a}.aioseo-buy-or-connect__connected .credits-actions a[data-v-d58bd455]{color:#8c8f9a;text-decoration:none}.aioseo-buy-or-connect__connected .credits-actions a[data-v-d58bd455]:hover{text-decoration:underline;color:#434960}.aioseo-buy-or-connect__connected .credits-actions a.is-refreshing[data-v-d58bd455]{opacity:.7;pointer-events:none;cursor:default}.aioseo-buy-or-connect__connected .credits-actions .separator[data-v-d58bd455]{margin:0 6px}.aioseo-buy-or-connect__container .license-key-error[data-v-d58bd455]{margin-top:12px}.aioseo-buy-or-connect__options[data-v-d58bd455]{display:flex;gap:24px}.aioseo-buy-or-connect__options.buttons-only[data-v-d58bd455]{justify-content:center}[dir=ltr] .aioseo-buy-or-connect__options.buttons-only .aioseo-buy-or-connect__option[data-v-d58bd455]:first-child{padding-right:0}[dir=rtl] .aioseo-buy-or-connect__options.buttons-only .aioseo-buy-or-connect__option[data-v-d58bd455]:first-child{padding-left:0}@media(max-width:768px){.aioseo-buy-or-connect__options[data-v-d58bd455]{flex-direction:column;gap:16px}}[dir=ltr] .aioseo-buy-or-connect__option[data-v-d58bd455]:first-child{padding-right:24px}[dir=rtl] .aioseo-buy-or-connect__option[data-v-d58bd455]:first-child{padding-left:24px}@media(max-width:768px){.aioseo-buy-or-connect__option[data-v-d58bd455]:first-child{padding-bottom:16px;border-bottom:1px solid #E8E8EB}[dir=ltr] .aioseo-buy-or-connect__option[data-v-d58bd455]:first-child{padding-right:0;border-right:none}[dir=rtl] .aioseo-buy-or-connect__option[data-v-d58bd455]:first-child{padding-left:0;border-left:none}}.aioseo-buy-or-connect__option .option-label[data-v-d58bd455]{font-size:14px;font-weight:600;color:#141b38;margin-bottom:2px}.aioseo-buy-or-connect__option .option-description[data-v-d58bd455]{font-size:14px;color:#434960;margin-bottom:8px}.aioseo-buy-or-connect__option .option-note[data-v-d58bd455]{font-size:14px;color:#434960;margin-bottom:8px;max-width:350px}
