.field-description[data-v-f926573a]{display:inline-block;margin-top:10px;font-size:14px}.aioseo-address-wrapper[data-v-720b3124]{display:flex;max-width:500px}.field-description[data-v-720b3124]{display:inline-block;margin-bottom:10px;font-size:14px}.mt-8[data-v-720b3124]{margin-top:8px}.field-description[data-v-3a0249d7]{display:inline-block;margin-bottom:10px;font-size:14px}.mt-8[data-v-3a0249d7]{margin-top:8px}.field-description[data-v-462e3315]{display:inline-block;margin-bottom:10px;font-size:14px}.mt-8[data-v-462e3315]{margin-top:8px}.field-description[data-v-1b48195c]{display:inline-block;margin-top:10px;font-size:14px}.field-description[data-v-dd6bc9e3]{display:inline-block;margin-bottom:10px;font-size:14px}.mt-8[data-v-dd6bc9e3]{margin-top:8px}.aioseo-localseo-info .aioseo-input,.aioseo-localseo-info .aioseo-select,.aioseo-localseo-info .aioseo-multiselect{max-width:480px}.aioseo-localseo-info .field-description{font-size:14px}.aioseo-localseo-info .info-businessaddress-row .columns{display:flex;flex:0 1 auto;flex-direction:row;flex-wrap:wrap}.aioseo-localseo-info.aioseo-tab-content svg.aioseo-circle-question-mark{width:17px;height:17px;color:#8c8f9a;transition:background-color .2s ease}.aioseo-localseo-opening .field-description{display:inline-block;margin:10px 0;font-size:14px}.aioseo-localseo-opening .field-description.mt-8{margin-top:8px}.aioseo-localseo-opening .aioseo-input,.aioseo-localseo-opening .aioseo-select,.aioseo-localseo-opening .aioseo-multiselect{max-width:480px}.aioseo-localseo-opening .aioseo-col-flex{display:flex;align-items:center;padding:12px 0;border-bottom:1px solid #E8E8EB}.aioseo-localseo-opening .aioseo-col-flex:first-of-type{padding-top:0}.aioseo-localseo-opening .aioseo-col-flex:last-of-type{padding-bottom:0;border:none}.aioseo-localseo-opening .aioseo-col-flex .aioseo-col-day{flex:1}.aioseo-localseo-opening .aioseo-col-flex .aioseo-col-hours,.aioseo-localseo-opening .aioseo-col-flex .aioseo-col-alwaysopen{flex:2}.aioseo-localseo-opening .aioseo-col-flex span.separator{margin:0 5px}.aioseo-localseo-opening .aioseo-col-flex .aioseo-select{display:inline-block;max-width:120px;margin-bottom:5px}.aioseo-localseo-opening .aioseo-col-flex .multiselect--disabled .multiselect__tags,.aioseo-localseo-opening .aioseo-col-flex .multiselect--disabled .multiselect__single{background:#f3f4f5}.aioseo-localseo-opening .aioseo-col-alwaysopen .aioseo-checkbox{padding:0 10px}.aioseo-localseo-maps .aioseo-input,.aioseo-localseo-maps .aioseo-select,.aioseo-localseo-maps .aioseo-multiselect{max-width:480px}.aioseo-localseo-maps .field-description{font-size:14px}
