<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models;

class CheckoutLocationSettingsBrandingHeaderType
{
    public const BUSINESS_NAME = 'BUSINESS_NAME';
    public const FRAMED_LOGO = 'FRAMED_LOGO';
    public const FULL_WIDTH_LOGO = 'FULL_WIDTH_LOGO';
}
