.aioseo-radio-toggle{display:flex;align-items:center;height:40px}.aioseo-radio-toggle div{height:100%}.aioseo-radio-toggle.inline{display:inline-flex}.aioseo-radio-toggle div:first-child{overflow:hidden}[dir=ltr] .aioseo-radio-toggle div:first-child{border-radius:3px 0 0 3px}[dir=rtl] .aioseo-radio-toggle div:first-child{border-radius:0 3px 3px 0}[dir=ltr] .aioseo-radio-toggle div:first-child label{border-radius:3px 0 0 3px}[dir=rtl] .aioseo-radio-toggle div:first-child label{border-radius:0 3px 3px 0}.aioseo-radio-toggle div:last-child{overflow:hidden}[dir=ltr] .aioseo-radio-toggle div:last-child{border-radius:0 3px 3px 0}[dir=rtl] .aioseo-radio-toggle div:last-child{border-radius:3px 0 0 3px}[dir=ltr] .aioseo-radio-toggle div:last-child label{border-radius:0 3px 3px 0}[dir=rtl] .aioseo-radio-toggle div:last-child label{border-radius:3px 0 0 3px}.aioseo-radio-toggle input{position:absolute!important;clip:rect(0,0,0,0);height:1px;width:1px;border:0;overflow:hidden}.aioseo-radio-toggle input:checked+label{background-color:#005ae0;color:#fff}.aioseo-radio-toggle input:checked+label.dark{background-color:#434960;color:#fff}.aioseo-radio-toggle label{height:100%;background-color:#e8e8eb;color:#141b38;font-size:14px;line-height:1;display:flex;align-items:center;justify-content:center;flex-direction:column;transition:all .1s ease-in-out;position:relative;padding:6px 14px;font-weight:600}.aioseo-radio-toggle label.disabled{cursor:default;pointer-events:none;opacity:.5}.aioseo-radio-toggle label:hover{background-color:#dadadf;cursor:pointer}.aioseo-radio-toggle label p{position:absolute;bottom:15px;margin:0}.aioseo-radio-toggle.small{height:32px}.aioseo-radio-toggle.small label{font-size:12px;padding:6px 14px}.aioseo-radio-toggle.circle{height:36px}.aioseo-radio-toggle.circle label{background:#fff;color:#8c8f9a}.aioseo-radio-toggle.circle input+label{border-radius:50%;width:36px;height:36px;padding:8px}.aioseo-radio-toggle.circle input:checked+label{background:#e8e8eb;color:#2c324c}[dir] .aioseo-radio-toggle.circle label{background:#fff;color:#8c8f9a}[dir] .aioseo-radio-toggle.circle input+label{border-radius:50%;width:36px;height:36px;padding:8px}[dir] .aioseo-radio-toggle.circle input:checked+label{background:#e8e8eb;color:#2c324c}
