.aioseo-primary-term-cta{position:relative;padding:0 25px}.aioseo-primary-term-cta .aioseo-circle-information{position:absolute;top:0;color:#f18200}[dir=ltr] .aioseo-primary-term-cta .aioseo-circle-information{left:0}[dir=rtl] .aioseo-primary-term-cta .aioseo-circle-information{right:0}.aioseo-primary-term-cta p{font-weight:400;font-size:14px;line-height:125%;color:#2c324c}.aioseo-primary-term-cta p:last-of-type{margin-bottom:0}.aioseo-primary-term-cta .aioseo-close{position:absolute;top:2px;cursor:pointer;color:#434960;width:10px;height:10px}[dir=ltr] .aioseo-primary-term-cta .aioseo-close{right:0}[dir=rtl] .aioseo-primary-term-cta .aioseo-close{left:0}.aioseo-primary-term:not(:empty){margin-top:12px;padding-top:12px;border-top:1px solid #DCDDE1}
