.aioseo-app .aioseo-search-statistics-redirects{font-size:14px}.aioseo-app .aioseo-search-statistics-redirects .aioseo-cta .aioseo-cta-background .header-text{font-size:15px}.aioseo-app .aioseo-search-statistics-redirects .aioseo-cta .aioseo-cta-background .description{font-size:14px}
