.aioseo-wizard-smart-recommendations .header{font-size:24px;color:#141b38;font-weight:600}.aioseo-wizard-smart-recommendations .description{margin-top:20px;font-size:16px;color:#434960;margin-bottom:40px;line-height:1.4}.aioseo-wizard-smart-recommendations .available-features{font-size:16px;color:#141b38;margin:20px 0}.aioseo-wizard-smart-recommendations .available-features.no-access{color:#434960}.aioseo-wizard-smart-recommendations .aioseo-settings-row{font-size:16px;color:#141b38}.aioseo-wizard-smart-recommendations .aioseo-settings-row .settings-name{margin-bottom:10px}.aioseo-wizard-smart-recommendations .aioseo-tooltip svg.aioseo-circle-question-mark{width:17px;height:17px;color:#8c8f9a;cursor:pointer}.aioseo-wizard-smart-recommendations .go-back a{color:#434960;font-size:14px}.aioseo-smart-recommendations-modal .aioseo-modal-body{padding:20px 40px 40px;display:flex;flex-direction:column;position:relative}.aioseo-smart-recommendations-modal .aioseo-modal-body .actions{margin-top:20px;display:flex;align-items:center}[dir=ltr] .aioseo-smart-recommendations-modal .aioseo-modal-body .actions>*{margin-right:20px}[dir=rtl] .aioseo-smart-recommendations-modal .aioseo-modal-body .actions>*{margin-left:20px}[dir=ltr] .aioseo-smart-recommendations-modal .aioseo-modal-body .actions>*:last-child{margin-right:0}[dir=rtl] .aioseo-smart-recommendations-modal .aioseo-modal-body .actions>*:last-child{margin-left:0}.aioseo-smart-recommendations-modal .aioseo-modal-body .actions .spacer{flex:1 0 auto}.aioseo-smart-recommendations-modal .aioseo-modal-body .aioseo-alert{margin-top:30px;font-size:14px;text-align:center}.aioseo-smart-recommendations-modal .aioseo-modal-body .bonus-alert{margin:24px auto;max-width:650px}
