.aioseo-seo-site-analysis-result{border:1px solid #DCDDE1;margin-top:8px}.aioseo-seo-site-analysis-result .result-header{height:48px;padding:0 13px;display:flex;align-items:center}.aioseo-seo-site-analysis-result .result-header .result-status{width:8px;height:8px;border-radius:50%}[dir=ltr] .aioseo-seo-site-analysis-result .result-header .result-status{margin-right:14px}[dir=rtl] .aioseo-seo-site-analysis-result .result-header .result-status{margin-left:14px}.aioseo-seo-site-analysis-result .result-header .result-status.passed{background-color:#00aa63}.aioseo-seo-site-analysis-result .result-header .result-status.error{background-color:#df2a4a}.aioseo-seo-site-analysis-result .result-header .result-status.warning{background-color:#f18200}.aioseo-seo-site-analysis-result .result-header .result-content{font-size:14px;line-height:22px;font-weight:600;flex:1}.aioseo-seo-site-analysis-result .result-header .result-toggle{width:30px;height:26px;border:1px solid #DCDDE1;border-radius:3px;display:flex;align-items:center;justify-content:center;cursor:pointer}.aioseo-seo-site-analysis-result .result-header .result-toggle.active,.aioseo-seo-site-analysis-result .result-header .result-toggle:hover{background-color:#005ae0}.aioseo-seo-site-analysis-result .result-header .result-toggle.active svg,.aioseo-seo-site-analysis-result .result-header .result-toggle:hover svg{color:#fff}[dir=ltr] .aioseo-seo-site-analysis-result .result-header .result-toggle.active svg{transform:rotate(-180deg)}[dir=rtl] .aioseo-seo-site-analysis-result .result-header .result-toggle.active svg{transform:rotate(180deg)}.aioseo-seo-site-analysis-result .result-header .result-toggle svg{width:100%;max-width:20px;height:auto;color:#141b38;transition:transform .3s}[dir=ltr] .aioseo-seo-site-analysis-result .result-header .result-toggle svg{transform:rotate(-90deg)}[dir=rtl] .aioseo-seo-site-analysis-result .result-header .result-toggle svg{transform:rotate(90deg)}.aioseo-seo-site-analysis-result .result-body{padding:0 40px 22px}.aioseo-seo-site-analysis-result .result-body .result-message{color:#434960;font-size:14px}.aioseo-seo-site-analysis-result .result-body .result-code pre,.aioseo-seo-site-analysis-result .result-body .result-code-alt pre{display:flex;background:#f3f4f5;border-radius:3px;max-width:100%;padding:10px;overflow:auto}.aioseo-seo-site-analysis-result .result-body .result-code pre code,.aioseo-seo-site-analysis-result .result-body .result-code-alt pre code{padding:0;background:transparent}.aioseo-seo-site-analysis-result .result-body .result-code pre{white-space:pre-line}.aioseo-seo-site-analysis-result .result-body .result-action{margin-top:20px}.aioseo-seo-site-analysis-results{padding-top:12px}.aioseo-seo-site-analysis-results .aioseo-google-search-preview{border:1px solid #E8E8EB;padding:16px}.aioseo-seo-site-analysis-results .group-header{font-size:16px;line-height:24px;font-weight:600;padding:12px;background-color:#f0f6ff;border-radius:4px}.aioseo-seo-site-analysis-results .group-header:not(:first-child){margin-top:20px}.aioseo-seo-site-analysis-results .no-results{margin-top:20px;padding:12px}
