.aioseo-separators{--aioseo-gutter: 8px;position:relative;margin-top:0}[dir=ltr] .aioseo-separators{padding-right:100px}[dir=rtl] .aioseo-separators{padding-left:100px}.aioseo-separators .aioseo-col.col-sm-1{flex:0 0 40px;max-width:none}.aioseo-separators .aioseo-col .separator{background-color:#f3f4f5;display:flex;align-items:center;justify-content:center;min-height:40px;font-weight:600;border:1px solid #D0D1D7;border-radius:3px;font-size:20px;cursor:pointer}.aioseo-separators .aioseo-col .separator:hover{background-color:#e5e7e9}.aioseo-separators .aioseo-col .separator.active{background-color:#005ae0;border-color:#005ae0;color:#fff}.aioseo-separators .aioseo-col .separator.active:hover{background-color:#005ae0}.aioseo-separators .aioseo-col .show-more{height:100%;display:flex;align-items:center}.aioseo-separators .aioseo-col .show-more a{color:#8c8f9a}.aioseo-separators .aioseo-col .custom-separator{font-weight:600;display:flex;flex-direction:column;align-items:flex-start;gap:4px;margin-top:8px}.aioseo-separators .aioseo-col .custom-separator .aioseo-input-container{max-width:200px}
