<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models\Builders;

use WPForms\Vendor\Core\Utils\CoreHelper;
use WPForms\Vendor\Square\Models\TeamMember;
use WPForms\Vendor\Square\Models\TeamMemberAssignedLocations;
use WPForms\Vendor\Square\Models\WageSetting;
/**
 * Builder for model TeamMember
 *
 * @see TeamMember
 */
class TeamMemberBuilder
{
    /**
     * @var TeamMember
     */
    private $instance;
    private function __construct(TeamMember $instance)
    {
        $this->instance = $instance;
    }
    /**
     * Initializes a new Team Member Builder object.
     */
    public static function init() : self
    {
        return new self(new TeamMember());
    }
    /**
     * Sets id field.
     *
     * @param string|null $value
     */
    public function id(?string $value) : self
    {
        $this->instance->setId($value);
        return $this;
    }
    /**
     * Sets reference id field.
     *
     * @param string|null $value
     */
    public function referenceId(?string $value) : self
    {
        $this->instance->setReferenceId($value);
        return $this;
    }
    /**
     * Unsets reference id field.
     */
    public function unsetReferenceId() : self
    {
        $this->instance->unsetReferenceId();
        return $this;
    }
    /**
     * Sets is owner field.
     *
     * @param bool|null $value
     */
    public function isOwner(?bool $value) : self
    {
        $this->instance->setIsOwner($value);
        return $this;
    }
    /**
     * Sets status field.
     *
     * @param string|null $value
     */
    public function status(?string $value) : self
    {
        $this->instance->setStatus($value);
        return $this;
    }
    /**
     * Sets given name field.
     *
     * @param string|null $value
     */
    public function givenName(?string $value) : self
    {
        $this->instance->setGivenName($value);
        return $this;
    }
    /**
     * Unsets given name field.
     */
    public function unsetGivenName() : self
    {
        $this->instance->unsetGivenName();
        return $this;
    }
    /**
     * Sets family name field.
     *
     * @param string|null $value
     */
    public function familyName(?string $value) : self
    {
        $this->instance->setFamilyName($value);
        return $this;
    }
    /**
     * Unsets family name field.
     */
    public function unsetFamilyName() : self
    {
        $this->instance->unsetFamilyName();
        return $this;
    }
    /**
     * Sets email address field.
     *
     * @param string|null $value
     */
    public function emailAddress(?string $value) : self
    {
        $this->instance->setEmailAddress($value);
        return $this;
    }
    /**
     * Unsets email address field.
     */
    public function unsetEmailAddress() : self
    {
        $this->instance->unsetEmailAddress();
        return $this;
    }
    /**
     * Sets phone number field.
     *
     * @param string|null $value
     */
    public function phoneNumber(?string $value) : self
    {
        $this->instance->setPhoneNumber($value);
        return $this;
    }
    /**
     * Unsets phone number field.
     */
    public function unsetPhoneNumber() : self
    {
        $this->instance->unsetPhoneNumber();
        return $this;
    }
    /**
     * Sets created at field.
     *
     * @param string|null $value
     */
    public function createdAt(?string $value) : self
    {
        $this->instance->setCreatedAt($value);
        return $this;
    }
    /**
     * Sets updated at field.
     *
     * @param string|null $value
     */
    public function updatedAt(?string $value) : self
    {
        $this->instance->setUpdatedAt($value);
        return $this;
    }
    /**
     * Sets assigned locations field.
     *
     * @param TeamMemberAssignedLocations|null $value
     */
    public function assignedLocations(?TeamMemberAssignedLocations $value) : self
    {
        $this->instance->setAssignedLocations($value);
        return $this;
    }
    /**
     * Sets wage setting field.
     *
     * @param WageSetting|null $value
     */
    public function wageSetting(?WageSetting $value) : self
    {
        $this->instance->setWageSetting($value);
        return $this;
    }
    /**
     * Initializes a new Team Member object.
     */
    public function build() : TeamMember
    {
        return CoreHelper::clone($this->instance);
    }
}
