.aioseo-wizard-close-and-exit{margin:40px 0;min-height:40px;text-align:center;font-size:14px;line-height:22px}.aioseo-wizard-close-and-exit a{color:#8c8f9a!important}.aioseo-close-and-exit-modal .modal-wrapper .modal-container{max-width:600px}.aioseo-close-and-exit-modal .modal-wrapper .modal-container .modal-header{border-bottom:none;font-size:18px}.aioseo-close-and-exit-modal .aioseo-modal-body{padding:0 30px 30px;display:flex;flex-direction:column;position:relative}.aioseo-close-and-exit-modal .aioseo-modal-body h3{font-size:20px;margin-bottom:16px}.aioseo-close-and-exit-modal .aioseo-modal-body .reset-description{font-size:16px;color:#141b38;margin-bottom:16px;max-width:515px;line-height:24px}[dir=ltr] .aioseo-close-and-exit-modal .aioseo-modal-body .reset-description{text-align:left}[dir=rtl] .aioseo-close-and-exit-modal .aioseo-modal-body .reset-description{text-align:right}.aioseo-close-and-exit-modal .aioseo-modal-body button.close{position:absolute;top:11px;width:24px;height:24px;background-color:#fff;border:none;display:flex;align-items:center}[dir=ltr] .aioseo-close-and-exit-modal .aioseo-modal-body button.close{right:11px}[dir=rtl] .aioseo-close-and-exit-modal .aioseo-modal-body button.close{left:11px}.aioseo-close-and-exit-modal .aioseo-modal-body button.close svg.aioseo-close{cursor:pointer;width:14px;height:14px}.aioseo-close-and-exit-modal .aioseo-modal-body .aioseo-description{max-width:510px;text-align:center}.aioseo-close-and-exit-modal .aioseo-modal-body .aioseo-button:not(.close){margin-top:16px}.aioseo-close-and-exit-modal .aioseo-modal-body div.actions{display:flex;justify-content:flex-end}[dir=ltr] .aioseo-close-and-exit-modal .aioseo-modal-body div.actions a{margin-right:10px}[dir=rtl] .aioseo-close-and-exit-modal .aioseo-modal-body div.actions a{margin-left:10px}
