.aioseo-app .aioseo-sa-image-seo[data-v-bc554ad9]{min-height:650px}.aioseo-app .aioseo-sa-image-seo .aioseo-cta .feature-list[data-v-bc554ad9]{max-width:600px}.aioseo-search-appearance-content-types .icon{display:flex;align-items:center}[dir=ltr] .aioseo-search-appearance-content-types .icon{margin-right:16px}[dir=rtl] .aioseo-search-appearance-content-types .icon{margin-left:16px}.aioseo-search-appearance-content-types .content:empty{display:none}
