.aioseo-wizard-additional-information .schema-graph-name .aioseo-input,.aioseo-wizard-additional-information .schema-graph-contact-type-manual .aioseo-input{max-width:600px}.aioseo-wizard-additional-information .schema-graph-contact-type .aioseo-select{max-width:300px}.aioseo-wizard-additional-information .person-chooser{max-width:600px}.aioseo-wizard-additional-information .person-chooser .person-label{display:flex;align-items:center}.aioseo-wizard-additional-information .person-chooser .person-label .person-avatar{height:30px}[dir=ltr] .aioseo-wizard-additional-information .person-chooser .person-label .person-avatar{margin-right:16px}[dir=rtl] .aioseo-wizard-additional-information .person-chooser .person-label .person-avatar{margin-left:16px}.aioseo-wizard-additional-information .person-chooser .person-label .person-avatar img{height:30px;width:30px;border-radius:50%}.aioseo-wizard-additional-information .go-back a{color:#434960;font-size:14px}.aioseo-wizard-additional-information .social-profiles:not(.show-more) .aioseo-social-profile-list .aioseo-settings-row:nth-child(n+6){display:none}.aioseo-wizard-additional-information .social-profiles:not(.show-more) .show-more-link{display:inline-block}.aioseo-wizard-additional-information .social-profiles:not(.show-more) .same-username .use-same .profiles .aioseo-col:nth-child(n+6){display:none}.aioseo-wizard-additional-information .social-profiles .show-more-link{display:none;margin-top:16px;cursor:pointer;text-decoration:underline}
