.aioseo-app .aioseo-lite-vs-pro{margin-top:var(--aioseo-gutter);width:100%;padding:2px;background:#fff;box-shadow:0 2px 5px #0000000d;border:1px solid #E8E8EB;color:#141b38}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-header,.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-grid,.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-cta{padding:40px}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-header,.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-cta{font-size:14px;background-color:#f9f9fa}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-header{display:flex;justify-content:space-between;align-items:center}[dir=ltr] .aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-header div{margin:0 30px 0 0}[dir=rtl] .aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-header div{margin:0 0 0 30px}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-header div .header-title{font-size:20px;font-weight:700}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-header div .header-text{margin:5px 0}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-header a{width:fit-content;min-width:220px}@media screen and (max-width:782px){.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-header{flex-direction:column;align-items:start}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-header div .header-text{margin:15px 0}}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-grid{font-size:14px}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-grid .header{display:grid;grid-template-columns:1.5fr 1fr 1fr;align-items:end;margin:0 0 24px;font-weight:700}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-grid .header .header-lite,.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-grid .header .header-pro{font-size:18px}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-grid .header .header-pro{color:#00aa63}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-grid .feature{display:grid;grid-template-columns:1.5fr 30px 1fr 30px 1fr}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-grid .feature>div{padding:15px 6px}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-grid .feature svg{margin:15px 0}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-grid .feature svg.aioseo-close{width:13px;height:13px;margin:18px 0;color:#8c8f9a}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-grid .feature svg.aioseo-circle-check{width:18px;height:18px;margin:15px 0;color:#00aa63}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-grid .feature .feature-title{font-weight:700}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-cta{text-align:center}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-cta .cta-title{font-size:18px;font-weight:700}.aioseo-app .aioseo-lite-vs-pro .aioseo-lite-vs-pro-cta .cta-text{margin:24px auto;max-width:650px}
