#wpbody-content{padding-bottom:173px}.aioseo-footer{display:flex;flex-direction:column;align-items:center;padding:20px 0 30px}.aioseo-footer div{margin-top:12px;color:#787c82}.aioseo-footer div:first-of-type{font-weight:600}.aioseo-footer div.social-icons{display:flex;gap:12px}.aioseo-footer div a{color:#005ae0}.aioseo-footer div a:hover{text-decoration:none}.aioseo-footer div span{padding:0 6px}.aioseo-footer div svg{color:#a7aaad}.aioseo-footer div svg.aioseo-facebook,.aioseo-footer div svg.aioseo-linkedin{width:16px;height:16px}.aioseo-footer div svg.aioseo-twitter,.aioseo-footer div svg.aioseo-youtube{width:17px;height:16px}.aioseo-footer div svg:hover{color:#005ae0}
