.aioseo-ai-content-settings .ai-content-description{border-bottom:1px solid #E8E8EB;margin-bottom:20px}.aioseo-ai-content-settings .ai-content-description .description{display:block;margin:0 0 20px;font-size:14px}.aioseo-ai-content-settings .aioseo-settings-row .aioseo-select{max-width:445px}.aioseo-ai-content-settings .aioseo-blur{min-height:650px}
