.aioseo-link-assistant-did-you-know{padding:16px 12px 24px;border-top:1px solid #ddd;display:flex}.aioseo-link-assistant-did-you-know svg.aioseo-circle-information{width:16px;min-width:16px;max-width:16px;height:16px;margin-top:2px}[dir=ltr] .aioseo-link-assistant-did-you-know svg.aioseo-circle-information{margin-right:5px}[dir=rtl] .aioseo-link-assistant-did-you-know svg.aioseo-circle-information{margin-left:5px}.aioseo-link-assistant-did-you-know span{flex:1}.aioseo-link-assistant-did-you-know svg.aioseo-close{margin-top:2px;cursor:pointer;color:#434960;min-width:10px;max-width:10px;width:10px;height:10px}
