<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit140f0a02132e38c544477abd08e06ea9
{
    public static $files = array (
        'bae36830fe54016361e84e8e0ee4aa4e' => __DIR__ . '/..' . '/codeinwp/themeisle-sdk/load.php',
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->classMap = ComposerStaticInit140f0a02132e38c544477abd08e06ea9::$classMap;

        }, null, ClassLoader::class);
    }
}
