<?php
/**
 * Compact field template.
 *
 * This template can be overridden by copying it to yourtheme/wpforms/emails/compact-field.php.
 *
 * @since 1.8.5
 */

?>

<tr class="field-{field_type}">
	<td class="field-name"><strong>{field_name}</strong></td>
	<td class="field-value" valign="middle">{field_value}</td>
</tr>
