.tab-facebook .facebook-image img{margin-top:20px;width:auto;max-width:525px;max-height:525px;height:auto}.tab-facebook .facebook-image.vertical img{max-width:158px;max-height:158px}.tab-facebook .aioseo-alert{margin-bottom:20px}.tab-twitter .twitter-image img{margin-top:20px;width:auto;max-width:525px;max-height:525px;height:auto}.tab-twitter .twitter-image.vertical img{max-width:158px;max-height:158px}.tab-twitter .aioseo-alert{margin-bottom:20px}.open-social-modal{margin:12px 0;border:1px solid #DCDDE1}[dir=ltr] .open-social-modal svg{margin-right:5px}[dir=rtl] .open-social-modal svg{margin-left:5px}.open-social-copy>.col-md-3{display:none}.aioseo-post-social .aioseo-row:has(.no-name){row-gap:0}.aioseo-post-social .aioseo-col.col-md-9{position:relative}.aioseo-post-social .aioseo-tabs{background:#fff!important;border:none!important;border-bottom:2px solid #E8E8EB!important}.aioseo-post-social svg.aioseo-pencil{width:12px;height:12px;color:#434960}[dir=ltr] .aioseo-post-social .aioseo-select .multiselect__tags{padding:9px 40px 9px 16px}[dir=rtl] .aioseo-post-social .aioseo-select .multiselect__tags{padding:9px 16px 9px 40px}.aioseo-modal-content .tab-facebook .aioseo-html-tags-editor .aioseo-description,.aioseo-modal-content .tab-twitter .aioseo-html-tags-editor .aioseo-description{display:none}
