<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Http;

use WPForms\Vendor\Core\Types\Sdk\CoreRequest;
/**
 * Represents a single Http Request
 */
class HttpRequest extends CoreRequest
{
}
