.aioseo-add-redirection-url-results{display:flex;position:absolute;background:#fff;width:100%;max-height:300px;overflow:auto;border:1px solid #D0D1D7;border-radius:3px;z-index:50;margin-top:-9px}[dir=ltr] .aioseo-add-redirection-url-results{left:1px}[dir=rtl] .aioseo-add-redirection-url-results{right:1px}.aioseo-add-redirection-url-results ul{display:inline-block;max-width:100%;list-style:none;padding:0;margin:0;min-width:100%;vertical-align:top}.aioseo-add-redirection-url-results ul li{margin:0;border-bottom:1px solid #E8E8EB;display:block}.aioseo-add-redirection-url-results ul li:last-of-type{border-bottom:none}.aioseo-add-redirection-url-results ul li>span{color:#141b38;font-weight:700;font-size:16px;white-space:normal;line-height:1.4;display:flex;padding:12px;min-height:40px;text-decoration:none;text-transform:none;vertical-align:middle;position:relative;cursor:pointer}.aioseo-add-redirection-url-results ul li>span:hover{background-color:#f2f7fd}.aioseo-add-redirection-url-results ul li>span:hover .option-title{color:#005ae0}.aioseo-add-redirection-url-results .option{flex:1}.aioseo-add-redirection-url-results .option .option-title{font-weight:500;display:flex;font-size:16px;color:#141b38}[dir=ltr] .aioseo-add-redirection-url-results .option .option-title>div{margin-right:5px}[dir=rtl] .aioseo-add-redirection-url-results .option .option-title>div{margin-left:5px}.aioseo-add-redirection-url-results .option .option-title>div:first-of-type{display:inline-block}.aioseo-add-redirection-url-results .option .option-title .search-term{font-weight:700}.aioseo-add-redirection-url-results .option .option-details{display:flex;align-items:center;font-size:14px;color:#8c8f9a}[dir=ltr] .aioseo-add-redirection-url-results .option .option-details span{margin-right:15px}[dir=rtl] .aioseo-add-redirection-url-results .option .option-details span{margin-left:15px}.aioseo-add-redirection-url-results .option-permalink{display:flex;align-items:center}.aioseo-add-redirection-url-results .option-permalink svg.aioseo-external{width:15px;height:15px;color:#434960}.aioseo-add-redirection-target-url,.aioseo-redirect-source-url{position:relative}[dir=ltr] .aioseo-redirect-source-url .aioseo-input input{padding-right:76px!important}[dir=rtl] .aioseo-redirect-source-url .aioseo-input input{padding-left:76px!important}.aioseo-redirect-source-url .aioseo-input .append-icon{width:60px;justify-content:flex-end}.aioseo-redirect-source-url .aioseo-input .append-icon svg{max-width:16px}[dir=ltr] .aioseo-redirect-source-url .aioseo-input .append-icon svg{margin-right:8px}[dir=rtl] .aioseo-redirect-source-url .aioseo-input .append-icon svg{margin-left:8px}[dir=ltr] .aioseo-redirect-source-url .aioseo-input .append-icon svg:last-of-type{margin-right:0}[dir=rtl] .aioseo-redirect-source-url .aioseo-input .append-icon svg:last-of-type{margin-left:0}.aioseo-redirect-source-url .aioseo-input .append-icon svg.aioseo-gear{color:#8c8f9a;cursor:pointer}.aioseo-redirect-source-url .aioseo-input .append-icon svg.aioseo-gear:hover,.aioseo-redirect-source-url .aioseo-input .append-icon svg.aioseo-gear.active{color:#005ae0}.aioseo-redirect-source-url .aioseo-input .append-icon svg.aioseo-circle-check{color:#00aa63}.aioseo-redirect-source-url .aioseo-input .append-icon svg.aioseo-circle-close{color:#df2a4a}.aioseo-redirect-source-url .aioseo-input .append-icon svg.aioseo-trash{color:#8c8f9a;cursor:pointer}.aioseo-redirect-source-url .aioseo-input .append-icon svg.aioseo-trash:hover,.aioseo-redirect-source-url .aioseo-input .append-icon svg.aioseo-trash.active{color:#df2a4a}.aioseo-redirect-source-url .source-url-warning,.aioseo-redirect-source-url .source-url-error{margin-bottom:10px}.aioseo-redirect-source-url .source-url-options{display:flex;flex-wrap:wrap;gap:8px 30px}.aioseo-redirect-source-url .source-url-options[aria-expanded=true]{margin:12px 0}
