.aioseo-loading-bar{display:flex;flex-direction:column;width:100%;gap:12px}.aioseo-loading-bar__bar{position:relative;width:100%;height:10px;background-color:#dcdde1;border-radius:100px;align-items:center;padding:0}.aioseo-loading-bar__progress{transition:width 1.5s ease-in-out;border-radius:100px;background:#005ae0;height:10px;width:0}.aioseo-loading-bar__number{font-size:18px;font-weight:700;text-align:center;color:#005ae0}
