.aioseo-ai-credit-counter--metabox{--counter-font-size: 14px}.aioseo-ai-credit-counter--settings{--counter-font-size: 14px;flex-direction:column!important;align-items:flex-start}.aioseo-ai-credit-counter--settings .counter-container-wrapper{width:100%}.aioseo-ai-credit-counter--settings .purchase-credits{margin-top:0}[dir=ltr] .aioseo-ai-credit-counter--settings .purchase-credits{margin-left:0}[dir=rtl] .aioseo-ai-credit-counter--settings .purchase-credits{margin-right:0}.aioseo-ai-credit-counter{color:#141b38;display:flex;flex-direction:row}.aioseo-ai-credit-counter .counter-container-wrapper{display:grid;grid-template-columns:32px auto;align-items:center}.aioseo-ai-credit-counter svg.aioseo-ai-sparkles{color:#005ae0;width:20px;height:20px}[dir=ltr] .aioseo-ai-credit-counter svg.aioseo-ai-sparkles{margin-right:8px}[dir=rtl] .aioseo-ai-credit-counter svg.aioseo-ai-sparkles{margin-left:8px}.aioseo-ai-credit-counter svg.aioseo-circle-question-mark{width:16px;height:16px;color:#8c8f9a}.aioseo-ai-credit-counter div.counter-container{align-items:center;display:flex;flex-wrap:wrap;line-height:22px;row-gap:4px;column-gap:8px}.aioseo-ai-credit-counter div.counter-container .counter{font-size:var(--counter-font-size, 12px);display:inline-grid;align-items:center;grid-template-columns:auto auto}.aioseo-ai-credit-counter div.counter-container .counter-sidebar .aioseo-tooltip .popper{top:70px!important;transform:unset!important}.aioseo-ai-credit-counter div.counter-container .counter .low-credits{color:#df2a4a}.aioseo-ai-credit-counter div.counter-container .counter span.credit-count{font-weight:700}.aioseo-ai-credit-counter div.counter-container .counter .aioseo-tooltip{cursor:pointer}[dir=ltr] .aioseo-ai-credit-counter div.counter-container .counter .aioseo-tooltip{margin-left:8px}[dir=rtl] .aioseo-ai-credit-counter div.counter-container .counter .aioseo-tooltip{margin-right:8px}.aioseo-ai-credit-counter div.counter-container .counter .aioseo-tooltip hr{border-color:#dcdde1;margin:12px 0}.aioseo-ai-credit-counter div.counter-container .counter .aioseo-tooltip .credit-heading{display:block;font-size:14px;font-weight:700;margin-bottom:8px}.aioseo-ai-credit-counter div.counter-container .counter .aioseo-tooltip .credit-orders{flex-direction:column;gap:8px}.aioseo-ai-credit-counter div.counter-container .counter .aioseo-tooltip .credit-orders .credit-order{display:block;line-height:22px;margin:6px 0}.aioseo-ai-credit-counter div.counter-container .counter .aioseo-tooltip .credit-orders .credit-order:first-of-type{margin-top:8px}.aioseo-ai-credit-counter div.counter-container .counter .aioseo-tooltip .credit-orders .credit-order:last-of-type{margin-bottom:8px}.aioseo-ai-credit-counter div.counter-container .counter .aioseo-tooltip .license-expiration{display:block;margin-top:8px}.aioseo-ai-credit-counter .purchase-credits{font-size:var(--counter-font-size, 12px)}.aioseo-ai-credit-counter .purchase-credits p{margin:8px 0 0}.aioseo-ai-credit-counter .purchase-credits a.buy-credits{font-style:normal;font-weight:700;text-decoration:none}
