.aioseo-table-column{display:flex;flex-direction:column;flex:1;padding:5px;justify-content:center;line-height:22px}.aioseo-table-row{display:flex;flex-direction:row;flex-wrap:wrap;width:100%}.aioseo-table-row.header-row{font-weight:600}
