html,body{margin:0;padding:0;background:#f3f4f5}.aioseo-header{position:initial}.aioseo-container.main-content{min-height:calc(100vh - 263px)}.aioseo-container.main-content .aioseo-card .animated-dannie{display:flex;align-items:center;justify-content:center;height:388px}footer{border-top:1px solid #E8E8EB;color:#999;font-size:13px;margin-top:50px;padding:30px 20px;text-align:center}footer p{margin:0 0 14px;font-size:13px!important}footer ul{display:inline-block;list-style:none;margin:0;padding:0}footer ul li{display:inline-block;margin:0 13px}
