.aioseo-seo-statistics-overview{max-width:1000px;margin:0 auto}.aioseo-seo-statistics-overview .statistics{position:relative}.aioseo-seo-statistics-overview .statistics-title{flex:1 1 auto;display:flex;align-items:center;margin-bottom:14px}.aioseo-seo-statistics-overview .statistics-current{display:flex;align-items:center;font-weight:700;font-size:28px;color:#2c324c;margin-bottom:16px}.aioseo-seo-statistics-overview .statistics-current-total{flex:1 1 auto}.aioseo-seo-statistics-overview .statistics-current-difference{display:flex;align-items:center;font-size:16px}.aioseo-seo-statistics-overview .statistics-current-difference-direction{display:flex}[dir=ltr] .aioseo-seo-statistics-overview .statistics-current-difference-direction{margin-right:9px}[dir=rtl] .aioseo-seo-statistics-overview .statistics-current-difference-direction{margin-left:9px}.aioseo-seo-statistics-overview .statistics-current-difference-direction svg{vertical-align:middle;width:11px;height:6px}.aioseo-seo-statistics-overview .statistics-current-difference--up{color:#00aa63}.aioseo-seo-statistics-overview .statistics-current-difference--down{color:#df2a4a}.aioseo-seo-statistics-overview .statistics .blurred{filter:blur(2px);pointer-events:none;-webkit-user-select:none;user-select:none}.aioseo-seo-statistics-overview.hide-graph .statistics-current-total{max-width:100px}.aioseo-seo-statistics-overview.grid{background-color:#e8e8eb;grid-gap:1px;display:grid}.aioseo-seo-statistics-overview.grid .statistics{background-color:#fff}[dir=ltr] .aioseo-seo-statistics-overview.grid .statistics:nth-child(odd){padding-right:15px}[dir=rtl] .aioseo-seo-statistics-overview.grid .statistics:nth-child(odd){padding-left:15px}[dir=ltr] .aioseo-seo-statistics-overview.grid .statistics:nth-child(2n){padding-left:15px}[dir=rtl] .aioseo-seo-statistics-overview.grid .statistics:nth-child(2n){padding-right:15px}.aioseo-seo-statistics-overview.grid .statistics:nth-child(n+3){padding-top:15px}.aioseo-seo-statistics-overview.grid .statistics:nth-last-child(n+3){padding-bottom:15px}.aioseo-seo-statistics-overview.grid .statistics:nth-child(odd):not(:nth-last-child(2)):after{content:"";position:absolute;bottom:-17px;width:48px;height:32px;background:#fff}[dir=ltr] .aioseo-seo-statistics-overview.grid .statistics:nth-child(odd):not(:nth-last-child(2)):after{right:-25px}[dir=rtl] .aioseo-seo-statistics-overview.grid .statistics:nth-child(odd):not(:nth-last-child(2)):after{left:-25px}.aioseo-seo-statistics-overview.side-by-side{grid-gap:40px;display:grid}.aioseo-seo-statistics-overview.side-by-side .statistics:not(:last-child):after{content:"";position:absolute;bottom:0;width:1px;height:100%;background:#e8e8eb}[dir=ltr] .aioseo-seo-statistics-overview.side-by-side .statistics:not(:last-child):after{right:-20px}[dir=rtl] .aioseo-seo-statistics-overview.side-by-side .statistics:not(:last-child):after{left:-20px}.aioseo-seo-statistics-overview.side-by-side .statistics .statistics-current-total{flex:0 1 auto}[dir=ltr] .aioseo-seo-statistics-overview.side-by-side .statistics .statistics-current-total{margin-right:16px}[dir=rtl] .aioseo-seo-statistics-overview.side-by-side .statistics .statistics-current-total{margin-left:16px}@media(max-width:1024px){.aioseo-seo-statistics-overview.side-by-side{grid-template-columns:repeat(2,1fr)}.aioseo-seo-statistics-overview.side-by-side .statistics:after{display:none}}.aioseo-seo-statistics-overview .aioseo-loading-spinner{inset:0;margin:auto}
