.aioseo-robots-meta .global-robots-settings.aioseo-description{margin-top:16px;font-weight:600}.aioseo-robots-meta .global-robots-settings.aioseo-description>.settings{margin-top:12px;font-weight:400;--aioseo-gutter: 12px;--total-gap-width: calc(3 * var(--aioseo-gutter));--aioseo-col-max-width: calc((100% - var(--total-gap-width)) / 4);display:grid;gap:var(--aioseo-gutter);grid-template-columns:repeat(auto-fill,minmax(max(150px,var(--aioseo-col-max-width)),1fr))}.aioseo-robots-meta .global-robots-settings.aioseo-description>.settings>*{max-width:none}.aioseo-robots-meta .global-robots-settings.aioseo-description>.settings .aioseo-col{max-width:none}.aioseo-robots-meta .global-robots-settings-options{display:flex;gap:12px;margin-top:16px}.aioseo-robots-meta .global-robots-settings-options>.aioseo-description{margin:0}.aioseo-robots-meta .global-robots-settings-options>.aioseo-description .aioseo-input,.aioseo-robots-meta .global-robots-settings-options>.aioseo-description .aioseo-select{min-width:200px;font-weight:400;margin-top:4px}@media screen and (max-width:782px){.aioseo-robots-meta .global-robots-settings-options{display:block}.aioseo-robots-meta .global-robots-settings-options .max-snippet,.aioseo-robots-meta .global-robots-settings-options .max-video-preview{margin-bottom:20px}[dir=ltr] .aioseo-robots-meta .global-robots-settings-options .max-snippet,[dir=ltr] .aioseo-robots-meta .global-robots-settings-options .max-video-preview{margin-right:0}[dir=rtl] .aioseo-robots-meta .global-robots-settings-options .max-snippet,[dir=rtl] .aioseo-robots-meta .global-robots-settings-options .max-video-preview{margin-left:0}.aioseo-robots-meta .global-robots-settings-options>div .aioseo-input,.aioseo-robots-meta .global-robots-settings-options>div .aioseo-select{min-width:100%}}
