.aioseo-html-sitemap-sidebar .block-editor-block-card{align-items:center}.aioseo-html-sitemap-sidebar .block-editor-block-card__title.block-editor-block-card__title{margin:0}.aioseo-html-sitemap-sidebar .sidebar-row{margin-top:16px}.aioseo-html-sitemap-sidebar .sidebar-row .aioseo-sidebar-title{font-weight:500}.aioseo-html-sitemap-sidebar .sidebar-row .aioseo-toggle{display:flex;margin:8px 0;align-items:center}.aioseo-html-sitemap-sidebar .sidebar-row .aioseo-select{margin-bottom:16px}[dir=ltr] .aioseo-html-sitemap-sidebar .sidebar-row .aioseo-tooltip .icon{margin-right:4px}[dir=rtl] .aioseo-html-sitemap-sidebar .sidebar-row .aioseo-tooltip .icon{margin-left:4px}
