.aioseo-add-template-tag{background-color:#fff;display:flex;align-items:center;border-radius:3px;padding:2px 8px;color:#141b38;font-size:12px;line-height:18px;border:1px solid #D0D1D7;cursor:pointer;-webkit-user-select:none;user-select:none;font-weight:600}.aioseo-add-template-tag:hover{background-color:#f3f4f5}.aioseo-add-template-tag svg.aioseo-plus{width:10px;height:10px;color:#005ae0}[dir=ltr] .aioseo-add-template-tag svg.aioseo-plus{margin-right:4px}[dir=rtl] .aioseo-add-template-tag svg.aioseo-plus{margin-left:4px}.aioseo-emoji-picker{position:relative;font-size:0}.aioseo-emoji-picker em-emoji-picker{font-size:initial;--rgb-color: 20, 27, 56;--font-family: inherit;--border-radius: 4px;--shadow: 0px 3px 15px rgb(0 0 0 / 10%);border:1px solid #D0D1D7;height:350px;min-height:400px;max-height:400px;max-width:298px;position:absolute;top:4px;z-index:1001}[dir=ltr] .aioseo-emoji-picker em-emoji-picker{left:0}[dir=rtl] .aioseo-emoji-picker em-emoji-picker{right:0}.aioseo-html-tags-editor .no-access{margin-bottom:20px}.aioseo-html-tags-editor .aioseo-description.tags-description{margin:0 0 12px}.aioseo-html-tags-editor .add-tags{display:flex;align-items:center;margin-bottom:12px;gap:8px}.aioseo-html-tags-editor .add-tags button{height:24px;background:#fff;border-radius:3px;padding:0 3px;line-height:24px;color:#141b38;font-size:14px;border:1px solid #D0D1D7;cursor:pointer;-webkit-user-select:none;user-select:none;font-weight:400}.aioseo-html-tags-editor .add-tags button:hover{background-color:#f3f4f5}.aioseo-html-tags-editor .add-tags a{font-size:12px;line-height:18px;text-decoration:underline}[dir=ltr] .aioseo-html-tags-editor .add-tags a.no-underline{padding-left:10px}[dir=rtl] .aioseo-html-tags-editor .add-tags a.no-underline{padding-right:10px}
