.aioseo-site-score-competitor{position:relative;display:flex;align-items:flex-start;justify-content:center;flex-direction:column}.aioseo-site-score-competitor .aioseo-seo-site-score-score{position:relative;width:100%;max-width:200px}.aioseo-site-score-competitor .aioseo-seo-site-score-score .aioseo-donut-chart-with-legend{flex-direction:column!important;gap:20px;margin-bottom:16px}[dir=ltr] .aioseo-site-score-competitor .aioseo-seo-site-score-score .aioseo-donut-chart-with-legend .chart-right{margin-left:0}[dir=rtl] .aioseo-site-score-competitor .aioseo-seo-site-score-score .aioseo-donut-chart-with-legend .chart-right{margin-right:0}.aioseo-site-score-competitor .refresh-results .aioseo-refresh{width:14px;height:14px}[dir=ltr] .aioseo-site-score-competitor .refresh-results .aioseo-refresh{margin-right:10px}[dir=rtl] .aioseo-site-score-competitor .refresh-results .aioseo-refresh{margin-left:10px}.aioseo-site-score-competitor .mobile-snapshot{width:250px;max-width:100%;margin-top:30px}.aioseo-site-score-competitor .mobile-snapshot-image{position:relative;padding:10px 4px 0;width:100%;height:445px;overflow:hidden;border-radius:35px}.aioseo-site-score-competitor .mobile-snapshot-image__frame{position:absolute;z-index:2;top:0;width:100%;height:100%}[dir=ltr] .aioseo-site-score-competitor .mobile-snapshot-image__frame{left:0}[dir=rtl] .aioseo-site-score-competitor .mobile-snapshot-image__frame{right:0}.aioseo-site-score-competitor .mobile-snapshot-image__content{width:100%;height:auto}.aioseo-site-score-competitor .mobile-snapshot div{font-weight:600;font-size:16px;margin-bottom:10px}.aioseo-analyze-competitor-site .header .aioseo-trash{width:20px;height:20px;color:#8c8f9a;cursor:pointer}[dir=ltr] .aioseo-analyze-competitor-site .header .aioseo-trash{margin-left:14px}[dir=rtl] .aioseo-analyze-competitor-site .header .aioseo-trash{margin-right:14px}.aioseo-analyze-competitor-site .header .aioseo-trash:hover{color:#434960}.aioseo-analyze-competitor-site .aioseo-competitor-results-wrapper{scroll-margin-top:92px}.aioseo-analyze-competitor-site .competitor-results-main{display:flex;flex-direction:row;font-size:16px;align-items:flex-start}.aioseo-analyze-competitor-site .competitor-results-main .competitor-results-body{flex:1;min-width:0}[dir=ltr] .aioseo-analyze-competitor-site .competitor-results-main .competitor-results-body{margin-left:30px}[dir=rtl] .aioseo-analyze-competitor-site .competitor-results-main .competitor-results-body{margin-right:30px}.aioseo-analyze-competitor-site .aioseo-seo-site-score-cta{position:absolute;top:50%;background-color:#fff;padding:20px;border:1px solid #E8E8EB;box-shadow:0 2px 10px #005ae033;color:#141b38;font-size:16px;font-weight:600;width:82%;max-width:500px;text-align:center}[dir=ltr] .aioseo-analyze-competitor-site .aioseo-seo-site-score-cta{left:50%;transform:translate(-50%) translateY(-50%)}[dir=rtl] .aioseo-analyze-competitor-site .aioseo-seo-site-score-cta{right:50%;transform:translate(50%) translateY(-50%)}
