#keyword-rank-tracker-keywords-table table th,#keyword-rank-tracker-keywords-table table td{vertical-align:middle;font-size:13px}#keyword-rank-tracker-keywords-table table td{border:none;position:relative}#keyword-rank-tracker-keywords-table table td.name,#keyword-rank-tracker-keywords-table table td.tracking{line-height:1}#keyword-rank-tracker-keywords-table .btn-view .aioseo-tooltip{margin:0}#keyword-rank-tracker-keywords-table .btn-view .aioseo-tooltip .popper{width:200px}#keyword-rank-tracker-keywords-table .btn-view a,#keyword-rank-tracker-keywords-table .btn-view svg{color:#434960;height:17px;width:17px}#keyword-rank-tracker-keywords-table .btn-view a:hover,#keyword-rank-tracker-keywords-table .btn-view svg:hover{color:#005ae0}#keyword-rank-tracker-keywords-table .btn-view a{display:flex}#keyword-rank-tracker-keywords-table .aioseo-loading-spinner{height:18px;top:50%;transform:translateY(-50%);width:18px}.keyword-rank-tracker-container[data-v-bf6a422d]{display:flex;flex-direction:column;gap:20px}.keyword-rank-tracker-container__card[data-v-bf6a422d]{border:1px solid #D0D1D7;padding:0 0 18px}.keyword-rank-tracker-container__card__header[data-v-bf6a422d]{align-items:center;background-color:#f3f4f5;display:flex;font-size:16px;font-weight:600;line-height:normal;padding:14px 16px}.keyword-rank-tracker-container__card__body[data-v-bf6a422d]{height:var(--adb54240)}.keyword-rank-tracker-container .aioseo-alert[data-v-bf6a422d]{display:grid;gap:10px}.keyword-rank-tracker-container .aioseo-alert a[data-v-bf6a422d],.keyword-rank-tracker-container .aioseo-alert button[data-v-bf6a422d]{pointer-events:all}.keyword-rank-tracker-main{color:#141b38}.keyword-rank-tracker-main__body{padding:20px}.keyword-rank-tracker-main__body--disable-click a,.keyword-rank-tracker-main__body--disable-click button,.keyword-rank-tracker-main__body--disable-click label,.keyword-rank-tracker-main__body--disable-click input[type=button],.keyword-rank-tracker-main__body--disable-click input[type=submit]{pointer-events:none}
