.aioseo-core-reset-settings .reset-success{margin-bottom:16px}.aioseo-core-reset-settings .reset-settings{margin-top:0;font-size:16px;color:#141b38}.aioseo-core-reset-settings .reset-settings>.settings>.aioseo-col:first-child{font-weight:600;padding-bottom:12px;border-bottom:1px solid #E8E8EB}.aioseo-core-reset-settings .reset-settings .aioseo-button{margin-top:16px}.aioseo-core-reset-settings-modal .aioseo-modal-body{padding:20px 40px 40px;display:flex;align-items:center;justify-content:center;flex-direction:column;position:relative}.aioseo-core-reset-settings-modal .aioseo-modal-body h3{font-size:20px;margin-bottom:16px}.aioseo-core-reset-settings-modal .aioseo-modal-body .reset-description{font-size:16px;color:#141b38;margin-bottom:16px;text-align:center;max-width:515px}.aioseo-core-reset-settings-modal .aioseo-modal-body button.close{position:absolute;top:11px;width:24px;height:24px;background-color:#fff;border:none;display:flex;align-items:center}[dir=ltr] .aioseo-core-reset-settings-modal .aioseo-modal-body button.close{right:11px}[dir=rtl] .aioseo-core-reset-settings-modal .aioseo-modal-body button.close{left:11px}.aioseo-core-reset-settings-modal .aioseo-modal-body button.close svg.aioseo-close{cursor:pointer;width:14px;height:14px}.aioseo-core-reset-settings-modal .aioseo-modal-body .aioseo-description{max-width:510px;text-align:center}.aioseo-core-reset-settings-modal .aioseo-modal-body .aioseo-button:not(.close){margin-top:16px}.aioseo-tools-database-tools-lite .aioseo-card .content{padding-bottom:120px}
