.aioseo-toc-header{width:100%;position:relative}.aioseo-toc-header:has(.aioseo-toc-header-area){flex-direction:column;align-items:flex-start}.aioseo-toc-header .aioseo-toc-header-title{align-items:center;color:#434960;display:flex;flex:1 0 auto;font-size:24px;font-weight:700;line-height:125%;max-width:100%;gap:8px}.aioseo-toc-header .aioseo-toc-header-title .aioseo-toc-header-collapsible{display:flex;border-radius:2px;cursor:pointer;transition:transform .3s ease;background-color:#e5f0ff;box-sizing:border-box;justify-content:center;align-items:center}[dir=ltr] .aioseo-toc-header .aioseo-toc-header-title .aioseo-toc-header-collapsible{padding:8px 0 8px 10px}[dir=rtl] .aioseo-toc-header .aioseo-toc-header-title .aioseo-toc-header-collapsible{padding:8px 10px 8px 0}.aioseo-toc-header .aioseo-toc-header-title .aioseo-toc-header-collapsible svg{width:14px;height:14px}[dir=ltr] .aioseo-toc-header .aioseo-toc-header-title .aioseo-toc-header-collapsible svg{margin-right:10px}[dir=rtl] .aioseo-toc-header .aioseo-toc-header-title .aioseo-toc-header-collapsible svg{margin-left:10px}.aioseo-toc-header .aioseo-toc-header-instructions{color:#2c324c;font-size:16px;margin-bottom:0;margin-top:16px}.aioseo-toc-header .aioseo-toc-header-buttons{flex:0 1 auto}.aioseo-toc-contents{transition:transform .3s ease,opacity .3s ease;transform-origin:top;display:block;opacity:1;transform:scaleY(1);padding-top:12px}.aioseo-toc-collapsed{opacity:0;transform:scaleY(0);height:0;overflow:hidden}
