.aioseo-exclude-posts{display:block}.aioseo-exclude-posts .aioseo-select{max-width:600px;display:inline-block}[dir=ltr] .aioseo-exclude-posts .aioseo-select{margin-right:16px}[dir=rtl] .aioseo-exclude-posts .aioseo-select{margin-left:16px}.aioseo-exclude-posts .aioseo-select button{display:none}.aioseo-exclude-posts .aioseo-select .multiselect__option{display:flex}.aioseo-exclude-posts .aioseo-select .multiselect__option--highlight .option-title{color:#005ae0}.aioseo-exclude-posts .aioseo-button.gray{margin-top:10px}.aioseo-exclude-posts .option{flex:1 0 auto}.aioseo-exclude-posts .option .option-title{font-weight:400;font-size:16px;color:#141b38}.aioseo-exclude-posts .option .option-title .search-term{font-weight:600}.aioseo-exclude-posts .option .option-details{display:flex;align-items:center;font-size:14px;color:#8c8f9a}[dir=ltr] .aioseo-exclude-posts .option .option-details span{margin-right:15px}[dir=rtl] .aioseo-exclude-posts .option .option-details span{margin-left:15px}.aioseo-exclude-posts .option-permalink{display:flex;align-items:center}.aioseo-exclude-posts .option-permalink svg.aioseo-external{width:15px;height:15px;color:#434960}.aioseo-exclude-posts .multiselect-toggle{padding:10px 13px;width:40px;position:absolute;height:36px;top:2px;text-align:center;z-index:1}[dir=ltr] .aioseo-exclude-posts .multiselect-toggle{right:2px}[dir=rtl] .aioseo-exclude-posts .multiselect-toggle{left:2px}.aioseo-exclude-posts .multiselect-toggle svg.aioseo-add-plus{width:14px;height:14px;color:#000}.aioseo-sidebar-row .aioseo-included-objects-toggle{margin-top:5px}.aioseo-sidebar-row .aioseo-included-objects-toggle .aioseo-included-list{margin-top:8px}
