.aioseo-priority-score{max-width:350px}.aioseo-priority-score .header-row{font-size:14px}.aioseo-general-sitemap .aioseo-links-per-site{max-width:110px}.aioseo-general-sitemap .aioseo-sitemap-preview{display:flex;align-items:center;margin-bottom:10px}[dir=ltr] .aioseo-general-sitemap .aioseo-sitemap-preview{margin-right:10px}[dir=rtl] .aioseo-general-sitemap .aioseo-sitemap-preview{margin-left:10px}.aioseo-general-sitemap .aioseo-sitemap-preview .aioseo-select{max-width:180px}[dir=ltr] .aioseo-general-sitemap .aioseo-sitemap-preview .aioseo-select{margin-right:16px}[dir=rtl] .aioseo-general-sitemap .aioseo-sitemap-preview .aioseo-select{margin-left:16px}.aioseo-general-sitemap .aioseo-sitemap-preview svg.aioseo-external{width:14px;height:14px}[dir=ltr] .aioseo-general-sitemap .aioseo-sitemap-preview svg.aioseo-external{margin-right:10px}[dir=rtl] .aioseo-general-sitemap .aioseo-sitemap-preview svg.aioseo-external{margin-left:10px}[dir=ltr] .aioseo-general-sitemap .ping>div:first-child{margin-right:40px}[dir=rtl] .aioseo-general-sitemap .ping>div:first-child{margin-left:40px}.aioseo-general-sitemap .aioseo-priority-score{max-width:500px}.aioseo-general-sitemap .aioseo-priority-score .header-row{font-size:14px}
