.aioseo-api-bar{display:flex;align-items:center;height:40px;background-color:#df2a4a;justify-content:center;color:#fff;font-size:13px}[dir=ltr] .aioseo-api-bar{padding:0 14px 0 40px}[dir=rtl] .aioseo-api-bar{padding:0 40px 0 14px}.aioseo-api-bar .upgrade-text{display:flex;align-items:center;flex:1;justify-content:center}.aioseo-api-bar strong{font-weight:600}.aioseo-api-bar svg.aioseo-logo-gear{width:20px;height:20px;min-width:20px}[dir=ltr] .aioseo-api-bar svg.aioseo-logo-gear{margin-right:14px}[dir=rtl] .aioseo-api-bar svg.aioseo-logo-gear{margin-left:14px}.aioseo-api-bar svg.aioseo-close{cursor:pointer;width:12px;height:12px}.aioseo-api-bar a{color:#fff;text-decoration:underline}.aioseo-api-bar a:hover{text-decoration:none}@media screen and (max-width:782px){.aioseo-api-bar{padding:0 10px;height:60px}}
