<?php

namespace WPForms\Vendor\Stripe\Exception\OAuth;

/**
 * InvalidScopeException is thrown when an invalid scope parameter is provided.
 */
class InvalidScopeException extends OAuthErrorException
{
}
