.aioseo-wizard-search-console{color:#141b38}.aioseo-wizard-search-console__panel{background-color:#f0f6ff;padding:40px;border-radius:4px}@media(max-width:768px){.aioseo-wizard-search-console__panel{flex-direction:column;gap:20px}}.aioseo-wizard-search-console__image,.aioseo-wizard-search-console__content{max-width:450px;margin:0 auto}.aioseo-wizard-search-console__image svg,.aioseo-wizard-search-console__content svg{width:100%}.aioseo-wizard-search-console__image{margin-bottom:20px}.aioseo-wizard-search-console__content-text{margin-bottom:16px;font-size:14px;font-weight:400;line-height:22px}.aioseo-wizard-search-console__content-list{display:grid;grid-template-columns:repeat(2,1fr);gap:10px;margin:0}.aioseo-wizard-search-console__content-list li{display:flex;align-items:flex-start}.aioseo-wizard-search-console__content-list .aioseo-circle-check{color:#00aa63;max-width:24px}[dir=ltr] .aioseo-wizard-search-console__content-list .aioseo-circle-check{margin-right:8px}[dir=rtl] .aioseo-wizard-search-console__content-list .aioseo-circle-check{margin-left:8px}.aioseo-wizard-search-console .go-back a{color:#434960;font-size:14px}
