.aioseo-setup-wizard-container{margin-block:var(--aioseo-gutter);padding:calc(var(--aioseo-gutter) * 2);color:#fff;position:relative;background-color:#005ae0}.aioseo-setup-wizard-container p{color:#fff}.aioseo-setup-wizard-container .getting-started-wrapper{position:relative;display:flex;justify-content:space-between;align-items:center;gap:20px}.aioseo-setup-wizard-container .getting-started-wrapper .text{max-width:534px}.aioseo-setup-wizard-container .getting-started-wrapper .video{flex:0 0 533px}.aioseo-setup-wizard-container .getting-started-wrapper .video .wrapper{padding-bottom:56.25%;margin-bottom:0;position:relative;height:0}.aioseo-setup-wizard-container .getting-started-wrapper .video .wrapper iframe{width:100%;height:100%;position:absolute;top:0}[dir=ltr] .aioseo-setup-wizard-container .getting-started-wrapper .video .wrapper iframe{left:0}[dir=rtl] .aioseo-setup-wizard-container .getting-started-wrapper .video .wrapper iframe{right:0}@media only screen and (max-width:1350px){.aioseo-setup-wizard-container .getting-started-wrapper .video{flex:0 0 593px;margin:20px;align-self:center}.aioseo-setup-wizard-container .getting-started-wrapper .video .wrapper{margin-bottom:0}.aioseo-setup-wizard-container .getting-started-wrapper .wizard-actions .aioseo-col{flex-basis:100%;max-width:100%;justify-content:center}}@media only screen and (max-width:1300px){.aioseo-setup-wizard-container .getting-started-wrapper{flex-direction:row;flex-wrap:wrap}.aioseo-setup-wizard-container .getting-started-wrapper .video{margin:0}.aioseo-setup-wizard-container .getting-started-wrapper .video,.aioseo-setup-wizard-container .getting-started-wrapper .text{flex-basis:100%;width:100%}.aioseo-setup-wizard-container .getting-started-wrapper .wizard-actions{justify-content:center}.aioseo-setup-wizard-container .getting-started-wrapper .wizard-actions .aioseo-col{flex-basis:inherit;max-width:inherit;justify-content:center}}@media only screen and (max-width:782px){.aioseo-setup-wizard-container .getting-started-wrapper .wizard-actions .aioseo-col{flex-basis:100%;max-width:100%;justify-content:center}}.aioseo-setup-wizard-container .aioseo-row{position:relative;z-index:1}.aioseo-setup-wizard-container .wizard-actions .aioseo-col{display:flex;align-items:center}.aioseo-setup-wizard-container .wizard-actions .aioseo-col:first-child{flex-basis:auto}.aioseo-setup-wizard-container .wizard-actions .aioseo-button{height:40px;font-size:14px;padding:0 16px}.aioseo-setup-wizard-container .wizard-actions .aioseo-button svg{width:14px;height:14px}[dir=ltr] .aioseo-setup-wizard-container .wizard-actions .aioseo-button svg{margin-right:10px}[dir=rtl] .aioseo-setup-wizard-container .wizard-actions .aioseo-button svg{margin-left:10px}.aioseo-setup-wizard-container .setup-wizard-bg{width:100%;height:100%;overflow:hidden;z-index:0;position:absolute;top:0}[dir=ltr] .aioseo-setup-wizard-container .setup-wizard-bg{left:0}[dir=rtl] .aioseo-setup-wizard-container .setup-wizard-bg{right:0}.aioseo-setup-wizard-container .setup-wizard-bg svg.aioseo-setup-wizard-bg{width:auto;height:100%}.aioseo-setup-wizard-container .setup-wizard-bg svg.aioseo-setup-wizard-bg rect{width:auto;height:100%}.aioseo-setup-wizard-container .close-wizard{color:#fff;width:20px;height:20px;position:absolute;top:20px;z-index:1;display:flex;align-items:center;justify-content:center}[dir=ltr] .aioseo-setup-wizard-container .close-wizard{right:20px}[dir=rtl] .aioseo-setup-wizard-container .close-wizard{left:20px}.aioseo-setup-wizard-container .close-wizard:hover{color:#ccc}.aioseo-setup-wizard-container .close-wizard svg.aioseo-close{width:12px;height:12px;cursor:pointer;color:#fff}.aioseo-setup-wizard-container .close-wizard svg.aioseo-close:hover{color:#dadada}.aioseo-setup-wizard-container p.how-to-get-started{font-size:16px;line-height:24px;margin:0}.aioseo-setup-wizard-container p.welcome-text{font-size:14px;line-height:24px;margin:0 0 32px}.aioseo-setup-wizard-container h2{color:#fff;font-size:28px;line-height:40px;margin-bottom:16px}.aioseo-setup-wizard-container a{color:#fff}.aioseo-setup-wizard-container svg.aioseo-book{width:16px;height:16px}[dir=ltr] .aioseo-setup-wizard-container svg.aioseo-book{margin:0 8px 0 0}[dir=rtl] .aioseo-setup-wizard-container svg.aioseo-book{margin:0 0 0 8px}.aioseo-setup-wizard-container .getting-started-video{margin-bottom:-60px;position:relative;height:0;padding-bottom:56.25%}[dir=ltr] .aioseo-setup-wizard-container .getting-started-video{padding-right:20px}[dir=rtl] .aioseo-setup-wizard-container .getting-started-video{padding-left:20px}.aioseo-setup-wizard-container .getting-started-video iframe{width:100%;height:100%;position:absolute;top:0}[dir=ltr] .aioseo-setup-wizard-container .getting-started-video iframe{left:0}[dir=rtl] .aioseo-setup-wizard-container .getting-started-video iframe{right:0}
