.aioseo-app .aioseo-cta .aioseo-cta-background .description .aioseo-alert.aioseo-required-plans,#aioseo-user-profile-tab .aioseo-cta .aioseo-cta-background .description .aioseo-alert.aioseo-required-plans{text-align:center}
