.aioseo-modal{--aioseo-modal-z-index: 9998}.aioseo-modal .modal-mask{position:fixed;z-index:var(--aioseo-modal-z-index);top:0;width:100%;height:100%;background-color:#0020504d;transition:opacity .3s ease;-webkit-backdrop-filter:blur(1.5px);backdrop-filter:blur(1.5px);pointer-events:none}[dir=ltr] .aioseo-modal .modal-mask{left:0}[dir=rtl] .aioseo-modal .modal-mask{right:0}@media screen and (max-width:520px){.aioseo-modal .modal-mask{display:block;top:46px}}.aioseo-modal .modal-wrapper{position:fixed;z-index:var(--aioseo-modal-z-index);top:0;width:100%;height:100%;pointer-events:auto;display:flex;align-items:center;justify-content:center;align-content:center;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif}[dir=ltr] .aioseo-modal .modal-wrapper{left:0}[dir=rtl] .aioseo-modal .modal-wrapper{right:0}@media screen and (max-width:520px){.aioseo-modal .modal-wrapper{display:block;height:100%}}.aioseo-modal .modal-wrapper .modal-container{width:100%;max-width:840px;overflow-y:hidden;overflow-x:hidden;margin:0 auto;background-color:#fff;box-shadow:0 10px 30px #00000026;transition:all .3s ease}@media screen and (max-width:520px){.aioseo-modal .modal-wrapper .modal-container{width:100%;max-width:100%;max-height:calc(100vh - 46px);height:100%}}.aioseo-modal .modal-wrapper .modal-container .modal-header{color:#141b38;position:relative;top:0;z-index:15;height:56px;font-size:18px;font-weight:600;line-height:1.4;border-bottom:1px solid #E8E8EB;background-color:#fff;display:flex;align-items:center}[dir=ltr] .aioseo-modal .modal-wrapper .modal-container .modal-header{padding:0 0 0 var(--aioseo-gutter)}[dir=rtl] .aioseo-modal .modal-wrapper .modal-container .modal-header{padding:0 var(--aioseo-gutter) 0 0}@media screen and (max-width:520px){[dir=ltr] .aioseo-modal .modal-wrapper .modal-container .modal-header{padding:15px 0 0 20px}[dir=rtl] .aioseo-modal .modal-wrapper .modal-container .modal-header{padding:15px 20px 0 0}}.aioseo-modal .modal-wrapper .modal-container .modal-header button.close{background-color:#fff;color:#141b38;border:none;cursor:pointer;line-height:14px;margin:0;opacity:1;outline:none;padding:0;position:absolute;top:50%;transform:translateY(-50%);width:14px;height:14px}[dir=ltr] .aioseo-modal .modal-wrapper .modal-container .modal-header button.close{right:20px}[dir=rtl] .aioseo-modal .modal-wrapper .modal-container .modal-header button.close{left:20px}.aioseo-modal .modal-wrapper .modal-container .modal-header button.close:focus{outline:1px solid #005AE0;outline-offset:2px}.aioseo-modal .modal-wrapper .modal-container .modal-header button.close svg.aioseo-close{width:inherit;height:inherit}.aioseo-modal .modal-wrapper .modal-container .modal-body{overflow-y:auto;overflow-x:hidden;max-height:75vh;padding:0;position:relative}.aioseo-modal .modal-wrapper .modal-container .modal-body .aioseo-modal-content.has-padding{padding:40px}.aioseo-modal .modal-wrapper .modal-container .modal-body.allow-overflow{overflow:visible}.aioseo-modal .modal-wrapper .modal-container .modal-container__footer{border-top:1px solid #E8E8EB}@media screen and (max-width:520px){.aioseo-modal .modal-wrapper .modal-container .modal-body,.aioseo-modal .modal-wrapper .modal-container .modal-body>div,.aioseo-modal .modal-wrapper .modal-container .aioseo-modal-content,.aioseo-modal .modal-wrapper .modal-container .aioseo-modal-content>.component-wrapper{height:100%}.aioseo-modal .modal-wrapper .modal-container .aioseo-modal-content>.component-wrapper{display:flex;align-items:flex-end}.aioseo-modal .modal-wrapper .modal-container .aioseo-post-social,.aioseo-modal .modal-wrapper .modal-container .aioseo-post-general{height:100%!important;max-height:100%!important}.aioseo-modal .modal-wrapper .modal-container .aioseo-post-social .mobile-radio-buttons,.aioseo-modal .modal-wrapper .modal-container .aioseo-post-general .mobile-radio-buttons{margin-bottom:0}.aioseo-modal .modal-wrapper .modal-container .aioseo-add-template-tag{display:none}.aioseo-modal .modal-wrapper .modal-container .tab-facebook .aioseo-settings-row:last-of-type,.aioseo-modal .modal-wrapper .modal-container .tab-twitter .aioseo-settings-row:last-of-type{margin-bottom:64px!important;padding-bottom:32px!important}}.aioseo-modal.allow-overflow .modal-container,.aioseo-modal.allow-overflow .modal-container .modal-body{overflow:visible}.modal-background-enter-active,.modal-background-leave-active{transition:opacity .3s ease}.modal-background-enter-from,.modal-background-leave-to{opacity:0}.modal-content-enter-active{transition:all .3s cubic-bezier(.52,.02,.19,1.02) .05s}.modal-content-leave-active{transition:all .3s cubic-bezier(.52,.02,.19,1.02)}.modal-content-enter-from,.modal-content-leave-to{opacity:0;transform:scale(.8)}
