.loading-container[data-v-db3edc20]{display:flex;justify-content:center;align-items:center;width:100%;min-height:100px}[dir=ltr] .var-tab>.label[data-v-db3edc20]{padding-left:8px}[dir=rtl] .var-tab>.label[data-v-db3edc20]{padding-right:8px}.var-tab>.icon[data-v-db3edc20]{width:16px;height:16px}.var-tab>.icon.green[data-v-db3edc20]{color:#00aa63}.var-tab>.icon.orange[data-v-db3edc20]{color:#f18200}.var-tab>.icon.red[data-v-db3edc20]{color:#df2a4a}.aioseo-seo-audit-checklist .content>.aioseo-seo-site-score{display:flex;justify-content:center;min-height:440px}.aioseo-seo-audit-checklist .round{position:relative;border-radius:50%;width:24px;min-width:24px;max-width:24px;height:24px;line-height:24px;display:inline-flex;align-items:center;justify-content:center;font-size:12px;color:#fff;font-weight:600}[dir=ltr] .aioseo-seo-audit-checklist .round{margin-right:10px}[dir=rtl] .aioseo-seo-audit-checklist .round{margin-left:10px}.aioseo-seo-audit-checklist .round.red{background-color:#df2a4a}.aioseo-seo-audit-checklist .round.blue{background-color:#005ae0}.aioseo-seo-audit-checklist .round.dark-blue{background-color:#004f9d}.aioseo-seo-audit-checklist .round.orange{background-color:#f18200}.aioseo-seo-audit-checklist .round.green{background-color:#00aa63}.aioseo-seo-audit-checklist .round.black{background-color:#434960}.aioseo-seo-audit-checklist .round.gray{background-color:#8c8f9a}.aioseo-seo-audit-checklist .aioseo-card .header-title{display:inline-flex;flex:1}[dir=ltr] .aioseo-seo-audit-checklist .aioseo-card .header-extra .refresh-results{margin-right:10px}[dir=rtl] .aioseo-seo-audit-checklist .aioseo-card .header-extra .refresh-results{margin-left:10px}.aioseo-seo-audit-checklist .aioseo-card .header-extra .refresh-results .aioseo-refresh{width:14px;height:14px}[dir=ltr] .aioseo-seo-audit-checklist .aioseo-card .header-extra .refresh-results .aioseo-refresh{margin-right:10px}[dir=rtl] .aioseo-seo-audit-checklist .aioseo-card .header-extra .refresh-results .aioseo-refresh{margin-left:10px}
