<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models;

/**
 * Standard ingredients for food and beverage items that are recommended on item creation.
 */
class CatalogItemFoodAndBeverageDetailsIngredientStandardIngredient
{
    public const CELERY = 'CELERY';
    public const CRUSTACEANS = 'CRUSTACEANS';
    public const EGGS = 'EGGS';
    public const FISH = 'FISH';
    public const GLUTEN = 'GLUTEN';
    public const LUPIN = 'LUPIN';
    public const MILK = 'MILK';
    public const MOLLUSCS = 'MOLLUSCS';
    public const MUSTARD = 'MUSTARD';
    public const PEANUTS = 'PEANUTS';
    public const SESAME = 'SESAME';
    public const SOY = 'SOY';
    public const SULPHITES = 'SULPHITES';
    public const TREE_NUTS = 'TREE_NUTS';
}
