.aioseo-wizard-features .feature-grid{border-bottom:1px solid #E8E8EB;padding-bottom:16px;margin-bottom:16px}.aioseo-wizard-features .feature-grid:last-child{border-bottom:none;padding-bottom:0;margin-bottom:0}.aioseo-wizard-features .feature-grid .settings-name{color:#141b38}.aioseo-wizard-features .feature-grid .settings-name .name{display:flex;align-items:center;font-weight:600}[dir=ltr] .aioseo-wizard-features .feature-grid .settings-name .name .aioseo-pro-badge{margin-left:12px}[dir=rtl] .aioseo-wizard-features .feature-grid .settings-name .name .aioseo-pro-badge{margin-right:12px}.aioseo-wizard-features .feature-grid .settings-name .name+.aioseo-description-text{margin-top:8px}.aioseo-wizard-features .feature-grid .settings-name .aioseo-description-text{max-width:650px;color:#434960}.aioseo-wizard-features .feature-grid .settings-name .aioseo-installs-text{font-style:italic;margin-top:5px;font-size:12px;color:#434960}.aioseo-wizard-features .plugins{font-style:italic;max-width:650px;margin:16px auto 0;font-size:12px;text-align:center;color:#8c8f9a;line-height:1.5}.aioseo-wizard-features .go-back a{color:#434960;font-size:14px}
