#aioseo-limit-modified-date>div{display:flex;align-items:center;gap:4px}#aioseo-limit-modified-date>div .components-checkbox-control__input-container--block-editor{height:20px;width:20px;position:relative}[dir=ltr] #aioseo-limit-modified-date>div .components-checkbox-control__input-container--block-editor{margin-right:8px}[dir=rtl] #aioseo-limit-modified-date>div .components-checkbox-control__input-container--block-editor{margin-left:8px}#aioseo-limit-modified-date>div .components-checkbox-control__input-container--block-editor input{height:20px;width:20px}#aioseo-limit-modified-date>div .components-checkbox-control__input-container--block-editor input[type=checkbox]{border-radius:2px}#aioseo-limit-modified-date>div .components-checkbox-control__input-container--block-editor input[type=checkbox]:checked{background:#007cba}#aioseo-limit-modified-date>div .components-checkbox-control__input-container--block-editor input[type=checkbox]:focus{box-shadow:0 0 0 2px #fff,0 0 0 4px #007cba}#aioseo-limit-modified-date>div label{max-width:100%}
