.aioseo-graph{position:relative}.aioseo-graph .apexcharts-legend{padding:0;inset:auto 0 0!important}.aioseo-graph .apexcharts-point-annotations{cursor:pointer}.aioseo-graph .apexcharts-point-annotations text,.aioseo-graph .apexcharts-point-annotations rect{pointer-events:none}.aioseo-graph .apexcharts-point-annotations .active-point{stroke:#005ae0;fill:#f0f6ff}.aioseo-graph .apexcharts-point-annotations .marker-circle{pointer-events:none}.aioseo-graph .aioseo-loading-spinner{inset:0;margin:auto}.aioseo-graph-blurred{filter:blur(2px);pointer-events:none;-webkit-user-select:none;user-select:none}.aioseo-graph-legend-simple .apexcharts-legend{display:flex;flex-direction:row;gap:12px}.aioseo-graph-legend-simple .apexcharts-legend-marker{width:12px!important;height:12px!important}[dir=ltr] .aioseo-graph-legend-simple .apexcharts-legend-marker{margin-right:8px}[dir=rtl] .aioseo-graph-legend-simple .apexcharts-legend-marker{margin-left:8px}.aioseo-graph-legend-custom .apexcharts-legend{display:grid;grid-column-gap:16px;grid-row-gap:16px;overflow-y:hidden}.aioseo-graph-legend-custom .apexcharts-legend-series{border:1px solid #005AE0;border-radius:2px;position:relative;margin:0}[dir=ltr] .aioseo-graph-legend-custom .apexcharts-legend-series{padding:8px 8px 8px 32px}[dir=rtl] .aioseo-graph-legend-custom .apexcharts-legend-series{padding:8px 32px 8px 8px}.aioseo-graph-legend-custom .apexcharts-legend-series.apexcharts-inactive-legend{opacity:1;border-color:#d0d1d7}.aioseo-graph-legend-custom .apexcharts-legend-series .apexcharts-legend-text{display:inline-flex;line-height:125%;font-size:14px;color:#2c324c}.aioseo-graph-legend-custom .apexcharts-legend-series .apexcharts-legend-text strong{font-size:16px;color:#141b38}[dir=ltr] .aioseo-graph-legend-custom .apexcharts-legend-series .apexcharts-legend-text strong{margin-right:8px}[dir=rtl] .aioseo-graph-legend-custom .apexcharts-legend-series .apexcharts-legend-text strong{margin-left:8px}.aioseo-graph-legend-custom .apexcharts-legend-marker .marker-checkbox{position:absolute;cursor:pointer;top:0;width:16px;height:16px;background-color:#005ae0;transition:.2s;border-radius:3px;display:flex;align-items:center;justify-content:center}[dir=ltr] .aioseo-graph-legend-custom .apexcharts-legend-marker .marker-checkbox{left:-24px}[dir=rtl] .aioseo-graph-legend-custom .apexcharts-legend-marker .marker-checkbox{right:-24px}.aioseo-graph-legend-custom .apexcharts-legend-marker .marker-checkbox:before{position:absolute;content:"";height:14px;width:14px;bottom:1px;transition:.2s;font-size:18px;line-height:28px;border-radius:2px}.aioseo-graph-legend-custom .apexcharts-legend-marker .marker-checkbox svg{color:#fff;width:12px;height:12px}.aioseo-graph-legend-custom .apexcharts-legend-marker.apexcharts-inactive-legend{opacity:1}.aioseo-graph-legend-custom .apexcharts-legend-marker.apexcharts-inactive-legend .marker-checkbox{background-color:#d0d1d7}.aioseo-graph-legend-custom .apexcharts-legend-marker.apexcharts-inactive-legend .marker-checkbox:before{background-color:#fff}.aioseo-graph-legend-custom .apexcharts-legend-text{position:absolute;padding-top:8px;padding-bottom:8px;width:100%}[dir=ltr] .aioseo-graph-legend-custom .apexcharts-legend-text{left:0;padding-left:72px;padding-right:8px}[dir=rtl] .aioseo-graph-legend-custom .apexcharts-legend-text{right:0;padding-right:72px;padding-left:8px}.aioseo-graph-legend-custom .apexcharts-legend-text strong{display:inline-block;font-size:16px;vertical-align:middle}[dir=ltr] .aioseo-graph-legend-custom .apexcharts-legend-text strong{margin-right:4px}[dir=rtl] .aioseo-graph-legend-custom .apexcharts-legend-text strong{margin-left:4px}.aioseo-graph-legend-columns-4 .apexcharts-legend{grid-template-columns:repeat(4,1fr)}.aioseo-graph-legend-columns-3 .apexcharts-legend{grid-template-columns:repeat(3,1fr)}
