.aioseo-progress-circle__circle{transform-origin:center;stroke:#005ae0}[dir=ltr] .aioseo-progress-circle__circle{transform:rotate(270deg)}[dir=rtl] .aioseo-progress-circle__circle{transform:rotate(-270deg)}.aioseo-progress-circle__background{stroke:#005ae040}.aioseo-seo-setup{display:flex;flex-direction:row;align-items:center}.aioseo-seo-setup .progress{display:inline-flex;align-items:center;line-height:1;border:1px solid #C3C4C7;border-radius:100px;margin-bottom:20px;color:#141b38}[dir=ltr] .aioseo-seo-setup .progress{padding:8px 14px 8px 8px}[dir=rtl] .aioseo-seo-setup .progress{padding:8px 8px 8px 14px}.aioseo-seo-setup .progress .aioseo-progress-circle{width:18px}[dir=ltr] .aioseo-seo-setup .progress .aioseo-progress-circle{margin-right:8px}[dir=rtl] .aioseo-seo-setup .progress .aioseo-progress-circle{margin-left:8px}.aioseo-seo-setup .aioseo-button{font-size:12px;height:32px}.aioseo-seo-setup .aioseo-button svg{width:14px;height:14px}[dir=ltr] .aioseo-seo-setup .aioseo-button svg{margin-right:10px}[dir=rtl] .aioseo-seo-setup .aioseo-button svg{margin-left:10px}.aioseo-seo-setup .description{font-size:14px;margin-bottom:20px;color:#434960}.aioseo-seo-setup .aioseo-seo{max-width:300px;min-width:275px;width:100%;height:auto}@media screen and (max-width:1280px){.aioseo-seo-setup .aioseo-seo{min-width:0}}@media screen and (max-width:912px){.aioseo-seo-setup{flex-direction:column}}.aioseo-seo-setup--wp-styles .progress{margin-bottom:12px}.aioseo-seo-setup--wp-styles .description{color:#3c434a;margin-bottom:12px}.aioseo-seo-setup--wp-styles .button svg{vertical-align:text-bottom;width:14px;height:14px}[dir=ltr] .aioseo-seo-setup--wp-styles .button svg{margin-right:10px}[dir=rtl] .aioseo-seo-setup--wp-styles .button svg{margin-left:10px}.aioseo-seo-setup--wp-styles .aioseo-seo{max-width:225px;min-width:175px}@media screen and (max-width:520px){.aioseo-seo-setup--wp-styles{flex-direction:column}}.aioseo-seo-checklist{display:flex;flex-direction:row;align-items:center}.aioseo-seo-checklist .checklist-status{font-size:14px;line-height:22px;font-weight:700;color:#141b38;margin-bottom:16px}.aioseo-seo-checklist .checklist-progress{margin-bottom:16px}.aioseo-seo-checklist .checklist-description{font-size:14px;line-height:1.6;color:#434960;margin-bottom:20px}.aioseo-seo-checklist .aioseo-button{font-size:12px;height:32px}.aioseo-seo-checklist .aioseo-seochecklist{max-width:300px;min-width:275px;width:100%;height:auto}@media screen and (max-width:1280px){.aioseo-seo-checklist .aioseo-seochecklist{min-width:0}}@media screen and (max-width:912px){.aioseo-seo-checklist{flex-direction:column;gap:24px}}.aioseo-seo-checklist--wp-styles .checklist-status{margin-bottom:12px}.aioseo-seo-checklist--wp-styles .checklist-description{color:#3c434a;margin-bottom:12px}.aioseo-seo-checklist--wp-styles .aioseo-seochecklist{display:none}@media screen and (max-width:520px){.aioseo-seo-checklist--wp-styles{flex-direction:column}}
