#wpcontent #wpbody .block-editor-link-control.aioseo-link-format .block-editor-link-control__search-item.is-current{background:rgba(0,0,0,0);border:0;width:100%;cursor:default;padding:16px 16px 16px 24px}#wpcontent #wpbody .block-editor-link-control.aioseo-link-format .block-editor-link-control__search-item{position:relative;display:flex;flex-direction:row !important;align-items:center;font-size:13px;cursor:pointer;background:#fff;width:100%;border:none;text-align:left;padding:12px 16px;border-radius:5px;height:auto}#wpcontent #wpbody .block-editor-link-control.aioseo-link-format .block-editor-link-control__search-item:hover .block-editor-link-control__search-item-type{background-color:#f0f0f0 !important}#wpcontent #wpbody .block-editor-link-control.aioseo-link-format .block-editor-link-control__settings{border-top:1px solid #ddd;margin:0;padding:16px 24px}#wpcontent #wpbody .block-editor-link-control.aioseo-link-format .block-editor-link-control__setting{padding:0;margin-bottom:12px}#wpcontent #wpbody .block-editor-link-control.aioseo-link-format input.block-editor-url-input__input,#wpcontent #wpbody .block-editor-link-control.aioseo-link-format input.components-input-control__input{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;box-shadow:0 0 0 rgba(0,0,0,0);transition:box-shadow .1s linear;width:calc(100% - 32px);display:block;padding:11px 36px 11px 16px;margin:16px;position:relative;border:1px solid #ddd;border-radius:2px;font-size:13px;line-height:normal}#wpcontent #wpbody .block-editor-link-control.aioseo-link-format input.block-editor-url-input__input:focus,#wpcontent #wpbody .block-editor-link-control.aioseo-link-format input.components-input-control__input:focus{border-color:var(--wp-admin-theme-color);box-shadow:none;outline:2px solid rgba(0,0,0,0)}#wpcontent #wpbody .block-editor-link-control.aioseo-link-format input.components-input-control__input{margin:16px 16px 8px 16px}#wpcontent #wpbody .block-editor-link-control.aioseo-link-format .components-input-control__backdrop{border:none;box-shadow:none}#wpcontent #wpbody .block-editor-link-control.aioseo-link-format .components-input-control__backdrop:focus{border:none;box-shadow:none}#wpcontent #wpbody .block-editor-link-control.aioseo-link-format .block-editor-link-control__search-actions{top:12px;right:10px;position:absolute;padding:8px}#wpcontent #wpbody .block-editor-link-control.aioseo-link-format .block-editor-link-control__setting.aioseo-link-title input{border:1px solid #ddd;border-radius:2px}
