.aioseo-settings-network-sites-activation .aioseo-wp-table .manage-column.activated{text-align:center}.aioseo-settings-network-sites-activation .aioseo-wp-table .row-actions .deactivate{color:#df2a4a}.aioseo-settings-network-sites-activation svg.aioseo-circle-check-solid{width:20px;height:20px;color:#00aa63}.aioseo-settings-network-sites-activation svg.aioseo-circle-close-solid{width:20px;height:20px;color:#df2a4a}.aioseo-general-settings .license-cta-box{font-size:14px;line-height:22px;border-radius:3px;background-color:#f2f7fd;padding:16px;max-width:620px;margin:12px 0}.aioseo-general-settings .license-cta-box a{color:#00aa63}.aioseo-general-settings .license-cta-box div{font-weight:600}.aioseo-general-settings .license-cta-box span{font-size:14px;font-style:italic}.aioseo-general-settings .license-key{margin-top:12px;display:flex;max-width:620px}[dir=ltr] .aioseo-general-settings .license-key .aioseo-input-container{margin-right:8px}[dir=rtl] .aioseo-general-settings .license-key .aioseo-input-container{margin-left:8px}.aioseo-general-settings .wizard-actions .aioseo-button{text-align:center}.aioseo-general-settings .more-tooltip-text strong{color:#00aa63}
