.aioseo-alert{position:relative;border-radius:3px;padding:12px;font-size:16px;color:#141b38;line-height:24px}.aioseo-alert.medium{padding:8px 12px;font-size:14px;line-height:22px}.aioseo-alert.small{padding:8px;font-size:14px;line-height:22px}.aioseo-alert.smaller{padding:6px;font-size:12px;line-height:18px}.aioseo-alert .aioseo-alert-close{cursor:pointer;position:absolute;top:-9px;width:18px;height:18px;border-radius:50%;padding:5px;display:inline-flex;justify-content:center;align-content:center}[dir=ltr] .aioseo-alert .aioseo-alert-close{right:-9px}[dir=rtl] .aioseo-alert .aioseo-alert-close{left:-9px}.aioseo-alert .aioseo-alert-close svg{margin:0!important;width:100%;height:100%}.aioseo-alert.blue{border:1px solid #005AE0;background-color:#f2f7fd}.aioseo-alert.blue .aioseo-alert-close{background-color:#005ae0;color:#fff}.aioseo-alert.blue .aioseo-alert-close:hover{background-color:#1a82ea}.aioseo-alert.green{border:1px solid #00AA63;background-color:#f2fdf8}.aioseo-alert.green .aioseo-alert-close{background-color:#00aa63;color:#fff}.aioseo-alert.green .aioseo-alert-close:hover{background-color:#07c575}.aioseo-alert.red{border:1px solid #DF2A4A;background-color:#fbe9ec}.aioseo-alert.red .aioseo-alert-close{background-color:#df2a4a;color:#fff}.aioseo-alert.red .aioseo-alert-close:hover{background-color:#ab2039}.aioseo-alert.yellow{border:1px solid #F18200;background-color:#fcfae8}.aioseo-alert.yellow .aioseo-alert-close{background-color:#f18200;color:#fff}.aioseo-alert.no-border{border-width:0}.aioseo-alert.text-center{text-align:center}
