.aioseo-seo-site-score__circle{animation:aioseo-seo-site-score-fill 1s reverse;transform-origin:center}[dir=ltr] .aioseo-seo-site-score__circle{transform:rotate(-180deg)}[dir=rtl] .aioseo-seo-site-score__circle{transform:rotate(180deg)}.aioseo-seo-site-score__circle.fast{animation-duration:.5s}.aioseo-seo-site-score__circle.medium{animation-duration:.75s}.aioseo-seo-site-score__circle.stroke-red{stroke:#df2a4a}.aioseo-seo-site-score__circle.stroke-orange{stroke:#f18200}.aioseo-seo-site-score__circle.stroke-green{stroke:#00aa63}.aioseo-seo-site-score__circle.stroke-blue{stroke:#005ae0}.aioseo-seo-site-score__background{stroke:#e8e8eb}@keyframes aioseo-seo-site-score-fill{to{stroke-dasharray:0 100}}.aioseo-score-amount-wrapper{position:absolute;inset:0;display:flex;align-items:center;justify-content:center;flex-direction:column;color:#141b38;margin:20px}.aioseo-score-amount-wrapper .aioseo-score-amount{line-height:1.2}.aioseo-score-amount-wrapper .aioseo-score-amount .score{font-size:50px;font-weight:600;color:inherit}.aioseo-score-amount-wrapper .aioseo-score-amount .total{font-size:18px;line-height:1.5;font-weight:600;color:#8c8f9a}[dir=ltr] .aioseo-score-amount-wrapper .aioseo-score-amount .total{padding-left:3px}[dir=rtl] .aioseo-score-amount-wrapper .aioseo-score-amount .total{padding-right:3px}.aioseo-score-amount-wrapper .score-description{max-width:80%;text-align:center;font-size:16px;font-weight:600;line-height:1.3;color:inherit}.aioseo-score-amount-wrapper .score-analyzing{margin-top:16px;font-size:24px}.aioseo-site-score{display:flex}.aioseo-site-score:has(.stroke-red) .aioseo-score-amount-wrapper{color:#df2a4a}.aioseo-site-score:has(.stroke-orange) .aioseo-score-amount-wrapper{color:#f18200}.aioseo-site-score:has(.stroke-green) .aioseo-score-amount-wrapper{color:#00aa63}
