.aioseo-badge[data-v-bc6fd085]{border-radius:10px}.aioseo-badge.black[data-v-bc6fd085]{color:#141b38;border:1px solid #141B38;background-color:#dcdde1!important}.aioseo-badge.green[data-v-bc6fd085]{color:#00aa63;border:1px solid #00AA63;background-color:#ecfdf5!important}.aioseo-badge.red[data-v-bc6fd085]{color:#df2a4a;border:1px solid #DF2A4A;background-color:#fef2f2!important}.aioseo-badge.orange[data-v-bc6fd085]{color:#f18200;border:1px solid #F18200;background-color:#fffbeb!important}.aioseo-badge.blue[data-v-bc6fd085]{color:#005ae0;border:1px solid #005AE0;background-color:#eff6ff!important}
