.aioseo-opening-hours-sidebar .sidebar-row{margin-bottom:16px}.aioseo-opening-hours-sidebar .sidebar-row .title{font-weight:600}.aioseo-opening-hours-sidebar .sidebar-row.labels label{display:block;margin-bottom:4px}
