<?php

// autoload_psr4.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'League\\HTMLToMarkdown\\' => array($vendorDir . '/league/html-to-markdown/src'),
    'AIOSEO\\Plugin\\' => array($baseDir . '/app'),
);
