<?php
/**
 * @package ACF
 * @author  WP Engine
 *
 * © 2026 Advanced Custom Fields (ACF®). All rights reserved.
 * "ACF" is a trademark of WP Engine.
 * Licensed under the GNU General Public License v2 or later.
 * https://www.gnu.org/licenses/gpl-2.0.html
 */

/**
 * Schema.org compatible properties by output type data
 *
 * This file is auto-generated by tools/generate-schema.js
 * DO NOT EDIT MANUALLY - Run 'npm run generate-schema' to regenerate
 *
 * Generated: 2026-02-25
 * Source: https://schema.org/version/latest/schemaorg-current-https.jsonld
 *
 * @package ACF\AI\GEO
 */

return array(
	'Text'           => array(
		'abstract',
		'acceptedPaymentMethod',
		'acceptsReservations',
		'accessCode',
		'accessMode',
		'accessibilityAPI',
		'accessibilityControl',
		'accessibilityFeature',
		'accessibilityHazard',
		'accessibilitySummary',
		'accommodationCategory',
		'accountId',
		'acrissCode',
		'actionOption',
		'actionPlatform',
		'activeIngredient',
		'activityDuration',
		'activityFrequency',
		'additionalName',
		'additionalType',
		'additionalVariable',
		'address',
		'addressCountry',
		'addressLocality',
		'addressRegion',
		'administrationRoute',
		'aircraft',
		'alcoholWarning',
		'algorithm',
		'alignmentType',
		'alternateName',
		'alternativeHeadline',
		'applicableCountry',
		'applicationCategory',
		'applicationDeadline',
		'applicationSubCategory',
		'applicationSuite',
		'areaServed',
		'arrivalGate',
		'arrivalPlatform',
		'arrivalTerminal',
		'artEdition',
		'artMedium',
		'artform',
		'articleBody',
		'articleSection',
		'artworkSurface',
		'asin',
		'aspect',
		'assembly',
		'assemblyVersion',
		'assesses',
		'associatedPathophysiology',
		'audienceType',
		'availableLanguage',
		'availableOnDevice',
		'award',
		'awards',
		'backstory',
		'bankAccountType',
		'bed',
		'beneficiaryBank',
		'benefits',
		'bestRating',
		'billingDuration',
		'billingPeriod',
		'biomechnicalClass',
		'bitrate',
		'boardingGroup',
		'bodyLocation',
		'bodyType',
		'bookEdition',
		'box',
		'branchCode',
		'breadcrumb',
		'breastfeedingWarning',
		'broadcastChannelId',
		'broadcastDisplayName',
		'broadcastFrequency',
		'broadcastServiceTier',
		'broadcastSignalModulation',
		'broadcastSubChannel',
		'broadcastTimezone',
		'browserRequirements',
		'busName',
		'busNumber',
		'byDay',
		'callSign',
		'calories',
		'caption',
		'carbohydrateContent',
		'carrierRequirements',
		'catalogNumber',
		'category',
		'certificationIdentification',
		'characterName',
		'checkoutPageURLTemplate',
		'chemicalComposition',
		'childTaxon',
		'cholesterolContent',
		'circle',
		'citation',
		'claimReviewed',
		'clincalPharmacology',
		'clinicalPharmacology',
		'clipNumber',
		'codeSampleType',
		'codeValue',
		'codingSystem',
		'color',
		'commentText',
		'competencyRequired',
		'conditionsOfAccess',
		'confirmationNumber',
		'contactType',
		'contentRating',
		'contentSize',
		'contentType',
		'contraindication',
		'cookTime',
		'cookingMethod',
		'copyrightNotice',
		'correction',
		'costCurrency',
		'costOrigin',
		'costPerUnit',
		'countriesNotSupported',
		'countriesSupported',
		'countryOfAssembly',
		'countryOfLastProcessing',
		'courseCode',
		'courseMode',
		'coursePrerequisites',
		'courseWorkload',
		'creativeWorkStatus',
		'credentialCategory',
		'creditText',
		'currenciesAccepted',
		'currency',
		'cvdCollectionDate',
		'cvdFacilityCounty',
		'cvdFacilityId',
		'dataFeedElement',
		'dateline',
		'defaultValue',
		'departureGate',
		'departurePlatform',
		'departureTerminal',
		'dependencies',
		'depth',
		'description',
		'device',
		'dietFeatures',
		'disambiguatingDescription',
		'discount',
		'discountCode',
		'discountCurrency',
		'distance',
		'dosageForm',
		'doseUnit',
		'driveWheelConfiguration',
		'drugUnit',
		'duns',
		'duration',
		'editEIDR',
		'eduQuestionType',
		'educationRequirements',
		'educationalCredentialAwarded',
		'educationalFramework',
		'educationalLevel',
		'educationalProgramMode',
		'educationalRole',
		'educationalUse',
		'elevation',
		'eligibilityToWorkRequirement',
		'eligibleRegion',
		'email',
		'embeddedTextCaption',
		'employerOverview',
		'employmentType',
		'encodingFormat',
		'encodingType',
		'engineType',
		'epidemiology',
		'episodeNumber',
		'errorCode',
		'estimatedCost',
		'estimatedFlightDuration',
		'evidenceOrigin',
		'executableLibraryName',
		'exerciseType',
		'exifData',
		'expectedPrognosis',
		'experienceRequirements',
		'expertConsiderations',
		'extendedAddress',
		'familyName',
		'fatContent',
		'faxNumber',
		'featureList',
		'feesAndCommissionsSpecification',
		'fiberContent',
		'fileFormat',
		'fileSize',
		'financialAidEligible',
		'flightDistance',
		'flightNumber',
		'floorLevel',
		'followup',
		'foodWarning',
		'frequency',
		'fuelType',
		'functionalClass',
		'gameAvailabilityType',
		'gameEdition',
		'gamePlatform',
		'gender',
		'genre',
		'geoRadius',
		'givenName',
		'globalLocationNumber',
		'gracePeriod',
		'gtin',
		'gtin12',
		'gtin13',
		'gtin14',
		'gtin8',
		'hasBioPolymerSequence',
		'hasMenu',
		'hasRepresentation',
		'hasTierRequirement',
		'headline',
		'healthPlanCoinsuranceOption',
		'healthPlanCopayOption',
		'healthPlanDrugOption',
		'healthPlanDrugTier',
		'healthPlanId',
		'healthPlanNetworkId',
		'healthPlanNetworkTier',
		'healthPlanPharmacyCategory',
		'height',
		'highPrice',
		'honorificPrefix',
		'honorificSuffix',
		'howPerformed',
		'httpMethod',
		'iataCode',
		'icaoCode',
		'identifier',
		'inChI',
		'inChIKey',
		'inLanguage',
		'inProductGroupWithID',
		'inSupportOf',
		'incentiveCompensation',
		'incentives',
		'incomeLimit',
		'industry',
		'ineligibleRegion',
		'infectiousAgent',
		'ingredients',
		'intensity',
		'interactivityType',
		'isbn',
		'isicV4',
		'iso6523Code',
		'isrcCode',
		'issn',
		'issueNumber',
		'iswcCode',
		'itemListElement',
		'itemListOrder',
		'itemLocation',
		'iupacName',
		'jobBenefits',
		'jobLocationType',
		'jobStartDate',
		'jobTitle',
		'jurisdiction',
		'keywords',
		'knownVehicleDamages',
		'knowsAbout',
		'knowsLanguage',
		'latitude',
		'learningResourceType',
		'leaseLength',
		'legalName',
		'legalStatus',
		'legislationIdentifier',
		'legislationJurisdiction',
		'legislationType',
		'leiCode',
		'line',
		'linkRelationship',
		'loanType',
		'location',
		'lodgingUnitDescription',
		'lodgingUnitType',
		'longitude',
		'lowPrice',
		'material',
		'materialExtent',
		'mathExpression',
		'mealService',
		'measurementMethod',
		'measurementTechnique',
		'mechanismOfAction',
		'meetsEmissionStandard',
		'membershipNumber',
		'memoryRequirements',
		'menu',
		'mobileUrl',
		'model',
		'molecularFormula',
		'molecularWeight',
		'monoisotopicMolecularWeight',
		'mpn',
		'muscleAction',
		'musicCompositionForm',
		'musicalKey',
		'naics',
		'name',
		'namedPosition',
		'naturalProgression',
		'negativeNotes',
		'nonProprietaryName',
		'normalRange',
		'nsn',
		'numberOfAirbags',
		'observationPeriod',
		'occupationalCategory',
		'occupationalCredentialAwarded',
		'openingHours',
		'operatingSystem',
		'option',
		'orderItemNumber',
		'orderNumber',
		'originalMediaContextDescription',
		'overdosage',
		'ownershipFundingInfo',
		'pageEnd',
		'pageStart',
		'pagination',
		'parentTaxon',
		'passengerPriorityStatus',
		'passengerSequenceNumber',
		'pathophysiology',
		'pattern',
		'paymentAccepted',
		'paymentMethod',
		'paymentMethodId',
		'paymentStatus',
		'performTime',
		'permissions',
		'permittedUsage',
		'petsAllowed',
		'phoneticText',
		'physicalRequirement',
		'physiologicalBenefits',
		'playerType',
		'polygon',
		'position',
		'positiveNotes',
		'possibleComplication',
		'postOfficeBoxNumber',
		'postOp',
		'postalCode',
		'postalCodeBegin',
		'postalCodeEnd',
		'postalCodePrefix',
		'preOp',
		'pregnancyWarning',
		'prepTime',
		'preparation',
		'prescriptionStatus',
		'price',
		'priceCurrency',
		'priceRange',
		'priceType',
		'printColumn',
		'printEdition',
		'printPage',
		'printSection',
		'procedure',
		'processingTime',
		'processorRequirements',
		'productGroupID',
		'productID',
		'productSupported',
		'proficiencyLevel',
		'programName',
		'programPrerequisites',
		'programType',
		'programmingLanguage',
		'programmingModel',
		'pronouns',
		'propertyID',
		'proprietaryName',
		'proteinContent',
		'providerMobility',
		'publicationType',
		'qualifications',
		'query',
		'ratingExplanation',
		'ratingValue',
		'recipeCategory',
		'recipeCuisine',
		'recipeIngredient',
		'recipeInstructions',
		'recipeYield',
		'recommendationStrength',
		'releaseNotes',
		'repeatFrequency',
		'reportNumber',
		'requiredCollateral',
		'requiredGender',
		'requiredQuantity',
		'requirements',
		'reservationId',
		'responsibilities',
		'restPeriods',
		'returnPolicyCountry',
		'reviewAspect',
		'reviewBody',
		'risks',
		'roleName',
		'runtime',
		'runtimePlatform',
		'rxcui',
		'safetyConsideration',
		'salaryCurrency',
		'sampleType',
		'saturatedFatContent',
		'scheduleTimezone',
		'schemaVersion',
		'seasonNumber',
		'seatNumber',
		'seatRow',
		'seatSection',
		'seatingType',
		'securityClearanceRequirement',
		'securityScreening',
		'sensoryRequirement',
		'serialNumber',
		'servesCuisine',
		'serviceType',
		'servingSize',
		'sha256',
		'significance',
		'size',
		'sizeGroup',
		'sizeSystem',
		'skills',
		'sku',
		'slogan',
		'smiles',
		'sodiumContent',
		'softwareRequirements',
		'softwareVersion',
		'specialCommitments',
		'speechToTextMarkup',
		'sport',
		'statType',
		'status',
		'step',
		'steps',
		'storageRequirements',
		'streetAddress',
		'strengthUnit',
		'structuralClass',
		'subStageSuffix',
		'subtitleLanguage',
		'sugarContent',
		'suggestedGender',
		'supply',
		'surface',
		'targetDescription',
		'targetName',
		'targetPlatform',
		'targetPopulation',
		'taxID',
		'taxonRank',
		'taxonomicRange',
		'teaches',
		'telephone',
		'temporal',
		'temporalCoverage',
		'termCode',
		'termDuration',
		'termsOfService',
		'text',
		'textValue',
		'tickerSymbol',
		'ticketNumber',
		'ticketToken',
		'timeOfDay',
		'timeRequired',
		'timeToComplete',
		'tissueSample',
		'title',
		'titleEIDR',
		'tool',
		'totalPrice',
		'totalTime',
		'touristType',
		'trackingNumber',
		'trainName',
		'trainNumber',
		'transFatContent',
		'transcript',
		'transmissionMethod',
		'typeOfBed',
		'typicalAgeRange',
		'unitCode',
		'unitText',
		'unsaturatedFatContent',
		'urlTemplate',
		'usNPI',
		'usesHealthPlanIdStandard',
		'utterances',
		'validFor',
		'value',
		'valueName',
		'valuePattern',
		'valueReference',
		'variableMeasured',
		'variantCover',
		'variesBy',
		'vatID',
		'vehicleConfiguration',
		'vehicleIdentificationNumber',
		'vehicleInteriorColor',
		'vehicleInteriorType',
		'vehicleSpecialUsage',
		'vehicleTransmission',
		'version',
		'videoFormat',
		'videoFrameSize',
		'videoQuality',
		'volumeNumber',
		'warning',
		'weight',
		'width',
		'workHours',
		'workload',
		'worstRating',
		'yield',
	),
	'URL'            => array(
		'acceptsReservations',
		'acquireLicensePage',
		'actionPlatform',
		'actionableFeedbackPolicy',
		'additionalType',
		'afterMedia',
		'applicationCategory',
		'applicationSubCategory',
		'archivedAt',
		'artMedium',
		'artform',
		'artworkSurface',
		'asin',
		'associatedDisease',
		'bankAccountType',
		'beforeMedia',
		'benefitsSummaryUrl',
		'bodyType',
		'category',
		'childTaxon',
		'codeRepository',
		'colleague',
		'colorSwatch',
		'competencyRequired',
		'constraintProperty',
		'contentUrl',
		'correction',
		'correctionsPolicy',
		'courseMode',
		'credentialCategory',
		'discussionUrl',
		'diseasePreventionInfo',
		'diseaseSpreadStatistics',
		'diversityPolicy',
		'diversityStaffingReport',
		'documentation',
		'downloadUrl',
		'duringMedia',
		'editEIDR',
		'educationalCredentialAwarded',
		'educationalLevel',
		'educationalProgramMode',
		'embedUrl',
		'encodingFormat',
		'engineType',
		'ethicsPolicy',
		'featureList',
		'feesAndCommissionsSpecification',
		'fileFormat',
		'fuelType',
		'gameLocation',
		'gamePlatform',
		'genre',
		'gettingTestedInfo',
		'gtin',
		'hasGS1DigitalLink',
		'hasMap',
		'hasMenu',
		'hasMolecularFunction',
		'hasRepresentation',
		'healthPlanMarketingUrl',
		'identifier',
		'image',
		'inCodeSet',
		'inDefinedTermSet',
		'installUrl',
		'isBasedOn',
		'isBasedOnUrl',
		'isInvolvedInBiologicalProcess',
		'isLocatedInSubcellularLocation',
		'isPartOf',
		'keywords',
		'knowsAbout',
		'labelDetails',
		'layoutImage',
		'legislationIdentifier',
		'license',
		'loanType',
		'logo',
		'mainEntityOfPage',
		'map',
		'maps',
		'masthead',
		'material',
		'measurementMethod',
		'measurementTechnique',
		'meetsEmissionStandard',
		'memoryRequirements',
		'menu',
		'merchantReturnLink',
		'missionCoveragePrioritiesPolicy',
		'namedPosition',
		'newsUpdatesAndGuidelines',
		'noBylinesPolicy',
		'occupationalCredentialAwarded',
		'originalMediaLink',
		'ownershipFundingInfo',
		'parentTaxon',
		'paymentUrl',
		'physicalRequirement',
		'prescribingInfo',
		'propertyID',
		'publicTransportClosuresInfo',
		'publishingPrinciples',
		'quarantineGuidelines',
		'relatedLink',
		'releaseNotes',
		'replyToUrl',
		'requirements',
		'roleName',
		'sameAs',
		'schemaVersion',
		'schoolClosuresInfo',
		'screenshot',
		'sdLicense',
		'season',
		'securityClearanceRequirement',
		'sensoryRequirement',
		'serviceUrl',
		'significantLink',
		'significantLinks',
		'softwareRequirements',
		'speakable',
		'sport',
		'statType',
		'storageRequirements',
		'surface',
		'target',
		'targetUrl',
		'taxonRank',
		'taxonomicRange',
		'temporalCoverage',
		'termsOfService',
		'thumbnailUrl',
		'ticketToken',
		'titleEIDR',
		'tourBookingPage',
		'trackingUrl',
		'travelBans',
		'unitCode',
		'unnamedSourcesPolicy',
		'url',
		'usageInfo',
		'usesHealthPlanIdStandard',
		'vehicleTransmission',
		'verificationFactCheckingPolicy',
		'warning',
		'webFeed',
	),
	'Number'         => array(
		'additionalNumberOfGuests',
		'amount',
		'amountOfThisGood',
		'annualPercentageRate',
		'baseSalary',
		'bestRating',
		'billingDuration',
		'billingIncrement',
		'billingStart',
		'broadcastFrequencyValue',
		'cashBack',
		'childMaxAge',
		'childMinAge',
		'copyrightYear',
		'costPerUnit',
		'cvdNumBeds',
		'cvdNumBedsOcc',
		'cvdNumC19Died',
		'cvdNumC19HOPats',
		'cvdNumC19HospPats',
		'cvdNumC19MechVentPats',
		'cvdNumC19OFMechVentPats',
		'cvdNumC19OverflowPats',
		'cvdNumICUBeds',
		'cvdNumICUBedsOcc',
		'cvdNumTotBeds',
		'cvdNumVent',
		'cvdNumVentUse',
		'discount',
		'doseValue',
		'downPayment',
		'elevation',
		'emissionsCO2',
		'endOffset',
		'estimatedSalary',
		'exchangeRateSpread',
		'geoRadius',
		'healthPlanCoinsuranceRate',
		'highPrice',
		'interestRate',
		'latitude',
		'loanPaymentFrequency',
		'longitude',
		'lowPrice',
		'maxPrice',
		'maxValue',
		'median',
		'membershipPointsEarned',
		'minPrice',
		'minValue',
		'monthlyMinimumRepaymentAmount',
		'monthsOfExperience',
		'numberOfAirbags',
		'numberOfAxles',
		'numberOfBedrooms',
		'numberOfBeds',
		'numberOfDoors',
		'numberOfForwardGears',
		'numberOfFullBathrooms',
		'numberOfLoanPayments',
		'numberOfPartialBathrooms',
		'numberOfPreviousOwners',
		'numberOfRooms',
		'numberedPosition',
		'orderPercentage',
		'orderQuantity',
		'percentile10',
		'percentile25',
		'percentile75',
		'percentile90',
		'price',
		'ratingValue',
		'repetitions',
		'requiredQuantity',
		'restockingFee',
		'screenCount',
		'seatingCapacity',
		'stageAsNumber',
		'startOffset',
		'stepValue',
		'strengthValue',
		'suggestedMaxAge',
		'suggestedMinAge',
		'termsPerYear',
		'totalPrice',
		'value',
		'valueMaxLength',
		'valueMinLength',
		'vehicleSeatingCapacity',
		'version',
		'weightPercentage',
		'worstRating',
		'yearBuilt',
	),
	'Integer'        => array(
		'answerCount',
		'artEdition',
		'byMonth',
		'byMonthDay',
		'byMonthWeek',
		'clipNumber',
		'collectionSize',
		'commentCount',
		'downvoteCount',
		'episodeNumber',
		'errorCode',
		'issueNumber',
		'maximumAttendeeCapacity',
		'maximumEnrollment',
		'maximumPhysicalAttendeeCapacity',
		'maximumVirtualAttendeeCapacity',
		'merchantReturnDays',
		'numAdults',
		'numChildren',
		'numConstraints',
		'numTracks',
		'numberOfBathroomsTotal',
		'numberOfCredits',
		'numberOfEpisodes',
		'numberOfItems',
		'numberOfPages',
		'numberOfSeasons',
		'offerCount',
		'pageEnd',
		'pageStart',
		'partySize',
		'playersOnline',
		'position',
		'ratingCount',
		'remainingAttendeeCapacity',
		'repeatCount',
		'requiredMaxAge',
		'requiredMinAge',
		'reviewCount',
		'seasonNumber',
		'totalHistoricalEnrollment',
		'totalJobOpenings',
		'typicalCreditsPerTerm',
		'upvoteCount',
		'userInteractionCount',
		'volumeNumber',
		'wordCount',
	),
	'Boolean'        => array(
		'abridged',
		'acceptsReservations',
		'cashBack',
		'contactlessPayment',
		'directApply',
		'doesNotShip',
		'domiciledMortgage',
		'experienceInPlaceOfEducation',
		'free',
		'hasDriveThroughService',
		'healthPlanCostSharing',
		'inStoreReturnsOffered',
		'isAcceptingNewPatients',
		'isAccessibleForFree',
		'isAvailableGenerically',
		'isFamilyFriendly',
		'isGift',
		'isLiveBroadcast',
		'isProprietary',
		'isResizable',
		'isUnlabelledFallback',
		'jobImmediateStart',
		'multipleValues',
		'offersPrescriptionByMail',
		'petsAllowed',
		'publicAccess',
		'readonlyValue',
		'recourseLoan',
		'renegotiableLoan',
		'representativeOfPage',
		'requiresSubscription',
		'smokingAllowed',
		'value',
		'valueAddedTaxIncluded',
		'valueRequired',
	),
	'Date'           => array(
		'applicationDeadline',
		'applicationStartDate',
		'auditDate',
		'availabilityEnds',
		'availabilityStarts',
		'birthDate',
		'commentTime',
		'dateCreated',
		'dateDeleted',
		'dateIssued',
		'dateModified',
		'datePosted',
		'datePublished',
		'dateRead',
		'dateVehicleFirstRegistered',
		'deathDate',
		'dissolutionDate',
		'endDate',
		'exceptDate',
		'expectedArrivalFrom',
		'expectedArrivalUntil',
		'expires',
		'foundingDate',
		'guidelineDate',
		'jobStartDate',
		'lastReviewed',
		'legislationDate',
		'legislationDateOfApplicability',
		'legislationDateVersion',
		'merchantReturnDays',
		'modelDate',
		'observationDate',
		'orderDate',
		'paymentDueDate',
		'previousStartDate',
		'priceValidUntil',
		'productionDate',
		'purchaseDate',
		'releaseDate',
		'scheduledPaymentDate',
		'scheduledTime',
		'sdDatePublished',
		'startDate',
		'uploadDate',
		'validFrom',
		'validThrough',
		'validUntil',
		'vehicleModelDate',
	),
	'DateTime'       => array(
		'arrivalTime',
		'auditDate',
		'availabilityEnds',
		'availabilityStarts',
		'availableFrom',
		'availableThrough',
		'bookingTime',
		'checkinTime',
		'checkoutTime',
		'commentTime',
		'contentReferenceTime',
		'coverageEndTime',
		'coverageStartTime',
		'cvdCollectionDate',
		'datasetTimeInterval',
		'dateCreated',
		'dateDeleted',
		'dateIssued',
		'dateModified',
		'datePosted',
		'datePublished',
		'dateRead',
		'dateReceived',
		'dateSent',
		'departureTime',
		'doorTime',
		'dropoffTime',
		'endDate',
		'endTime',
		'exceptDate',
		'expectedArrivalFrom',
		'expectedArrivalUntil',
		'expires',
		'merchantReturnDays',
		'modifiedTime',
		'observationDate',
		'orderDate',
		'ownedFrom',
		'ownedThrough',
		'paymentDue',
		'paymentDueDate',
		'pickupTime',
		'scheduledTime',
		'startDate',
		'startTime',
		'temporal',
		'temporalCoverage',
		'timestamp',
		'uploadDate',
		'validFrom',
		'validThrough',
		'webCheckinTime',
	),
	'Time'           => array(
		'arrivalTime',
		'availabilityEnds',
		'availabilityStarts',
		'checkinTime',
		'checkoutTime',
		'closes',
		'cutoffTime',
		'departureTime',
		'doorTime',
		'endTime',
		'opens',
		'startTime',
	),
	'ImageObject'    => array(
		'afterMedia',
		'associatedMedia',
		'beforeMedia',
		'caption',
		'colorSwatch',
		'diagram',
		'duringMedia',
		'encoding',
		'encodings',
		'image',
		'layoutImage',
		'logo',
		'mediaItemAppearance',
		'originalMediaLink',
		'photo',
		'photos',
		'primaryImageOfPage',
		'screenshot',
		'thumbnail',
	),
	'MediaObject'    => array(
		'acquireLicensePage',
		'actionableFeedbackPolicy',
		'afterMedia',
		'appearance',
		'associatedMedia',
		'backstory',
		'beforeMedia',
		'caption',
		'cheatCode',
		'citation',
		'correctionsPolicy',
		'discusses',
		'diversityPolicy',
		'documentation',
		'duringMedia',
		'encodesCreativeWork',
		'encoding',
		'encodings',
		'ethicsPolicy',
		'exampleOfWork',
		'firstAppearance',
		'fundedItem',
		'gameTip',
		'hasPart',
		'isBasedOn',
		'isBasedOnUrl',
		'isPartOf',
		'itemOffered',
		'license',
		'lyrics',
		'mainEntityOfPage',
		'masthead',
		'mediaItemAppearance',
		'messageAttachment',
		'missionCoveragePrioritiesPolicy',
		'noBylinesPolicy',
		'originalMediaLink',
		'ownershipFundingInfo',
		'parentItem',
		'publishingPrinciples',
		'recipeInstructions',
		'recordedIn',
		'sdLicense',
		'sharedContent',
		'softwareHelp',
		'step',
		'steps',
		'subjectOf',
		'translationOfWork',
		'unnamedSourcesPolicy',
		'usageInfo',
		'verificationFactCheckingPolicy',
		'workExample',
		'workFeatured',
		'workPerformed',
		'workTranslation',
	),
	'AudioObject'    => array(
		'afterMedia',
		'associatedMedia',
		'audio',
		'beforeMedia',
		'caption',
		'duringMedia',
		'encoding',
		'encodings',
		'mediaItemAppearance',
		'originalMediaLink',
	),
	'VideoObject'    => array(
		'afterMedia',
		'associatedMedia',
		'beforeMedia',
		'caption',
		'duringMedia',
		'encoding',
		'encodings',
		'mediaItemAppearance',
		'originalMediaLink',
		'trailer',
		'video',
	),
	'DataDownload'   => array(
		'afterMedia',
		'associatedMedia',
		'beforeMedia',
		'caption',
		'distribution',
		'duringMedia',
		'encoding',
		'encodings',
		'mediaItemAppearance',
		'originalMediaLink',
	),
	'Person'         => array(
		'about',
		'accountablePerson',
		'acquiredFrom',
		'actionOption',
		'actor',
		'actors',
		'agent',
		'aggregateElement',
		'alumni',
		'artist',
		'athlete',
		'attendee',
		'attendees',
		'author',
		'awayTeam',
		'bccRecipient',
		'bookingAgent',
		'borrower',
		'broker',
		'buyer',
		'byArtist',
		'candidate',
		'category',
		'ccRecipient',
		'character',
		'characterAttribute',
		'children',
		'claimInterpreter',
		'coach',
		'colleague',
		'colleagues',
		'collection',
		'colorist',
		'competitor',
		'composer',
		'contributor',
		'copyrightHolder',
		'creator',
		'creditedTo',
		'customer',
		'data',
		'dataFeedElement',
		'defaultValue',
		'director',
		'directors',
		'editor',
		'employee',
		'employees',
		'endorsee',
		'endorsers',
		'error',
		'followee',
		'follows',
		'founder',
		'founders',
		'fundedItem',
		'funder',
		'gameItem',
		'gamePlatform',
		'grantee',
		'hiringOrganization',
		'homeTeam',
		'illustrator',
		'inker',
		'instructor',
		'instrument',
		'item',
		'itemListElement',
		'itemReviewed',
		'knows',
		'knowsAbout',
		'landlord',
		'legalRepresentative',
		'legislationCountersignedBy',
		'legislationPassedBy',
		'legislationResponsible',
		'lender',
		'letterer',
		'loser',
		'lyricist',
		'mainEntity',
		'maintainer',
		'member',
		'members',
		'mentions',
		'merchant',
		'musicBy',
		'musicGroupMember',
		'object',
		'observationAbout',
		'offeredBy',
		'opponent',
		'option',
		'organizer',
		'owner',
		'owns',
		'parent',
		'parents',
		'participant',
		'penciler',
		'performer',
		'performers',
		'producer',
		'produces',
		'provider',
		'publishedBy',
		'publisher',
		'quest',
		'readBy',
		'recipient',
		'referee',
		'relatedTo',
		'replacee',
		'replacer',
		'requiredCollateral',
		'reservationFor',
		'result',
		'reviewedBy',
		'sdPublisher',
		'seller',
		'sender',
		'serviceOutput',
		'sibling',
		'siblings',
		'source',
		'spokenByCharacter',
		'sponsor',
		'spouse',
		'targetCollection',
		'toRecipient',
		'translator',
		'underName',
		'vendor',
		'winner',
	),
	'Organization'   => array(
		'about',
		'acquiredFrom',
		'actionOption',
		'affiliation',
		'agent',
		'aggregateElement',
		'alumniOf',
		'attendee',
		'attendees',
		'authenticator',
		'author',
		'bccRecipient',
		'bookingAgent',
		'branchOf',
		'brand',
		'broadcastAffiliateOf',
		'broadcaster',
		'broker',
		'buyer',
		'carrier',
		'category',
		'ccRecipient',
		'characterAttribute',
		'claimInterpreter',
		'collection',
		'composer',
		'contributor',
		'copyrightHolder',
		'creator',
		'creditedTo',
		'customer',
		'data',
		'dataFeedElement',
		'defaultValue',
		'department',
		'eligibleWithSupplier',
		'employmentUnit',
		'endorsee',
		'endorsers',
		'error',
		'followee',
		'founder',
		'fundedItem',
		'funder',
		'gameItem',
		'gamePlatform',
		'grantee',
		'hiringOrganization',
		'hostingOrganization',
		'instrument',
		'issuedBy',
		'item',
		'itemListElement',
		'itemReviewed',
		'knowsAbout',
		'landlord',
		'legislationCountersignedBy',
		'legislationPassedBy',
		'legislationResponsible',
		'lender',
		'mainEntity',
		'maintainer',
		'manufacturer',
		'member',
		'memberOf',
		'members',
		'mentions',
		'merchant',
		'object',
		'observationAbout',
		'offeredBy',
		'option',
		'organizer',
		'owner',
		'owns',
		'parentOrganization',
		'participant',
		'performer',
		'performers',
		'producer',
		'produces',
		'productionCompany',
		'provider',
		'publishedBy',
		'publisher',
		'publisherImprint',
		'quest',
		'recipient',
		'recognizedBy',
		'recognizingAuthority',
		'recordLabel',
		'replacee',
		'replacer',
		'requiredCollateral',
		'reservationFor',
		'result',
		'reviewedBy',
		'sdPublisher',
		'seller',
		'sender',
		'serviceOperator',
		'serviceOutput',
		'source',
		'sourceOrganization',
		'spokenByCharacter',
		'sponsor',
		'subOrganization',
		'targetCollection',
		'toRecipient',
		'translator',
		'underName',
		'vendor',
		'worksFor',
	),
	'Place'          => array(
		'about',
		'actionOption',
		'aggregateElement',
		'area',
		'areaServed',
		'availableAtOrFrom',
		'birthPlace',
		'category',
		'characterAttribute',
		'collection',
		'containedIn',
		'containedInPlace',
		'containsPlace',
		'contentLocation',
		'course',
		'data',
		'dataFeedElement',
		'deathPlace',
		'defaultValue',
		'displayLocation',
		'dropoffLocation',
		'eligibleRegion',
		'error',
		'exerciseCourse',
		'foodEstablishment',
		'foundingLocation',
		'fromLocation',
		'gameItem',
		'gameLocation',
		'gamePlatform',
		'geoContains',
		'geoCoveredBy',
		'geoCovers',
		'geoCrosses',
		'geoDisjoint',
		'geoEquals',
		'geoIntersects',
		'geoOverlaps',
		'geoTouches',
		'geoWithin',
		'hasPOS',
		'homeLocation',
		'ineligibleRegion',
		'instrument',
		'item',
		'itemListElement',
		'itemLocation',
		'itemReviewed',
		'itinerary',
		'jobLocation',
		'knowsAbout',
		'location',
		'locationCreated',
		'mainEntity',
		'mentions',
		'object',
		'observationAbout',
		'option',
		'owns',
		'pickupLocation',
		'produces',
		'quest',
		'regionsAllowed',
		'replacee',
		'replacer',
		'requiredCollateral',
		'reservationFor',
		'result',
		'serviceArea',
		'serviceLocation',
		'serviceOutput',
		'source',
		'spatial',
		'spatialCoverage',
		'targetCollection',
		'toLocation',
		'tripOrigin',
		'workLocation',
	),
	'GeoCoordinates' => array(
		'geo',
		'geoMidpoint',
		'numberOfCredits',
		'pronouns',
		'reviewAspect',
		'typicalCreditsPerTerm',
		'value',
		'valueReference',
	),
	'PostalAddress'  => array(
		'address',
		'applicationContact',
		'bccRecipient',
		'billingAddress',
		'ccRecipient',
		'contactPoint',
		'contactPoints',
		'deliveryAddress',
		'gameLocation',
		'grantee',
		'homeLocation',
		'itemLocation',
		'legalAddress',
		'location',
		'originAddress',
		'recipient',
		'servicePhone',
		'servicePostalAddress',
		'serviceSmsNumber',
		'toRecipient',
		'workLocation',
	),
	'WebPage'        => array(
		'acquireLicensePage',
		'actionableFeedbackPolicy',
		'appearance',
		'archivedAt',
		'backstory',
		'cheatCode',
		'citation',
		'correctionsPolicy',
		'discusses',
		'diversityPolicy',
		'documentation',
		'encodesCreativeWork',
		'ethicsPolicy',
		'exampleOfWork',
		'firstAppearance',
		'fundedItem',
		'gameTip',
		'hasPart',
		'isBasedOn',
		'isBasedOnUrl',
		'isPartOf',
		'itemOffered',
		'license',
		'lyrics',
		'mainEntityOfPage',
		'masthead',
		'messageAttachment',
		'missionCoveragePrioritiesPolicy',
		'noBylinesPolicy',
		'originalMediaLink',
		'ownershipFundingInfo',
		'parentItem',
		'publishingPrinciples',
		'recipeInstructions',
		'recordedIn',
		'sdLicense',
		'sharedContent',
		'softwareHelp',
		'step',
		'steps',
		'subjectOf',
		'translationOfWork',
		'unnamedSourcesPolicy',
		'usageInfo',
		'verificationFactCheckingPolicy',
		'workExample',
		'workFeatured',
		'workPerformed',
		'workTranslation',
	),
	'DefinedTerm'    => array(
		'assesses',
		'biologicalRole',
		'certificationIdentification',
		'chemicalRole',
		'competencyRequired',
		'creativeWorkStatus',
		'credentialCategory',
		'educationalLevel',
		'educationalUse',
		'errorCode',
		'expressedIn',
		'financialAidEligible',
		'genre',
		'hasDefinedTerm',
		'hasMolecularFunction',
		'incentivizedItem',
		'industry',
		'isInvolvedInBiologicalProcess',
		'isLocatedInSubcellularLocation',
		'jobTitle',
		'keywords',
		'learningResourceType',
		'measurementMethod',
		'measurementTechnique',
		'pattern',
		'physicalRequirement',
		'potentialUse',
		'programType',
		'pronouns',
		'sensoryRequirement',
		'size',
		'skills',
		'taxonomicRange',
		'teaches',
		'valueReference',
		'variesBy',
	),
	'Thing'          => array(
		'about',
		'accelerationTime',
		'acceptedAnswer',
		'acceptedOffer',
		'acceptedPaymentMethod',
		'accessModeSufficient',
		'accommodationFloorPlan',
		'accountMinimumInflow',
		'accountOverdraftLimit',
		'accountablePerson',
		'acquireLicensePage',
		'acquiredFrom',
		'actionAccessibilityRequirement',
		'actionApplication',
		'actionOption',
		'actionPlatform',
		'actionProcess',
		'actionStatus',
		'actionableFeedbackPolicy',
		'activityDuration',
		'activityFrequency',
		'actor',
		'actors',
		'addOn',
		'additionalProperty',
		'address',
		'addressCountry',
		'addressRegion',
		'advanceBookingRequirement',
		'adverseOutcome',
		'affectedBy',
		'affiliation',
		'afterMedia',
		'agent',
		'agentInteractionStatistic',
		'aggregateElement',
		'aggregateRating',
		'aircraft',
		'album',
		'albumProductionType',
		'albumRelease',
		'albumReleaseType',
		'albums',
		'alternativeOf',
		'alumni',
		'alumniOf',
		'amenityFeature',
		'amount',
		'announcementLocation',
		'annualPercentageRate',
		'answerExplanation',
		'antagonist',
		'appearance',
		'applicableCountry',
		'applicableLocation',
		'applicantLocationRequirements',
		'application',
		'applicationContact',
		'appliesToDeliveryMethod',
		'appliesToPaymentMethod',
		'archiveHeld',
		'archivedAt',
		'area',
		'areaServed',
		'arrivalAirport',
		'arrivalBoatTerminal',
		'arrivalBusStop',
		'arrivalStation',
		'arterialBranch',
		'artist',
		'assesses',
		'associatedAnatomy',
		'associatedArticle',
		'associatedClaimReview',
		'associatedDisease',
		'associatedMedia',
		'associatedMediaReview',
		'associatedReview',
		'athlete',
		'attendee',
		'attendees',
		'audience',
		'audio',
		'authenticator',
		'author',
		'availability',
		'availableAtOrFrom',
		'availableChannel',
		'availableDeliveryMethod',
		'availableIn',
		'availableLanguage',
		'availableService',
		'availableStrength',
		'availableTest',
		'awayTeam',
		'backstory',
		'baseSalary',
		'bccRecipient',
		'bed',
		'beforeMedia',
		'beneficiaryBank',
		'billingAddress',
		'billingDuration',
		'bioChemInteraction',
		'bioChemSimilarity',
		'biologicalRole',
		'birthPlace',
		'blogPost',
		'blogPosts',
		'bloodSupply',
		'boardingPolicy',
		'bodyType',
		'bookFormat',
		'bookingAgent',
		'borrower',
		'branch',
		'branchOf',
		'brand',
		'breadcrumb',
		'broadcastAffiliateOf',
		'broadcastFrequency',
		'broadcastFrequencyValue',
		'broadcastOfEvent',
		'broadcastSignalModulation',
		'broadcaster',
		'broker',
		'businessDays',
		'businessFunction',
		'buyer',
		'byArtist',
		'byDay',
		'candidate',
		'caption',
		'cargoVolume',
		'carrier',
		'catalog',
		'category',
		'cause',
		'causeOf',
		'ccRecipient',
		'certificationIdentification',
		'certificationRating',
		'certificationStatus',
		'character',
		'characterAttribute',
		'cheatCode',
		'chemicalRole',
		'childTaxon',
		'children',
		'citation',
		'claimInterpreter',
		'coach',
		'code',
		'colleague',
		'colleagues',
		'collection',
		'colorSwatch',
		'colorist',
		'comment',
		'companyRegistration',
		'competencyRequired',
		'competitor',
		'composer',
		'comprisedOf',
		'connectedTo',
		'constraintProperty',
		'contactOption',
		'contactPoint',
		'contactPoints',
		'containedIn',
		'containedInPlace',
		'containsPlace',
		'containsSeason',
		'contentLocation',
		'contentRating',
		'contraindication',
		'contributor',
		'copyrightHolder',
		'correction',
		'correctionsPolicy',
		'costCategory',
		'costPerUnit',
		'countryOfOrigin',
		'course',
		'coursePrerequisites',
		'courseSchedule',
		'creativeWorkStatus',
		'creator',
		'credentialCategory',
		'creditedTo',
		'cssSelector',
		'currentExchangeRate',
		'customer',
		'customerRemorseReturnFees',
		'customerRemorseReturnLabelSource',
		'customerRemorseReturnShippingFeesAmount',
		'data',
		'dataFeedElement',
		'dataset',
		'dayOfWeek',
		'deathPlace',
		'defaultValue',
		'deliveryAddress',
		'deliveryLeadTime',
		'deliveryMethod',
		'deliveryStatus',
		'deliveryTime',
		'department',
		'departureAirport',
		'departureBoatTerminal',
		'departureBusStop',
		'departureStation',
		'depth',
		'description',
		'diagnosis',
		'diagram',
		'diet',
		'differentialDiagnosis',
		'digitalSourceType',
		'director',
		'directors',
		'discusses',
		'diseasePreventionInfo',
		'diseaseSpreadStatistics',
		'displayLocation',
		'distinguishingSign',
		'distribution',
		'diversityPolicy',
		'diversityStaffingReport',
		'documentation',
		'domainIncludes',
		'doseSchedule',
		'doseValue',
		'downPayment',
		'drainsTo',
		'driveWheelConfiguration',
		'dropoffLocation',
		'drug',
		'drugClass',
		'duplicateTherapy',
		'duration',
		'durationOfWarranty',
		'duringMedia',
		'earlyPrepaymentPenalty',
		'editor',
		'educationRequirements',
		'educationalAlignment',
		'educationalCredentialAwarded',
		'educationalLevel',
		'educationalUse',
		'eligibleCustomerType',
		'eligibleDuration',
		'eligibleQuantity',
		'eligibleRegion',
		'eligibleTransactionVolume',
		'eligibleWithSupplier',
		'employee',
		'employees',
		'employmentUnit',
		'encodesBioChemEntity',
		'encodesCreativeWork',
		'encoding',
		'encodings',
		'endOffset',
		'endorsee',
		'endorsers',
		'energyEfficiencyScaleMax',
		'energyEfficiencyScaleMin',
		'engineDisplacement',
		'enginePower',
		'engineType',
		'entertainmentBusiness',
		'episode',
		'episodes',
		'equal',
		'error',
		'errorCode',
		'estimatedCost',
		'estimatedSalary',
		'estimatesRiskOf',
		'ethicsPolicy',
		'event',
		'eventAttendanceMode',
		'eventSchedule',
		'eventStatus',
		'events',
		'evidenceLevel',
		'exampleOfWork',
		'exchangeRateSpread',
		'exerciseCourse',
		'exercisePlan',
		'exerciseRelatedDiet',
		'exifData',
		'expectsAcceptanceOf',
		'experienceRequirements',
		'expressedIn',
		'financialAidEligible',
		'firstAppearance',
		'firstPerformance',
		'floorLimit',
		'floorSize',
		'followee',
		'follows',
		'foodEstablishment',
		'foodEvent',
		'founder',
		'founders',
		'foundingLocation',
		'freeShippingThreshold',
		'fromLocation',
		'fuelCapacity',
		'fuelConsumption',
		'fuelEfficiency',
		'fuelType',
		'fulfillmentType',
		'functionalClass',
		'fundedItem',
		'funder',
		'funding',
		'game',
		'gameAvailabilityType',
		'gameItem',
		'gameLocation',
		'gamePlatform',
		'gameServer',
		'gameTip',
		'gender',
		'genre',
		'geo',
		'geoContains',
		'geoCoveredBy',
		'geoCovers',
		'geoCrosses',
		'geoDisjoint',
		'geoEquals',
		'geoIntersects',
		'geoMidpoint',
		'geoOverlaps',
		'geoTouches',
		'geoWithin',
		'geographicArea',
		'gettingTestedInfo',
		'governmentBenefitsInfo',
		'grantee',
		'greater',
		'greaterOrEqual',
		'guideline',
		'guidelineSubject',
		'handlingTime',
		'hasAdultConsideration',
		'hasBioChemEntityPart',
		'hasBroadcastChannel',
		'hasCategoryCode',
		'hasCertification',
		'hasCourse',
		'hasCourseInstance',
		'hasCredential',
		'hasDefinedTerm',
		'hasDeliveryMethod',
		'hasDigitalDocumentPermission',
		'hasEnergyConsumptionDetails',
		'hasEnergyEfficiencyCategory',
		'hasHealthAspect',
		'hasMap',
		'hasMeasurement',
		'hasMemberProgram',
		'hasMenu',
		'hasMenuItem',
		'hasMenuSection',
		'hasMerchantReturnPolicy',
		'hasMolecularFunction',
		'hasOccupation',
		'hasOfferCatalog',
		'hasPOS',
		'hasPart',
		'hasParticipationOffer',
		'hasRepresentation',
		'hasShippingService',
		'hasSponsorshipOffer',
		'hasStore',
		'hasTierBenefit',
		'hasTierRequirement',
		'hasTiers',
		'hasVariant',
		'healthCondition',
		'healthPlanCopay',
		'healthPlanCostSharing',
		'healthcareReportingData',
		'height',
		'hiringOrganization',
		'holdingArchive',
		'homeLocation',
		'homeTeam',
		'hospitalAffiliation',
		'hostingOrganization',
		'hoursAvailable',
		'identifier',
		'identifyingExam',
		'identifyingTest',
		'illustrator',
		'image',
		'imagingTechnique',
		'inAlbum',
		'inBroadcastLineup',
		'inCodeSet',
		'inDefinedTermSet',
		'inLanguage',
		'inPlaylist',
		'incentiveAmount',
		'incentiveStatus',
		'incentiveType',
		'incentivizedItem',
		'includedComposition',
		'includedDataCatalog',
		'includedInDataCatalog',
		'includedInHealthInsurancePlan',
		'includedRiskFactor',
		'includesAttraction',
		'includesHealthPlanFormulary',
		'includesHealthPlanNetwork',
		'includesObject',
		'incomeLimit',
		'increasesRiskOf',
		'industry',
		'ineligibleRegion',
		'infectiousAgentClass',
		'inker',
		'insertion',
		'instructor',
		'instrument',
		'intensity',
		'interactingDrug',
		'interactionService',
		'interactionStatistic',
		'interactionType',
		'interestRate',
		'interpretedAsClaim',
		'inventoryLevel',
		'inverseOf',
		'isAccessoryOrSparePartFor',
		'isBasedOn',
		'isBasedOnUrl',
		'isConsumableFor',
		'isEncodedByBioChemEntity',
		'isInvolvedInBiologicalProcess',
		'isLocatedInSubcellularLocation',
		'isPartOf',
		'isPartOfBioChemEntity',
		'isPlanForApartment',
		'isRelatedTo',
		'isSimilarTo',
		'isStoreOn',
		'isTierOf',
		'isVariantOf',
		'issuedBy',
		'issuedThrough',
		'item',
		'itemCondition',
		'itemDefectReturnFees',
		'itemDefectReturnLabelSource',
		'itemDefectReturnShippingFeesAmount',
		'itemListElement',
		'itemListOrder',
		'itemLocation',
		'itemOffered',
		'itemReviewed',
		'itemShipped',
		'itinerary',
		'jobLocation',
		'jobTitle',
		'jurisdiction',
		'keywords',
		'knows',
		'knowsAbout',
		'knowsLanguage',
		'landlord',
		'language',
		'layoutImage',
		'learningResourceType',
		'leaseLength',
		'legalAddress',
		'legalRepresentative',
		'legalStatus',
		'legislationAmends',
		'legislationApplies',
		'legislationChanges',
		'legislationCommences',
		'legislationConsolidates',
		'legislationCorrects',
		'legislationCountersignedBy',
		'legislationEnsuresImplementationOf',
		'legislationJurisdiction',
		'legislationLegalForce',
		'legislationLegalValue',
		'legislationPassedBy',
		'legislationRepeals',
		'legislationResponsible',
		'legislationTransposes',
		'legislationType',
		'lender',
		'lesser',
		'lesserOrEqual',
		'letterer',
		'license',
		'lifeEvent',
		'liveBlogUpdate',
		'loanMortgageMandateAmount',
		'loanPaymentAmount',
		'loanRepaymentForm',
		'loanTerm',
		'location',
		'locationCreated',
		'lodgingUnitType',
		'logo',
		'loser',
		'lyricist',
		'lyrics',
		'mainContentOfPage',
		'mainEntity',
		'mainEntityOfPage',
		'maintainer',
		'makesOffer',
		'manufacturer',
		'mapType',
		'marginOfError',
		'masthead',
		'material',
		'materialExtent',
		'mathExpression',
		'maximumIntake',
		'measuredProperty',
		'measurementDenominator',
		'measurementMethod',
		'measurementQualifier',
		'measurementTechnique',
		'mediaAuthenticityCategory',
		'mediaItemAppearance',
		'medicalAudience',
		'medicalSpecialty',
		'medicineSystem',
		'meetsEmissionStandard',
		'member',
		'memberOf',
		'members',
		'membershipPointsEarned',
		'mentions',
		'menu',
		'menuAddOn',
		'merchant',
		'messageAttachment',
		'mileageFromOdometer',
		'minimumPaymentDue',
		'missionCoveragePrioritiesPolicy',
		'model',
		'molecularWeight',
		'monoisotopicMolecularWeight',
		'monthlyMinimumRepaymentAmount',
		'musicArrangement',
		'musicBy',
		'musicGroupMember',
		'musicReleaseFormat',
		'nationality',
		'negativeNotes',
		'nerve',
		'nerveMotor',
		'netWorth',
		'newsUpdatesAndGuidelines',
		'nextItem',
		'noBylinesPolicy',
		'nonEqual',
		'nonprofitStatus',
		'normalRange',
		'numAdults',
		'numChildren',
		'numItems',
		'numberOfAccommodationUnits',
		'numberOfAvailableAccommodationUnits',
		'numberOfAxles',
		'numberOfBedrooms',
		'numberOfCredits',
		'numberOfDoors',
		'numberOfEmployees',
		'numberOfForwardGears',
		'numberOfPlayers',
		'numberOfPreviousOwners',
		'numberOfRooms',
		'nutrition',
		'object',
		'observationAbout',
		'occupancy',
		'occupationLocation',
		'occupationalCategory',
		'occupationalCredentialAwarded',
		'offeredBy',
		'offers',
		'openingHoursSpecification',
		'operatingSystem',
		'opponent',
		'option',
		'orderDelivery',
		'orderItemStatus',
		'orderQuantity',
		'orderStatus',
		'orderValue',
		'orderedItem',
		'organizer',
		'originAddress',
		'originalMediaLink',
		'originatesFrom',
		'owner',
		'ownershipFundingInfo',
		'owns',
		'parent',
		'parentItem',
		'parentOrganization',
		'parentService',
		'parentTaxon',
		'parents',
		'partOfEpisode',
		'partOfInvoice',
		'partOfOrder',
		'partOfSeason',
		'partOfSeries',
		'partOfSystem',
		'partOfTVSeries',
		'partOfTrip',
		'participant',
		'partySize',
		'passengerPriorityStatus',
		'pattern',
		'payload',
		'paymentMethod',
		'paymentMethodType',
		'paymentStatus',
		'penciler',
		'performer',
		'performerIn',
		'performers',
		'permissionType',
		'permitAudience',
		'photo',
		'photos',
		'physicalRequirement',
		'pickupLocation',
		'playMode',
		'populationType',
		'positiveNotes',
		'possibleTreatment',
		'postalCodeRange',
		'potentialAction',
		'potentialUse',
		'practicesAt',
		'predecessorOf',
		'pregnancyCategory',
		'preparation',
		'prescriptionStatus',
		'previousItem',
		'priceComponent',
		'priceComponentType',
		'priceSpecification',
		'priceType',
		'primaryImageOfPage',
		'primaryPrevention',
		'procedureType',
		'producer',
		'produces',
		'productSupported',
		'productionCompany',
		'program',
		'programMembershipUsed',
		'programPrerequisites',
		'programType',
		'programmingLanguage',
		'pronouns',
		'provider',
		'providesBroadcastService',
		'providesService',
		'publicTransportClosuresInfo',
		'publication',
		'publishedBy',
		'publishedOn',
		'publisher',
		'publisherImprint',
		'publishingPrinciples',
		'purchasePriceLimit',
		'purchaseType',
		'qualifications',
		'qualifiedExpense',
		'quarantineGuidelines',
		'quest',
		'question',
		'rangeIncludes',
		'readBy',
		'realEstateAgent',
		'recipe',
		'recipeIngredient',
		'recipeInstructions',
		'recipeYield',
		'recipient',
		'recognizedBy',
		'recognizingAuthority',
		'recommendedIntake',
		'recordLabel',
		'recordedAs',
		'recordedAt',
		'recordedIn',
		'recordingOf',
		'referee',
		'referenceQuantity',
		'referencesOrder',
		'refundType',
		'regionDrained',
		'regionsAllowed',
		'relatedAnatomy',
		'relatedCondition',
		'relatedDrug',
		'relatedStructure',
		'relatedTherapy',
		'relatedTo',
		'releaseOf',
		'releasedEvent',
		'relevantOccupation',
		'relevantSpecialty',
		'repetitions',
		'replacee',
		'replacer',
		'requiredCollateral',
		'requiredQuantity',
		'requiresSubscription',
		'reservationFor',
		'reservationStatus',
		'reservedTicket',
		'restPeriods',
		'restockingFee',
		'result',
		'resultComment',
		'resultReview',
		'returnFees',
		'returnLabelSource',
		'returnMethod',
		'returnPolicyCategory',
		'returnPolicyCountry',
		'returnPolicySeasonalOverride',
		'returnShippingFeesAmount',
		'review',
		'reviewAspect',
		'reviewRating',
		'reviewedBy',
		'reviews',
		'riskFactor',
		'roofLoad',
		'rsvpResponse',
		'runsTo',
		'runtimePlatform',
		'salaryUponCompletion',
		'schoolClosuresInfo',
		'screenshot',
		'sdLicense',
		'sdPublisher',
		'season',
		'seasonalOverride',
		'seasons',
		'seatingCapacity',
		'seatingType',
		'secondaryPrevention',
		'seeks',
		'seller',
		'sender',
		'sensoryRequirement',
		'sensoryUnit',
		'seriousAdverseOutcome',
		'serverStatus',
		'serviceArea',
		'serviceAudience',
		'serviceLocation',
		'serviceOperator',
		'serviceOutput',
		'servicePhone',
		'servicePostalAddress',
		'serviceSmsNumber',
		'serviceType',
		'sharedContent',
		'shippingConditions',
		'shippingDestination',
		'shippingDetails',
		'shippingOrigin',
		'shippingRate',
		'sibling',
		'siblings',
		'signDetected',
		'signOrSymptom',
		'size',
		'sizeGroup',
		'sizeSystem',
		'skills',
		'softwareAddOn',
		'softwareHelp',
		'softwareRequirements',
		'source',
		'sourceOrganization',
		'sourcedFrom',
		'spatial',
		'spatialCoverage',
		'speakable',
		'specialOpeningHoursSpecification',
		'specialty',
		'speed',
		'spokenByCharacter',
		'sponsor',
		'sportsActivityLocation',
		'sportsEvent',
		'sportsTeam',
		'spouse',
		'stage',
		'starRating',
		'startOffset',
		'statType',
		'status',
		'steeringPosition',
		'step',
		'steps',
		'study',
		'studyDesign',
		'studyLocation',
		'studySubject',
		'subEvent',
		'subEvents',
		'subOrganization',
		'subReservation',
		'subStructure',
		'subTest',
		'subTrip',
		'subjectOf',
		'subtitleLanguage',
		'successorOf',
		'suggestedAge',
		'suggestedAnswer',
		'suggestedGender',
		'suggestedMeasurement',
		'suitableForDiet',
		'superEvent',
		'supersededBy',
		'supply',
		'supplyTo',
		'supportingData',
		'syllabusSections',
		'target',
		'targetCollection',
		'targetProduct',
		'taxonRank',
		'taxonomicRange',
		'teaches',
		'thumbnail',
		'ticketedSeat',
		'toLocation',
		'toRecipient',
		'tocContinuation',
		'tocEntry',
		'tongueWeight',
		'tool',
		'torque',
		'totalPaymentDue',
		'totalPrice',
		'touristType',
		'track',
		'tracks',
		'trailer',
		'trailerWeight',
		'trainingSalary',
		'transitTime',
		'translationOfWork',
		'translator',
		'travelBans',
		'trialDesign',
		'tributary',
		'tripOrigin',
		'typeOfBed',
		'typeOfGood',
		'typicalCreditsPerTerm',
		'typicalTest',
		'underName',
		'unnamedSourcesPolicy',
		'usageInfo',
		'usedToDiagnose',
		'usesDevice',
		'validForMemberTier',
		'validIn',
		'value',
		'valueReference',
		'variableMeasured',
		'variesBy',
		'vehicleEngine',
		'vehicleSeatingCapacity',
		'vehicleSpecialUsage',
		'vehicleTransmission',
		'vendor',
		'verificationFactCheckingPolicy',
		'video',
		'warranty',
		'warrantyPromise',
		'warrantyScope',
		'webFeed',
		'weight',
		'weightTotal',
		'wheelbase',
		'width',
		'winner',
		'workExample',
		'workFeatured',
		'workLocation',
		'workPerformed',
		'workPresented',
		'workTranslation',
		'workload',
		'worksFor',
		'xpath',
		'yearlyRevenue',
		'yearsInOperation',
		'yield',
	),
	'ItemList'       => array(
		'acceptedAnswer',
		'accessModeSufficient',
		'itinerary',
		'negativeNotes',
		'positiveNotes',
		'recipeIngredient',
		'recipeInstructions',
		'steps',
		'suggestedAnswer',
		'track',
	),
);
