<?php
/**
 * Dashboard widget welcome message block template.
 *
 * @since 1.8.8
 * @deprecated 1.9.7
 *
 * @var string $welcome_message Welcome message.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
