.aioseo-wizard-search-appearance{color:#141b38}.aioseo-wizard-search-appearance .aioseo-settings-row .aioseo-radio-toggle{margin-top:8px}.aioseo-wizard-search-appearance .aioseo-settings-row .edit-site-info-activator{margin-top:8px;display:flex;align-items:center;justify-content:center;position:relative}.aioseo-wizard-search-appearance .aioseo-settings-row .edit-site-info-activator .aioseo-google-search-preview{border:1px solid #E8E8EB;flex:1;padding:16px}.aioseo-wizard-search-appearance .aioseo-settings-row .edit-site-info-activator .action{position:absolute;top:1;left:1;right:1;bottom:1}.aioseo-wizard-search-appearance .aioseo-settings-row .edit-site-info-activator .background-fade{position:absolute;inset:0;border:1px solid #E8E8EB;cursor:pointer}.aioseo-wizard-search-appearance .aioseo-settings-row .edit-site-info-activator.hover .background-fade{background:#fff;opacity:.7}.aioseo-wizard-search-appearance .aioseo-settings-row.enable-sitemaps .aioseo-checkbox{font-weight:600}.aioseo-wizard-search-appearance .aioseo-settings-row.post-types .aioseo-toggle{color:#141b38;font-weight:600}.aioseo-wizard-search-appearance .go-back a{color:#434960;font-size:14px}
