/* General CSS */
.ehssl-margin-10{
    margin: 10px;
}
.ehssl-margin-top-10{
    margin-top: 10px;
}
.ehssl-margin-bottom-10{
    margin-bottom: 10px;
}
.ehssl-hidden{
    display: none;
}
.ehssl-green-success-text{
    font-weight: bold;
    color: green;    
}
.ehssl-red-error-text{
    font-weight: bold;
    color: red;
}
.ehssl-box-shadow {
    box-shadow: 0 1px 1px rgba(0,0,0,.04);
}

/* Wrap directly with this class (not to be used with a paragraph tag) */
.ehssl-yellow-box{
    margin: 10px 0px;
    padding: 10px;
    background-color: #FFFFE0;
    border-color: #E6DB55;
    border-radius: 3px 3px 3px 3px;
    border-style: solid;
    border-width: 1px;
}

/* Wrap directly with this class (not to be used with a paragraph tag) */
.ehssl-red-box {
    margin: 10px 0px;
    padding: 10px;
    background-color: #FFEBE8;
    border-color: #CC0000;
    color: #333333;
    border-radius: 3px 3px 3px 3px;
    border-style: solid;
    border-width: 1px;
}

/* Wrap directly with this class (not to be used with a paragraph tag) */
.ehssl-orange-box{
    margin: 10px 0px;
    padding: 15px 10px;
    color: #3F2502;
    background-color: #FFF6D5;
    border-color: #D1B655;
    border-radius: 3px 3px 3px 3px;
    border-style: solid;
    border-width: 1px;
}

/* Wrap directly with this class (not to be used with a paragraph tag) */
.ehssl-white-box{
    margin: 10px 0px;
    padding: 15px 10px;
    color: #3c434a;
    background-color: #fff;
    border-color: #c3c4c7;
    border-width: 1px;
    border-radius: 3px 3px 3px 3px;
    border-style: solid;
}

/* Wrap directly with this class (not to be used with a paragraph tag) */
.ehssl-grey-box{
    margin: 10px 0px;
    padding: 15px 10px;
    background-color: #DDDDDD;
    border-color: #CCCCCC;
    border-radius: 3px 3px 3px 3px;
    border-style: solid;
    border-width: 1px;
}

/* Wrap directly with this class (not to be used with a paragraph tag) */
.ehssl-green-box {
    margin: 10px 0px;
    padding: 15px 10px;
    background-color: #CCF4D6;
    border-color: #059B53;
    color: #043B14;
    border-radius: 3px 3px 3px 3px;
    border-style: solid;
    border-width: 1px;
}

/* Wrap directly with this class (not to be used with a paragraph tag) */
.ehssl-blue-box {
    margin: 10px 0px;
    padding: 15px 10px;
    background-color: #E7F4FE;
    border-color: #AACEE6;
    color: #1D263B;
    border-radius: 3px 3px 3px 3px;
    border-style: solid;
    border-width: 1px;
}

/*
* styles for settings page
*/
.rewrite_info {
    color: rgb(136, 136, 136); 
    font-size: 10px;
    clear: both;
}

.rewrite_item_delete_btn, .rewrite_item_add_btn {
    display: inline-flex !important;
    align-items: center;
    justify-content: center;
    padding-left: 6px !important;
    padding-right: 6px !important;
	cursor: pointer;
}
.rewrite_select_item .rewrite_delete_select_item{
	padding: 0 6px 0 6px;
}

.rewrite_item_blank_error{
	color: red;
	display: none;
}

/*----- Email tags hint ----- */

.ehssl-tags-table-cont {
    margin-top: 10px;
}

a.ehssl-toggle {
    text-decoration: none;
    border-bottom: 1px dashed;
}

a.ehssl-toggle.toggled-on::after {
    content: " ↑";
}

a.ehssl-toggle.toggled-off::after {
    content: " ↓";
}

table.ehssl-tags-hint td, table.ehssl-tags-hint th {
    padding: 5px 10px;
}

table.ehssl-tags-hint {
    background: #fff;
    width: 100%;
}

table.ehssl-tags-hint td.ehssl-tag-name {
    width: 150px;
    border-bottom: 1px solid #ededed;
}

table.ehssl-tags-hint td.ehssl-tag-descr {
    width: 70%;
    border-bottom: 1px solid #ededed;
}

/*----- END Email tags hint ----- */

.ehssl-settings-field-cat-1{
    width: 70px;
}

.ehssl-settings-field-cat-2{
    width: 400px;
}

.ehssl-settings-field-cat-3{
    width: 650px;
}

@media only screen and (max-width: 782px){
    .ehssl-settings-field-cat-1,
    .ehssl-settings-field-cat-2,
    .ehssl-settings-field-cat-3{
        width: 100%;
    }
}