.aioseo-feature-manager .aioseo-alert{margin-bottom:var(--aioseo-gutter)}.aioseo-feature-manager .aioseo-alert.install-failed{margin-top:var(--aioseo-gutter);margin-bottom:0}.aioseo-feature-manager .aioseo-alert .buttons{margin-top:8px}[dir=ltr] .aioseo-feature-manager .aioseo-alert .buttons .aioseo-button+.aioseo-button{margin-left:12px}[dir=rtl] .aioseo-feature-manager .aioseo-alert .buttons .aioseo-button+.aioseo-button{margin-right:12px}.aioseo-feature-manager .aioseo-feature-manager-header{border-bottom:2px solid #E8E8EB;margin:0 0 var(--aioseo-gutter);display:flex;align-items:center}.aioseo-feature-manager .aioseo-feature-manager-header .buttons{flex:1 0}.aioseo-feature-manager .aioseo-feature-manager-header .buttons .aioseo-button{margin-bottom:10px}[dir=ltr] .aioseo-feature-manager .aioseo-feature-manager-header .buttons .aioseo-button{margin-right:16px}[dir=rtl] .aioseo-feature-manager .aioseo-feature-manager-header .buttons .aioseo-button{margin-left:16px}.aioseo-feature-manager .aioseo-feature-manager-header .aioseo-input{max-width:325px;margin-bottom:10px}.aioseo-feature-manager .aioseo-feature-manager-addons>.aioseo-row{--total-gap-width: calc(2 * var(--aioseo-gutter));--aioseo-col-max-width: calc((100% - var(--total-gap-width)) / 3);display:grid;gap:var(--aioseo-gutter);grid-template-columns:repeat(auto-fill,minmax(max(290px,var(--aioseo-col-max-width)),1fr))}.aioseo-feature-manager .aioseo-feature-manager-addons>.aioseo-row>*{max-width:none}.aioseo-feature-manager .aioseo-feature-manager-addons>.aioseo-row .aioseo-col{max-width:none}.aioseo-feature-manager .feature-manager-upsell{margin-top:var(--aioseo-gutter)}.aioseo-feature-manager-modal .aioseo-modal-body{padding:20px 40px 40px;display:flex;align-items:center;justify-content:center;flex-direction:column;position:relative}.aioseo-feature-manager-modal .aioseo-modal-body h3{font-size:18px;margin-bottom:16px}.aioseo-feature-manager-modal .aioseo-modal-body .reset-description{font-size:14px;color:#141b38;margin-bottom:16px;text-align:center;max-width:515px}.aioseo-feature-manager-modal .aioseo-modal-body button.close{position:absolute;top:11px;width:24px;height:24px;background-color:#fff;border:none;display:flex;align-items:center}[dir=ltr] .aioseo-feature-manager-modal .aioseo-modal-body button.close{right:11px}[dir=rtl] .aioseo-feature-manager-modal .aioseo-modal-body button.close{left:11px}.aioseo-feature-manager-modal .aioseo-modal-body button.close svg.aioseo-close{cursor:pointer;width:14px;height:14px}.aioseo-feature-manager-modal .aioseo-modal-body .aioseo-button:not(.close){margin-top:16px}
