.aioseo-ui-element-slider svg.aioseo-new-page{width:100%;height:auto;max-width:45px}.aioseo-ui-element-slider .new-page .aioseo-row{margin:0}.aioseo-ui-element-slider .new-page svg.aioseo-external{width:14px;height:14px}[dir=ltr] .aioseo-ui-element-slider .new-page svg.aioseo-external{margin-right:10px}[dir=rtl] .aioseo-ui-element-slider .new-page svg.aioseo-external{margin-left:10px}.aioseo-ui-element-slider .new-page .aioseo-description{color:#434960}.aioseo-ui-element-slider .new-page button.aioseo-html-sitemaps-disabled-button{border:1px solid #DCDDE1;color:#8c8f9a;background-color:#f3f4f5;cursor:default}.aioseo-ui-element-slider .new-page .aioseo-alert{width:100%;margin:8px 8px 0}.aioseo-ui-element-slider .new-page .aioseo-loading-spinner{position:relative}.aioseo-app .aioseo-html-sitemap .aioseo-html-sitemap-settings .aioseo-select.medium{max-width:300px}
