.aioseo-monsterinsights-intro.aioseo-card.aioseo-card--intro{background-color:#f8fbff;box-shadow:none}.aioseo-monsterinsights-intro .aioseo-analytics__intro{text-align:center}.aioseo-monsterinsights-intro .aioseo-analytics__intro .intro-image{max-width:300px;margin:0 auto;display:flex;justify-content:space-between;font-size:45px;align-items:center}.aioseo-monsterinsights-intro .aioseo-analytics__intro .intro-image .aioseo-logo-gear{width:100%;max-width:90px;color:#005ae0}.aioseo-monsterinsights-intro .aioseo-analytics__intro .intro-image span{color:#df2a4a}.aioseo-monsterinsights-intro .aioseo-analytics__intro .intro-heading{margin:24px auto;font-size:36px;line-height:1.25}.aioseo-monsterinsights-intro .aioseo-analytics__intro p{margin:0 auto}.aioseo-monsterinsights-intro .aioseo-analytics__intro .aioseo-button{margin-top:30px}.aioseo-monsterinsights-intro .preview-list{display:flex;align-items:center;max-width:800px;margin:24px auto 0}[dir=ltr] .aioseo-monsterinsights-intro .preview-list{text-align:left}[dir=rtl] .aioseo-monsterinsights-intro .preview-list{text-align:right}[dir=ltr] .aioseo-monsterinsights-intro .preview-list ul{margin-left:24px}[dir=rtl] .aioseo-monsterinsights-intro .preview-list ul{margin-right:24px}.aioseo-monsterinsights-intro .preview-list li{display:flex;align-items:flex-start;font-size:16px}.aioseo-monsterinsights-intro .aioseo-circle-check{color:#00aa63;max-width:18px;margin-top:3px}[dir=ltr] .aioseo-monsterinsights-intro .aioseo-circle-check{margin-right:18px}[dir=rtl] .aioseo-monsterinsights-intro .aioseo-circle-check{margin-left:18px}
