.info-urls-row .field-description{display:block;padding-bottom:6px;font-size:12px}.aioseo-locations-lite .aioseo-locations-card .content{min-height:550px}.aioseo-locations-lite .location-description{margin-top:0;margin-bottom:16px}.aioseo-locations-lite .location-description.mb-0{margin-bottom:0}.aioseo-locations-lite .aioseo-input,.aioseo-locations-lite .aioseo-select,.aioseo-locations-lite .aioseo-multiselect{max-width:480px}.aioseo-locations-lite .aioseo-tag{background:#dcdde1;padding:3px 8px;border-radius:3px}[dir=ltr] .aioseo-locations-lite .aioseo-tag{margin-right:8px}[dir=rtl] .aioseo-locations-lite .aioseo-tag{margin-left:8px}.aioseo-locations-lite .info-business-image .image-upload{display:flex}.aioseo-locations-lite .info-business-image .image-upload .aioseo-input-container{width:100%;max-width:445px}[dir=ltr] .aioseo-locations-lite .info-business-image .image-upload .aioseo-input-container{margin-right:8px}[dir=rtl] .aioseo-locations-lite .info-business-image .image-upload .aioseo-input-container{margin-left:8px}.aioseo-locations-lite .info-business-image .image-upload .aioseo-input-container .aioseo-input{width:100%}.aioseo-locations-lite .info-business-image .image-upload .insert-image{min-width:214px}[dir=ltr] .aioseo-locations-lite .info-business-image .image-upload .insert-image{margin-right:8px}[dir=rtl] .aioseo-locations-lite .info-business-image .image-upload .insert-image{margin-left:8px}.aioseo-locations-lite .info-business-image .image-upload .insert-image svg.aioseo-circle-plus{width:13px;height:13px}[dir=ltr] .aioseo-locations-lite .info-business-image .image-upload .insert-image svg.aioseo-circle-plus{margin-right:10px}[dir=rtl] .aioseo-locations-lite .info-business-image .image-upload .insert-image svg.aioseo-circle-plus{margin-left:10px}.aioseo-locations-lite .info-business-image img{margin-top:20px;width:auto;max-width:525px;max-height:525px;height:auto}
