.aioseo-search-statistics-authentication-alert,.aioseo-app .sample-data-alert{margin-bottom:20px}.aioseo-app .aioseo-card{margin:0 0 20px}.aioseo-app .aioseo-card:has(.aioseo-card-footer){position:relative;padding-bottom:44px}.aioseo-app .aioseo-card:has(.aioseo-card-footer) .content{position:static}.aioseo-app .aioseo-datepicker-picker{font-weight:700}.aioseo-app .aioseo-wp-table tbody td{font-size:14px}.aioseo-app .aioseo-wp-table tbody .object-title a{font-weight:700;color:#141b38}.aioseo-app .aioseo-wp-table tbody .object-title a:hover{color:#005ae0}.aioseo-app .aioseo-wp-table tbody .no-results{font-size:16px}.aioseo-app .connect-cta{position:relative}
