.aioseo-draggable{position:absolute}[dir=ltr] .aioseo-pagebuilder-modal .aioseo-score-button[data-v-8c4e05e7]{margin-left:auto;margin-right:20px}[dir=rtl] .aioseo-pagebuilder-modal .aioseo-score-button[data-v-8c4e05e7]{margin-right:auto;margin-left:20px}
