.card-block-query .aioseo-card{border-radius:4px;margin:0}.card-block-query .header{padding:16px;border-bottom:none}.card-block-query .header .header-title span{font-size:14px;font-weight:400}.card-block-query .query-arg-logs{width:100%}.card-block-query .query-arg-logs .query-arg-options{padding:16px;display:flex;align-items:center;gap:16px;background:#f3f4f5;border-style:solid;border-width:1px 0;border-color:#d0d1d7}.card-block-query .query-arg-logs .query-arg-options .query-arg-key{flex:1}.card-block-query .query-arg-logs .query-arg-options .query-arg-value{flex:2}.card-block-query .query-arg-logs .query-arg-button{padding:8px 16px}.card-block-query .query-arg-logs .query-arg-button svg.aioseo-circle-plus{width:16px;height:16px}[dir=ltr] .card-block-query .query-arg-logs .query-arg-button svg.aioseo-circle-plus{margin-right:8px}[dir=rtl] .card-block-query .query-arg-logs .query-arg-button svg.aioseo-circle-plus{margin-left:8px}.aioseo-query-args-table{margin-top:20px}.aioseo-query-args-table thead th,.aioseo-query-args-table tfoot th{white-space:nowrap}[dir=ltr] .aioseo-query-args-table .aioseo-wp-table .widefat .check-column{padding:11px 0 11px 3px}[dir=rtl] .aioseo-query-args-table .aioseo-wp-table .widefat .check-column{padding:11px 3px 11px 0}.aioseo-query-args-table .aioseo-tooltip{display:inline-block;margin:0;line-height:10px;vertical-align:sub}.aioseo-query-args-table .aioseo-tooltip svg{cursor:pointer;height:16px;width:16px}.aioseo-query-args-table .aioseo-alert{margin:20px 0}.aioseo-query-args-table .actions-query-args div{display:flex;align-items:start;gap:5px}.aioseo-query-args-table .actions-query-args div span{cursor:pointer;color:#005ae0}.aioseo-query-args-table .actions-query-args div span.separator{color:#8c8f9a}.aioseo-query-args-table .actions-query-args div span.no-link{cursor:text;color:#141b38}.block-arg-modal .modal-container{max-width:650px!important}.block-arg-modal .aioseo-modal-body{display:flex;align-items:center;justify-content:center;flex-direction:column;position:relative;margin:20px 0 50px}.block-arg-modal .aioseo-modal-body button.close{position:absolute;top:0;width:24px;height:24px;background-color:#fff;border:none;display:flex;align-items:center}[dir=ltr] .block-arg-modal .aioseo-modal-body button.close{right:11px}[dir=rtl] .block-arg-modal .aioseo-modal-body button.close{left:11px}.block-arg-modal .aioseo-modal-body button.close svg.aioseo-close{cursor:pointer;width:14px;height:14px}.block-arg-modal .aioseo-modal-body h3{font-size:20px;margin-bottom:16px}.block-arg-modal .aioseo-modal-body .reset-description{font-size:16px;color:#141b38;margin-bottom:16px;text-align:center;max-width:515px}.block-arg-modal .aioseo-modal-body .aioseo-button:not(.close):not(.import){margin-top:16px}.aioseo-search-appearance-advanced .description-format .add-tags,.aioseo-search-appearance-advanced .paged-format .add-tags{margin-top:0}.aioseo-search-appearance-advanced .description-notice{margin-top:10px}.aioseo-search-appearance-advanced .run-shortcodes-alert{margin-top:12px}.aioseo-search-appearance-advanced svg.aioseo-external{width:14px;height:14px}[dir=ltr] .aioseo-search-appearance-advanced svg.aioseo-external{margin-right:10px}[dir=rtl] .aioseo-search-appearance-advanced svg.aioseo-external{margin-left:10px}.aioseo-search-appearance-advanced .aioseo-alert{margin-top:16px}.aioseo-search-appearance-advanced .aioseo-rss-content-advanced .aioseo-settings-row .aioseo-col,.aioseo-search-appearance-advanced #aioseo-query-arg-monitoring .aioseo-settings-row .aioseo-col{padding-top:0}.aioseo-search-appearance-advanced .aioseo-rss-content-advanced .aioseo-description p,.aioseo-search-appearance-advanced #aioseo-query-arg-monitoring .aioseo-description p{font-size:14px;line-height:1.8;margin:8px 0 0}.aioseo-search-appearance-advanced .aioseo-rss-content-advanced .aioseo-description div.rss-link,.aioseo-search-appearance-advanced #aioseo-query-arg-monitoring .aioseo-description div.rss-link{margin:8px 0 0}.aioseo-search-appearance-advanced .card-block-query .header{height:unset}.aioseo-search-appearance-advanced .card-block-query .content{padding:0!important}.aioseo-search-appearance-advanced .table-retention .aioseo-select{max-width:200px}
