.aioseo-twitter-preview[data-v-3ab503eb]{--primary-text: #0f1419;--secondary-text: #536471;--tertiary-text: #cfd9de;align-items:center;background-color:#f0f2f5;display:flex;justify-content:center;padding:20px}.aioseo-twitter-preview .twitter-post[data-v-3ab503eb]{background-color:#fff;border-radius:16px;border:1px solid #E8E8EB;max-width:500px;width:100%}.aioseo-twitter-preview .twitter-post .twitter-header[data-v-3ab503eb]{height:65px;padding:0 18px;display:flex;align-items:center}.aioseo-twitter-preview .twitter-post .twitter-header .profile-photo[data-v-3ab503eb]{overflow:hidden;width:40px;height:40px;border:1px solid #E8E8EB;border-radius:50%}.aioseo-twitter-preview .twitter-post .twitter-header .profile-photo svg[data-v-3ab503eb]{height:100%;width:100%}.aioseo-twitter-preview .twitter-post .twitter-header .poster[data-v-3ab503eb]{flex:1 0 auto}[dir=ltr] .aioseo-twitter-preview .twitter-post .twitter-header .poster[data-v-3ab503eb]{margin-left:10px}[dir=rtl] .aioseo-twitter-preview .twitter-post .twitter-header .poster[data-v-3ab503eb]{margin-right:10px}.aioseo-twitter-preview .twitter-post .twitter-header .poster .poster-name[data-v-3ab503eb]{font-size:15px;color:var(--primary-text);font-weight:600}.aioseo-twitter-preview .twitter-post .twitter-header .poster .poster-username[data-v-3ab503eb]{color:var(--secondary-text);font-weight:500;font-size:13px}.aioseo-twitter-preview .twitter-post .twitter-container[data-v-3ab503eb]{margin-bottom:0;padding:0 20px 20px}.aioseo-twitter-preview .twitter-post .twitter-container.summary .twitter-content[data-v-3ab503eb]{flex-direction:row}.aioseo-twitter-preview .twitter-post .twitter-container.summary .twitter-content .twitter-image-preview[data-v-3ab503eb]{align-items:center;background-color:#f7f9f9;background-position:center center;background-repeat:no-repeat;background-size:cover;display:flex;justify-content:center;min-height:127px;min-width:127px}[dir=ltr] .aioseo-twitter-preview .twitter-post .twitter-container.summary .twitter-content .twitter-image-preview[data-v-3ab503eb]{border-right:1px solid var(--tertiary-text)}[dir=rtl] .aioseo-twitter-preview .twitter-post .twitter-container.summary .twitter-content .twitter-image-preview[data-v-3ab503eb]{border-left:1px solid var(--tertiary-text)}.aioseo-twitter-preview .twitter-post .twitter-container.summary .twitter-content .twitter-image-preview svg.aioseo-book[data-v-3ab503eb]{width:50px;color:var(--secondary-text)}.aioseo-twitter-preview .twitter-post .twitter-container.summary_large_image .twitter-image-preview[data-v-3ab503eb]{overflow:hidden;padding-top:56.25%;position:relative}.aioseo-twitter-preview .twitter-post .twitter-container.summary_large_image .twitter-image-preview img[data-v-3ab503eb]{height:100%;object-fit:cover;position:absolute;top:0;width:100%}[dir=ltr] .aioseo-twitter-preview .twitter-post .twitter-container.summary_large_image .twitter-image-preview img[data-v-3ab503eb]{left:0}[dir=rtl] .aioseo-twitter-preview .twitter-post .twitter-container.summary_large_image .twitter-image-preview img[data-v-3ab503eb]{right:0}.aioseo-twitter-preview .twitter-post .twitter-container.summary_large_image .twitter-image-preview svg.aioseo-book[data-v-3ab503eb]{display:none}.aioseo-twitter-preview .twitter-post .twitter-container .twitter-content[data-v-3ab503eb]{border-radius:16px;overflow:hidden;display:flex;flex-direction:column;border:1px solid var(--tertiary-text)}.aioseo-twitter-preview .twitter-post .twitter-container .twitter-content .twitter-site-description[data-v-3ab503eb]{display:flex;flex-direction:column;gap:2px;justify-content:center;padding:12px}.aioseo-twitter-preview .twitter-post .twitter-container .twitter-content .twitter-site-description .site-domain[data-v-3ab503eb],.aioseo-twitter-preview .twitter-post .twitter-container .twitter-content .twitter-site-description .site-title[data-v-3ab503eb],.aioseo-twitter-preview .twitter-post .twitter-container .twitter-content .twitter-site-description .site-description[data-v-3ab503eb]{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif;font-style:normal;font-weight:400;line-height:1.4;letter-spacing:normal;margin:0;padding:0;text-transform:none;overflow-wrap:break-word;word-break:break-word}.aioseo-twitter-preview .twitter-post .twitter-container .twitter-content .twitter-site-description .site-domain[data-v-3ab503eb]{color:var(--secondary-text);font-size:13px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.aioseo-twitter-preview .twitter-post .twitter-container .twitter-content .twitter-site-description .site-title[data-v-3ab503eb]{color:var(--primary-text);font-size:17px}.aioseo-twitter-preview .twitter-post .twitter-container .twitter-content .twitter-site-description .site-description[data-v-3ab503eb]{color:var(--secondary-text);font-size:14px}
