.aioseo-feature-card{height:100%;border:1px solid #E8E8EB;background:#fff;box-shadow:0 2px 5px #0000000d;color:#141b38;display:flex;flex-direction:column}.aioseo-feature-card .feature-card-body{line-height:22px;padding:20px;flex:1}.aioseo-feature-card .feature-card-body.static{padding:20px}.aioseo-feature-card .feature-card-body .feature-card-header{display:flex;align-items:center;font-size:14px;font-weight:600;margin-bottom:12px}.aioseo-feature-card .feature-card-body .feature-card-header img,.aioseo-feature-card .feature-card-body .feature-card-header svg{width:24px;height:24px}[dir=ltr] .aioseo-feature-card .feature-card-body .feature-card-header img,[dir=ltr] .aioseo-feature-card .feature-card-body .feature-card-header svg{margin-right:10px}[dir=rtl] .aioseo-feature-card .feature-card-body .feature-card-header img,[dir=rtl] .aioseo-feature-card .feature-card-body .feature-card-header svg{margin-left:10px}.aioseo-feature-card .feature-card-body .feature-card-description{color:#434960;font-size:14px}.aioseo-feature-card .feature-card-body .feature-card-description .learn-more{margin-top:12px;font-size:14px}.aioseo-feature-card .feature-card-footer{padding:15px}.aioseo-feature-card .feature-card-footer:not(.upgrade-required){border:2px solid #fff;background-color:#f9f9fa;padding:12px 20px;min-height:43px}.aioseo-feature-card .feature-card-footer .feature-card-install-activate{display:flex;align-items:center;justify-content:flex-end;height:30px;position:relative}.aioseo-feature-card .feature-card-footer .feature-card-install-activate .aioseo-loading-spinner{position:absolute}[dir=ltr] .aioseo-feature-card .feature-card-footer .feature-card-install-activate .aioseo-loading-spinner{left:0}[dir=rtl] .aioseo-feature-card .feature-card-footer .feature-card-install-activate .aioseo-loading-spinner{right:0}.aioseo-feature-card .feature-card-footer .feature-card-install-activate .version{flex:1}.aioseo-feature-card .feature-card-footer .feature-card-install-activate .status{font-weight:600;font-size:14px}[dir=ltr] .aioseo-feature-card .feature-card-footer .feature-card-install-activate .aioseo-toggle .toggle-content{margin-right:0;margin-left:10px}[dir=rtl] .aioseo-feature-card .feature-card-footer .feature-card-install-activate .aioseo-toggle .toggle-content{margin-left:0;margin-right:10px}.aioseo-feature-card .feature-card-footer .feature-card-upgrade-cta{display:flex;align-items:center;justify-content:flex-end}.aioseo-feature-card .feature-card-footer .feature-card-upgrade-cta .aioseo-tooltip{margin:0;display:inline-block;flex:1}.aioseo-feature-card .feature-card-footer .feature-card-upgrade-cta .aioseo-tooltip .version{cursor:pointer;color:#005ae0;font-weight:600;text-decoration:underline}.aioseo-feature-card .feature-card-footer.installed .feature-card-install-activate .status{color:#8c8f9a}.aioseo-feature-card-modal .aioseo-modal-body{padding:20px 40px 40px;display:flex;align-items:center;justify-content:center;flex-direction:column;position:relative}.aioseo-feature-card-modal .aioseo-modal-body h3{font-size:20px;margin-bottom:16px}.aioseo-feature-card-modal .aioseo-modal-body .reset-description{font-size:16px;color:#141b38;margin-bottom:16px;text-align:center;max-width:515px}.aioseo-feature-card-modal .aioseo-modal-body button.close{position:absolute;top:11px;width:24px;height:24px;background-color:#fff;border:none;display:flex;align-items:center}[dir=ltr] .aioseo-feature-card-modal .aioseo-modal-body button.close{right:11px}[dir=rtl] .aioseo-feature-card-modal .aioseo-modal-body button.close{left:11px}.aioseo-feature-card-modal .aioseo-modal-body button.close svg.aioseo-close{cursor:pointer;width:14px;height:14px}.aioseo-feature-card-modal .aioseo-modal-body .aioseo-button:not(.close){margin-top:16px}
