.analyze-main{display:flex;flex-direction:column;align-items:center;justify-self:center;font-size:16px}.analyze-main .analyze-header{font-size:24px;line-height:30px;font-weight:600;margin-bottom:12px}.analyze-main .analyze-description{text-align:center;font-size:16px;line-height:24px}.analyze-main .analyze-input{margin-top:12px;display:flex;align-items:center;gap:8px}.analyze-main .analyze-input .aioseo-input{min-width:430px}[dir=ltr] .analyze-main .analyze-input .aioseo-input{margin-right:10px}[dir=rtl] .analyze-main .analyze-input .aioseo-input{margin-left:10px}.analyze-progress{min-width:548px;margin-top:30px;background:#dcdde1;justify-content:flex-start;border-radius:100px;align-items:center;position:relative;padding:0;display:flex;height:10px;width:500px}.analyze-progress .analyze-progress-value{animation:analyze-load 2s normal forwards;border-radius:100px;background:#005ae0;height:10px;width:0}@keyframes analyze-load{0%{width:0}to{width:100%}}.aioseo-analyze-score{border:1px solid #00AA63;border-radius:3px;color:#00aa63;font-size:14px;padding:0 8px;height:26px;line-height:26px}[dir=ltr] .aioseo-analyze-score{margin-right:12px}[dir=rtl] .aioseo-analyze-score{margin-left:12px}.aioseo-analyze-score.red{color:#df2a4a;border-color:#df2a4a}.aioseo-analyze-score.orange{color:#f18200;border-color:#f18200}
