<?php

namespace WPForms\Vendor\Stripe;

/**
 * @property string $id Unique identifier for the event.
 * @property string $type
 * @property string $url
 */
class RelatedObject
{
    public $id;
    public $type;
    public $url;
}
