<?php

namespace WPForms\Vendor\CoreInterfaces\Core;

interface Format
{
    public const JSON = 'application/json';
    public const XML = 'application/xml';
    public const SCALAR = 'text/plain; charset=utf-8';
}
