<?php return array(
    'root' => array(
        'name' => 'awesomemotive/all-in-one-seo-pack-pro',
        'pretty_version' => 'dev-develop',
        'version' => 'dev-develop',
        'reference' => '47a09bd4f83d98339af1b2f7f79b26d75aef3c3f',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'awesomemotive/all-in-one-seo-pack-pro' => array(
            'pretty_version' => 'dev-develop',
            'version' => 'dev-develop',
            'reference' => '47a09bd4f83d98339af1b2f7f79b26d75aef3c3f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'jwhennessey/phpinsight' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'reference' => '0618bd228db16f408f5004bd97c6423d281edc51',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jwhennessey/phpinsight',
            'aliases' => array(
                0 => '9999999-dev',
            ),
            'dev_requirement' => false,
        ),
        'league/html-to-markdown' => array(
            'pretty_version' => '5.1.1',
            'version' => '5.1.1.0',
            'reference' => '0b4066eede55c48f38bcee4fb8f0aa85654390fd',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/html-to-markdown',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'woocommerce/action-scheduler' => array(
            'pretty_version' => '3.9.3',
            'version' => '3.9.3.0',
            'reference' => 'c58cdbab17651303d406cd3b22cf9d75c71c986c',
            'type' => 'wordpress-plugin',
            'install_path' => __DIR__ . '/../woocommerce/action-scheduler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
