.aioseo-overview-title{font-weight:600;margin-bottom:15px;font-size:14px;line-height:21px}.aioseo-overview-description{color:#434960;font-size:14px!important;margin:0 0 16px}.aioseo-overview-selector{margin:0 0 16px}.aioseo-overview-selector strong{font-size:14px;display:inline-block;margin-bottom:4px;font-weight:600}.aioseo-overview .aioseo-donut-chart-with-legend{margin:0 0 16px}.aioseo-overview .aioseo-donut-chart-with-legend .chart-left{max-width:145px}[dir=ltr] .aioseo-overview .aioseo-donut-chart-with-legend .chart-right{margin-left:32px}[dir=rtl] .aioseo-overview .aioseo-donut-chart-with-legend .chart-right{margin-right:32px}@media screen and (max-width:600px){[dir=ltr] .aioseo-overview .aioseo-donut-chart-with-legend .chart-right{margin-left:auto}[dir=rtl] .aioseo-overview .aioseo-donut-chart-with-legend .chart-right{margin-right:auto}}@media screen and (max-width:911px)and (min-width:601px){.aioseo-overview .aioseo-donut-chart-with-legend .chart-right{max-width:50%}[dir=ltr] .aioseo-overview .aioseo-donut-chart-with-legend .chart-right{margin-left:auto}[dir=rtl] .aioseo-overview .aioseo-donut-chart-with-legend .chart-right{margin-right:auto}}.aioseo-overview .aioseo-alert{margin:0 0 24px}.aioseo-overview .aioseo-alert a{color:#2c324c!important}.aioseo-overview .aioseo-separator{width:100%;width:calc(100% + 60px);margin:24px 0;border-color:#e8e8eb}[dir=ltr] .aioseo-overview .aioseo-separator{margin-left:-30px}[dir=rtl] .aioseo-overview .aioseo-separator{margin-right:-30px}.aioseo-overview .aioseo-button{font-size:12px;height:32px}.aioseo-overview .aioseo-button svg{width:16px;height:16px}[dir=ltr] .aioseo-overview .aioseo-button svg{margin-right:10px}[dir=rtl] .aioseo-overview .aioseo-button svg{margin-left:10px}.aioseo-overview .aioseo-overview{max-width:300px;min-width:275px;width:100%;height:auto}@media screen and (max-width:1280px){.aioseo-overview .aioseo-overview{min-width:0}}.aioseo-overview>:last-child{margin-bottom:0}.aioseo-overview--invalid{display:flex;flex-direction:row;align-items:center}.aioseo-overview--wp-styles .aioseo-overview-description{color:#434960}.aioseo-overview--wp-styles .aioseo-overview-selector select{width:100%}.aioseo-overview--wp-styles .aioseo-overview-selector strong{font-weight:400}.aioseo-overview--wp-styles a:not(.button){color:#2271b1!important}.aioseo-overview--wp-styles .button svg{width:16px;height:16px;vertical-align:sub}[dir=ltr] .aioseo-overview--wp-styles .button svg{margin-right:10px}[dir=rtl] .aioseo-overview--wp-styles .button svg{margin-left:10px}.aioseo-overview--wp-styles .aioseo-alert{font-weight:400!important}.aioseo-overview--wp-styles .aioseo-separator{width:calc(100% + 24px);margin:12px 0;border-color:#c3c4c7;border-top:0}[dir=ltr] .aioseo-overview--wp-styles .aioseo-separator{margin-left:-12px}[dir=rtl] .aioseo-overview--wp-styles .aioseo-separator{margin-right:-12px}.aioseo-overview--wp-styles .aioseo-overview{max-width:225px;min-width:175px}
