.aioseo-flyout-menu{position:fixed;z-index:1000;bottom:40px}[dir=ltr] .aioseo-flyout-menu{right:20px}[dir=rtl] .aioseo-flyout-menu{left:20px}.aioseo-flyout-menu-label{font-weight:600;font-size:12px;line-height:15px;color:#141b38;background:#fff;border:1px solid #DCDDE1;box-sizing:border-box;border-radius:80px;transition:all .05s ease}[dir=ltr] .aioseo-flyout-menu-label{box-shadow:.5px .5px 10px #8c8f9a}[dir=rtl] .aioseo-flyout-menu-label{box-shadow:-.5px .5px 10px #8c8f9a}.aioseo-flyout-menu-button{display:flex;align-items:center;justify-content:flex-end;cursor:pointer}.aioseo-flyout-menu-button>span{position:relative;z-index:0;padding:8px 16px;transition:all .2s ease;opacity:0;transform:scale(.5)}[dir=ltr] .aioseo-flyout-menu-button>span{margin-right:-100px}[dir=rtl] .aioseo-flyout-menu-button>span{margin-left:-100px}.aioseo-flyout-menu-button svg{position:relative;z-index:1;background:#fff;border:2px solid #004F9D;box-sizing:border-box;border-radius:70px}[dir=ltr] .aioseo-flyout-menu-button svg{box-shadow:.5px .5px 10px #8c8f9a}[dir=rtl] .aioseo-flyout-menu-button svg{box-shadow:-.5px .5px 10px #8c8f9a}.aioseo-flyout-menu-button:hover>span{opacity:1;transform:scale(1)}[dir=ltr] .aioseo-flyout-menu-button:hover>span{margin-right:12px}[dir=rtl] .aioseo-flyout-menu-button:hover>span{margin-left:12px}.aioseo-flyout-menu-items{display:none}.aioseo-flyout-menu-items a{display:flex;align-items:center;justify-content:flex-end;margin-bottom:12px;text-decoration:none;transition:all .2s ease;opacity:0}[dir=ltr] .aioseo-flyout-menu-items a{transform:translate(100%)}[dir=rtl] .aioseo-flyout-menu-items a{transform:translate(-100%)}.aioseo-flyout-menu-items a span{flex-shrink:0;padding:8px 16px}.aioseo-flyout-menu-items a .icon{width:40px;height:40px;display:flex;justify-content:center;align-items:center}[dir=ltr] .aioseo-flyout-menu-items a .icon{margin-left:8px}[dir=rtl] .aioseo-flyout-menu-items a .icon{margin-right:8px}.aioseo-flyout-menu-items a .icon svg{max-width:60%;max-height:60%;transition:all .2s ease}@supports (-webkit-appearance: none){.aioseo-flyout-menu-items a .icon svg{min-height:20px;min-width:20px}}.aioseo-flyout-menu-items a .icon svg path,.aioseo-flyout-menu-items a .icon svg g{will-change:transform,opacity;transition-property:transform,opacity;transition-duration:.5s;transition-timing-function:ease}.aioseo-flyout-menu-items a:hover .aioseo-flyout-menu-label{border-color:#004f9d;color:#004f9d}[dir=ltr] .aioseo-flyout-menu-items a:hover .aioseo-flyout-menu-label{box-shadow:.5px .5px 10px #8c8f9a,inset 0 0 0 1px #004f9d}[dir=rtl] .aioseo-flyout-menu-items a:hover .aioseo-flyout-menu-label{box-shadow:-.5px .5px 10px #8c8f9a,inset 0 0 0 1px #004f9d}.aioseo-flyout-menu-items a:hover .icon svg{max-width:70%;max-height:70%}.aioseo-flyout-menu.is-open .aioseo-flyout-menu-items{display:block}.aioseo-flyout-menu.is-open .aioseo-flyout-menu-items a{opacity:1;transform:translate(0)}.aioseo-flyout-menu.is-open .aioseo-flyout-menu-items,.aioseo-flyout-menu.will-open .aioseo-flyout-menu-items{margin-bottom:20px;display:block}[dir=ltr] .aioseo-flyout-menu.is-open .aioseo-flyout-menu-items,[dir=ltr] .aioseo-flyout-menu.will-open .aioseo-flyout-menu-items{margin-right:8px}[dir=rtl] .aioseo-flyout-menu.is-open .aioseo-flyout-menu-items,[dir=rtl] .aioseo-flyout-menu.will-open .aioseo-flyout-menu-items{margin-left:8px}
