.ai-providers{display:flex;gap:12px;justify-content:center;flex-wrap:wrap;margin-bottom:32px}.ai-provider{display:flex;align-items:center;gap:8px;padding:4px 12px;background:#e8e8eb;border-radius:30px}.ai-provider .ai-provider-icon{display:flex;align-items:center;justify-content:center;width:24px;height:24px}.ai-provider .ai-provider-icon svg{width:20px;height:20px}.ai-provider .ai-provider-name{font-size:14px;color:#434960;font-weight:400}.promotional-alert[data-v-1f971962]{margin-bottom:24px}.promotional-alert .aioseo-alert[data-v-1f971962]{border:1px solid #005AE0;border-radius:8px;box-shadow:0 2px 8px #007bff1a;padding:16px 20px;position:relative;overflow:hidden}.promotional-alert .aioseo-alert .promotional-alert-content[data-v-1f971962]{display:flex;align-items:center;gap:12px}.promotional-alert .aioseo-alert .promotional-alert-icon[data-v-1f971962]{flex-shrink:0;width:32px;height:32px;display:flex;align-items:center;justify-content:center;background:#005ae0;border-radius:50%;color:#fff;box-shadow:0 2px 6px #007bff40}.promotional-alert .aioseo-alert .promotional-alert-icon .aioseo-ai-content[data-v-1f971962]{width:18px;height:18px}.status-badge[data-v-2fe2f1af]{display:inline-block;padding:2px 6px;border-radius:2px;font-size:12px;font-weight:600;text-transform:capitalize;border:1px solid}.status-badge.status-processing[data-v-2fe2f1af],.status-badge.status-pending[data-v-2fe2f1af]{color:#f18200;border-color:#f18200}.status-badge.status-failed[data-v-2fe2f1af]{color:#df2a4a;border-color:#df2a4a}.status-badge.status-completed[data-v-2fe2f1af]{color:#00aa63;border-color:#00aa63}.aioseo-modal-body[data-v-2fe2f1af]{padding:20px!important;display:flex;align-items:center;justify-content:center;flex-direction:column;position:relative}.aioseo-modal-body h3[data-v-2fe2f1af]{font-size:20px;margin-bottom:16px}.aioseo-modal-body .reset-description[data-v-2fe2f1af]{font-size:16px;color:#141b38;margin-bottom:16px;text-align:center;max-width:515px}.aioseo-modal-body button.close[data-v-2fe2f1af]{position:absolute;top:11px;width:24px;height:24px;background-color:#fff;border:none;display:flex;align-items:center;cursor:pointer}[dir=ltr] .aioseo-modal-body button.close[data-v-2fe2f1af]{right:11px}[dir=rtl] .aioseo-modal-body button.close[data-v-2fe2f1af]{left:11px}.aioseo-modal-body button.close svg[data-v-2fe2f1af]{cursor:pointer;width:14px;height:14px}.aioseo-modal-body .aioseo-button[data-v-2fe2f1af]:not(.close){margin-top:16px}.btn-toggle-row[data-v-2fe2f1af]{display:flex;height:26px;margin:0 auto;padding:0;width:30px}.btn-toggle-row svg[data-v-2fe2f1af]{transition:transform .3s}[dir=ltr] .btn-toggle-row svg[data-v-2fe2f1af]{transform:rotate(-90deg)}[dir=rtl] .btn-toggle-row svg[data-v-2fe2f1af]{transform:rotate(90deg)}.btn-toggle-row.active svg[data-v-2fe2f1af]{transform:rotate(0)}.aioseo-ai-insights .keyword-intro{text-align:center;margin-left:auto;margin-right:auto}.aioseo-ai-insights .keyword-intro .keyword-title{font-size:24px;font-weight:600;color:#141b38;margin:0 0 16px;line-height:1.3}.aioseo-ai-insights .keyword-intro .keyword-description{font-size:16px;color:#141b38;margin:0 0 32px;line-height:1.5}.aioseo-ai-insights .keyword-intro .keyword-form{display:flex;gap:12px;align-items:flex-start}.aioseo-ai-insights .keyword-intro .keyword-form .aioseo-input{flex:1}.aioseo-ai-insights .keyword-intro .keyword-form+.aioseo-alert{margin-top:20px}@media screen and (min-width:768px){.aioseo-ai-insights .keyword-intro{max-width:750px;padding:20px}.aioseo-ai-insights .keyword-intro .keyword-form{padding:0 70px}}
