.aioseo-breadcrumbs .content[data-v-2c71bae2]{position:relative}.aioseo-breadcrumbs .alert{margin-top:24px}.aioseo-breadcrumbs svg.aioseo-shortcode{width:100%;height:auto;max-width:60px}.aioseo-breadcrumbs svg.aioseo-gutenberg-block{width:59px;height:54px}.aioseo-breadcrumbs svg.aioseo-gutenberg-block rect{width:100%;width:56px;height:51px}.aioseo-breadcrumbs svg.aioseo-php{width:110px}.aioseo-breadcrumbs .previews-box{padding:12px;border:1px solid #D0D1D7;border-radius:4px}.aioseo-breadcrumbs .previews-box+.aioseo-row{margin-top:16px}.aioseo-breadcrumbs .aioseo-settings-content>div:not(.previews-box)>.aioseo-preview-box{padding:12px;border:1px solid #D0D1D7;border-radius:4px}.aioseo-breadcrumbs .aioseo-settings-content>div:not(.previews-box)>.aioseo-preview-box+.aioseo-row{margin-top:16px}.aioseo-breadcrumbs .aioseo-settings-content>div:not(.previews-box)>.aioseo-preview-box+.aioseo-row>.aioseo-col:first-child{margin-top:0}.aioseo-breadcrumbs .aioseo-settings-content>div:not(.previews-box)>.aioseo-preview-box+.aioseo-row+.aioseo-row{margin-top:16px}.aioseo-breadcrumbs .aioseo-preview-box{font-size:14px;line-height:22px}.aioseo-breadcrumbs .aioseo-preview-box+.aioseo-preview-box{margin-top:8px}.aioseo-breadcrumbs .aioseo-preview-box .label{font-weight:600;min-width:75px;display:inline-block}.aioseo-breadcrumbs .aioseo-preview-box .breadcrumb-preview{padding-bottom:20px}.aioseo-breadcrumbs .aioseo-preview-box .breadcrumb-preview:last-child{padding-bottom:0}.aioseo-breadcrumbs .aioseo-preview-box .breadcrumb-preview span:last-child{font-weight:600}.aioseo-breadcrumbs .aioseo-preview-box .aioseo-breadcrumb-separator{color:#8c8f9a;padding:0 4px}.aioseo-breadcrumbs .aioseo-preview-box .aioseo-breadcrumb{padding:0 4px}.aioseo-breadcrumbs .aioseo-preview-box .last.noLink,.aioseo-breadcrumbs .aioseo-preview-box .last.noLink a{font-weight:600}.aioseo-breadcrumbs .aioseo-preview-box .link,.aioseo-breadcrumbs .aioseo-preview-box a{color:#005ae0;text-decoration:underline;font-weight:600;cursor:pointer;pointer-events:none}.aioseo-breadcrumbs .aioseo-preview-box .noLink a{color:inherit;text-decoration:none;cursor:inherit;pointer-events:none}.aioseo-breadcrumbs .homepage-link{display:flex;align-items:center}.aioseo-breadcrumbs .homepage-link .homepage-link-label{font-size:14px;line-height:22px;flex:1 1 auto;display:flex;align-items:center}[dir=ltr] .aioseo-breadcrumbs .homepage-link .homepage-link-label{margin:0 0 0 20px}[dir=rtl] .aioseo-breadcrumbs .homepage-link .homepage-link-label{margin:0 20px 0 0}.aioseo-breadcrumbs .homepage-link .homepage-link-label .aioseo-input-container{flex:1}.aioseo-breadcrumbs .homepage-link .homepage-link-label .aioseo-input{max-width:250px}[dir=ltr] .aioseo-breadcrumbs .homepage-link .homepage-link-label .aioseo-input{margin-left:10px}[dir=rtl] .aioseo-breadcrumbs .homepage-link .homepage-link-label .aioseo-input{margin-right:10px}@media only screen and (max-width:782px){.aioseo-breadcrumbs .homepage-link{display:block}.aioseo-breadcrumbs .homepage-link .homepage-link-label{margin:20px 0 0}.aioseo-breadcrumbs .homepage-link .homepage-link-label .aioseo-input{max-width:215px}}.aioseo-breadcrumbs .content:is([active=ContentTypes],[active=Taxonomies],[active=Archives]) .settings-name:not(.no-name){margin-top:4px}
