<?php
/**
 * @package ACF
 * @author  WP Engine
 *
 * © 2026 Advanced Custom Fields (ACF®). All rights reserved.
 * "ACF" is a trademark of WP Engine.
 * Licensed under the GNU General Public License v2 or later.
 * https://www.gnu.org/licenses/gpl-2.0.html
 */

/**
 * Schema.org property ranges data
 *
 * This file is auto-generated by tools/generate-schema.js
 * DO NOT EDIT MANUALLY - Run 'npm run generate-schema' to regenerate
 *
 * Generated: 2026-02-25
 * Source: https://schema.org/version/latest/schemaorg-current-https.jsonld
 *
 * @package ACF\AI\GEO
 */

return array(
	'legislationPassedBy'                     => array(
		'Organization',
		'Person',
	),
	'funding'                                 => array(
		'Grant',
	),
	'valuePattern'                            => array(
		'Text',
	),
	'provider'                                => array(
		'Person',
		'Organization',
	),
	'honorificPrefix'                         => array(
		'Text',
	),
	'modifiedTime'                            => array(
		'DateTime',
	),
	'numberOfCredits'                         => array(
		'StructuredValue',
		'Integer',
	),
	'noBylinesPolicy'                         => array(
		'CreativeWork',
		'URL',
	),
	'genre'                                   => array(
		'URL',
		'Text',
		'DefinedTerm',
	),
	'sameAs'                                  => array(
		'URL',
	),
	'wordCount'                               => array(
		'Integer',
	),
	'recommendedIntake'                       => array(
		'RecommendedDoseSchedule',
	),
	'isGift'                                  => array(
		'Boolean',
	),
	'interactingDrug'                         => array(
		'Drug',
	),
	'experienceInPlaceOfEducation'            => array(
		'Boolean',
	),
	'isProprietary'                           => array(
		'Boolean',
	),
	'accessModeSufficient'                    => array(
		'ItemList',
	),
	'breadcrumb'                              => array(
		'BreadcrumbList',
		'Text',
	),
	'recordedAs'                              => array(
		'MusicRecording',
	),
	'vehicleConfiguration'                    => array(
		'Text',
	),
	'orderItemNumber'                         => array(
		'Text',
	),
	'legislationIdentifier'                   => array(
		'Text',
		'URL',
	),
	'weightTotal'                             => array(
		'QuantitativeValue',
	),
	'numberOfFullBathrooms'                   => array(
		'Number',
	),
	'imagingTechnique'                        => array(
		'MedicalImagingTechnique',
	),
	'readBy'                                  => array(
		'Person',
	),
	'readonlyValue'                           => array(
		'Boolean',
	),
	'containsSeason'                          => array(
		'CreativeWorkSeason',
	),
	'legislationCommences'                    => array(
		'Legislation',
	),
	'pickupTime'                              => array(
		'DateTime',
	),
	'hoursAvailable'                          => array(
		'OpeningHoursSpecification',
	),
	'targetPlatform'                          => array(
		'Text',
	),
	'connectedTo'                             => array(
		'AnatomicalStructure',
	),
	'cvdNumBedsOcc'                           => array(
		'Number',
	),
	'nonEqual'                                => array(
		'QualitativeValue',
	),
	'qualifiedExpense'                        => array(
		'IncentiveQualifiedExpenseType',
	),
	'paymentUrl'                              => array(
		'URL',
	),
	'acquireLicensePage'                      => array(
		'CreativeWork',
		'URL',
	),
	'hasRepresentation'                       => array(
		'Text',
		'URL',
		'PropertyValue',
	),
	'suggestedMinAge'                         => array(
		'Number',
	),
	'polygon'                                 => array(
		'Text',
	),
	'duration'                                => array(
		'Duration',
		'QuantitativeValue',
	),
	'maximumEnrollment'                       => array(
		'Integer',
	),
	'numberOfForwardGears'                    => array(
		'Number',
		'QuantitativeValue',
	),
	'taxonRank'                               => array(
		'Text',
		'URL',
		'PropertyValue',
	),
	'actionPlatform'                          => array(
		'DigitalPlatformEnumeration',
		'URL',
		'Text',
	),
	'numTracks'                               => array(
		'Integer',
	),
	'legislationLegalValue'                   => array(
		'LegalValueLevel',
	),
	'totalPaymentDue'                         => array(
		'PriceSpecification',
		'MonetaryAmount',
	),
	'sensoryRequirement'                      => array(
		'DefinedTerm',
		'URL',
		'Text',
	),
	'hasDefinedTerm'                          => array(
		'DefinedTerm',
	),
	'orderNumber'                             => array(
		'Text',
	),
	'geoCovers'                               => array(
		'GeospatialGeometry',
		'Place',
	),
	'mathExpression'                          => array(
		'SolveMathAction',
		'Text',
	),
	'lender'                                  => array(
		'Organization',
		'Person',
	),
	'currency'                                => array(
		'Text',
	),
	'temporalCoverage'                        => array(
		'DateTime',
		'URL',
		'Text',
	),
	'shippingDetails'                         => array(
		'OfferShippingDetails',
	),
	'specialOpeningHoursSpecification'        => array(
		'OpeningHoursSpecification',
	),
	'publicAccess'                            => array(
		'Boolean',
	),
	'structuralClass'                         => array(
		'Text',
	),
	'smokingAllowed'                          => array(
		'Boolean',
	),
	'currenciesAccepted'                      => array(
		'Text',
	),
	'publisher'                               => array(
		'Person',
		'Organization',
	),
	'targetUrl'                               => array(
		'URL',
	),
	'endOffset'                               => array(
		'HyperTocEntry',
		'Number',
	),
	'eligibleDuration'                        => array(
		'QuantitativeValue',
	),
	'costCurrency'                            => array(
		'Text',
	),
	'arrivalTime'                             => array(
		'DateTime',
		'Time',
	),
	'hasMeasurement'                          => array(
		'QuantitativeValue',
	),
	'runtime'                                 => array(
		'Text',
	),
	'serviceAudience'                         => array(
		'Audience',
	),
	'vehicleTransmission'                     => array(
		'Text',
		'QualitativeValue',
		'URL',
	),
	'reportNumber'                            => array(
		'Text',
	),
	'exerciseCourse'                          => array(
		'Place',
	),
	'seasons'                                 => array(
		'CreativeWorkSeason',
	),
	'knownVehicleDamages'                     => array(
		'Text',
	),
	'name'                                    => array(
		'Text',
	),
	'warranty'                                => array(
		'WarrantyPromise',
	),
	'distribution'                            => array(
		'DataDownload',
	),
	'actionAccessibilityRequirement'          => array(
		'ActionAccessSpecification',
	),
	'numberOfAccommodationUnits'              => array(
		'QuantitativeValue',
	),
	'weight'                                  => array(
		'Mass',
		'QuantitativeValue',
	),
	'associatedArticle'                       => array(
		'NewsArticle',
	),
	'commentTime'                             => array(
		'Date',
		'DateTime',
	),
	'awards'                                  => array(
		'Text',
	),
	'steeringPosition'                        => array(
		'SteeringPositionValue',
	),
	'legislationConsolidates'                 => array(
		'Legislation',
	),
	'hasEnergyEfficiencyCategory'             => array(
		'EnergyEfficiencyEnumeration',
	),
	'reservationFor'                          => array(
		'Thing',
	),
	'cssSelector'                             => array(
		'CssSelectorType',
	),
	'contraindication'                        => array(
		'MedicalContraindication',
		'Text',
	),
	'proficiencyLevel'                        => array(
		'Text',
	),
	'question'                                => array(
		'Question',
	),
	'thumbnail'                               => array(
		'ImageObject',
	),
	'strengthUnit'                            => array(
		'Text',
	),
	'propertyID'                              => array(
		'Text',
		'URL',
	),
	'servicePostalAddress'                    => array(
		'PostalAddress',
	),
	'billingDuration'                         => array(
		'Duration',
		'QuantitativeValue',
		'Number',
	),
	'additionalNumberOfGuests'                => array(
		'Number',
	),
	'thumbnailUrl'                            => array(
		'URL',
	),
	'mediaAuthenticityCategory'               => array(
		'MediaManipulationRatingEnumeration',
	),
	'geoOverlaps'                             => array(
		'GeospatialGeometry',
		'Place',
	),
	'inAlbum'                                 => array(
		'MusicAlbum',
	),
	'commentCount'                            => array(
		'Integer',
	),
	'availableThrough'                        => array(
		'DateTime',
	),
	'busNumber'                               => array(
		'Text',
	),
	'guidelineSubject'                        => array(
		'MedicalEntity',
	),
	'refundType'                              => array(
		'RefundTypeEnumeration',
	),
	'height'                                  => array(
		'QuantitativeValue',
		'Distance',
	),
	'addressCountry'                          => array(
		'Country',
		'Text',
	),
	'catalog'                                 => array(
		'DataCatalog',
	),
	'customer'                                => array(
		'Person',
		'Organization',
	),
	'hasMenuItem'                             => array(
		'MenuItem',
	),
	'displayLocation'                         => array(
		'Place',
	),
	'practicesAt'                             => array(
		'MedicalOrganization',
	),
	'roofLoad'                                => array(
		'QuantitativeValue',
	),
	'latitude'                                => array(
		'Number',
		'Text',
	),
	'coverageStartTime'                       => array(
		'DateTime',
	),
	'medicalSpecialty'                        => array(
		'MedicalSpecialty',
	),
	'emissionsCO2'                            => array(
		'Number',
	),
	'webCheckinTime'                          => array(
		'DateTime',
	),
	'experienceRequirements'                  => array(
		'Text',
		'OccupationalExperienceRequirements',
	),
	'printPage'                               => array(
		'Text',
	),
	'includesHealthPlanFormulary'             => array(
		'HealthPlanFormulary',
	),
	'fatContent'                              => array(
		'Mass',
	),
	'musicBy'                                 => array(
		'MusicGroup',
		'Person',
	),
	'knowsAbout'                              => array(
		'Text',
		'Thing',
		'URL',
	),
	'syllabusSections'                        => array(
		'Syllabus',
	),
	'gtin'                                    => array(
		'Text',
		'URL',
	),
	'orderDelivery'                           => array(
		'ParcelDelivery',
	),
	'archivedAt'                              => array(
		'WebPage',
		'URL',
	),
	'cholesterolContent'                      => array(
		'Mass',
	),
	'workPresented'                           => array(
		'Movie',
	),
	'broker'                                  => array(
		'Person',
		'Organization',
	),
	'epidemiology'                            => array(
		'Text',
	),
	'numberOfRooms'                           => array(
		'QuantitativeValue',
		'Number',
	),
	'checkoutPageURLTemplate'                 => array(
		'Text',
	),
	'fileSize'                                => array(
		'Text',
	),
	'expectedPrognosis'                       => array(
		'Text',
	),
	'countriesSupported'                      => array(
		'Text',
	),
	'signOrSymptom'                           => array(
		'MedicalSignOrSymptom',
	),
	'sampleType'                              => array(
		'Text',
	),
	'openingHoursSpecification'               => array(
		'OpeningHoursSpecification',
	),
	'vehicleInteriorType'                     => array(
		'Text',
	),
	'partOfInvoice'                           => array(
		'Invoice',
	),
	'employee'                                => array(
		'Person',
	),
	'data'                                    => array(
		'Thing',
	),
	'scheduledPaymentDate'                    => array(
		'Date',
	),
	'geoRadius'                               => array(
		'Number',
		'Distance',
		'Text',
	),
	'occupationLocation'                      => array(
		'AdministrativeArea',
	),
	'validIn'                                 => array(
		'AdministrativeArea',
	),
	'exerciseRelatedDiet'                     => array(
		'Diet',
	),
	'digitalSourceType'                       => array(
		'IPTCDigitalSourceEnumeration',
	),
	'departureTime'                           => array(
		'Time',
		'DateTime',
	),
	'normalRange'                             => array(
		'MedicalEnumeration',
		'Text',
	),
	'broadcastOfEvent'                        => array(
		'Event',
	),
	'reviews'                                 => array(
		'Review',
	),
	'stage'                                   => array(
		'MedicalConditionStage',
	),
	'boardingPolicy'                          => array(
		'BoardingPolicyType',
	),
	'issn'                                    => array(
		'Text',
	),
	'instructor'                              => array(
		'Person',
	),
	'vendor'                                  => array(
		'Organization',
		'Person',
	),
	'educationalCredentialAwarded'            => array(
		'Text',
		'EducationalOccupationalCredential',
		'URL',
	),
	'transcript'                              => array(
		'Text',
	),
	'byMonth'                                 => array(
		'Integer',
	),
	'assembly'                                => array(
		'Text',
	),
	'freeShippingThreshold'                   => array(
		'DeliveryChargeSpecification',
		'MonetaryAmount',
	),
	'discusses'                               => array(
		'CreativeWork',
	),
	'requiredGender'                          => array(
		'Text',
	),
	'termsPerYear'                            => array(
		'Number',
	),
	'source'                                  => array(
		'Thing',
	),
	'assesses'                                => array(
		'DefinedTerm',
		'Text',
	),
	'logo'                                    => array(
		'URL',
		'ImageObject',
	),
	'isStoreOn'                               => array(
		'OnlineMarketplace',
	),
	'relevantSpecialty'                       => array(
		'MedicalSpecialty',
	),
	'gtin12'                                  => array(
		'Text',
	),
	'upvoteCount'                             => array(
		'Integer',
	),
	'hasCourseInstance'                       => array(
		'CourseInstance',
	),
	'usNPI'                                   => array(
		'Text',
	),
	'price'                                   => array(
		'Number',
		'Text',
	),
	'result'                                  => array(
		'Thing',
	),
	'geoContains'                             => array(
		'Place',
		'GeospatialGeometry',
	),
	'featureList'                             => array(
		'URL',
		'Text',
	),
	'hasMenuSection'                          => array(
		'MenuSection',
	),
	'license'                                 => array(
		'CreativeWork',
		'URL',
	),
	'servesCuisine'                           => array(
		'Text',
	),
	'salaryUponCompletion'                    => array(
		'MonetaryAmountDistribution',
	),
	'query'                                   => array(
		'Text',
	),
	'gender'                                  => array(
		'Text',
		'GenderType',
	),
	'processorRequirements'                   => array(
		'Text',
	),
	'totalHistoricalEnrollment'               => array(
		'Integer',
	),
	'foundingDate'                            => array(
		'Date',
	),
	'missionCoveragePrioritiesPolicy'         => array(
		'CreativeWork',
		'URL',
	),
	'eduQuestionType'                         => array(
		'Text',
	),
	'additionalType'                          => array(
		'URL',
		'Text',
	),
	'broadcastChannelId'                      => array(
		'Text',
	),
	'yearBuilt'                               => array(
		'Number',
	),
	'partOfSeason'                            => array(
		'CreativeWorkSeason',
	),
	'broadcastSignalModulation'               => array(
		'QualitativeValue',
		'Text',
	),
	'performers'                              => array(
		'Person',
		'Organization',
	),
	'programName'                             => array(
		'Text',
	),
	'providerMobility'                        => array(
		'Text',
	),
	'amountOfThisGood'                        => array(
		'Number',
	),
	'amount'                                  => array(
		'Number',
		'MonetaryAmount',
	),
	'actionProcess'                           => array(
		'HowTo',
	),
	'diversityStaffingReport'                 => array(
		'URL',
		'Article',
	),
	'textValue'                               => array(
		'Text',
	),
	'gameTip'                                 => array(
		'CreativeWork',
	),
	'legislationTransposes'                   => array(
		'Legislation',
	),
	'sourcedFrom'                             => array(
		'BrainStructure',
	),
	'paymentStatus'                           => array(
		'Text',
		'PaymentStatusType',
	),
	'requiredCollateral'                      => array(
		'Thing',
		'Text',
	),
	'financialAidEligible'                    => array(
		'DefinedTerm',
		'Text',
	),
	'paymentDue'                              => array(
		'DateTime',
	),
	'itinerary'                               => array(
		'Place',
		'ItemList',
	),
	'bookEdition'                             => array(
		'Text',
	),
	'addOn'                                   => array(
		'Offer',
	),
	'baseSalary'                              => array(
		'MonetaryAmount',
		'PriceSpecification',
		'Number',
	),
	'evidenceOrigin'                          => array(
		'Text',
	),
	'foodEstablishment'                       => array(
		'Place',
		'FoodEstablishment',
	),
	'byArtist'                                => array(
		'Person',
		'MusicGroup',
	),
	'algorithm'                               => array(
		'Text',
	),
	'numberOfPartialBathrooms'                => array(
		'Number',
	),
	'orderPercentage'                         => array(
		'Number',
	),
	'hasMolecularFunction'                    => array(
		'DefinedTerm',
		'URL',
		'PropertyValue',
	),
	'pickupLocation'                          => array(
		'Place',
	),
	'payload'                                 => array(
		'QuantitativeValue',
	),
	'startTime'                               => array(
		'DateTime',
		'Time',
	),
	'isrcCode'                                => array(
		'Text',
	),
	'applicableCountry'                       => array(
		'Country',
		'Text',
	),
	'howPerformed'                            => array(
		'Text',
	),
	'isRelatedTo'                             => array(
		'Service',
		'Product',
	),
	'clipNumber'                              => array(
		'Text',
		'Integer',
	),
	'storageRequirements'                     => array(
		'URL',
		'Text',
	),
	'colorist'                                => array(
		'Person',
	),
	'keywords'                                => array(
		'Text',
		'DefinedTerm',
		'URL',
	),
	'healthPlanCoinsuranceOption'             => array(
		'Text',
	),
	'priceCurrency'                           => array(
		'Text',
	),
	'blogPosts'                               => array(
		'BlogPosting',
	),
	'track'                                   => array(
		'ItemList',
		'MusicRecording',
	),
	'legislationType'                         => array(
		'Text',
		'CategoryCode',
	),
	'serviceSmsNumber'                        => array(
		'ContactPoint',
	),
	'interactionService'                      => array(
		'SoftwareApplication',
		'WebSite',
	),
	'slogan'                                  => array(
		'Text',
	),
	'broadcastTimezone'                       => array(
		'Text',
	),
	'educationalProgramMode'                  => array(
		'URL',
		'Text',
	),
	'priceType'                               => array(
		'Text',
		'PriceTypeEnumeration',
	),
	'labelDetails'                            => array(
		'URL',
	),
	'endDate'                                 => array(
		'DateTime',
		'Date',
	),
	'requiredQuantity'                        => array(
		'Number',
		'Text',
		'QuantitativeValue',
	),
	'eventAttendanceMode'                     => array(
		'EventAttendanceModeEnumeration',
	),
	'seatSection'                             => array(
		'Text',
	),
	'calories'                                => array(
		'Energy',
	),
	'hasPart'                                 => array(
		'CreativeWork',
	),
	'transitTime'                             => array(
		'ServicePeriod',
		'QuantitativeValue',
	),
	'floorSize'                               => array(
		'QuantitativeValue',
	),
	'totalJobOpenings'                        => array(
		'Integer',
	),
	'funder'                                  => array(
		'Organization',
		'Person',
	),
	'publishedOn'                             => array(
		'BroadcastService',
	),
	'accessMode'                              => array(
		'Text',
	),
	'appearance'                              => array(
		'CreativeWork',
	),
	'seasonNumber'                            => array(
		'Text',
		'Integer',
	),
	'cvdCollectionDate'                       => array(
		'DateTime',
		'Text',
	),
	'bookFormat'                              => array(
		'BookFormatType',
	),
	'deliveryLeadTime'                        => array(
		'QuantitativeValue',
	),
	'returnMethod'                            => array(
		'ReturnMethodEnumeration',
	),
	'representativeOfPage'                    => array(
		'Boolean',
	),
	'incomeLimit'                             => array(
		'MonetaryAmount',
		'Text',
	),
	'printColumn'                             => array(
		'Text',
	),
	'inChI'                                   => array(
		'Text',
	),
	'toRecipient'                             => array(
		'ContactPoint',
		'Person',
		'Organization',
		'Audience',
	),
	'issueNumber'                             => array(
		'Text',
		'Integer',
	),
	'yearsInOperation'                        => array(
		'QuantitativeValue',
	),
	'pageEnd'                                 => array(
		'Integer',
		'Text',
	),
	'productID'                               => array(
		'Text',
	),
	'realEstateAgent'                         => array(
		'RealEstateAgent',
	),
	'usesDevice'                              => array(
		'MedicalDevice',
	),
	'legislationDateOfApplicability'          => array(
		'Date',
	),
	'countryOfLastProcessing'                 => array(
		'Text',
	),
	'schoolClosuresInfo'                      => array(
		'URL',
		'WebContent',
	),
	'duringMedia'                             => array(
		'MediaObject',
		'URL',
	),
	'providesService'                         => array(
		'Service',
	),
	'mobileUrl'                               => array(
		'Text',
	),
	'actor'                                   => array(
		'PerformingGroup',
		'Person',
	),
	'geo'                                     => array(
		'GeoShape',
		'GeoCoordinates',
	),
	'maximumVirtualAttendeeCapacity'          => array(
		'Integer',
	),
	'constraintProperty'                      => array(
		'URL',
		'Property',
	),
	'aggregateRating'                         => array(
		'AggregateRating',
	),
	'isPlanForApartment'                      => array(
		'Accommodation',
	),
	'cause'                                   => array(
		'MedicalCause',
	),
	'postalCodeRange'                         => array(
		'PostalCodeRangeSpecification',
	),
	'statType'                                => array(
		'Text',
		'Property',
		'URL',
	),
	'prepTime'                                => array(
		'Duration',
	),
	'itemReviewed'                            => array(
		'Thing',
	),
	'itemDefectReturnLabelSource'             => array(
		'ReturnLabelSourceEnumeration',
	),
	'holdingArchive'                          => array(
		'ArchiveOrganization',
	),
	'smiles'                                  => array(
		'Text',
	),
	'eligibilityToWorkRequirement'            => array(
		'Text',
	),
	'measurementTechnique'                    => array(
		'MeasurementMethodEnum',
		'DefinedTerm',
		'URL',
		'Text',
	),
	'illustrator'                             => array(
		'Person',
	),
	'strengthValue'                           => array(
		'Number',
	),
	'relatedTherapy'                          => array(
		'MedicalTherapy',
	),
	'namedPosition'                           => array(
		'URL',
		'Text',
	),
	'jobStartDate'                            => array(
		'Date',
		'Text',
	),
	'material'                                => array(
		'Product',
		'URL',
		'Text',
	),
	'candidate'                               => array(
		'Person',
	),
	'accessibilityControl'                    => array(
		'Text',
	),
	'arterialBranch'                          => array(
		'AnatomicalStructure',
	),
	'numberOfSeasons'                         => array(
		'Integer',
	),
	'recordedAt'                              => array(
		'Event',
	),
	'studyDesign'                             => array(
		'MedicalObservationalStudyDesign',
	),
	'bankAccountType'                         => array(
		'URL',
		'Text',
	),
	'trainNumber'                             => array(
		'Text',
	),
	'clincalPharmacology'                     => array(
		'Text',
	),
	'authenticator'                           => array(
		'Organization',
	),
	'serviceOutput'                           => array(
		'Thing',
	),
	'productSupported'                        => array(
		'Text',
		'Product',
	),
	'rangeIncludes'                           => array(
		'Class',
	),
	'recipeInstructions'                      => array(
		'CreativeWork',
		'ItemList',
		'Text',
	),
	'bed'                                     => array(
		'BedType',
		'Text',
		'BedDetails',
	),
	'accelerationTime'                        => array(
		'QuantitativeValue',
	),
	'merchantReturnDays'                      => array(
		'Date',
		'Integer',
		'DateTime',
	),
	'successorOf'                             => array(
		'ProductModel',
	),
	'applicationStartDate'                    => array(
		'Date',
	),
	'countryOfAssembly'                       => array(
		'Text',
	),
	'characterAttribute'                      => array(
		'Thing',
	),
	'coursePrerequisites'                     => array(
		'Course',
		'AlignmentObject',
		'Text',
	),
	'dependencies'                            => array(
		'Text',
	),
	'leiCode'                                 => array(
		'Text',
	),
	'loanPaymentAmount'                       => array(
		'MonetaryAmount',
	),
	'orderItemStatus'                         => array(
		'OrderStatus',
	),
	'evidenceLevel'                           => array(
		'MedicalEvidenceLevel',
	),
	'knowsLanguage'                           => array(
		'Language',
		'Text',
	),
	'maintainer'                              => array(
		'Person',
		'Organization',
	),
	'meetsEmissionStandard'                   => array(
		'Text',
		'QualitativeValue',
		'URL',
	),
	'playerType'                              => array(
		'Text',
	),
	'populationType'                          => array(
		'Class',
	),
	'healthPlanCopayOption'                   => array(
		'Text',
	),
	'timeRequired'                            => array(
		'Duration',
	),
	'assemblyVersion'                         => array(
		'Text',
	),
	'tool'                                    => array(
		'HowToTool',
		'Text',
	),
	'sha256'                                  => array(
		'Text',
	),
	'isBasedOn'                               => array(
		'CreativeWork',
		'URL',
		'Product',
	),
	'spokenByCharacter'                       => array(
		'Person',
		'Organization',
	),
	'downvoteCount'                           => array(
		'Integer',
	),
	'parentService'                           => array(
		'BroadcastService',
	),
	'partOfOrder'                             => array(
		'Order',
	),
	'warning'                                 => array(
		'URL',
		'Text',
	),
	'dropoffTime'                             => array(
		'DateTime',
	),
	'legislationJurisdiction'                 => array(
		'Text',
		'AdministrativeArea',
	),
	'answerCount'                             => array(
		'Integer',
	),
	'yearlyRevenue'                           => array(
		'QuantitativeValue',
	),
	'maxPrice'                                => array(
		'Number',
	),
	'availableStrength'                       => array(
		'DrugStrength',
	),
	'estimatedFlightDuration'                 => array(
		'Text',
		'Duration',
	),
	'itemShipped'                             => array(
		'Product',
	),
	'lodgingUnitDescription'                  => array(
		'Text',
	),
	'playersOnline'                           => array(
		'Integer',
	),
	'extendedAddress'                         => array(
		'Text',
	),
	'sugarContent'                            => array(
		'Mass',
	),
	'gtin14'                                  => array(
		'Text',
	),
	'tributary'                               => array(
		'AnatomicalStructure',
	),
	'value'                                   => array(
		'Boolean',
		'Number',
		'Text',
		'StructuredValue',
	),
	'brand'                                   => array(
		'Brand',
		'Organization',
	),
	'streetAddress'                           => array(
		'Text',
	),
	'codeValue'                               => array(
		'Text',
	),
	'identifier'                              => array(
		'URL',
		'PropertyValue',
		'Text',
	),
	'downPayment'                             => array(
		'Number',
		'MonetaryAmount',
	),
	'skills'                                  => array(
		'Text',
		'DefinedTerm',
	),
	'cvdNumC19MechVentPats'                   => array(
		'Number',
	),
	'associatedAnatomy'                       => array(
		'SuperficialAnatomy',
		'AnatomicalStructure',
		'AnatomicalSystem',
	),
	'editEIDR'                                => array(
		'URL',
		'Text',
	),
	'unsaturatedFatContent'                   => array(
		'Mass',
	),
	'returnFees'                              => array(
		'ReturnFeesEnumeration',
	),
	'naics'                                   => array(
		'Text',
	),
	'firstPerformance'                        => array(
		'Event',
	),
	'referencesOrder'                         => array(
		'Order',
	),
	'departureGate'                           => array(
		'Text',
	),
	'founder'                                 => array(
		'Organization',
		'Person',
	),
	'expectsAcceptanceOf'                     => array(
		'Offer',
	),
	'hasMerchantReturnPolicy'                 => array(
		'MerchantReturnPolicy',
	),
	'artworkSurface'                          => array(
		'Text',
		'URL',
	),
	'parentOrganization'                      => array(
		'Organization',
	),
	'possibleTreatment'                       => array(
		'Drug',
		'DrugClass',
		'MedicalTherapy',
		'LifestyleModification',
	),
	'inverseOf'                               => array(
		'Property',
	),
	'eligibleWithSupplier'                    => array(
		'Organization',
	),
	'seatingCapacity'                         => array(
		'QuantitativeValue',
		'Number',
	),
	'releaseNotes'                            => array(
		'URL',
		'Text',
	),
	'hasAdultConsideration'                   => array(
		'AdultOrientedEnumeration',
	),
	'exerciseType'                            => array(
		'Text',
	),
	'broadcastFrequencyValue'                 => array(
		'QuantitativeValue',
		'Number',
	),
	'originalMediaLink'                       => array(
		'WebPage',
		'MediaObject',
		'URL',
	),
	'hasMap'                                  => array(
		'URL',
		'Map',
	),
	'orderQuantity'                           => array(
		'QuantitativeValue',
		'Number',
	),
	'areaServed'                              => array(
		'Place',
		'AdministrativeArea',
		'GeoShape',
		'Text',
	),
	'artist'                                  => array(
		'Person',
	),
	'object'                                  => array(
		'Thing',
	),
	'comprisedOf'                             => array(
		'AnatomicalStructure',
		'AnatomicalSystem',
	),
	'customerRemorseReturnFees'               => array(
		'ReturnFeesEnumeration',
	),
	'firstAppearance'                         => array(
		'CreativeWork',
	),
	'containedIn'                             => array(
		'Place',
	),
	'globalLocationNumber'                    => array(
		'Text',
	),
	'handlingTime'                            => array(
		'ServicePeriod',
		'QuantitativeValue',
	),
	'proprietaryName'                         => array(
		'Text',
	),
	'shippingConditions'                      => array(
		'ShippingConditions',
	),
	'lyrics'                                  => array(
		'CreativeWork',
	),
	'availableDeliveryMethod'                 => array(
		'DeliveryMethod',
	),
	'opponent'                                => array(
		'Person',
	),
	'size'                                    => array(
		'QuantitativeValue',
		'Text',
		'DefinedTerm',
		'SizeSpecification',
	),
	'courseSchedule'                          => array(
		'Schedule',
	),
	'inventoryLevel'                          => array(
		'QuantitativeValue',
	),
	'insertion'                               => array(
		'AnatomicalStructure',
	),
	'alignmentType'                           => array(
		'Text',
	),
	'printEdition'                            => array(
		'Text',
	),
	'membershipNumber'                        => array(
		'Text',
	),
	'suggestedGender'                         => array(
		'Text',
		'GenderType',
	),
	'valueAddedTaxIncluded'                   => array(
		'Boolean',
	),
	'owner'                                   => array(
		'Person',
		'Organization',
	),
	'branch'                                  => array(
		'AnatomicalStructure',
	),
	'hasVariant'                              => array(
		'Product',
	),
	'pronouns'                                => array(
		'Text',
		'StructuredValue',
		'DefinedTerm',
	),
	'citation'                                => array(
		'Text',
		'CreativeWork',
	),
	'courseMode'                              => array(
		'Text',
		'URL',
	),
	'healthPlanNetworkId'                     => array(
		'Text',
	),
	'review'                                  => array(
		'Review',
	),
	'event'                                   => array(
		'Event',
	),
	'phoneticText'                            => array(
		'Text',
	),
	'returnShippingFeesAmount'                => array(
		'MonetaryAmount',
	),
	'governmentBenefitsInfo'                  => array(
		'GovernmentService',
	),
	'partOfTVSeries'                          => array(
		'TVSeries',
	),
	'addressRegion'                           => array(
		'AdministrativeArea',
		'Text',
	),
	'broadcastSubChannel'                     => array(
		'Text',
	),
	'headline'                                => array(
		'Text',
	),
	'numberOfDoors'                           => array(
		'QuantitativeValue',
		'Number',
	),
	'deathDate'                               => array(
		'Date',
	),
	'employerOverview'                        => array(
		'Text',
	),
	'affiliation'                             => array(
		'Organization',
	),
	'interactionStatistic'                    => array(
		'InteractionCounter',
	),
	'acceptsReservations'                     => array(
		'Boolean',
		'URL',
		'Text',
	),
	'workExample'                             => array(
		'CreativeWork',
	),
	'children'                                => array(
		'Person',
	),
	'touristType'                             => array(
		'Text',
		'Audience',
	),
	'certificationStatus'                     => array(
		'CertificationStatusEnumeration',
	),
	'xpath'                                   => array(
		'XPathType',
	),
	'closes'                                  => array(
		'Time',
	),
	'uploadDate'                              => array(
		'DateTime',
		'Date',
	),
	'cvdNumICUBeds'                           => array(
		'Number',
	),
	'iataCode'                                => array(
		'Text',
	),
	'gtin8'                                   => array(
		'Text',
	),
	'trialDesign'                             => array(
		'MedicalTrialDesign',
	),
	'nutrition'                               => array(
		'NutritionInformation',
	),
	'typeOfGood'                              => array(
		'Service',
		'Product',
	),
	'possibleComplication'                    => array(
		'Text',
	),
	'webFeed'                                 => array(
		'DataFeed',
		'URL',
	),
	'supersededBy'                            => array(
		'Property',
		'Class',
		'Enumeration',
	),
	'sku'                                     => array(
		'Text',
	),
	'isLiveBroadcast'                         => array(
		'Boolean',
	),
	'maxValue'                                => array(
		'Number',
	),
	'tourBookingPage'                         => array(
		'URL',
	),
	'artform'                                 => array(
		'URL',
		'Text',
	),
	'unitCode'                                => array(
		'URL',
		'Text',
	),
	'materialExtent'                          => array(
		'QuantitativeValue',
		'Text',
	),
	'softwareRequirements'                    => array(
		'URL',
		'SoftwareApplication',
		'Text',
	),
	'superEvent'                              => array(
		'Event',
	),
	'expectedArrivalFrom'                     => array(
		'DateTime',
		'Date',
	),
	'cheatCode'                               => array(
		'CreativeWork',
	),
	'domainIncludes'                          => array(
		'Class',
	),
	'distinguishingSign'                      => array(
		'MedicalSignOrSymptom',
	),
	'ccRecipient'                             => array(
		'ContactPoint',
		'Organization',
		'Person',
	),
	'measurementMethod'                       => array(
		'Text',
		'MeasurementMethodEnum',
		'DefinedTerm',
		'URL',
	),
	'employmentUnit'                          => array(
		'Organization',
	),
	'recordLabel'                             => array(
		'Organization',
	),
	'legalName'                               => array(
		'Text',
	),
	'address'                                 => array(
		'PostalAddress',
		'Text',
	),
	'publicTransportClosuresInfo'             => array(
		'URL',
		'WebContent',
	),
	'recipeIngredient'                        => array(
		'ItemList',
		'PropertyValue',
		'Text',
	),
	'category'                                => array(
		'Text',
		'PhysicalActivityCategory',
		'CategoryCode',
		'Thing',
		'URL',
	),
	'healthCondition'                         => array(
		'MedicalCondition',
	),
	'membershipPointsEarned'                  => array(
		'QuantitativeValue',
		'Number',
	),
	'follows'                                 => array(
		'Person',
	),
	'lesserOrEqual'                           => array(
		'QualitativeValue',
	),
	'programmingLanguage'                     => array(
		'ComputerLanguage',
		'Text',
	),
	'beneficiaryBank'                         => array(
		'BankOrCreditUnion',
		'Text',
	),
	'tocContinuation'                         => array(
		'HyperTocEntry',
	),
	'certificationRating'                     => array(
		'Rating',
	),
	'prescribingInfo'                         => array(
		'URL',
	),
	'hasTierBenefit'                          => array(
		'TierBenefitEnumeration',
	),
	'measurementDenominator'                  => array(
		'StatisticalVariable',
	),
	'isTierOf'                                => array(
		'MemberProgram',
	),
	'spatial'                                 => array(
		'Place',
	),
	'language'                                => array(
		'Language',
	),
	'valueReference'                          => array(
		'StructuredValue',
		'DefinedTerm',
		'PropertyValue',
		'QuantitativeValue',
		'Enumeration',
		'MeasurementTypeEnumeration',
		'Text',
		'QualitativeValue',
	),
	'carrierRequirements'                     => array(
		'Text',
	),
	'molecularFormula'                        => array(
		'Text',
	),
	'reviewCount'                             => array(
		'Integer',
	),
	'cookingMethod'                           => array(
		'Text',
	),
	'courseWorkload'                          => array(
		'Text',
	),
	'associatedClaimReview'                   => array(
		'Review',
	),
	'releaseOf'                               => array(
		'MusicAlbum',
	),
	'videoFormat'                             => array(
		'Text',
	),
	'homeTeam'                                => array(
		'Person',
		'SportsTeam',
	),
	'cvdNumC19OFMechVentPats'                 => array(
		'Number',
	),
	'parentTaxon'                             => array(
		'Taxon',
		'URL',
		'Text',
	),
	'elevation'                               => array(
		'Number',
		'Text',
	),
	'marginOfError'                           => array(
		'QuantitativeValue',
	),
	'gtin13'                                  => array(
		'Text',
	),
	'subTrip'                                 => array(
		'Trip',
	),
	'producer'                                => array(
		'Person',
		'Organization',
	),
	'audienceType'                            => array(
		'Text',
	),
	'cvdNumC19HOPats'                         => array(
		'Number',
	),
	'procedureType'                           => array(
		'MedicalProcedureType',
	),
	'vehicleSpecialUsage'                     => array(
		'Text',
		'CarUsageType',
	),
	'safetyConsideration'                     => array(
		'Text',
	),
	'offers'                                  => array(
		'Offer',
		'Demand',
	),
	'departureBoatTerminal'                   => array(
		'BoatTerminal',
	),
	'mentions'                                => array(
		'Thing',
	),
	'vehicleSeatingCapacity'                  => array(
		'QuantitativeValue',
		'Number',
	),
	'signDetected'                            => array(
		'MedicalSign',
	),
	'acceptedOffer'                           => array(
		'Offer',
	),
	'costPerUnit'                             => array(
		'Text',
		'QualitativeValue',
		'Number',
	),
	'encodings'                               => array(
		'MediaObject',
	),
	'servicePhone'                            => array(
		'ContactPoint',
	),
	'albumRelease'                            => array(
		'MusicRelease',
	),
	'workload'                                => array(
		'QuantitativeValue',
		'Energy',
	),
	'loanPaymentFrequency'                    => array(
		'Number',
	),
	'relatedTo'                               => array(
		'Person',
	),
	'valueName'                               => array(
		'Text',
	),
	'timeToComplete'                          => array(
		'Duration',
	),
	'customerRemorseReturnShippingFeesAmount' => array(
		'MonetaryAmount',
	),
	'seasonalOverride'                        => array(
		'OpeningHoursSpecification',
	),
	'serverStatus'                            => array(
		'GameServerStatus',
	),
	'domiciledMortgage'                       => array(
		'Boolean',
	),
	'study'                                   => array(
		'MedicalStudy',
	),
	'lowPrice'                                => array(
		'Text',
		'Number',
	),
	'isFamilyFriendly'                        => array(
		'Boolean',
	),
	'referenceQuantity'                       => array(
		'QuantitativeValue',
	),
	'serviceUrl'                              => array(
		'URL',
	),
	'mileageFromOdometer'                     => array(
		'QuantitativeValue',
	),
	'riskFactor'                              => array(
		'MedicalRiskFactor',
	),
	'accessibilityFeature'                    => array(
		'Text',
	),
	'legislationLegalForce'                   => array(
		'LegalForceStatus',
	),
	'monthsOfExperience'                      => array(
		'Number',
	),
	'secondaryPrevention'                     => array(
		'Drug',
		'DrugClass',
		'MedicalTherapy',
		'LifestyleModification',
	),
	'addressLocality'                         => array(
		'Text',
	),
	'datasetTimeInterval'                     => array(
		'DateTime',
	),
	'jobImmediateStart'                       => array(
		'Boolean',
	),
	'claimReviewed'                           => array(
		'Text',
	),
	'nationality'                             => array(
		'Country',
	),
	'termsOfService'                          => array(
		'URL',
		'Text',
	),
	'step'                                    => array(
		'Text',
		'HowToStep',
		'HowToSection',
		'CreativeWork',
	),
	'containsPlace'                           => array(
		'Place',
	),
	'memberOf'                                => array(
		'ProgramMembership',
		'Organization',
		'MemberProgramTier',
	),
	'suggestedAnswer'                         => array(
		'ItemList',
		'Answer',
	),
	'bookingTime'                             => array(
		'DateTime',
	),
	'gameServer'                              => array(
		'GameServer',
	),
	'videoFrameSize'                          => array(
		'Text',
	),
	'code'                                    => array(
		'MedicalCode',
	),
	'dateIssued'                              => array(
		'DateTime',
		'Date',
	),
	'version'                                 => array(
		'Number',
		'Text',
	),
	'availableFrom'                           => array(
		'DateTime',
	),
	'employmentType'                          => array(
		'Text',
	),
	'actionableFeedbackPolicy'                => array(
		'CreativeWork',
		'URL',
	),
	'floorLimit'                              => array(
		'MonetaryAmount',
	),
	'numberOfBeds'                            => array(
		'Number',
	),
	'purchaseDate'                            => array(
		'Date',
	),
	'originalMediaContextDescription'         => array(
		'Text',
	),
	'multipleValues'                          => array(
		'Boolean',
	),
	'video'                                   => array(
		'VideoObject',
		'Clip',
	),
	'events'                                  => array(
		'Event',
	),
	'contactlessPayment'                      => array(
		'Boolean',
	),
	'recordedIn'                              => array(
		'CreativeWork',
	),
	'flightNumber'                            => array(
		'Text',
	),
	'itemDefectReturnShippingFeesAmount'      => array(
		'MonetaryAmount',
	),
	'remainingAttendeeCapacity'               => array(
		'Integer',
	),
	'hasTiers'                                => array(
		'MemberProgramTier',
	),
	'birthDate'                               => array(
		'Date',
	),
	'ineligibleRegion'                        => array(
		'GeoShape',
		'Text',
		'Place',
	),
	'blogPost'                                => array(
		'BlogPosting',
	),
	'arrivalBoatTerminal'                     => array(
		'BoatTerminal',
	),
	'permittedUsage'                          => array(
		'Text',
	),
	'hasEnergyConsumptionDetails'             => array(
		'EnergyConsumptionDetails',
	),
	'endorsers'                               => array(
		'Person',
		'Organization',
	),
	'purchaseType'                            => array(
		'PurchaseType',
	),
	'operatingSystem'                         => array(
		'OperatingSystem',
		'Text',
	),
	'referee'                                 => array(
		'Person',
	),
	'merchant'                                => array(
		'Person',
		'Organization',
	),
	'applicationDeadline'                     => array(
		'Date',
		'Text',
	),
	'gameEdition'                             => array(
		'Text',
	),
	'relatedAnatomy'                          => array(
		'AnatomicalStructure',
		'AnatomicalSystem',
	),
	'permissionType'                          => array(
		'DigitalDocumentPermissionType',
	),
	'replacer'                                => array(
		'Thing',
	),
	'associatedDisease'                       => array(
		'MedicalCondition',
		'URL',
		'PropertyValue',
	),
	'hospitalAffiliation'                     => array(
		'Hospital',
	),
	'softwareVersion'                         => array(
		'Text',
	),
	'accountId'                               => array(
		'Text',
	),
	'availableOnDevice'                       => array(
		'Text',
	),
	'embedUrl'                                => array(
		'URL',
	),
	'workPerformed'                           => array(
		'CreativeWork',
	),
	'opens'                                   => array(
		'Time',
	),
	'musicArrangement'                        => array(
		'MusicComposition',
	),
	'postOp'                                  => array(
		'Text',
	),
	'feesAndCommissionsSpecification'         => array(
		'URL',
		'Text',
	),
	'author'                                  => array(
		'Organization',
		'Person',
	),
	'actionOption'                            => array(
		'Thing',
		'Text',
	),
	'percentile10'                            => array(
		'Number',
	),
	'item'                                    => array(
		'Thing',
	),
	'postOfficeBoxNumber'                     => array(
		'Text',
	),
	'hasBioPolymerSequence'                   => array(
		'Text',
	),
	'requiredMinAge'                          => array(
		'Integer',
	),
	'contentSize'                             => array(
		'Text',
	),
	'validFrom'                               => array(
		'DateTime',
		'Date',
	),
	'comment'                                 => array(
		'Comment',
	),
	'userInteractionCount'                    => array(
		'Integer',
	),
	'attendee'                                => array(
		'Person',
		'Organization',
	),
	'nerve'                                   => array(
		'Nerve',
	),
	'contentRating'                           => array(
		'Text',
		'Rating',
	),
	'subStructure'                            => array(
		'AnatomicalStructure',
	),
	'passengerPriorityStatus'                 => array(
		'Text',
		'QualitativeValue',
	),
	'priceComponent'                          => array(
		'PriceSpecification',
	),
	'postalCodeBegin'                         => array(
		'Text',
	),
	'incentiveCompensation'                   => array(
		'Text',
	),
	'fuelCapacity'                            => array(
		'QuantitativeValue',
	),
	'leaseLength'                             => array(
		'Duration',
		'QuantitativeValue',
	),
	'trailerWeight'                           => array(
		'QuantitativeValue',
	),
	'hasBioChemEntityPart'                    => array(
		'BioChemEntity',
	),
	'branchOf'                                => array(
		'Organization',
	),
	'contactPoint'                            => array(
		'ContactPoint',
	),
	'drainsTo'                                => array(
		'Vessel',
	),
	'collection'                              => array(
		'Thing',
	),
	'positiveNotes'                           => array(
		'ListItem',
		'Text',
		'WebContent',
		'ItemList',
	),
	'containedInPlace'                        => array(
		'Place',
	),
	'accommodationCategory'                   => array(
		'Text',
	),
	'dateline'                                => array(
		'Text',
	),
	'competencyRequired'                      => array(
		'DefinedTerm',
		'URL',
		'Text',
	),
	'iupacName'                               => array(
		'Text',
	),
	'carrier'                                 => array(
		'Organization',
	),
	'actionStatus'                            => array(
		'ActionStatusType',
	),
	'dosageForm'                              => array(
		'Text',
	),
	'reviewAspect'                            => array(
		'Text',
		'StructuredValue',
	),
	'inBroadcastLineup'                       => array(
		'CableOrSatelliteService',
	),
	'typeOfBed'                               => array(
		'Text',
		'BedType',
	),
	'processingTime'                          => array(
		'Duration',
	),
	'subjectOf'                               => array(
		'Event',
		'CreativeWork',
	),
	'foodEvent'                               => array(
		'FoodEvent',
	),
	'relatedDrug'                             => array(
		'Drug',
	),
	'encodesBioChemEntity'                    => array(
		'BioChemEntity',
	),
	'naturalProgression'                      => array(
		'Text',
	),
	'healthPlanCostSharing'                   => array(
		'HealthPlanCostSharingSpecification',
		'Boolean',
	),
	'significance'                            => array(
		'Text',
	),
	'manufacturer'                            => array(
		'Organization',
	),
	'lodgingUnitType'                         => array(
		'QualitativeValue',
		'Text',
	),
	'trainingSalary'                          => array(
		'MonetaryAmountDistribution',
	),
	'recourseLoan'                            => array(
		'Boolean',
	),
	'eligibleCustomerType'                    => array(
		'BusinessEntityType',
	),
	'sdLicense'                               => array(
		'CreativeWork',
		'URL',
	),
	'shippingDestination'                     => array(
		'DefinedRegion',
	),
	'orderDate'                               => array(
		'DateTime',
		'Date',
	),
	'isInvolvedInBiologicalProcess'           => array(
		'DefinedTerm',
		'URL',
		'PropertyValue',
	),
	'employees'                               => array(
		'Person',
	),
	'incentivizedItem'                        => array(
		'DefinedTerm',
		'Product',
	),
	'programmingModel'                        => array(
		'Text',
	),
	'contentReferenceTime'                    => array(
		'DateTime',
	),
	'agent'                                   => array(
		'Organization',
		'Person',
	),
	'recognizedBy'                            => array(
		'Organization',
	),
	'validForMemberTier'                      => array(
		'MemberProgramTier',
	),
	'contentLocation'                         => array(
		'Place',
	),
	'hasBroadcastChannel'                     => array(
		'BroadcastChannel',
	),
	'albums'                                  => array(
		'MusicAlbum',
	),
	'accountOverdraftLimit'                   => array(
		'MonetaryAmount',
	),
	'colorSwatch'                             => array(
		'ImageObject',
		'URL',
	),
	'educationalFramework'                    => array(
		'Text',
	),
	'dateReceived'                            => array(
		'DateTime',
	),
	'sodiumContent'                           => array(
		'Mass',
	),
	'caption'                                 => array(
		'Text',
		'MediaObject',
	),
	'quarantineGuidelines'                    => array(
		'URL',
		'WebContent',
	),
	'codeRepository'                          => array(
		'URL',
	),
	'modelDate'                               => array(
		'Date',
	),
	'priceComponentType'                      => array(
		'PriceComponentTypeEnumeration',
	),
	'datePublished'                           => array(
		'Date',
		'DateTime',
	),
	'arrivalPlatform'                         => array(
		'Text',
	),
	'sdPublisher'                             => array(
		'Person',
		'Organization',
	),
	'openingHours'                            => array(
		'Text',
	),
	'tongueWeight'                            => array(
		'QuantitativeValue',
	),
	'occupationalCredentialAwarded'           => array(
		'EducationalOccupationalCredential',
		'URL',
		'Text',
	),
	'episode'                                 => array(
		'Episode',
	),
	'bioChemInteraction'                      => array(
		'BioChemEntity',
	),
	'programMembershipUsed'                   => array(
		'ProgramMembership',
	),
	'ethicsPolicy'                            => array(
		'CreativeWork',
		'URL',
	),
	'suitableForDiet'                         => array(
		'RestrictedDiet',
	),
	'area'                                    => array(
		'Place',
	),
	'suggestedMaxAge'                         => array(
		'Number',
	),
	'pathophysiology'                         => array(
		'Text',
	),
	'surface'                                 => array(
		'Text',
		'URL',
	),
	'identifyingTest'                         => array(
		'MedicalTest',
	),
	'geoMidpoint'                             => array(
		'GeoCoordinates',
	),
	'numberOfAvailableAccommodationUnits'     => array(
		'QuantitativeValue',
	),
	'expertConsiderations'                    => array(
		'Text',
	),
	'affectedBy'                              => array(
		'Drug',
	),
	'alternativeHeadline'                     => array(
		'Text',
	),
	'lyricist'                                => array(
		'Person',
	),
	'permitAudience'                          => array(
		'Audience',
	),
	'repeatFrequency'                         => array(
		'Text',
		'Duration',
	),
	'recipe'                                  => array(
		'Recipe',
	),
	'applicableLocation'                      => array(
		'AdministrativeArea',
	),
	'reservationId'                           => array(
		'Text',
	),
	'requiredMaxAge'                          => array(
		'Integer',
	),
	'supportingData'                          => array(
		'DataFeed',
	),
	'percentile75'                            => array(
		'Number',
	),
	'geoEquals'                               => array(
		'GeospatialGeometry',
		'Place',
	),
	'mechanismOfAction'                       => array(
		'Text',
	),
	'rxcui'                                   => array(
		'Text',
	),
	'salaryCurrency'                          => array(
		'Text',
	),
	'ticketToken'                             => array(
		'URL',
		'Text',
	),
	'hasParticipationOffer'                   => array(
		'Offer',
	),
	'isbn'                                    => array(
		'Text',
	),
	'grantee'                                 => array(
		'Audience',
		'ContactPoint',
		'Person',
		'Organization',
	),
	'abstract'                                => array(
		'Text',
	),
	'vehicleIdentificationNumber'             => array(
		'Text',
	),
	'orderStatus'                             => array(
		'OrderStatus',
	),
	'geographicArea'                          => array(
		'AdministrativeArea',
	),
	'publisherImprint'                        => array(
		'Organization',
	),
	'encodingFormat'                          => array(
		'URL',
		'Text',
	),
	'inLanguage'                              => array(
		'Language',
		'Text',
	),
	'loanRepaymentForm'                       => array(
		'RepaymentSpecification',
	),
	'healthPlanPharmacyCategory'              => array(
		'Text',
	),
	'biomechnicalClass'                       => array(
		'Text',
	),
	'acceptedAnswer'                          => array(
		'Answer',
		'ItemList',
	),
	'trainName'                               => array(
		'Text',
	),
	'accessCode'                              => array(
		'Text',
	),
	'produces'                                => array(
		'Thing',
	),
	'mainEntityOfPage'                        => array(
		'CreativeWork',
		'URL',
	),
	'ticketNumber'                            => array(
		'Text',
	),
	'arrivalStation'                          => array(
		'TrainStation',
	),
	'dietFeatures'                            => array(
		'Text',
	),
	'layoutImage'                             => array(
		'ImageObject',
		'URL',
	),
	'significantLink'                         => array(
		'URL',
	),
	'game'                                    => array(
		'VideoGame',
	),
	'dateCreated'                             => array(
		'DateTime',
		'Date',
	),
	'benefitsSummaryUrl'                      => array(
		'URL',
	),
	'albumReleaseType'                        => array(
		'MusicAlbumReleaseType',
	),
	'archiveHeld'                             => array(
		'ArchiveComponent',
	),
	'hasCertification'                        => array(
		'Certification',
	),
	'seller'                                  => array(
		'Person',
		'Organization',
	),
	'negativeNotes'                           => array(
		'ItemList',
		'ListItem',
		'Text',
		'WebContent',
	),
	'increasesRiskOf'                         => array(
		'MedicalEntity',
	),
	'yield'                                   => array(
		'QuantitativeValue',
		'Text',
	),
	'hasDriveThroughService'                  => array(
		'Boolean',
	),
	'includesAttraction'                      => array(
		'TouristAttraction',
	),
	'restockingFee'                           => array(
		'Number',
		'MonetaryAmount',
	),
	'numberOfPreviousOwners'                  => array(
		'QuantitativeValue',
		'Number',
	),
	'typicalCreditsPerTerm'                   => array(
		'StructuredValue',
		'Integer',
	),
	'wheelbase'                               => array(
		'QuantitativeValue',
	),
	'legislationDateVersion'                  => array(
		'Date',
	),
	'accommodationFloorPlan'                  => array(
		'FloorPlan',
	),
	'subEvents'                               => array(
		'Event',
	),
	'fromLocation'                            => array(
		'Place',
	),
	'additionalProperty'                      => array(
		'PropertyValue',
	),
	'broadcastServiceTier'                    => array(
		'Text',
	),
	'numberOfEmployees'                       => array(
		'QuantitativeValue',
	),
	'renegotiableLoan'                        => array(
		'Boolean',
	),
	'torque'                                  => array(
		'QuantitativeValue',
	),
	'sourceOrganization'                      => array(
		'Organization',
	),
	'depth'                                   => array(
		'Distance',
		'QuantitativeValue',
	),
	'runsTo'                                  => array(
		'Vessel',
	),
	'roleName'                                => array(
		'URL',
		'Text',
	),
	'audio'                                   => array(
		'MusicRecording',
		'Clip',
		'AudioObject',
	),
	'usedToDiagnose'                          => array(
		'MedicalCondition',
	),
	'isPartOfBioChemEntity'                   => array(
		'BioChemEntity',
	),
	'composer'                                => array(
		'Person',
		'Organization',
	),
	'monoisotopicMolecularWeight'             => array(
		'QuantitativeValue',
		'Text',
	),
	'targetDescription'                       => array(
		'Text',
	),
	'expressedIn'                             => array(
		'DefinedTerm',
		'AnatomicalSystem',
		'BioChemEntity',
		'AnatomicalStructure',
	),
	'workHours'                               => array(
		'Text',
	),
	'targetPopulation'                        => array(
		'Text',
	),
	'distance'                                => array(
		'Distance',
	),
	'availableLanguage'                       => array(
		'Language',
		'Text',
	),
	'serviceType'                             => array(
		'Text',
		'GovernmentBenefitsType',
	),
	'expectedArrivalUntil'                    => array(
		'Date',
		'DateTime',
	),
	'issuedThrough'                           => array(
		'Service',
	),
	'healthPlanCopay'                         => array(
		'PriceSpecification',
	),
	'appliesToDeliveryMethod'                 => array(
		'DeliveryMethod',
	),
	'answerExplanation'                       => array(
		'Comment',
		'WebContent',
	),
	'eventStatus'                             => array(
		'EventStatusType',
	),
	'seriousAdverseOutcome'                   => array(
		'MedicalEntity',
	),
	'subEvent'                                => array(
		'Event',
	),
	'legislationRepeals'                      => array(
		'Legislation',
	),
	'mainContentOfPage'                       => array(
		'WebPageElement',
	),
	'followup'                                => array(
		'Text',
	),
	'occupationalCategory'                    => array(
		'Text',
		'CategoryCode',
	),
	'paymentMethodType'                       => array(
		'PaymentMethodType',
	),
	'arrivalTerminal'                         => array(
		'Text',
	),
	'preOp'                                   => array(
		'Text',
	),
	'inProductGroupWithID'                    => array(
		'Text',
	),
	'securityScreening'                       => array(
		'Text',
	),
	'quest'                                   => array(
		'Thing',
	),
	'learningResourceType'                    => array(
		'Text',
		'DefinedTerm',
	),
	'minValue'                                => array(
		'Number',
	),
	'resultReview'                            => array(
		'Review',
	),
	'circle'                                  => array(
		'Text',
	),
	'creativeWorkStatus'                      => array(
		'DefinedTerm',
		'Text',
	),
	'potentialUse'                            => array(
		'DefinedTerm',
	),
	'hasDigitalDocumentPermission'            => array(
		'DigitalDocumentPermission',
	),
	'audience'                                => array(
		'Audience',
	),
	'dayOfWeek'                               => array(
		'DayOfWeek',
	),
	'startDate'                               => array(
		'DateTime',
		'Date',
	),
	'gettingTestedInfo'                       => array(
		'URL',
		'WebContent',
	),
	'iso6523Code'                             => array(
		'Text',
	),
	'vehicleEngine'                           => array(
		'EngineSpecification',
	),
	'cvdNumC19Died'                           => array(
		'Number',
	),
	'breastfeedingWarning'                    => array(
		'Text',
	),
	'sharedContent'                           => array(
		'CreativeWork',
	),
	'typicalTest'                             => array(
		'MedicalTest',
	),
	'auditDate'                               => array(
		'DateTime',
		'Date',
	),
	'byDay'                                   => array(
		'Text',
		'DayOfWeek',
	),
	'guidelineDate'                           => array(
		'Date',
	),
	'birthPlace'                              => array(
		'Place',
	),
	'intensity'                               => array(
		'QuantitativeValue',
		'Text',
	),
	'serviceArea'                             => array(
		'AdministrativeArea',
		'GeoShape',
		'Place',
	),
	'trailer'                                 => array(
		'VideoObject',
	),
	'supply'                                  => array(
		'Text',
		'HowToSupply',
	),
	'correctionsPolicy'                       => array(
		'URL',
		'CreativeWork',
	),
	'locationCreated'                         => array(
		'Place',
	),
	'ingredients'                             => array(
		'Text',
	),
	'returnLabelSource'                       => array(
		'ReturnLabelSourceEnumeration',
	),
	'fiberContent'                            => array(
		'Mass',
	),
	'acceptedPaymentMethod'                   => array(
		'Text',
		'LoanOrCredit',
		'PaymentMethod',
	),
	'broadcastFrequency'                      => array(
		'Text',
		'BroadcastFrequencySpecification',
	),
	'byMonthWeek'                             => array(
		'Integer',
	),
	'itemOffered'                             => array(
		'Product',
		'Event',
		'AggregateOffer',
		'Trip',
		'CreativeWork',
		'Service',
		'MenuItem',
	),
	'legislationEnsuresImplementationOf'      => array(
		'Legislation',
	),
	'legalStatus'                             => array(
		'Text',
		'DrugLegalStatus',
		'MedicalEnumeration',
	),
	'performer'                               => array(
		'Person',
		'Organization',
	),
	'line'                                    => array(
		'Text',
	),
	'numChildren'                             => array(
		'QuantitativeValue',
		'Integer',
	),
	'transFatContent'                         => array(
		'Mass',
	),
	'recipient'                               => array(
		'ContactPoint',
		'Person',
		'Organization',
		'Audience',
	),
	'availability'                            => array(
		'ItemAvailability',
	),
	'repetitions'                             => array(
		'QuantitativeValue',
		'Number',
	),
	'billingPeriod'                           => array(
		'Duration',
	),
	'diseaseSpreadStatistics'                 => array(
		'Dataset',
		'URL',
		'WebContent',
		'Observation',
	),
	'workTranslation'                         => array(
		'CreativeWork',
	),
	'loanTerm'                                => array(
		'QuantitativeValue',
	),
	'albumProductionType'                     => array(
		'MusicAlbumProductionType',
	),
	'volumeNumber'                            => array(
		'Text',
		'Integer',
	),
	'liveBlogUpdate'                          => array(
		'BlogPosting',
	),
	'loanMortgageMandateAmount'               => array(
		'MonetaryAmount',
	),
	'typicalAgeRange'                         => array(
		'Text',
	),
	'returnPolicyCategory'                    => array(
		'MerchantReturnEnumeration',
	),
	'isResizable'                             => array(
		'Boolean',
	),
	'underName'                               => array(
		'Person',
		'Organization',
	),
	'recommendationStrength'                  => array(
		'Text',
	),
	'contentType'                             => array(
		'Text',
	),
	'jobBenefits'                             => array(
		'Text',
	),
	'isicV4'                                  => array(
		'Text',
	),
	'scheduleTimezone'                        => array(
		'Text',
	),
	'recordingOf'                             => array(
		'MusicComposition',
	),
	'deliveryMethod'                          => array(
		'DeliveryMethod',
	),
	'jobLocation'                             => array(
		'Place',
	),
	'costOrigin'                              => array(
		'Text',
	),
	'departureAirport'                        => array(
		'Airport',
	),
	'awayTeam'                                => array(
		'SportsTeam',
		'Person',
	),
	'medicalAudience'                         => array(
		'MedicalAudienceType',
		'MedicalAudience',
	),
	'option'                                  => array(
		'Text',
		'Thing',
	),
	'season'                                  => array(
		'CreativeWorkSeason',
		'URL',
	),
	'healthPlanCoinsuranceRate'               => array(
		'Number',
	),
	'departurePlatform'                       => array(
		'Text',
	),
	'bodyType'                                => array(
		'Text',
		'QualitativeValue',
		'URL',
	),
	'childMinAge'                             => array(
		'Number',
	),
	'timestamp'                               => array(
		'DateTime',
	),
	'equal'                                   => array(
		'QualitativeValue',
	),
	'iswcCode'                                => array(
		'Text',
	),
	'relevantOccupation'                      => array(
		'Occupation',
	),
	'ownedFrom'                               => array(
		'DateTime',
	),
	'highPrice'                               => array(
		'Number',
		'Text',
	),
	'validUntil'                              => array(
		'Date',
	),
	'postalCodeEnd'                           => array(
		'Text',
	),
	'saturatedFatContent'                     => array(
		'Mass',
	),
	'observationAbout'                        => array(
		'Place',
		'Thing',
	),
	'servingSize'                             => array(
		'Text',
	),
	'courseCode'                              => array(
		'Text',
	),
	'measurementQualifier'                    => array(
		'Enumeration',
	),
	'identifyingExam'                         => array(
		'PhysicalExam',
	),
	'creator'                                 => array(
		'Person',
		'Organization',
	),
	'checkinTime'                             => array(
		'DateTime',
		'Time',
	),
	'color'                                   => array(
		'Text',
	),
	'cvdNumVent'                              => array(
		'Number',
	),
	'broadcaster'                             => array(
		'Organization',
	),
	'discount'                                => array(
		'Number',
		'Text',
	),
	'numberOfAirbags'                         => array(
		'Number',
		'Text',
	),
	'isBasedOnUrl'                            => array(
		'CreativeWork',
		'URL',
		'Product',
	),
	'percentile90'                            => array(
		'Number',
	),
	'reviewedBy'                              => array(
		'Person',
		'Organization',
	),
	'associatedMediaReview'                   => array(
		'Review',
	),
	'suggestedAge'                            => array(
		'QuantitativeValue',
	),
	'measuredProperty'                        => array(
		'Property',
	),
	'publicationType'                         => array(
		'Text',
	),
	'deliveryAddress'                         => array(
		'PostalAddress',
	),
	'includesObject'                          => array(
		'TypeAndQuantityNode',
	),
	'ownedThrough'                            => array(
		'DateTime',
	),
	'returnPolicySeasonalOverride'            => array(
		'MerchantReturnPolicySeasonalOverride',
	),
	'dateRead'                                => array(
		'Date',
		'DateTime',
	),
	'fileFormat'                              => array(
		'URL',
		'Text',
	),
	'titleEIDR'                               => array(
		'URL',
		'Text',
	),
	'itemCondition'                           => array(
		'OfferItemCondition',
	),
	'bodyLocation'                            => array(
		'Text',
	),
	'encoding'                                => array(
		'MediaObject',
	),
	'releasedEvent'                           => array(
		'PublicationEvent',
	),
	'accountablePerson'                       => array(
		'Person',
	),
	'musicCompositionForm'                    => array(
		'Text',
	),
	'steps'                                   => array(
		'CreativeWork',
		'ItemList',
		'Text',
	),
	'educationalUse'                          => array(
		'Text',
		'DefinedTerm',
	),
	'subtitleLanguage'                        => array(
		'Text',
		'Language',
	),
	'chemicalComposition'                     => array(
		'Text',
	),
	'department'                              => array(
		'Organization',
	),
	'playMode'                                => array(
		'GamePlayMode',
	),
	'ticketedSeat'                            => array(
		'Seat',
	),
	'percentile25'                            => array(
		'Number',
	),
	'availableChannel'                        => array(
		'ServiceChannel',
	),
	'sizeGroup'                               => array(
		'Text',
		'SizeGroupEnumeration',
	),
	'costCategory'                            => array(
		'DrugCostCategory',
	),
	'cargoVolume'                             => array(
		'QuantitativeValue',
	),
	'greaterOrEqual'                          => array(
		'QualitativeValue',
	),
	'legalRepresentative'                     => array(
		'Person',
	),
	'accountMinimumInflow'                    => array(
		'MonetaryAmount',
	),
	'flightDistance'                          => array(
		'Distance',
		'Text',
	),
	'bioChemSimilarity'                       => array(
		'BioChemEntity',
	),
	'regionsAllowed'                          => array(
		'Place',
	),
	'occupancy'                               => array(
		'QuantitativeValue',
	),
	'physicalRequirement'                     => array(
		'DefinedTerm',
		'URL',
		'Text',
	),
	'isAcceptingNewPatients'                  => array(
		'Boolean',
	),
	'productionDate'                          => array(
		'Date',
	),
	'fuelConsumption'                         => array(
		'QuantitativeValue',
	),
	'sportsActivityLocation'                  => array(
		'SportsActivityLocation',
	),
	'activityFrequency'                       => array(
		'Text',
		'QuantitativeValue',
	),
	'foundingLocation'                        => array(
		'Place',
	),
	'schemaVersion'                           => array(
		'Text',
		'URL',
	),
	'companyRegistration'                     => array(
		'Certification',
	),
	'businessFunction'                        => array(
		'BusinessFunction',
	),
	'minimumPaymentDue'                       => array(
		'PriceSpecification',
		'MonetaryAmount',
	),
	'durationOfWarranty'                      => array(
		'QuantitativeValue',
	),
	'workFeatured'                            => array(
		'CreativeWork',
	),
	'codeSampleType'                          => array(
		'Text',
	),
	'acquiredFrom'                            => array(
		'Person',
		'Organization',
	),
	'dateVehicleFirstRegistered'              => array(
		'Date',
	),
	'hasMemberProgram'                        => array(
		'MemberProgram',
	),
	'member'                                  => array(
		'Organization',
		'Person',
	),
	'catalogNumber'                           => array(
		'Text',
	),
	'potentialAction'                         => array(
		'Action',
	),
	'jurisdiction'                            => array(
		'AdministrativeArea',
		'Text',
	),
	'isUnlabelledFallback'                    => array(
		'Boolean',
	),
	'dateDeleted'                             => array(
		'DateTime',
		'Date',
	),
	'tocEntry'                                => array(
		'HyperTocEntry',
	),
	'adverseOutcome'                          => array(
		'MedicalEntity',
	),
	'accessibilityHazard'                     => array(
		'Text',
	),
	'correction'                              => array(
		'CorrectionComment',
		'URL',
		'Text',
	),
	'recipeYield'                             => array(
		'QuantitativeValue',
		'Text',
	),
	'sport'                                   => array(
		'Text',
		'URL',
	),
	'appliesToPaymentMethod'                  => array(
		'PaymentMethod',
	),
	'pageStart'                               => array(
		'Text',
		'Integer',
	),
	'episodeNumber'                           => array(
		'Text',
		'Integer',
	),
	'fulfillmentType'                         => array(
		'FulfillmentTypeEnumeration',
	),
	'advanceBookingRequirement'               => array(
		'QuantitativeValue',
	),
	'doseValue'                               => array(
		'Number',
		'QualitativeValue',
	),
	'hasOccupation'                           => array(
		'Occupation',
	),
	'differentialDiagnosis'                   => array(
		'DDxElement',
	),
	'printSection'                            => array(
		'Text',
	),
	'menu'                                    => array(
		'Menu',
		'URL',
		'Text',
	),
	'doesNotShip'                             => array(
		'Boolean',
	),
	'functionalClass'                         => array(
		'MedicalEntity',
		'Text',
	),
	'drugClass'                               => array(
		'DrugClass',
	),
	'legislationCountersignedBy'              => array(
		'Person',
		'Organization',
	),
	'geoDisjoint'                             => array(
		'Place',
		'GeospatialGeometry',
	),
	'colleague'                               => array(
		'Person',
		'URL',
	),
	'doorTime'                                => array(
		'Time',
		'DateTime',
	),
	'menuAddOn'                               => array(
		'MenuSection',
		'MenuItem',
	),
	'collectionSize'                          => array(
		'Integer',
	),
	'arrivalAirport'                          => array(
		'Airport',
	),
	'buyer'                                   => array(
		'Person',
		'Organization',
	),
	'musicGroupMember'                        => array(
		'Person',
	),
	'proteinContent'                          => array(
		'Mass',
	),
	'travelBans'                              => array(
		'URL',
		'WebContent',
	),
	'lifeEvent'                               => array(
		'Event',
	),
	'rsvpResponse'                            => array(
		'RsvpResponseType',
	),
	'documentation'                           => array(
		'URL',
		'CreativeWork',
	),
	'partOfSystem'                            => array(
		'AnatomicalSystem',
	),
	'actionApplication'                       => array(
		'SoftwareApplication',
	),
	'isVariantOf'                             => array(
		'ProductModel',
		'ProductGroup',
	),
	'bloodSupply'                             => array(
		'Vessel',
	),
	'studyLocation'                           => array(
		'AdministrativeArea',
	),
	'itemListElement'                         => array(
		'Thing',
		'ListItem',
		'Text',
	),
	'unitText'                                => array(
		'Text',
	),
	'legislationCorrects'                     => array(
		'Legislation',
	),
	'album'                                   => array(
		'MusicAlbum',
	),
	'longitude'                               => array(
		'Number',
		'Text',
	),
	'honorificSuffix'                         => array(
		'Text',
	),
	'contactOption'                           => array(
		'ContactPointOption',
	),
	'inStoreReturnsOffered'                   => array(
		'Boolean',
	),
	'minPrice'                                => array(
		'Number',
	),
	'geoIntersects'                           => array(
		'Place',
		'GeospatialGeometry',
	),
	'urlTemplate'                             => array(
		'Text',
	),
	'healthPlanMarketingUrl'                  => array(
		'URL',
	),
	'cvdNumVentUse'                           => array(
		'Number',
	),
	'fuelType'                                => array(
		'URL',
		'Text',
		'QualitativeValue',
	),
	'alumni'                                  => array(
		'Person',
	),
	'availableService'                        => array(
		'MedicalProcedure',
		'MedicalTest',
		'MedicalTherapy',
	),
	'estimatedCost'                           => array(
		'MonetaryAmount',
		'Text',
	),
	'speed'                                   => array(
		'QuantitativeValue',
	),
	'subOrganization'                         => array(
		'Organization',
	),
	'temporal'                                => array(
		'Text',
		'DateTime',
	),
	'announcementLocation'                    => array(
		'CivicStructure',
		'LocalBusiness',
	),
	'seatingType'                             => array(
		'Text',
		'QualitativeValue',
	),
	'legalAddress'                            => array(
		'PostalAddress',
	),
	'targetProduct'                           => array(
		'SoftwareApplication',
	),
	'studySubject'                            => array(
		'MedicalEntity',
	),
	'publishedBy'                             => array(
		'Person',
		'Organization',
	),
	'isSimilarTo'                             => array(
		'Service',
		'Product',
	),
	'stageAsNumber'                           => array(
		'Number',
	),
	'orderValue'                              => array(
		'MonetaryAmount',
	),
	'energyEfficiencyScaleMax'                => array(
		'EUEnergyEfficiencyEnumeration',
	),
	'byMonthDay'                              => array(
		'Integer',
	),
	'speakable'                               => array(
		'URL',
		'SpeakableSpecification',
	),
	'relatedStructure'                        => array(
		'AnatomicalStructure',
	),
	'nextItem'                                => array(
		'ListItem',
	),
	'requiresSubscription'                    => array(
		'Boolean',
		'MediaSubscription',
	),
	'dropoffLocation'                         => array(
		'Place',
	),
	'executableLibraryName'                   => array(
		'Text',
	),
	'gracePeriod'                             => array(
		'Duration',
	),
	'reservationStatus'                       => array(
		'ReservationStatusType',
	),
	'course'                                  => array(
		'Place',
	),
	'instrument'                              => array(
		'Thing',
	),
	'checkoutTime'                            => array(
		'DateTime',
		'Time',
	),
	'educationalRole'                         => array(
		'Text',
	),
	'expires'                                 => array(
		'DateTime',
		'Date',
	),
	'softwareHelp'                            => array(
		'CreativeWork',
	),
	'interestRate'                            => array(
		'QuantitativeValue',
		'Number',
	),
	'physiologicalBenefits'                   => array(
		'Text',
	),
	'relatedCondition'                        => array(
		'MedicalCondition',
	),
	'diseasePreventionInfo'                   => array(
		'URL',
		'WebContent',
	),
	'variableMeasured'                        => array(
		'Property',
		'PropertyValue',
		'Text',
		'StatisticalVariable',
	),
	'knows'                                   => array(
		'Person',
	),
	'numberOfEpisodes'                        => array(
		'Integer',
	),
	'programType'                             => array(
		'Text',
		'DefinedTerm',
	),
	'energyEfficiencyScaleMin'                => array(
		'EUEnergyEfficiencyEnumeration',
	),
	'itemLocation'                            => array(
		'Place',
		'PostalAddress',
		'Text',
	),
	'engineType'                              => array(
		'URL',
		'Text',
		'QualitativeValue',
	),
	'telephone'                               => array(
		'Text',
	),
	'merchantReturnLink'                      => array(
		'URL',
	),
	'applicationCategory'                     => array(
		'Text',
		'URL',
	),
	'sibling'                                 => array(
		'Person',
	),
	'hasDeliveryMethod'                       => array(
		'DeliveryMethod',
	),
	'replacee'                                => array(
		'Thing',
	),
	'aggregateElement'                        => array(
		'Thing',
	),
	'industry'                                => array(
		'DefinedTerm',
		'Text',
	),
	'bookingAgent'                            => array(
		'Organization',
		'Person',
	),
	'contactPoints'                           => array(
		'ContactPoint',
	),
	'paymentMethod'                           => array(
		'PaymentMethod',
		'Text',
	),
	'diet'                                    => array(
		'Diet',
	),
	'endorsee'                                => array(
		'Person',
		'Organization',
	),
	'copyrightNotice'                         => array(
		'Text',
	),
	'boardingGroup'                           => array(
		'Text',
	),
	'exchangeRateSpread'                      => array(
		'Number',
		'MonetaryAmount',
	),
	'isEncodedByBioChemEntity'                => array(
		'Gene',
	),
	'prescriptionStatus'                      => array(
		'DrugPrescriptionStatus',
		'Text',
	),
	'starRating'                              => array(
		'Rating',
	),
	'newsUpdatesAndGuidelines'                => array(
		'URL',
		'WebContent',
	),
	'median'                                  => array(
		'Number',
	),
	'broadcastAffiliateOf'                    => array(
		'Organization',
	),
	'infectiousAgent'                         => array(
		'Text',
	),
	'netWorth'                                => array(
		'PriceSpecification',
		'MonetaryAmount',
	),
	'availableIn'                             => array(
		'AdministrativeArea',
	),
	'cvdFacilityCounty'                       => array(
		'Text',
	),
	'hiringOrganization'                      => array(
		'Person',
		'Organization',
	),
	'offerCount'                              => array(
		'Integer',
	),
	'jobLocationType'                         => array(
		'Text',
	),
	'recipeCuisine'                           => array(
		'Text',
	),
	'estimatesRiskOf'                         => array(
		'MedicalEntity',
	),
	'recognizingAuthority'                    => array(
		'Organization',
	),
	'discountCode'                            => array(
		'Text',
	),
	'hasSponsorshipOffer'                     => array(
		'Offer',
	),
	'mpn'                                     => array(
		'Text',
	),
	'coverageEndTime'                         => array(
		'DateTime',
	),
	'warrantyScope'                           => array(
		'WarrantyScope',
	),
	'drugUnit'                                => array(
		'Text',
	),
	'greater'                                 => array(
		'QualitativeValue',
	),
	'risks'                                   => array(
		'Text',
	),
	'incentiveType'                           => array(
		'IncentiveType',
	),
	'arrivalBusStop'                          => array(
		'BusStop',
		'BusStation',
	),
	'programPrerequisites'                    => array(
		'Course',
		'EducationalOccupationalCredential',
		'AlignmentObject',
		'Text',
	),
	'shippingOrigin'                          => array(
		'DefinedRegion',
	),
	'workLocation'                            => array(
		'Place',
		'ContactPoint',
	),
	'priceRange'                              => array(
		'Text',
	),
	'predecessorOf'                           => array(
		'ProductModel',
	),
	'contactType'                             => array(
		'Text',
	),
	'maps'                                    => array(
		'URL',
	),
	'educationRequirements'                   => array(
		'Text',
		'EducationalOccupationalCredential',
	),
	'competitor'                              => array(
		'Person',
		'SportsTeam',
	),
	'installUrl'                              => array(
		'URL',
	),
	'eligibleRegion'                          => array(
		'GeoShape',
		'Text',
		'Place',
	),
	'ratingCount'                             => array(
		'Integer',
	),
	'gameItem'                                => array(
		'Thing',
	),
	'description'                             => array(
		'TextObject',
		'Text',
	),
	'creditedTo'                              => array(
		'Person',
		'Organization',
	),
	'legislationResponsible'                  => array(
		'Person',
		'Organization',
	),
	'ratingValue'                             => array(
		'Number',
		'Text',
	),
	'stepValue'                               => array(
		'Number',
	),
	'numItems'                                => array(
		'QuantitativeValue',
	),
	'commentText'                             => array(
		'Text',
	),
	'incentives'                              => array(
		'Text',
	),
	'previousItem'                            => array(
		'ListItem',
	),
	'numberOfLoanPayments'                    => array(
		'Number',
	),
	'frequency'                               => array(
		'Text',
	),
	'partySize'                               => array(
		'Integer',
		'QuantitativeValue',
	),
	'includedRiskFactor'                      => array(
		'MedicalRiskFactor',
	),
	'trackingNumber'                          => array(
		'Text',
	),
	'musicReleaseFormat'                      => array(
		'MusicReleaseFormatType',
	),
	'restPeriods'                             => array(
		'Text',
		'QuantitativeValue',
	),
	'sdDatePublished'                         => array(
		'Date',
	),
	'cvdNumICUBedsOcc'                        => array(
		'Number',
	),
	'petsAllowed'                             => array(
		'Boolean',
		'Text',
	),
	'requirements'                            => array(
		'URL',
		'Text',
	),
	'doseUnit'                                => array(
		'Text',
	),
	'engineDisplacement'                      => array(
		'QuantitativeValue',
	),
	'teaches'                                 => array(
		'DefinedTerm',
		'Text',
	),
	'deliveryTime'                            => array(
		'ShippingDeliveryTime',
	),
	'carbohydrateContent'                     => array(
		'Mass',
	),
	'hasMenu'                                 => array(
		'Text',
		'Menu',
		'URL',
	),
	'healthPlanId'                            => array(
		'Text',
	),
	'reviewRating'                            => array(
		'Rating',
	),
	'sportsTeam'                              => array(
		'SportsTeam',
	),
	'screenCount'                             => array(
		'Number',
	),
	'alcoholWarning'                          => array(
		'Text',
	),
	'partOfSeries'                            => array(
		'CreativeWorkSeries',
	),
	'businessDays'                            => array(
		'OpeningHoursSpecification',
		'DayOfWeek',
	),
	'dataset'                                 => array(
		'Dataset',
	),
	'alumniOf'                                => array(
		'EducationalOrganization',
		'Organization',
	),
	'numberOfItems'                           => array(
		'Integer',
	),
	'publishingPrinciples'                    => array(
		'CreativeWork',
		'URL',
	),
	'hasStore'                                => array(
		'OnlineStore',
	),
	'productionCompany'                       => array(
		'Organization',
	),
	'trackingUrl'                             => array(
		'URL',
	),
	'valueMaxLength'                          => array(
		'Number',
	),
	'nerveMotor'                              => array(
		'Muscle',
	),
	'includedDataCatalog'                     => array(
		'DataCatalog',
	),
	'hasHealthAspect'                         => array(
		'HealthAspectEnumeration',
	),
	'editor'                                  => array(
		'Person',
	),
	'exceptDate'                              => array(
		'Date',
		'DateTime',
	),
	'interactionType'                         => array(
		'Action',
	),
	'spatialCoverage'                         => array(
		'Place',
	),
	'suggestedMeasurement'                    => array(
		'QuantitativeValue',
	),
	'entertainmentBusiness'                   => array(
		'EntertainmentBusiness',
	),
	'associatedReview'                        => array(
		'Review',
	),
	'award'                                   => array(
		'Text',
	),
	'parents'                                 => array(
		'Person',
	),
	'inChIKey'                                => array(
		'Text',
	),
	'targetCollection'                        => array(
		'Thing',
	),
	'healthPlanNetworkTier'                   => array(
		'Text',
	),
	'directors'                               => array(
		'Person',
	),
	'ownershipFundingInfo'                    => array(
		'CreativeWork',
		'URL',
		'AboutPage',
		'Text',
	),
	'doseSchedule'                            => array(
		'DoseSchedule',
	),
	'mealService'                             => array(
		'Text',
	),
	'purchasePriceLimit'                      => array(
		'MonetaryAmount',
	),
	'usageInfo'                               => array(
		'CreativeWork',
		'URL',
	),
	'jobTitle'                                => array(
		'DefinedTerm',
		'Text',
	),
	'siblings'                                => array(
		'Person',
	),
	'infectiousAgentClass'                    => array(
		'InfectiousAgentClass',
	),
	'replyToUrl'                              => array(
		'URL',
	),
	'floorLevel'                              => array(
		'Text',
	),
	'sportsEvent'                             => array(
		'SportsEvent',
	),
	'taxID'                                   => array(
		'Text',
	),
	'followee'                                => array(
		'Person',
		'Organization',
	),
	'application'                             => array(
		'SoftwareApplication',
	),
	'dateSent'                                => array(
		'DateTime',
	),
	'overdosage'                              => array(
		'Text',
	),
	'monthlyMinimumRepaymentAmount'           => array(
		'Number',
		'MonetaryAmount',
	),
	'isAccessibleForFree'                     => array(
		'Boolean',
	),
	'about'                                   => array(
		'Thing',
	),
	'endTime'                                 => array(
		'DateTime',
		'Time',
	),
	'colleagues'                              => array(
		'Person',
	),
	'numConstraints'                          => array(
		'Integer',
	),
	'activeIngredient'                        => array(
		'Text',
	),
	'hostingOrganization'                     => array(
		'Organization',
	),
	'clinicalPharmacology'                    => array(
		'Text',
	),
	'numberOfBedrooms'                        => array(
		'QuantitativeValue',
		'Number',
	),
	'discussionUrl'                           => array(
		'URL',
	),
	'alternateName'                           => array(
		'Text',
	),
	'numberOfPlayers'                         => array(
		'QuantitativeValue',
	),
	'inSupportOf'                             => array(
		'Text',
	),
	'encodesCreativeWork'                     => array(
		'CreativeWork',
	),
	'model'                                   => array(
		'Text',
		'ProductModel',
	),
	'beforeMedia'                             => array(
		'MediaObject',
		'URL',
	),
	'partOfEpisode'                           => array(
		'Episode',
	),
	'athlete'                                 => array(
		'Person',
	),
	'pagination'                              => array(
		'Text',
	),
	'originAddress'                           => array(
		'PostalAddress',
	),
	'hasCategoryCode'                         => array(
		'CategoryCode',
	),
	'muscleAction'                            => array(
		'Text',
	),
	'biologicalRole'                          => array(
		'DefinedTerm',
	),
	'duplicateTherapy'                        => array(
		'MedicalTherapy',
	),
	'screenshot'                              => array(
		'ImageObject',
		'URL',
	),
	'certificationIdentification'             => array(
		'DefinedTerm',
		'Text',
	),
	'nsn'                                     => array(
		'Text',
	),
	'warrantyPromise'                         => array(
		'WarrantyPromise',
	),
	'subReservation'                          => array(
		'Reservation',
	),
	'familyName'                              => array(
		'Text',
	),
	'codingSystem'                            => array(
		'Text',
	),
	'additionalVariable'                      => array(
		'Text',
	),
	'supplyTo'                                => array(
		'AnatomicalStructure',
	),
	'childMaxAge'                             => array(
		'Number',
	),
	'billingIncrement'                        => array(
		'Number',
	),
	'diversityPolicy'                         => array(
		'CreativeWork',
		'URL',
	),
	'countryOfOrigin'                         => array(
		'Country',
	),
	'photos'                                  => array(
		'Photograph',
		'ImageObject',
	),
	'articleBody'                             => array(
		'Text',
	),
	'availabilityStarts'                      => array(
		'DateTime',
		'Date',
		'Time',
	),
	'deliveryStatus'                          => array(
		'DeliveryEvent',
	),
	'hasCredential'                           => array(
		'EducationalOccupationalCredential',
	),
	'paymentMethodId'                         => array(
		'Text',
	),
	'significantLinks'                        => array(
		'URL',
	),
	'artEdition'                              => array(
		'Text',
		'Integer',
	),
	'causeOf'                                 => array(
		'MedicalEntity',
	),
	'isAvailableGenerically'                  => array(
		'Boolean',
	),
	'parentItem'                              => array(
		'CreativeWork',
		'Comment',
	),
	'encodingType'                            => array(
		'Text',
	),
	'sponsor'                                 => array(
		'Person',
		'Organization',
	),
	'downloadUrl'                             => array(
		'URL',
	),
	'valueMinLength'                          => array(
		'Number',
	),
	'coach'                                   => array(
		'Person',
	),
	'performerIn'                             => array(
		'Event',
	),
	'isConsumableFor'                         => array(
		'Product',
	),
	'maximumPhysicalAttendeeCapacity'         => array(
		'Integer',
	),
	'agentInteractionStatistic'               => array(
		'InteractionCounter',
	),
	'masthead'                                => array(
		'CreativeWork',
		'URL',
	),
	'bccRecipient'                            => array(
		'Person',
		'Organization',
		'ContactPoint',
	),
	'dataFeedElement'                         => array(
		'DataFeedItem',
		'Thing',
		'Text',
	),
	'billingStart'                            => array(
		'Number',
	),
	'primaryPrevention'                       => array(
		'MedicalTherapy',
	),
	'serviceOperator'                         => array(
		'Organization',
	),
	'includedComposition'                     => array(
		'MusicComposition',
	),
	'recipeCategory'                          => array(
		'Text',
	),
	'geoWithin'                               => array(
		'GeospatialGeometry',
		'Place',
	),
	'givenName'                               => array(
		'Text',
	),
	'branchCode'                              => array(
		'Text',
	),
	'width'                                   => array(
		'QuantitativeValue',
		'Distance',
	),
	'borrower'                                => array(
		'Person',
	),
	'subTest'                                 => array(
		'MedicalTest',
	),
	'musicalKey'                              => array(
		'Text',
	),
	'error'                                   => array(
		'Thing',
	),
	'startOffset'                             => array(
		'HyperTocEntry',
		'Number',
	),
	'cvdFacilityId'                           => array(
		'Text',
	),
	'partOfTrip'                              => array(
		'Trip',
	),
	'geoCoveredBy'                            => array(
		'GeospatialGeometry',
		'Place',
	),
	'abridged'                                => array(
		'Boolean',
	),
	'lastReviewed'                            => array(
		'Date',
	),
	'cvdNumBeds'                              => array(
		'Number',
	),
	'worksFor'                                => array(
		'Organization',
	),
	'orderedItem'                             => array(
		'Service',
		'Product',
		'OrderItem',
	),
	'specialty'                               => array(
		'Specialty',
	),
	'interactivityType'                       => array(
		'Text',
	),
	'includedInDataCatalog'                   => array(
		'DataCatalog',
	),
	'numberedPosition'                        => array(
		'Number',
	),
	'maximumAttendeeCapacity'                 => array(
		'Integer',
	),
	'guideline'                               => array(
		'MedicalGuideline',
	),
	'associatedPathophysiology'               => array(
		'Text',
	),
	'lesser'                                  => array(
		'QualitativeValue',
	),
	'returnPolicyCountry'                     => array(
		'Country',
		'Text',
	),
	'translator'                              => array(
		'Organization',
		'Person',
	),
	'includesHealthPlanNetwork'               => array(
		'HealthPlanNetwork',
	),
	'eligibleTransactionVolume'               => array(
		'PriceSpecification',
	),
	'healthPlanDrugTier'                      => array(
		'Text',
	),
	'creditText'                              => array(
		'Text',
	),
	'vehicleInteriorColor'                    => array(
		'Text',
	),
	'inDefinedTermSet'                        => array(
		'URL',
		'DefinedTermSet',
	),
	'taxonomicRange'                          => array(
		'Taxon',
		'DefinedTerm',
		'URL',
		'Text',
	),
	'location'                                => array(
		'Text',
		'VirtualLocation',
		'Place',
		'PostalAddress',
	),
	'legislationAmends'                       => array(
		'Legislation',
	),
	'inCodeSet'                               => array(
		'CategoryCodeSet',
		'URL',
	),
	'timeOfDay'                               => array(
		'Text',
	),
	'messageAttachment'                       => array(
		'CreativeWork',
	),
	'offersPrescriptionByMail'                => array(
		'Boolean',
	),
	'letterer'                                => array(
		'Person',
	),
	'actors'                                  => array(
		'Person',
	),
	'availableTest'                           => array(
		'MedicalTest',
	),
	'seeks'                                   => array(
		'Demand',
	),
	'legislationDate'                         => array(
		'Date',
	),
	'serviceLocation'                         => array(
		'Place',
	),
	'applicationSubCategory'                  => array(
		'Text',
		'URL',
	),
	'numberOfPages'                           => array(
		'Integer',
	),
	'mapType'                                 => array(
		'MapCategoryType',
	),
	'ratingExplanation'                       => array(
		'Text',
	),
	'contributor'                             => array(
		'Person',
		'Organization',
	),
	'paymentDueDate'                          => array(
		'DateTime',
		'Date',
	),
	'translationOfWork'                       => array(
		'CreativeWork',
	),
	'winner'                                  => array(
		'Person',
	),
	'utterances'                              => array(
		'Text',
	),
	'loanType'                                => array(
		'URL',
		'Text',
	),
	'healthPlanDrugOption'                    => array(
		'Text',
	),
	'passengerSequenceNumber'                 => array(
		'Text',
	),
	'makesOffer'                              => array(
		'Offer',
	),
	'applicationSuite'                        => array(
		'Text',
	),
	'alternativeOf'                           => array(
		'Gene',
	),
	'enginePower'                             => array(
		'QuantitativeValue',
	),
	'verificationFactCheckingPolicy'          => array(
		'URL',
		'CreativeWork',
	),
	'productGroupID'                          => array(
		'Text',
	),
	'legislationApplies'                      => array(
		'Legislation',
	),
	'observationPeriod'                       => array(
		'Text',
	),
	'inPlaylist'                              => array(
		'MusicPlaylist',
	),
	'map'                                     => array(
		'URL',
	),
	'vatID'                                   => array(
		'Text',
	),
	'status'                                  => array(
		'EventStatusType',
		'Text',
		'MedicalStudyStatus',
	),
	'valueRequired'                           => array(
		'Boolean',
	),
	'associatedMedia'                         => array(
		'MediaObject',
	),
	'participant'                             => array(
		'Person',
		'Organization',
	),
	'discountCurrency'                        => array(
		'Text',
	),
	'maximumIntake'                           => array(
		'MaximumDoseSchedule',
	),
	'datePosted'                              => array(
		'DateTime',
		'Date',
	),
	'originatesFrom'                          => array(
		'Vessel',
	),
	'permissions'                             => array(
		'Text',
	),
	'molecularWeight'                         => array(
		'QuantitativeValue',
		'Text',
	),
	'nonProprietaryName'                      => array(
		'Text',
	),
	'members'                                 => array(
		'Person',
		'Organization',
	),
	'pattern'                                 => array(
		'DefinedTerm',
		'Text',
	),
	'asin'                                    => array(
		'URL',
		'Text',
	),
	'gamePlatform'                            => array(
		'Text',
		'Thing',
		'URL',
	),
	'directApply'                             => array(
		'Boolean',
	),
	'educationalAlignment'                    => array(
		'AlignmentObject',
	),
	'usesHealthPlanIdStandard'                => array(
		'URL',
		'Text',
	),
	'serialNumber'                            => array(
		'Text',
	),
	'previousStartDate'                       => array(
		'Date',
	),
	'credentialCategory'                      => array(
		'DefinedTerm',
		'URL',
		'Text',
	),
	'url'                                     => array(
		'URL',
	),
	'gameLocation'                            => array(
		'URL',
		'Place',
		'PostalAddress',
	),
	'incentiveStatus'                         => array(
		'IncentiveStatus',
	),
	'hasCourse'                               => array(
		'Course',
	),
	'weightPercentage'                        => array(
		'Number',
	),
	'accessibilityAPI'                        => array(
		'Text',
	),
	'duns'                                    => array(
		'Text',
	),
	'geoTouches'                              => array(
		'Place',
		'GeospatialGeometry',
	),
	'box'                                     => array(
		'Text',
	),
	'worstRating'                             => array(
		'Text',
		'Number',
	),
	'director'                                => array(
		'Person',
	),
	'characterName'                           => array(
		'Text',
	),
	'chemicalRole'                            => array(
		'DefinedTerm',
	),
	'diagram'                                 => array(
		'ImageObject',
	),
	'providesBroadcastService'                => array(
		'BroadcastService',
	),
	'artMedium'                               => array(
		'URL',
		'Text',
	),
	'termCode'                                => array(
		'Text',
	),
	'fuelEfficiency'                          => array(
		'QuantitativeValue',
	),
	'loser'                                   => array(
		'Person',
	),
	'hasShippingService'                      => array(
		'ShippingService',
	),
	'variantCover'                            => array(
		'Text',
	),
	'image'                                   => array(
		'ImageObject',
		'URL',
	),
	'tracks'                                  => array(
		'MusicRecording',
	),
	'confirmationNumber'                      => array(
		'Text',
	),
	'totalTime'                               => array(
		'Duration',
	),
	'homeLocation'                            => array(
		'Place',
		'ContactPoint',
	),
	'offeredBy'                               => array(
		'Person',
		'Organization',
	),
	'billingAddress'                          => array(
		'PostalAddress',
	),
	'accessibilitySummary'                    => array(
		'Text',
	),
	'embeddedTextCaption'                     => array(
		'Text',
	),
	'exampleOfWork'                           => array(
		'CreativeWork',
	),
	'publication'                             => array(
		'PublicationEvent',
	),
	'attendees'                               => array(
		'Person',
		'Organization',
	),
	'reviewBody'                              => array(
		'Text',
	),
	'fundedItem'                              => array(
		'Product',
		'Event',
		'CreativeWork',
		'MedicalEntity',
		'BioChemEntity',
		'Person',
		'Organization',
	),
	'faxNumber'                               => array(
		'Text',
	),
	'vehicleModelDate'                        => array(
		'Date',
	),
	'eligibleQuantity'                        => array(
		'QuantitativeValue',
	),
	'pregnancyCategory'                       => array(
		'DrugPregnancyCategory',
	),
	'repeatCount'                             => array(
		'Integer',
	),
	'aircraft'                                => array(
		'Vehicle',
		'Text',
	),
	'pregnancyWarning'                        => array(
		'Text',
	),
	'tripOrigin'                              => array(
		'Place',
	),
	'performTime'                             => array(
		'Duration',
	),
	'hasPOS'                                  => array(
		'Place',
	),
	'bitrate'                                 => array(
		'Text',
	),
	'busName'                                 => array(
		'Text',
	),
	'softwareAddOn'                           => array(
		'SoftwareApplication',
	),
	'isAccessoryOrSparePartFor'               => array(
		'Product',
	),
	'foodWarning'                             => array(
		'Text',
	),
	'paymentAccepted'                         => array(
		'Text',
	),
	'driveWheelConfiguration'                 => array(
		'Text',
		'DriveWheelConfigurationValue',
	),
	'seatNumber'                              => array(
		'Text',
	),
	'departureBusStop'                        => array(
		'BusStop',
		'BusStation',
	),
	'medicineSystem'                          => array(
		'MedicineSystem',
	),
	'disambiguatingDescription'               => array(
		'Text',
	),
	'responsibilities'                        => array(
		'Text',
	),
	'isLocatedInSubcellularLocation'          => array(
		'DefinedTerm',
		'URL',
		'PropertyValue',
	),
	'parent'                                  => array(
		'Person',
	),
	'device'                                  => array(
		'Text',
	),
	'countriesNotSupported'                   => array(
		'Text',
	),
	'position'                                => array(
		'Text',
		'Integer',
	),
	'relatedLink'                             => array(
		'URL',
	),
	'validThrough'                            => array(
		'DateTime',
		'Date',
	),
	'tissueSample'                            => array(
		'Text',
	),
	'hasGS1DigitalLink'                       => array(
		'URL',
	),
	'conditionsOfAccess'                      => array(
		'Text',
	),
	'mainEntity'                              => array(
		'Thing',
	),
	'observationDate'                         => array(
		'Date',
		'DateTime',
	),
	'copyrightYear'                           => array(
		'Number',
	),
	'title'                                   => array(
		'Text',
	),
	'acrissCode'                              => array(
		'Text',
	),
	'additionalName'                          => array(
		'Text',
	),
	'text'                                    => array(
		'Text',
	),
	'exifData'                                => array(
		'PropertyValue',
		'Text',
	),
	'contentUrl'                              => array(
		'URL',
	),
	'seatRow'                                 => array(
		'Text',
	),
	'cashBack'                                => array(
		'Boolean',
		'Number',
	),
	'reservedTicket'                          => array(
		'Ticket',
	),
	'tickerSymbol'                            => array(
		'Text',
	),
	'defaultValue'                            => array(
		'Text',
		'Thing',
	),
	'childTaxon'                              => array(
		'Taxon',
		'URL',
		'Text',
	),
	'releaseDate'                             => array(
		'Date',
	),
	'preparation'                             => array(
		'Text',
		'MedicalEntity',
	),
	'email'                                   => array(
		'Text',
	),
	'interpretedAsClaim'                      => array(
		'Claim',
	),
	'procedure'                               => array(
		'Text',
	),
	'diagnosis'                               => array(
		'MedicalCondition',
	),
	'callSign'                                => array(
		'Text',
	),
	'cookTime'                                => array(
		'Duration',
	),
	'hasOfferCatalog'                         => array(
		'OfferCatalog',
	),
	'isPartOf'                                => array(
		'URL',
		'CreativeWork',
	),
	'legislationChanges'                      => array(
		'Legislation',
	),
	'deathPlace'                              => array(
		'Place',
	),
	'claimInterpreter'                        => array(
		'Person',
		'Organization',
	),
	'landlord'                                => array(
		'Organization',
		'Person',
	),
	'antagonist'                              => array(
		'Muscle',
	),
	'nonprofitStatus'                         => array(
		'NonprofitType',
	),
	'transmissionMethod'                      => array(
		'Text',
	),
	'itemListOrder'                           => array(
		'ItemListOrderType',
		'Text',
	),
	'shippingRate'                            => array(
		'MonetaryAmount',
		'ShippingRateSettings',
	),
	'termDuration'                            => array(
		'Duration',
	),
	'linkRelationship'                        => array(
		'Text',
	),
	'httpMethod'                              => array(
		'Text',
	),
	'numberOfBathroomsTotal'                  => array(
		'Integer',
	),
	'browserRequirements'                     => array(
		'Text',
	),
	'priceSpecification'                      => array(
		'PriceSpecification',
	),
	'numberOfAxles'                           => array(
		'QuantitativeValue',
		'Number',
	),
	'exercisePlan'                            => array(
		'ExercisePlan',
	),
	'arrivalGate'                             => array(
		'Text',
	),
	'speechToTextMarkup'                      => array(
		'Text',
	),
	'geoCrosses'                              => array(
		'Place',
		'GeospatialGeometry',
	),
	'earlyPrepaymentPenalty'                  => array(
		'MonetaryAmount',
	),
	'postalCode'                              => array(
		'Text',
	),
	'educationalLevel'                        => array(
		'DefinedTerm',
		'URL',
		'Text',
	),
	'variesBy'                                => array(
		'DefinedTerm',
		'Text',
	),
	'broadcastDisplayName'                    => array(
		'Text',
	),
	'itemDefectReturnFees'                    => array(
		'ReturnFeesEnumeration',
	),
	'administrationRoute'                     => array(
		'Text',
	),
	'eventSchedule'                           => array(
		'Schedule',
	),
	'toLocation'                              => array(
		'Place',
	),
	'applicantLocationRequirements'           => array(
		'AdministrativeArea',
	),
	'postalCodePrefix'                        => array(
		'Text',
	),
	'sizeSystem'                              => array(
		'SizeSystemEnumeration',
		'Text',
	),
	'founders'                                => array(
		'Person',
	),
	'articleSection'                          => array(
		'Text',
	),
	'videoQuality'                            => array(
		'Text',
	),
	'subStageSuffix'                          => array(
		'Text',
	),
	'regionDrained'                           => array(
		'AnatomicalSystem',
		'AnatomicalStructure',
	),
	'memoryRequirements'                      => array(
		'URL',
		'Text',
	),
	'applicationContact'                      => array(
		'ContactPoint',
	),
	'numAdults'                               => array(
		'QuantitativeValue',
		'Integer',
	),
	'customerRemorseReturnLabelSource'        => array(
		'ReturnLabelSourceEnumeration',
	),
	'activityDuration'                        => array(
		'Duration',
		'QuantitativeValue',
	),
	'validFor'                                => array(
		'Duration',
	),
	'primaryImageOfPage'                      => array(
		'ImageObject',
	),
	'penciler'                                => array(
		'Person',
	),
	'errorCode'                               => array(
		'Text',
		'Integer',
		'DefinedTerm',
		'StatusEnumeration',
	),
	'sender'                                  => array(
		'Organization',
		'Audience',
		'Person',
	),
	'bestRating'                              => array(
		'Text',
		'Number',
	),
	'character'                               => array(
		'Person',
	),
	'spouse'                                  => array(
		'Person',
	),
	'copyrightHolder'                         => array(
		'Person',
		'Organization',
	),
	'runtimePlatform'                         => array(
		'Text',
		'RuntimePlatform',
	),
	'target'                                  => array(
		'EntryPoint',
		'URL',
	),
	'free'                                    => array(
		'Boolean',
	),
	'benefits'                                => array(
		'Text',
	),
	'securityClearanceRequirement'            => array(
		'Text',
		'URL',
	),
	'gameAvailabilityType'                    => array(
		'Text',
		'GameAvailabilityEnumeration',
	),
	'specialCommitments'                      => array(
		'Text',
	),
	'departureStation'                        => array(
		'TrainStation',
	),
	'issuedBy'                                => array(
		'Organization',
	),
	'backstory'                               => array(
		'Text',
		'CreativeWork',
	),
	'dateModified'                            => array(
		'Date',
		'DateTime',
	),
	'departureTerminal'                       => array(
		'Text',
	),
	'resultComment'                           => array(
		'Comment',
	),
	'mediaItemAppearance'                     => array(
		'MediaObject',
	),
	'aspect'                                  => array(
		'Text',
	),
	'currentExchangeRate'                     => array(
		'UnitPriceSpecification',
	),
	'availabilityEnds'                        => array(
		'DateTime',
		'Date',
		'Time',
	),
	'priceValidUntil'                         => array(
		'Date',
	),
	'includedInHealthInsurancePlan'           => array(
		'HealthInsurancePlan',
	),
	'hasTierRequirement'                      => array(
		'MonetaryAmount',
		'Text',
		'CreditCard',
		'UnitPriceSpecification',
	),
	'afterMedia'                              => array(
		'MediaObject',
		'URL',
	),
	'availableAtOrFrom'                       => array(
		'Place',
	),
	'cvdNumC19OverflowPats'                   => array(
		'Number',
	),
	'sensoryUnit'                             => array(
		'SuperficialAnatomy',
		'AnatomicalStructure',
	),
	'cvdNumTotBeds'                           => array(
		'Number',
	),
	'healthcareReportingData'                 => array(
		'Dataset',
		'CDCPMDRecord',
	),
	'dissolutionDate'                         => array(
		'Date',
	),
	'cutoffTime'                              => array(
		'Time',
	),
	'cvdNumC19HospPats'                       => array(
		'Number',
	),
	'unnamedSourcesPolicy'                    => array(
		'CreativeWork',
		'URL',
	),
	'icaoCode'                                => array(
		'Text',
	),
	'targetName'                              => array(
		'Text',
	),
	'estimatedSalary'                         => array(
		'Number',
		'MonetaryAmount',
		'MonetaryAmountDistribution',
	),
	'drug'                                    => array(
		'Drug',
	),
	'annualPercentageRate'                    => array(
		'QuantitativeValue',
		'Number',
	),
	'episodes'                                => array(
		'Episode',
	),
	'owns'                                    => array(
		'Thing',
	),
	'incentiveAmount'                         => array(
		'LoanOrCredit',
		'UnitPriceSpecification',
		'QuantitativeValue',
	),
	'program'                                 => array(
		'MemberProgram',
	),
	'inker'                                   => array(
		'Person',
	),
	'scheduledTime'                           => array(
		'Date',
		'DateTime',
	),
	'photo'                                   => array(
		'Photograph',
		'ImageObject',
	),
	'totalPrice'                              => array(
		'Number',
		'Text',
		'PriceSpecification',
	),
	'amenityFeature'                          => array(
		'LocationFeatureSpecification',
	),
	'organizer'                               => array(
		'Person',
		'Organization',
	),
	'qualifications'                          => array(
		'EducationalOccupationalCredential',
		'Text',
	),
);
