.aioseo-seo-analysis{display:flex;position:relative;flex:1;justify-content:center;align-items:center;gap:40px}.aioseo-seo-analysis .seo-analysis-score{position:relative;width:100%;max-width:160px}.aioseo-seo-analysis .seo-analysis-score .aioseo-site-score{display:flex}.aioseo-seo-analysis .seo-analysis-score .score-analyzing{margin-top:0!important}.aioseo-seo-analysis .seo-analysis-score .aioseo-score-amount .score{font-size:40px;line-height:1.2}.aioseo-seo-analysis .seo-analysis-score .aioseo-score-amount .total{font-size:14px}.aioseo-seo-analysis .seo-analysis-score .score-description{font-size:13px}.aioseo-seo-analysis .seo-analysis-score svg{width:100%;height:auto}.aioseo-seo-analysis .seo-analysis-mobile-snapshot{display:none;width:245px}@media screen and (min-width:1042px){.aioseo-seo-analysis .seo-analysis-mobile-snapshot{display:block}}.aioseo-seo-analysis .seo-analysis-mobile-snapshot .mobile-snapshot-image{position:relative;padding:10px 4px 0;width:100%;height:445px;overflow:hidden;border-radius:35px}.aioseo-seo-analysis .seo-analysis-mobile-snapshot .mobile-snapshot-image__frame{position:absolute;z-index:2;top:0;width:100%;height:100%}[dir=ltr] .aioseo-seo-analysis .seo-analysis-mobile-snapshot .mobile-snapshot-image__frame{left:0}[dir=rtl] .aioseo-seo-analysis .seo-analysis-mobile-snapshot .mobile-snapshot-image__frame{right:0}.aioseo-seo-analysis .seo-analysis-mobile-snapshot .mobile-snapshot-image__content{width:100%;height:100%}.aioseo-seo-analysis .seo-analysis-homepage-url{display:block;padding:8px 12px;background-color:#f3f4f5;border-radius:4px;font-weight:700;margin-bottom:12px}.aioseo-seo-analysis .seo-analysis-description h2{font-size:24px;line-height:30px;margin-bottom:12px}.aioseo-seo-analysis .seo-analysis-description .links{margin-top:30px;font-size:14px;font-weight:600}[dir=ltr] .aioseo-seo-analysis .seo-analysis-description .links .no-underline{padding-left:5px}[dir=rtl] .aioseo-seo-analysis .seo-analysis-description .links .no-underline{padding-right:5px}.aioseo-seo-analysis .seo-analysis-description div[class]{margin-top:12px}.aioseo-seo-analysis .seo-analysis-description svg.aioseo-book{width:20px;height:20px;color:#005ae0}[dir=ltr] .aioseo-seo-analysis .seo-analysis-description svg.aioseo-book{margin:0 10px 0 0}[dir=rtl] .aioseo-seo-analysis .seo-analysis-description svg.aioseo-book{margin:0 0 0 10px}.aioseo-seo-analysis .seo-analysis-error{max-width:740px;text-align:center;margin:40px 0}.aioseo-seo-analysis .seo-analysis-error p.error-title{margin:20px 0 8px;font-size:24px;font-weight:700;line-height:30px}.aioseo-seo-analysis .seo-analysis-error p.error-description{font-size:16px;font-weight:400;line-height:24px}.aioseo-seo-analysis .seo-analysis-error .error-action-buttons{display:flex;gap:12px;margin-top:20px;justify-content:center}.aioseo-seo-analysis .seo-analysis-error svg.aioseo-dannie-lab{width:120px;height:120px}.aioseo-seo-site-score .aioseo-blur{display:flex;align-items:center}.aioseo-seo-site-score .aioseo-seo-site-score-cta{position:absolute;top:50%;background-color:#fff;padding:20px;border:1px solid #E8E8EB;box-shadow:0 2px 10px #005ae033;color:#141b38;font-size:16px;font-weight:600;width:82%;max-width:500px;text-align:center}[dir=ltr] .aioseo-seo-site-score .aioseo-seo-site-score-cta{left:50%;transform:translate(-50%) translateY(-50%)}[dir=rtl] .aioseo-seo-site-score .aioseo-seo-site-score-cta{right:50%;transform:translate(50%) translateY(-50%)}
