.aioseo-social-profiles{--aioseo-gutter: 20px}.aioseo-social-profiles .same-username .use-same{padding:16px;background:#f9f9fa;border-radius:4px}.aioseo-social-profiles .same-username .use-same>label{align-items:flex-start}.aioseo-social-profiles .same-username .use-same>label .form-checkbox-wrapper{margin-top:2px}.aioseo-social-profiles .same-username .use-same>.aioseo-settings-row{flex-direction:column;max-width:720px;gap:4px;flex-wrap:nowrap}[dir=ltr] .aioseo-social-profiles .same-username .use-same>.aioseo-settings-row{margin:16px 0 0 24px}[dir=rtl] .aioseo-social-profiles .same-username .use-same>.aioseo-settings-row{margin:16px 24px 0 0}.aioseo-social-profiles .same-username .use-same>.aioseo-settings-row .aioseo-input-container{max-width:470px}.aioseo-social-profiles .same-username .use-same .profiles{margin-top:12px;--aioseo-gutter: 12px;--total-gap-width: calc(4 * var(--aioseo-gutter));--aioseo-col-max-width: calc((100% - var(--total-gap-width)) / 5);display:grid;gap:var(--aioseo-gutter);grid-template-columns:repeat(auto-fill,minmax(max(130px,var(--aioseo-col-max-width)),1fr))}.aioseo-social-profiles .same-username .use-same .profiles>*{max-width:none}.aioseo-social-profiles .same-username .use-same .profiles .aioseo-col{max-width:none}.aioseo-social-profiles .aioseo-social-profile-list{margin-top:20px;display:flex;flex-direction:column;gap:12px}.aioseo-social-profiles .aioseo-social-profile-list .social-profile{margin-bottom:0;padding-bottom:0;border-bottom:none;gap:8px}.aioseo-social-profiles .aioseo-social-profile-list .social-profile>.col-md-9:last-child{max-width:none}[dir=ltr] .aioseo-social-profiles .aioseo-social-profile-list .social-profile .logo-svg{margin-right:12px}[dir=rtl] .aioseo-social-profiles .aioseo-social-profile-list .social-profile .logo-svg{margin-left:12px}.aioseo-social-profiles .aioseo-social-profile-list .social-profile .profile-error{margin-top:10px}.aioseo-social-profiles .aioseo-social-profile-list .social-profile .name{margin-bottom:0}.aioseo-social-profiles .additional-social-profiles{margin-top:var(--aioseo-gutter);padding-top:var(--aioseo-gutter);border-top:1px solid #E8E8EB;gap:8px}.aioseo-social-profiles .additional-social-profiles>.col-md-9:last-child{max-width:none}
