.open-redirects-modal[data-v-1754537e]{margin:12px 0}.open-redirects-modal svg[data-v-1754537e]{width:10px;height:10px}[dir=ltr] .open-redirects-modal svg[data-v-1754537e]{margin-right:8px}[dir=rtl] .open-redirects-modal svg[data-v-1754537e]{margin-left:8px}.aioseo-redirects-page .aioseo-redirects-table{margin-top:40px}.aioseo-redirects-table .test-redirect-modal .aioseo-description{font-size:16px;color:#141b38;margin-bottom:20px}.aioseo-redirects-table .test-redirect-modal .test-redirect-input{display:flex;align-items:center;gap:10px;margin-bottom:20px}.aioseo-redirects-table .test-redirect-modal .test-redirect-input .test-redirect-url{flex:1}.aioseo-redirects-table .test-redirect-modal .test-redirect-results{margin-top:20px}.aioseo-redirects.metabox{padding:0!important}.aioseo-redirects.metabox .aioseo-wp-table .wp-table tr.edit-row td{padding:0 20px}.aioseo-redirects.metabox .aioseo-add-redirection.edit-url{margin-bottom:0}.aioseo-redirects.aioseo-modal .modal-body{padding:20px}.aioseo-alert.permalink{margin-bottom:15px}
