.aioseo-highlight-toggle{border:1px solid #E8E8EB;border-radius:3px;min-height:40px;display:flex;align-items:center;padding:5px 10px;cursor:pointer}.aioseo-highlight-toggle>*{cursor:pointer;-webkit-user-select:none;user-select:none}.aioseo-highlight-toggle.active{border-color:#005ae0;box-shadow:0 5px 10px #005ae01a}.aioseo-highlight-toggle.medium{min-height:40px}.aioseo-highlight-toggle .icon{display:flex;align-items:center}[dir=ltr] .aioseo-highlight-toggle .icon{margin-right:5px}[dir=rtl] .aioseo-highlight-toggle .icon{margin-left:5px}
