.inline-upsell[data-v-b393e975]{margin-top:0!important}.aioseo-modal .bd[data-v-34e6f863]{padding:20px}.aioseo-button svg[data-v-34e6f863]{width:12px;height:12px;color:#434960}[dir=ltr] .aioseo-button svg[data-v-34e6f863]{margin-right:11px}[dir=rtl] .aioseo-button svg[data-v-34e6f863]{margin-left:11px}.aioseo-robots-meta .global-robots-settings{margin-top:16px;font-weight:600}.aioseo-robots-meta .global-robots-settings>.settings{margin-top:12px;font-weight:400;--aioseo-gutter: 12px;--total-gap-width: calc(3 * var(--aioseo-gutter));--aioseo-col-max-width: calc((100% - var(--total-gap-width)) / 4);display:grid;gap:var(--aioseo-gutter);grid-template-columns:repeat(auto-fill,minmax(max(150px,var(--aioseo-col-max-width)),1fr))}.aioseo-robots-meta .global-robots-settings>.settings>*{max-width:none}.aioseo-robots-meta .global-robots-settings>.settings .aioseo-col{max-width:none}.aioseo-robots-meta .global-robots-settings-options{display:flex;gap:12px;margin-top:16px}.aioseo-robots-meta .global-robots-settings-options>.aioseo-description{margin:0}.aioseo-robots-meta .global-robots-settings-options>.aioseo-description .aioseo-input,.aioseo-robots-meta .global-robots-settings-options>.aioseo-description .aioseo-select{min-width:200px;font-weight:400;margin-top:4px}@media screen and (max-width:782px){.aioseo-robots-meta .global-robots-settings-options{display:block}.aioseo-robots-meta .global-robots-settings-options .max-snippet,.aioseo-robots-meta .global-robots-settings-options .max-video-preview{margin-bottom:20px}[dir=ltr] .aioseo-robots-meta .global-robots-settings-options .max-snippet,[dir=ltr] .aioseo-robots-meta .global-robots-settings-options .max-video-preview{margin-right:0}[dir=rtl] .aioseo-robots-meta .global-robots-settings-options .max-snippet,[dir=rtl] .aioseo-robots-meta .global-robots-settings-options .max-video-preview{margin-left:0}.aioseo-robots-meta .global-robots-settings-options>div .aioseo-input,.aioseo-robots-meta .global-robots-settings-options>div .aioseo-select{min-width:100%}}.edit-post-sidebar .global-robots-settings,.editor-sidebar .global-robots-settings{padding-top:12px}.edit-post-sidebar .global-robots-settings>.settings,.editor-sidebar .global-robots-settings>.settings{padding:4px 0 12px}.edit-post-sidebar .global-robots-settings>.settings label,.editor-sidebar .global-robots-settings>.settings label{font-size:14px}.edit-post-sidebar .global-robots-settings .robots-meta-title,.editor-sidebar .global-robots-settings .robots-meta-title{padding-top:4px;display:inline-block}.edit-post-sidebar .global-robots-settings-options,.editor-sidebar .global-robots-settings-options{flex-wrap:wrap}[dir=ltr] .edit-post-sidebar .max-snippet,[dir=ltr] .editor-sidebar .max-snippet{margin-right:30px!important}[dir=rtl] .edit-post-sidebar .max-snippet,[dir=rtl] .editor-sidebar .max-snippet{margin-left:30px!important}[dir=ltr] .edit-post-sidebar .max-video-preview,[dir=ltr] .editor-sidebar .max-video-preview{margin-right:0!important}[dir=rtl] .edit-post-sidebar .max-video-preview,[dir=rtl] .editor-sidebar .max-video-preview{margin-left:0!important}.edit-post-sidebar .max-image-preview,.editor-sidebar .max-image-preview{margin-top:20px!important}.aioseo-post-advanced .inline-upsell{display:inline-flex;margin-top:12px}.aioseo-post-advanced .cannonical-url-error{margin:8px 0}.aioseo-post-advanced .selectbox-row{display:flex;align-items:center}.aioseo-post-advanced .selectbox-row .separator{display:inline-block;margin:0 20px;padding-bottom:10px;align-self:flex-end}.aioseo-post-advanced .selectbox-row .select{display:inline-block;width:100%;max-width:125px}.aioseo-post-advanced .selectbox-row .select>span{display:inline-block;font-size:14px;margin-bottom:10px}
