.aioseo-opening-hours .aioseo-input,.aioseo-opening-hours .aioseo-select,.aioseo-opening-hours .aioseo-multiselect{max-width:480px}.aioseo-opening-hours .mt-10{display:inline-block;margin-top:10px;font-size:14px}.aioseo-opening-hours .mt-16{margin-top:16px}.aioseo-col-flex{display:flex;align-items:center;padding:12px 0;border-bottom:1px solid #E8E8EB}.aioseo-col-flex:first-of-type{padding-top:0}.aioseo-col-flex:last-of-type{padding-bottom:0;border:none}.aioseo-col-flex .aioseo-col-day{flex:1}.aioseo-col-flex .aioseo-col-hours,.aioseo-col-flex .aioseo-col-alwaysopen{flex:2}.aioseo-col-flex .aioseo-select{display:inline-block;max-width:125px}.aioseo-col-flex .multiselect--disabled .multiselect__tags,.aioseo-col-flex .multiselect--disabled .multiselect__single{background:#f3f4f5}
