.aioseo-wizard-import{font-size:14px}.aioseo-wizard-import .plugins{--aioseo-gutter: 16px}.aioseo-wizard-import .plugins img{width:25px;height:auto}.aioseo-wizard-import .plugins img.seopress,.aioseo-wizard-import .plugins img.seopress-pro{width:20px;margin:0 5px}.aioseo-wizard-import .go-back a{color:#434960;font-size:14px}
