#aioseo-admin-bar-noindex-warning{display:flex;margin:4px 0;padding:0 4px;border-radius:4px;background-color:#fee2e2}#aioseo-admin-bar-noindex-warning .wrapper{display:inline-flex;align-items:center;max-height:24px}#aioseo-admin-bar-noindex-warning .wrapper svg{color:#df2a4a}[dir=ltr] #aioseo-admin-bar-noindex-warning .wrapper svg{margin-right:6px}[dir=rtl] #aioseo-admin-bar-noindex-warning .wrapper svg{margin-left:6px}#aioseo-admin-bar-noindex-warning .wrapper span{font-size:13px;font-weight:600;letter-spacing:-.4px;color:#df2a4a}#aioseo-admin-bar-noindex-warning .wrapper .noindex-warning-tooltip{display:none}#aioseo-admin-bar-noindex-warning .wrapper:hover .noindex-warning-tooltip{display:block;position:absolute;top:35px;width:185px;padding:12px;border:1px solid white;border-radius:5px;background-color:#fff;box-shadow:0 8px 36px #2c324c29;cursor:default;z-index:1}[dir=ltr] #aioseo-admin-bar-noindex-warning .wrapper:hover .noindex-warning-tooltip{left:-10px;text-align:left}[dir=rtl] #aioseo-admin-bar-noindex-warning .wrapper:hover .noindex-warning-tooltip{right:-10px;text-align:right}#aioseo-admin-bar-noindex-warning .wrapper:hover .noindex-warning-tooltip p{font-size:12px;font-style:normal;font-weight:400;line-height:18px;color:#141b38}#aioseo-admin-bar-noindex-warning .wrapper:hover .noindex-warning-tooltip p a{display:contents;font-size:12px;font-style:normal;font-weight:400;line-height:18px;text-decoration:underline;color:#005ae0}#aioseo-admin-bar-noindex-warning .wrapper:hover .noindex-warning-tooltip p a:hover{text-decoration:none}#aioseo-admin-bar-noindex-warning .wrapper .noindex-warning-tooltip>svg{position:absolute;top:-12px}[dir=ltr] #aioseo-admin-bar-noindex-warning .wrapper .noindex-warning-tooltip>svg{left:92.5px}[dir=rtl] #aioseo-admin-bar-noindex-warning .wrapper .noindex-warning-tooltip>svg{right:92.5px}#aioseo-admin-bar-noindex-warning .wrapper .noindex-warning-tooltip>svg *{fill:#fff}
