<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models;

/**
 * Standard dietary preferences for food and beverage items that are recommended on item creation.
 */
class CatalogItemFoodAndBeverageDetailsDietaryPreferenceStandardDietaryPreference
{
    public const DAIRY_FREE = 'DAIRY_FREE';
    public const GLUTEN_FREE = 'GLUTEN_FREE';
    public const HALAL = 'HALAL';
    public const KOSHER = 'KOSHER';
    public const NUT_FREE = 'NUT_FREE';
    public const VEGAN = 'VEGAN';
    public const VEGETARIAN = 'VEGETARIAN';
}
