.aioseo-facebook .inline-upsell{display:inline-flex;margin-top:12px}.aioseo-facebook .facebook-image img{margin-top:20px;width:auto;max-width:525px;max-height:525px;height:auto}.aioseo-facebook .facebook-image.vertical img{max-width:158px;max-height:158px}.aioseo-facebook .how-to{display:flex;align-items:center;gap:8px;margin-top:16px;font-size:12px;line-height:18px}.aioseo-facebook .how-to svg.aioseo-book{width:16px;height:16px;vertical-align:middle}.aioseo-facebook .facebook-default-image-source .aioseo-select{max-width:445px}.aioseo-facebook .facebook-object-types{max-width:445px;display:flex;flex-direction:column;align-items:flex-start}.aioseo-facebook .facebook-object-types+.facebook-object-types{margin-top:12px}.aioseo-facebook .facebook-object-types .aioseo-table-column{width:100%;padding:0}.aioseo-facebook .facebook-object-types .aioseo-table-column:first-child{font-weight:600;margin-bottom:4px}.aioseo-facebook .facebook-home-page-object-type .aioseo-select{max-width:300px}
