[data-type="aioseo/faq"]>.wp-block[data-align=full]{margin-left:0;margin-right:0}[dir=ltr] [data-type="aioseo/faq"]>.wp-block[data-align=full]{left:0}[dir=rtl] [data-type="aioseo/faq"]>.wp-block[data-align=full]{right:0}.wp-block-aioseo-faq[data-schema-only=true]{opacity:.5}.is-selected[data-type="aioseo/faq"],.has-child-selected[data-type="aioseo/faq"]{border-radius:2px}.is-selected[data-type="aioseo/faq"]:after,.has-child-selected[data-type="aioseo/faq"]:after{border-radius:2px;outline:1px dotted #8C8F9A}
