.aioseo-thrive-sidebar__header{height:48px;display:flex;align-items:center;flex-shrink:0;border-bottom:1px solid #E0E3E7;padding:0 10px;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif}.aioseo-thrive-sidebar__header-title{font-size:13px;font-weight:700;line-height:17.7px;color:#247ba0}.aioseo-thrive-sidebar__header .aioseo-score-button{border-radius:4px}.aioseo-thrive-sidebar .popper{max-width:220px}.aioseo-thrive-sidebar__content{overflow:auto}.aioseo-thrive-score-button>.aioseo-score-button{padding:4px 5px;font-size:13px}.aioseo-thrive-score-button>.aioseo-score-button svg{height:16px}.aioseo-thrive-score-button>.aioseo-score-button.score-red{border-color:#df2a4a!important}.aioseo-thrive-score-button>.aioseo-score-button.score-orange{border-color:#f18200!important}.aioseo-thrive-score-button>.aioseo-score-button.score-green{border-color:#00aa63!important}
