<?php

// autoload_files.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'bae36830fe54016361e84e8e0ee4aa4e' => $vendorDir . '/codeinwp/themeisle-sdk/load.php',
);
