<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models;

/**
 * The type of mapping.
 */
class LoyaltyAccountMappingType
{
    /**
     * The loyalty account is mapped by phone.
     */
    public const PHONE = 'PHONE';
}
