<?php
$neu = array(
  '(o;',
  '*)',
  '8-)',
  ':-',
  ':-\\',
  ':-o',
  ':0->-<|:',
  ':l',
  ':|',
  ';)',
  ';o)',
  '<:}',
  'absolute',
  'absolutely',
  'absorbed',
  'accentuate',
  'activist',
  'actual',
  'actuality',
  'adolescents',
  'affect',
  'affected',
  'aha',
  'air',
  'alert',
  'all-time',
  'allegorize',
  'alliance',
  'alliances',
  'allusion',
  'allusions',
  'alright',
  'altogether',
  'amplify',
  'analytical',
  'apparent',
  'apparently',
  'appearance',
  'apprehend',
  'assess',
  'assessment',
  'assessments',
  'assumption',
  'astronomic',
  'astronomical',
  'astronomically',
  'attitude',
  'attitudes',
  'average',
  'aware',
  'awareness',
  'baby',
  'basically',
  'batons',
  'belief',
  'beliefs',
  'big',
  'blood',
  'broad-based',
  'ceaseless',
  'central',
  'certified',
  'chant',
  'claim',
  'clandestine',
  'cogitate',
  'cognizance',
  'comment',
  'commentator',
  'complete',
  'completely',
  'comprehend',
  'concerted',
  'confide',
  'conjecture',
  'conscience',
  'consciousness',
  'considerable',
  'considerably',
  'consideration',
  'constitutions',
  'contemplate',
  'continuous',
  'corrective',
  'covert',
  'decide',
  'deduce',
  'deeply',
  'destiny',
  'difference',
  'diplomacy',
  'discern',
  'disposition',
  'distinctly',
  'dominant',
  'downright',
  'dramatically',
  'duty',
  'effectively',
  'elaborate',
  'embodiment',
  'emotion',
  'emotions',
  'emphasise',
  'engage',
  'engross',
  'entire',
  'entrenchment',
  'evaluate',
  'evaluation',
  'exclusively',
  'expectation',
  'expound',
  'expression',
  'expressions',
  'extemporize',
  'extensive',
  'extensively',
  'eyebrows',
  'fact',
  'facts',
  'factual',
  'familiar',
  'far-reaching',
  'fast',
  'feel',
  'feeling',
  'feelings',
  'feels',
  'felt',
  'finally',
  'firm',
  'firmly',
  'fixer',
  'floor',
  'foretell',
  'forsee',
  'fortress',
  'frankly',
  'frequent',
  'full',
  'full-scale',
  'fully',
  'fundamental',
  'fundamentally',
  'funded',
  'galvanize',
  'gestures',
  'giant',
  'giants',
  'gigantic',
  'glean',
  'greatly',
  'growing',
  'halfway',
  'halt',
  'heavy-duty',
  'hefty',
  'high',
  'high-powered',
  'hm',
  'hmm',
  'huge',
  'hypnotize',
  'idea',
  'ignite',
  'imagination',
  'imagine',
  'immediately',
  'immense',
  'immensely',
  'immensity',
  'immensurable',
  'immune',
  'imperative',
  'imperatively',
  'implicit',
  'imply',
  'inarguable',
  'inarguably',
  'increasing',
  'increasingly',
  'indication',
  'indicative',
  'indirect',
  'infectious',
  'infer',
  'inference',
  'influence',
  'informational',
  'inherent',
  'inkling',
  'inklings',
  'innumerable',
  'innumerably',
  'innumerous',
  'insights',
  'intend',
  'intensive',
  'intensively',
  'intent',
  'intention',
  'intentions',
  'intents',
  'intimate',
  'intrigue',
  'irregardless',
  'judgement',
  'judgements',
  'judgment',
  'judgments',
  'key',
  'knew',
  'knowing',
  'knowingly',
  'knowledge',
  'large',
  'large-scale',
  'largely',
  'lastly',
  'learn',
  'legacies',
  'legacy',
  'legalistic',
  'likelihood',
  'likewise',
  'limitless',
  'major',
  'mantra',
  'massive',
  'matter',
  'mediocre',
  'memories',
  'mentality',
  'metaphorize',
  'minor',
  'mm',
  'motive',
  'move',
  'mum',
  'nap',
  'nascent',
  'nature',
  'needful',
  'needfully',
  'nonviolent',
  'notion',
  'nuance',
  'nuances',
  'obligation',
  'obvious',
  'ok',
  'olympic',
  'open-ended',
  'opinion',
  'opinions',
  'orthodoxy',
  'outlook',
  'outright',
  'outspoken',
  'overt',
  'overtures',
  'pacify',
  'perceptions',
  'persistence',
  'perspective',
  'philosophize',
  'pivotal',
  'player',
  'plenary',
  'point',
  'ponder',
  'position',
  'possibility',
  'possibly',
  'posture',
  'power',
  'practically',
  'pray',
  'predictable',
  'predictablely',
  'predominant',
  'pressure',
  'pressures',
  'prevalent',
  'primarily',
  'primary',
  'prime',
  'proclaim',
  'prognosticate',
  'prophesy',
  'proportionate',
  'proportionately',
  'prove',
  'quick',
  'rapid',
  'rare',
  'rarely',
  'react',
  'reaction',
  'reactions',
  'readiness',
  'realization',
  'recognizable',
  'reflecting',
  'regard',
  'regardlessly',
  'reiterate',
  'reiterated',
  'reiterates',
  'relations',
  'remark',
  'renewable',
  'replete',
  'reputed',
  'reveal',
  'revealing',
  'revelatory',
  'screaming',
  'screamingly',
  'scrutinize',
  'scrutiny',
  'seemingly',
  'self-examination',
  'show',
  'signals',
  'simply',
  'sleepy',
  'soliloquize',
  'sovereignty',
  'specific',
  'specifically',
  'speculate',
  'speculation',
  'splayed-finger',
  'stance',
  'stances',
  'stands',
  'statements',
  'stir',
  'strength',
  'stronger-than-expected',
  'stuffed',
  'stupefy',
  'suppose',
  'supposing',
  'surprise',
  'surprising',
  'surprisingly',
  'swing',
  'tale',
  'tall',
  'tantamount',
  'taste',
  'tendency',
  'theoretize',
  'thinking',
  'thought',
  'thusly',
  'tint',
  'touch',
  'touches',
  'transparency',
  'transparent',
  'transport',
  'unaudited',
  'utterances',
  'view',
  'viewpoints',
  'views',
  'vocal',
  'whiff',
  'yeah',
);
