.aioseo-checkbox{color:#141b38;display:inline-flex;align-items:center}.aioseo-checkbox.disabled,.aioseo-checkbox.no-clicks,.aioseo-checkbox.disabled .form-checkbox .fancy-checkbox,.aioseo-checkbox.no-clicks .form-checkbox .fancy-checkbox{cursor:default}.aioseo-checkbox .form-checkbox-wrapper{display:flex}[dir=ltr] .aioseo-checkbox .form-checkbox-wrapper{margin-right:8px}[dir=rtl] .aioseo-checkbox .form-checkbox-wrapper{margin-left:8px}.aioseo-checkbox.round .form-checkbox span{border-radius:50%}.aioseo-checkbox.round .form-checkbox span:before{border-radius:50%}.aioseo-checkbox.round:not(.medium) .form-checkbox{width:24px;height:24px}.aioseo-checkbox.round:not(.medium) .form-checkbox .fancy-checkbox svg{width:12px;height:12px}.aioseo-checkbox.round:not(.medium) .form-checkbox span:before{height:22px;width:22px;line-height:24px}.aioseo-checkbox .form-checkbox{position:relative;display:inline-block;width:16px;height:16px;color:#fff;vertical-align:bottom;text-align:center}.aioseo-checkbox .form-checkbox input{display:none}.aioseo-checkbox .form-checkbox input:checked+.fancy-checkbox.blue{background:#005ae0}.aioseo-checkbox .form-checkbox input:checked+.fancy-checkbox.green{background:#00aa63}.aioseo-checkbox .form-checkbox input:checked+.fancy-checkbox:before{background:transparent}.aioseo-checkbox .form-checkbox input:disabled+.fancy-checkbox{background:#e8e8eb!important;border:1px solid #D0D1D7;cursor:default}.aioseo-checkbox .form-checkbox input:disabled+.fancy-checkbox svg{color:#8c8f9a}.aioseo-checkbox .form-checkbox input:not(:checked):disabled+.fancy-checkbox:before{bottom:0;background:#e8e8eb}[dir=ltr] .aioseo-checkbox .form-checkbox input:not(:checked):disabled+.fancy-checkbox:before{left:0}[dir=rtl] .aioseo-checkbox .form-checkbox input:not(:checked):disabled+.fancy-checkbox:before{right:0}.aioseo-checkbox .form-checkbox .fancy-checkbox svg{color:#fff;width:10px;height:10px}.aioseo-checkbox .form-checkbox span{position:absolute;cursor:pointer;inset:0;background-color:#d0d1d7;transition:.2s;border-radius:3px;display:flex;align-items:center;justify-content:center}.aioseo-checkbox .form-checkbox span:before{position:absolute;content:"";height:14px;width:14px;bottom:1px;background-color:#fff;transition:.2s;font-size:14px;line-height:16px;border-radius:2px}[dir=ltr] .aioseo-checkbox .form-checkbox span:before{left:1px}[dir=rtl] .aioseo-checkbox .form-checkbox span:before{right:1px}
