<?php

namespace WPForms\Vendor\enshrined\svgSanitize\data;

/**
 * Class AttributeInterface
 *
 * @package enshrined\svgSanitize\data
 */
interface AttributeInterface
{
    /**
     * Returns an array of attributes
     *
     * @return array
     */
    public static function getAttributes();
}
