.aioseo-card{position:relative;color:#141b38;background-color:#fff;border:1px solid #E8E8EB;box-shadow:0 2px 5px #0000000d;margin:var(--aioseo-gutter) 0}.aioseo-card.disabled .content{background:#f9f9fa}.aioseo-card svg.aioseo-circle-question-mark{width:17px;height:17px;color:#8c8f9a!important}.aioseo-card>.header{display:flex;align-items:center;height:60px;padding:0 20px;font-weight:600;font-size:16px;border-bottom:1px solid #E8E8EB}.aioseo-card>.header.toggles{cursor:pointer}.aioseo-card>.header .text{flex:1 1 auto;display:flex;align-items:center}.aioseo-card>.header .text>*{cursor:auto}.aioseo-card>.header .text .header-icon{display:flex}.aioseo-card>.header .text .header-icon svg{width:24px;height:24px}[dir=ltr] .aioseo-card>.header .text .header-icon svg{margin-right:8px}[dir=rtl] .aioseo-card>.header .text .header-icon svg{margin-left:8px}.aioseo-card>.header .text .header-title{display:flex;align-items:center}.aioseo-card>.header .text .header-title .aioseo-tooltip>div:has(svg),.aioseo-card>.header .text .header-title+.aioseo-tooltip>div:has(svg){display:inline-flex}.aioseo-card>.header .text svg.aioseo-circle-question-mark{cursor:pointer;width:17px;height:17px}[dir=ltr] .aioseo-card>.header .text .aioseo-pro-badge{margin-left:10px}[dir=rtl] .aioseo-card>.header .text .aioseo-pro-badge{margin-right:10px}.aioseo-card>.header .text .card-score{display:flex;flex:1;align-items:center;justify-content:flex-end;font-size:12px}[dir=ltr] .aioseo-card>.header .text .card-score{padding-right:10px}[dir=rtl] .aioseo-card>.header .text .card-score{padding-left:10px}.aioseo-card>.header .text .card-score.green{color:#00aa63}.aioseo-card>.header .text .card-score.orange{color:#f18200}.aioseo-card>.header .text .card-score.red{color:#df2a4a}[dir=ltr] .aioseo-card>.header .text .card-score svg{margin-right:4px}[dir=rtl] .aioseo-card>.header .text .card-score svg{margin-left:4px}.aioseo-card>.header svg.aioseo-caret{width:24px;height:24px;cursor:pointer;transition:transform .3s}[dir=ltr] .aioseo-card>.header svg.aioseo-caret{transform:rotate(-180deg)}[dir=rtl] .aioseo-card>.header svg.aioseo-caret{transform:rotate(180deg)}[dir=ltr] .aioseo-card>.header svg.aioseo-caret.rotated{transform:rotate(-90deg)}[dir=rtl] .aioseo-card>.header svg.aioseo-caret.rotated{transform:rotate(90deg)}.aioseo-card>.header svg.aioseo-close{width:14px;height:14px;cursor:pointer}.aioseo-card .content{font-size:14px;line-height:22px;padding:20px;position:relative}.aioseo-card div.aioseo-settings-row:last-child{margin-bottom:0;border-bottom:none;padding-bottom:0}@media only screen and (max-width:911px){.aioseo-col.col-sm-12>.aioseo-card:last-child,.aioseo-col.col-xs-12>.aioseo-card:last-child{margin-bottom:0}.aioseo-col.col-sm-12+.aioseo-col>.aioseo-card:first-child,.aioseo-col.col-xs-12+.aioseo-col>.aioseo-card:first-child{margin-top:0}}
