.aioseo-tools-wpcode{position:relative}.aioseo-wpcode-snippet{height:100%;border:1px solid #E8E8EB;background:#fff;box-shadow:0 2px 5px #0000000d;color:#141b38;display:flex;flex-direction:column}.aioseo-wpcode-snippet .wpcode-snippet-body{padding:20px 20px 10px;flex:1;line-height:22px}.aioseo-wpcode-snippet .wpcode-snippet-footer{padding:15px;justify-content:flex-end;display:flex}.aioseo-wpcode-snippet .snippet-title{display:flex;align-items:center;font-size:16px;font-weight:600;margin-bottom:16px;line-height:1.4}
