.aioseo-toggle{color:#141b38;display:inline-flex;align-items:center;vertical-align:middle}.aioseo-toggle:active,.aioseo-toggle:focus{outline:2px solid transparent}.aioseo-toggle.disabled{pointer-events:none}.aioseo-toggle.disabled .toggle-content{opacity:.5}.aioseo-toggle .toggle-content{position:relative;display:inline-block;width:32px;height:18px}[dir=ltr] .aioseo-toggle .toggle-content{margin-right:8px}[dir=rtl] .aioseo-toggle .toggle-content{margin-left:8px}.aioseo-toggle .toggle-content input{display:none}.aioseo-toggle .toggle-content input:checked+.toggle-switch{border:1px solid #005AE0;background-color:#005ae0}.aioseo-toggle .toggle-content input:checked+.toggle-switch:focus{outline:2px solid transparent}.aioseo-toggle .toggle-content input:checked+.toggle-switch:before{background-color:#fff}[dir=ltr] .aioseo-toggle .toggle-content input:checked+.toggle-switch:before{transform:translate(13px)}[dir=rtl] .aioseo-toggle .toggle-content input:checked+.toggle-switch:before{transform:translate(-13px)}.aioseo-toggle .toggle-content input:focus+.toggle-switch{box-shadow:0 0 1px #005ae0;outline:2px solid transparent}.aioseo-toggle .toggle-content .toggle-switch{position:absolute;cursor:pointer;inset:0;background-color:#fff;border:1px solid #D0D1D7;border-radius:16px;transition:.2s}.aioseo-toggle .toggle-content .toggle-switch:before{position:absolute;content:"";height:12px;width:12px;bottom:2px;background-color:#d0d1d7;border-radius:50%;transition:.2s}[dir=ltr] .aioseo-toggle .toggle-content .toggle-switch:before{left:3px}[dir=rtl] .aioseo-toggle .toggle-content .toggle-switch:before{right:3px}
