<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models;

class V1UpdateOrderRequestAction
{
    public const COMPLETE = 'COMPLETE';
    public const CANCEL = 'CANCEL';
    public const REFUND = 'REFUND';
}
