.aioseo-settings-row{margin-bottom:var(--aioseo-gutter);padding-bottom:var(--aioseo-gutter);border-bottom:1px solid #E8E8EB}.aioseo-settings-row:last-child{border-bottom:0;margin-bottom:0;padding-bottom:0}@media only screen and (min-width:912px){.aioseo-settings-row>.col-md-3:first-child{max-width:240px}.aioseo-settings-row:not(.no-right-max-width)>.col-md-9:last-child{max-width:940px;flex:1}}.aioseo-settings-row :where(.aioseo-row){--aioseo-gutter: 12px}.aioseo-settings-row>:last-child{margin-bottom:0}.aioseo-settings-row.no-margin{margin-bottom:0}.aioseo-settings-row.small-padding{padding-bottom:4px}.aioseo-settings-row.medium-margin{margin-bottom:16px}.aioseo-settings-row.no-border{border:none;margin-bottom:0}.aioseo-settings-row.no-horizontal-margin{margin-left:0!important;margin-right:0!important}.aioseo-settings-row.no-vertical-margin{margin-top:0!important;margin-bottom:0!important}.aioseo-settings-row>.aioseo-col{padding-block:0}.aioseo-settings-row .settings-name{color:#141b38}.aioseo-settings-row .settings-name .name{font-weight:600;font-size:14px;line-height:22px;display:flex;align-items:center}.aioseo-settings-row .settings-name .name.small-margin{margin-bottom:5px}.aioseo-settings-row .settings-name .name.align-small{line-height:30px}[dir=ltr] .aioseo-settings-row .settings-name .name .aioseo-pro-badge{margin-left:10px}[dir=rtl] .aioseo-settings-row .settings-name .name .aioseo-pro-badge{margin-right:10px}.aioseo-settings-row .settings-name .required-field{color:#df2a4a}.aioseo-settings-row .settings-name .aioseo-description{margin-top:12px}.aioseo-settings-row .aioseo-settings-content{font-size:14px;line-height:22px}.aioseo-settings-row p.description{font-size:14px}
