.aioseo-llms-sitemap .aioseo-links-per-post-tax{max-width:110px}.aioseo-llms-sitemap .aioseo-llms-txt-description{display:flex;flex-direction:column;align-items:flex-start;gap:8px}.aioseo-llms-sitemap .aioseo-llms-txt-description .aioseo-llms-txt-tooltip{margin:0}.aioseo-llms-sitemap .aioseo-llms-txt-description .aioseo-llms-txt-button svg.aioseo-external{width:14px;height:14px}[dir=ltr] .aioseo-llms-sitemap .aioseo-llms-txt-description .aioseo-llms-txt-button svg.aioseo-external{margin-right:10px}[dir=rtl] .aioseo-llms-sitemap .aioseo-llms-txt-description .aioseo-llms-txt-button svg.aioseo-external{margin-left:10px}.aioseo-llms-sitemap .aioseo-alert{margin-top:8px}
