.aioseo-setup-wizard-welcome{padding:25px;height:100vh;display:flex;align-items:center;justify-content:center;overflow:hidden}.aioseo-setup-wizard-welcome svg.aioseo-giant-gear{width:904px;min-width:904px;height:auto;color:#dddee2;opacity:.3}.aioseo-setup-wizard-welcome .aioseo-welcome-container{position:absolute;inset:0;display:flex;align-items:center;justify-content:center;flex-direction:column;gap:20px}.aioseo-setup-wizard-welcome .aioseo-welcome-container svg.aioseo-logo{height:40px;margin-top:-60px}.aioseo-setup-wizard-welcome .aioseo-welcome-container .aioseo-welcome-content{position:relative;width:100%;max-width:640px;background-color:#fff;border:1px solid #E8E8EB;box-shadow:0 2px 10px #005ae033;padding:40px;display:flex;justify-content:center;flex-direction:column;text-align:center}.aioseo-setup-wizard-welcome .aioseo-welcome-container .aioseo-welcome-content .aioseo-go-back{position:absolute;bottom:-120px;align-self:center}.aioseo-setup-wizard-welcome .aioseo-welcome-container .aioseo-welcome-content .header{font-size:24px;line-height:1.2;color:#141b38;font-weight:600;margin-bottom:30px}.aioseo-setup-wizard-welcome .aioseo-welcome-container .aioseo-welcome-content .description{line-height:1.4;font-size:16px;color:#434960}.aioseo-setup-wizard-welcome .aioseo-welcome-container .aioseo-welcome-content .aioseo-button{margin-top:20px;max-width:265px;align-self:center}@media screen and (max-width:782px){.aioseo-setup-wizard-welcome .aioseo-welcome-container .aioseo-welcome-content{padding:30px}}.aioseo-setup-wizard-welcome .modal-wrapper .modal-container{max-width:600px}.aioseo-setup-wizard-welcome .modal-wrapper .modal-container .modal-header{border-bottom:none;font-size:18px}.aioseo-setup-wizard-welcome .aioseo-modal-body{padding:0 30px 30px;display:flex;flex-direction:column;position:relative}.aioseo-setup-wizard-welcome .aioseo-modal-body h3{font-size:20px;margin-bottom:16px}.aioseo-setup-wizard-welcome .aioseo-modal-body .reset-description{font-size:16px;color:#141b38;margin-bottom:16px;max-width:515px;line-height:24px}[dir=ltr] .aioseo-setup-wizard-welcome .aioseo-modal-body .reset-description{text-align:left}[dir=rtl] .aioseo-setup-wizard-welcome .aioseo-modal-body .reset-description{text-align:right}.aioseo-setup-wizard-welcome .aioseo-modal-body button.close{position:absolute;top:11px;width:24px;height:24px;background-color:#fff;border:none;display:flex;align-items:center}[dir=ltr] .aioseo-setup-wizard-welcome .aioseo-modal-body button.close{right:11px}[dir=rtl] .aioseo-setup-wizard-welcome .aioseo-modal-body button.close{left:11px}.aioseo-setup-wizard-welcome .aioseo-modal-body button.close svg.aioseo-close{cursor:pointer;width:14px;height:14px}.aioseo-setup-wizard-welcome .aioseo-modal-body .aioseo-description{max-width:510px;text-align:center}.aioseo-setup-wizard-welcome .aioseo-modal-body .aioseo-button:not(.close){margin-top:16px}.aioseo-setup-wizard-welcome .aioseo-modal-body div.actions{display:flex;justify-content:flex-end}[dir=ltr] .aioseo-setup-wizard-welcome .aioseo-modal-body div.actions a{margin-right:10px}[dir=rtl] .aioseo-setup-wizard-welcome .aioseo-modal-body div.actions a{margin-left:10px}
