.aioseo-seoboost-login{display:flex;flex-direction:column;align-items:center;text-align:center}[dir=ltr] .aioseo-writing-assistant-sidebar .aioseo-seoboost-login{text-align:left}[dir=rtl] .aioseo-writing-assistant-sidebar .aioseo-seoboost-login{text-align:right}.aioseo-seoboost-login__title{font-size:16px;font-weight:700;margin-top:40px;line-height:24px}.aioseo-seoboost-login__description{max-width:600px;margin-top:8px;line-height:22px}.aioseo-seoboost-login button{margin-top:20px}[dir=ltr] .aioseo-seoboost-login button>img{margin-right:8px}[dir=rtl] .aioseo-seoboost-login button>img{margin-left:8px}.aioseo-seoboost-login button>.aioseo-caret{width:16px;height:16px;color:#fff;fill:#fff}[dir=ltr] .aioseo-seoboost-login button>.aioseo-caret{margin:0 0 0 8px;transform:rotate(-90deg)}[dir=rtl] .aioseo-seoboost-login button>.aioseo-caret{margin:0 8px 0 0;transform:rotate(90deg)}.aioseo-seoboost-login button>.aioseo-caret path{fill:#fff!important}.aioseo-seoboost-login--button-only{align-items:flex-start}.aioseo-seoboost-login--button-only>button{margin-top:0}
