<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models;

/**
 * Indicates the specific day  of the week.
 */
class DayOfWeek
{
    /**
     * Sunday
     */
    public const SUN = 'SUN';
    /**
     * Monday
     */
    public const MON = 'MON';
    /**
     * Tuesday
     */
    public const TUE = 'TUE';
    /**
     * Wednesday
     */
    public const WED = 'WED';
    /**
     * Thursday
     */
    public const THU = 'THU';
    /**
     * Friday
     */
    public const FRI = 'FRI';
    /**
     * Saturday
     */
    public const SAT = 'SAT';
}
