.aioseo-business-info-sidebar .labels label{display:block;font-weight:600;margin-bottom:4px}.aioseo-business-info-sidebar .sidebar-row{margin-bottom:16px}.aioseo-business-info-sidebar .sidebar-row .title{font-weight:600}
