<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models;

/**
 * An enum for ComponentType.
 */
class ComponentComponentType
{
    public const APPLICATION = 'APPLICATION';
    public const CARD_READER = 'CARD_READER';
    public const BATTERY = 'BATTERY';
    public const WIFI = 'WIFI';
    public const ETHERNET = 'ETHERNET';
    public const PRINTER = 'PRINTER';
}
