.aioseo-app .aioseo-about-us .aioseo-about-us-welcome,.aioseo-app .aioseo-about-us .aioseo-about-us-plugins{margin-top:var(--aioseo-gutter);width:100%}.aioseo-app .aioseo-about-us .aioseo-about-us-welcome,.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-main,.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer{background-color:#fff;box-shadow:0 2px 5px #0000000d;border:1px solid #E8E8EB}.aioseo-app .aioseo-about-us .aioseo-about-us-welcome{display:flex;align-items:center;gap:calc(var(--aioseo-gutter) * 2);padding:calc(var(--aioseo-gutter) * 2);font-size:14px;color:#141b38}@media only screen and (max-width:1042px){.aioseo-app .aioseo-about-us .aioseo-about-us-welcome{flex-direction:column}}.aioseo-app .aioseo-about-us .aioseo-about-us-welcome .welcome-intro{flex:2 2 auto}.aioseo-app .aioseo-about-us .aioseo-about-us-welcome .welcome-intro div{line-height:1.5}.aioseo-app .aioseo-about-us .aioseo-about-us-welcome .welcome-intro div+div{margin-top:20px}.aioseo-app .aioseo-about-us .aioseo-about-us-welcome .welcome-intro div:first-of-type{font-size:24px;line-height:30px;font-weight:600;margin:0 0 20px}.aioseo-app .aioseo-about-us .aioseo-about-us-welcome .welcome-image{text-align:center}.aioseo-app .aioseo-about-us .aioseo-about-us-welcome .welcome-image figure{margin:0}.aioseo-app .aioseo-about-us .aioseo-about-us-welcome .welcome-image img{max-width:100%}.aioseo-app .aioseo-about-us .aioseo-about-us-welcome .welcome-image figcaption{margin:16px 0 0;color:#8c8f9a}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin{display:flex;flex-direction:column;font-size:14px;line-height:24px}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-main{display:flex;flex-direction:row;padding:22px;flex-grow:1}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-main img{width:50px;max-width:50px;max-height:50px}[dir=ltr] .aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-main img{margin:0 30px 0 0}[dir=rtl] .aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-main img{margin:0 0 0 30px}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-main .main-name{margin:0 0 10px;font-size:14px;font-weight:700;color:#141b38}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer{display:flex;justify-content:space-between;align-items:center;padding:12px}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-status{font-size:14px;line-height:22px;font-weight:700}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-status div{display:inline-block}[dir=ltr] .aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-status div{margin-right:12px}[dir=rtl] .aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-status div{margin-left:12px}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-status .footer-status-label{color:#8c8f9a}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-status .footer-status-not-installed{color:#434960}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-status .footer-status-deactivated{color:#df2a4a}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-status .footer-status-activated{color:#00aa63}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-action button,.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-action a{width:fit-content;height:fit-content;padding:7px 14px;font-size:inherit;font-size:12px;line-height:18px}.aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-action .aioseo-button svg.aioseo-external{width:14px;height:14px}[dir=ltr] .aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-action .aioseo-button svg.aioseo-external{margin-right:10px}[dir=rtl] .aioseo-app .aioseo-about-us .aioseo-about-us-plugins .plugin .plugin-footer .footer-action .aioseo-button svg.aioseo-external{margin-left:10px}
