.aioseo-radio{display:inline-flex;align-items:center}.aioseo-radio .form-radio-wrapper{display:flex}[dir=ltr] .aioseo-radio .form-radio-wrapper{margin-right:10px}[dir=rtl] .aioseo-radio .form-radio-wrapper{margin-left:10px}.aioseo-radio.small .form-radio{width:16px;height:16px}.aioseo-radio.small.type-2 .form-radio span:before{width:inherit;height:inherit}.aioseo-radio.small.type-2 .form-radio span:after{bottom:4px;height:6px;width:6px}[dir=ltr] .aioseo-radio.small.type-2 .form-radio span:after{left:4px}[dir=rtl] .aioseo-radio.small.type-2 .form-radio span:after{right:4px}.aioseo-radio.medium .form-radio{width:16px;height:16px}.aioseo-radio.medium .form-radio .fancy-radio svg{width:10px;height:10px}.aioseo-radio.medium.type-1 .form-radio span:before{height:14px;width:14px;line-height:16px}.aioseo-radio.medium.type-2 .form-radio span:before{height:12px;width:12px;line-height:16px}.aioseo-radio.medium.type-2 .form-radio span:after{height:6px;width:6px;bottom:4px}[dir=ltr] .aioseo-radio.medium.type-2 .form-radio span:after{left:4px}[dir=rtl] .aioseo-radio.medium.type-2 .form-radio span:after{right:4px}.aioseo-radio .form-radio{position:relative;display:inline-block;width:24px;height:24px;color:#fff;vertical-align:bottom;text-align:center}.aioseo-radio .form-radio input{opacity:0}.aioseo-radio .form-radio input:checked+.fancy-radio{background:#005ae0;border-color:#005ae0}.aioseo-radio .form-radio input:checked+.fancy-radio:before{background:transparent}.aioseo-radio .form-radio input:checked+.fancy-radio:after{display:block}.aioseo-radio .form-radio input:disabled+.fancy-radio{cursor:default}.aioseo-radio .form-radio input:focus+.fancy-radio{border-color:#005ae0;box-shadow:0 0 0 1px #005ae0}.aioseo-radio .form-radio .fancy-radio{border-radius:50%}.aioseo-radio .form-radio .fancy-radio svg{color:#fff;width:16px;height:16px}.aioseo-radio .form-radio span{position:absolute;cursor:pointer;inset:0;transition:.2s;border-radius:50%;display:flex;align-items:center;justify-content:center}.aioseo-radio .form-radio span:before{position:absolute;content:"";height:22px;width:22px;bottom:1px;transition:.2s;font-size:16px;line-height:24px;border-radius:50%}[dir=ltr] .aioseo-radio .form-radio span:before{left:1px}[dir=rtl] .aioseo-radio .form-radio span:before{right:1px}.aioseo-radio.type-1 .form-radio span{background-color:#f3f4f5}.aioseo-radio.type-1 .form-radio span:before{background-color:#f3f4f5}.aioseo-radio.type-2 .form-radio span{border:1px solid #D0D1D7;background-color:#fff}.aioseo-radio.type-2 .form-radio span:after{display:none;position:absolute;content:"";height:10px;width:10px;bottom:6px;background-color:#fff;transition:.2s;border-radius:50%}[dir=ltr] .aioseo-radio.type-2 .form-radio span:after{left:6px}[dir=rtl] .aioseo-radio.type-2 .form-radio span:after{right:6px}.aioseo-radio.disabled{cursor:default}.aioseo-radio.disabled.type-2 .form-radio input:checked+.fancy-radio{background-color:#e8e8eb;border-color:#d0d1d7}.aioseo-radio.disabled.type-2 .form-radio span{background-color:#e8e8eb}.aioseo-radio.disabled.type-2 .form-radio span:after{background-color:#8c8f9a}
