.aioseo-search-appearance-content-types .icon{display:flex;align-items:center}[dir=ltr] .aioseo-search-appearance-content-types .icon{margin-right:16px}[dir=rtl] .aioseo-search-appearance-content-types .icon{margin-left:16px}
