.aioseo-site-origin-integration>.aioseo-score-button{padding:3px 6px;cursor:pointer}[dir=ltr] .aioseo-site-origin-integration>.aioseo-score-button{margin-left:10px}[dir=rtl] .aioseo-site-origin-integration>.aioseo-score-button{margin-right:10px}.aioseo-site-origin-integration>.aioseo-score-button--active{border-color:transparent}.aioseo-site-origin-sidebar{position:absolute;z-index:100;top:47px;background:#fff;overflow:visible;width:100%}[dir=ltr] .aioseo-site-origin-sidebar{transition:left .25s ease;left:-100%;right:auto}[dir=rtl] .aioseo-site-origin-sidebar{transition:right .25s ease;right:-100%;left:auto}.aioseo-site-origin-sidebar--active .aioseo-site-origin-sidebar{box-shadow:0 0 15px #00000026}[dir=ltr] .aioseo-site-origin-sidebar--active .aioseo-site-origin-sidebar{left:0}[dir=rtl] .aioseo-site-origin-sidebar--active .aioseo-site-origin-sidebar{right:0}.aioseo-site-origin-sidebar__header{display:flex;align-items:center;flex-shrink:0;border-bottom:1px solid #E0E3E7;padding:12px;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif}.aioseo-site-origin-sidebar__header-title{font-size:16px;font-style:normal;font-weight:700;line-height:125%;color:#141b38}.aioseo-site-origin-sidebar__header-close{cursor:pointer;color:#141b38}[dir=ltr] .aioseo-site-origin-sidebar__header-close{margin-left:auto;margin-right:5px}[dir=rtl] .aioseo-site-origin-sidebar__header-close{margin-right:auto;margin-left:5px}.aioseo-site-origin-sidebar__header-close svg{width:15px;height:15px;vertical-align:middle}.aioseo-site-origin-sidebar__content{overflow:auto}[dir=ltr] .aioseo-site-origin-lmd{float:right;margin:9px 10px 0 -15px}[dir=rtl] .aioseo-site-origin-lmd{float:left;margin:9px -15px 0 10px}.aioseo-site-origin-lmd .aioseo-caret{width:18px;height:18px;transition:transform .3s;vertical-align:sub}[dir=ltr] .aioseo-site-origin-lmd .aioseo-caret.rotated{transform:rotate(-180deg)}[dir=rtl] .aioseo-site-origin-lmd .aioseo-caret.rotated{transform:rotate(180deg)}.aioseo-site-origin-lmd__button:focus{box-shadow:none!important}.aioseo-site-origin-lmd__options{position:absolute;top:95%;background:#f5f5f5;border:1px solid #BCB9B9;border-radius:3px;box-shadow:0 0 10px #00000030;padding:10px;z-index:999;cursor:pointer}[dir=ltr] .aioseo-site-origin-lmd__options{right:10px}[dir=rtl] .aioseo-site-origin-lmd__options{left:10px}.aioseo-site-origin-lmd__options:hover{background:#e9e9e9}
