<?php
/**
 * General media queries style template.
 *
 * This template can be overridden by copying it to yourtheme/wpforms/emails/general-queries.php.
 *
 * @since 1.5.4
 *
 * @version 1.5.4
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$min = wpforms_get_min_suffix();

require \WPFORMS_PLUGIN_DIR . "assets/css/emails/partials/media_queries{$min}.css";
