<?php return array(
    'root' => array(
        'name' => 'codeinwp/remove-category-url',
        'pretty_version' => 'v1.2.3',
        'version' => '1.2.3.0',
        'reference' => 'f45f0de1be805d3a034e5ea19e2d423d0bf20a1f',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'codeinwp/remove-category-url' => array(
            'pretty_version' => 'v1.2.3',
            'version' => '1.2.3.0',
            'reference' => 'f45f0de1be805d3a034e5ea19e2d423d0bf20a1f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'codeinwp/themeisle-sdk' => array(
            'pretty_version' => '3.3.52',
            'version' => '3.3.52.0',
            'reference' => 'd1ae68cbd4f84934b4d982e9eeff317b9f4c814a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../codeinwp/themeisle-sdk',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
