<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models;

class DeviceStatusCategory
{
    public const AVAILABLE = 'AVAILABLE';
    public const NEEDS_ATTENTION = 'NEEDS_ATTENTION';
    public const OFFLINE = 'OFFLINE';
}
