.aioseo-location-map-sidebar .sidebar-row{margin-bottom:16px}.aioseo-location-map-sidebar .sidebar-row .title{font-weight:600}.aioseo-location-map-sidebar .sidebar-row.dimensions{display:flex;flex-direction:row;justify-content:space-between;margin-left:-10px;margin-right:-10px}.aioseo-location-map-sidebar .sidebar-row.dimensions>div{padding:0 10px}.aioseo-location-map-sidebar .sidebar-row.dimensions label{display:block;padding-bottom:8px}
