.aioseo-addons-list[data-v-a1f4dc34]{display:grid;row-gap:12px}.aioseo-app .v3-migration-info{border-top:1px solid #E8E8EB;padding-top:10px;margin-top:15px}.aioseo-app .v3-migration-info ul.info-items{margin:0}.aioseo-app .v3-migration-info ul.info-items li{display:flex}.aioseo-app .v3-migration-info ul.info-items li span:first-of-type{flex:0 0 130px}.aioseo-app .aioseo-tools-debug .select-site{font-size:16px;font-weight:700;margin-bottom:5px}.aioseo-app .aioseo-tools-debug .aioseo-alert div:first-of-type{margin-bottom:10px}.aioseo-app .aioseo-tools-debug .aioseo-tabs.internal{margin:8px 0 var(--aioseo-gutter) 0}.aioseo-debug-modal .aioseo-description:empty{display:none}.aioseo-debug-modal .aioseo-modal-body{padding:20px 40px 40px;display:flex;align-items:center;justify-content:center;flex-direction:column;position:relative}.aioseo-debug-modal .aioseo-modal-body .description{font-size:16px;color:#141b38;margin-bottom:16px}.aioseo-debug-modal .aioseo-modal-body .selected-addons-list{text-align:center}.aioseo-debug-modal .aioseo-modal-body .selected-addons-list ul{display:inline-block;text-align:center}.aioseo-debug-modal .aioseo-modal-body .selected-addons-list ul li{margin:4px 0}.aioseo-debug-modal .aioseo-modal-body button.aioseo-button{margin-top:16px}.aioseo-debug-modal .aioseo-modal-body button.close{position:absolute;top:11px;width:24px;height:24px;background-color:#fff;border:none;display:flex;align-items:center}[dir=ltr] .aioseo-debug-modal .aioseo-modal-body button.close{right:11px}[dir=rtl] .aioseo-debug-modal .aioseo-modal-body button.close{left:11px}.aioseo-debug-modal .aioseo-modal-body button.close svg.aioseo-close{cursor:pointer;width:14px;height:14px}
