.aioseo-search-appearance-global .schema-graph-name,.aioseo-search-appearance-global .schema-graph-contact-type-manual{margin-bottom:16px}.aioseo-search-appearance-global .schema-graph-name .aioseo-input,.aioseo-search-appearance-global .schema-graph-contact-type-manual .aioseo-input{max-width:600px}.aioseo-search-appearance-global .schema-graph-contact-type{margin-bottom:16px}.aioseo-search-appearance-global .schema-graph-contact-type .aioseo-select{max-width:300px}.aioseo-search-appearance-global .schema-graph-image{margin-bottom:16px}.aioseo-search-appearance-global .person-chooser{max-width:600px}.aioseo-search-appearance-global .person-chooser .person-label{display:flex;align-items:center}.aioseo-search-appearance-global .person-chooser .person-label .person-avatar{height:30px}[dir=ltr] .aioseo-search-appearance-global .person-chooser .person-label .person-avatar{margin-right:16px}[dir=rtl] .aioseo-search-appearance-global .person-chooser .person-label .person-avatar{margin-left:16px}.aioseo-search-appearance-global .person-chooser .person-label .person-avatar img{height:30px;width:30px;border-radius:50%}.aioseo-search-appearance-global .aioseo-settings-row.local-seo{display:flex;align-items:center;background:#f9f9fa}.aioseo-search-appearance-global .aioseo-settings-row.local-seo .local-seo-text{line-height:1.4;font-size:15px;color:#141b38;max-width:750px}.aioseo-search-appearance-global .aioseo-settings-row.local-seo .local-seo-text .aioseo-button{margin-top:10px}.aioseo-search-appearance-global .aioseo-settings-row.local-seo svg.aioseo-local-seo{width:139px;height:106px}[dir=ltr] .aioseo-search-appearance-global .aioseo-settings-row.local-seo svg.aioseo-local-seo{margin-right:60px}[dir=rtl] .aioseo-search-appearance-global .aioseo-settings-row.local-seo svg.aioseo-local-seo{margin-left:60px}.aioseo-search-appearance-global .aioseo-settings-row.local-seo:last-child{padding:30px}.aioseo-search-appearance-global .aioseo-google-search-preview{border:1px solid #E8E8EB;padding:16px}.aioseo-search-appearance-global .number-of-employees-number{margin-top:12px;max-width:420px}.aioseo-search-appearance-global .number-of-employees-range{display:flex;align-items:center;margin-top:12px}[dir=ltr] .aioseo-search-appearance-global .number-of-employees-range label{margin-right:12px}[dir=rtl] .aioseo-search-appearance-global .number-of-employees-range label{margin-left:12px}[dir=ltr] .aioseo-search-appearance-global .number-of-employees-range .aioseo-input-container{margin-right:12px}[dir=rtl] .aioseo-search-appearance-global .number-of-employees-range .aioseo-input-container{margin-left:12px}
