<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models;

class CheckoutLocationSettingsBrandingButtonShape
{
    public const SQUARED = 'SQUARED';
    public const ROUNDED = 'ROUNDED';
    public const PILL = 'PILL';
}
