.et-vb-icon[data-v-bd4fc1f3]{width:var(--icon-width);height:var(--icon-height);min-width:var(--icon-min-width)}.et-vb-icon svg[data-v-bd4fc1f3]{width:var(--icon-width);height:var(--icon-height)}.et-vb-icon.is-active svg[data-v-bd4fc1f3]{color:#005ae0}.aioseo-divi-modal .modal-body{min-height:min(60vh,500px)}.aioseo-divi-modal .modal-header{gap:10px}.aioseo-divi-modal .aioseo-tabs.internal{--tab-padding: 16px}.aioseo-divi-modal .aioseo-tabs.internal .tabs-scroller{flex-grow:1}[dir=ltr] .aioseo-limit-modified-date-divi{margin-left:1px}[dir=rtl] .aioseo-limit-modified-date-divi{margin-right:1px}.aioseo-limit-modified-date-divi__button-toggle .aioseo-caret{width:18px;height:18px;transition:transform .3s}[dir=ltr] .aioseo-limit-modified-date-divi__button-toggle .aioseo-caret.rotated{transform:rotate(-180deg)}[dir=rtl] .aioseo-limit-modified-date-divi__button-toggle .aioseo-caret.rotated{transform:rotate(180deg)}.aioseo-limit-modified-date-divi__options{position:absolute;top:calc(-100% - 1px)}[dir=ltr] .aioseo-limit-modified-date-divi__options{right:0}[dir=rtl] .aioseo-limit-modified-date-divi__options{left:0}
