.aioseo-seo-checklist{position:relative}.aioseo-seo-checklist .confetti-container{position:fixed;top:0;width:100%;height:100%;pointer-events:none;overflow:hidden;z-index:9999}[dir=ltr] .aioseo-seo-checklist .confetti-container{left:0}[dir=rtl] .aioseo-seo-checklist .confetti-container{right:0}.aioseo-seo-checklist .confetti{position:absolute;width:10px;height:10px;top:-10px;opacity:0;animation:confetti-fall 8s ease-in-out forwards}@keyframes confetti-fall{0%{transform:translateY(0) rotate(0);opacity:1}to{transform:translateY(100vh) rotate(720deg);opacity:0}}.aioseo-seo-checklist .seo-checklist-description{font-size:14px;line-height:1.6;color:#434960;margin-bottom:16px}.aioseo-seo-checklist .aioseo-seo-checklist-progress-bar{margin-bottom:16px}.aioseo-seo-checklist .progress-motivation{color:#434960}.aioseo-seo-checklist .seo-checklist-divider{border:none;border-top:1px solid #E8E8EB;margin:0 0 16px}.aioseo-seo-checklist .checklist-title-wrapper{display:flex;flex-direction:column;gap:4px}.aioseo-seo-checklist .checklist-title{font-weight:600}.aioseo-seo-checklist .checklist-description{font-weight:400;font-size:13px}.aioseo-seo-checklist .priority-label{display:inline-flex;align-items:center;gap:10px;font-size:13px;line-height:1;color:#434960}.aioseo-seo-checklist .priority-label .priority-dot{width:8px;height:8px;border-radius:50%;flex-shrink:0;vertical-align:middle}.aioseo-seo-checklist .priority-label.priority-high .priority-dot{background-color:#dc2626}.aioseo-seo-checklist .priority-label.priority-medium .priority-dot{background-color:#d97706}.aioseo-seo-checklist .priority-label.priority-low .priority-dot{background-color:#2563eb}.aioseo-seo-checklist .priority-label.priority-optional .priority-dot{background-color:#9ca3af}.aioseo-seo-checklist .time-estimate{font-size:13px}[dir=ltr] .aioseo-seo-checklist th.actions,[dir=ltr] .aioseo-seo-checklist td.actions{text-align:right}[dir=rtl] .aioseo-seo-checklist th.actions,[dir=rtl] .aioseo-seo-checklist td.actions{text-align:left}.aioseo-seo-checklist.filter-completed th.actions,.aioseo-seo-checklist.filter-completed td.actions{text-align:center}.aioseo-seo-checklist.filter-completed .checklist-actions{align-items:center}.aioseo-seo-checklist .checklist-actions{display:flex;flex-direction:column;align-items:flex-end;gap:6px}.aioseo-seo-checklist .checklist-actions .actions-primary{display:flex;gap:8px}.aioseo-seo-checklist .checklist-actions .actions-primary .action-link{display:inline-flex;align-items:center;gap:4px;color:#005ae0;font-size:13px}[dir=ltr] .aioseo-seo-checklist .checklist-actions .actions-primary .action-link.has-separator{padding-right:8px;border-right:1px solid #8C8F9A}[dir=rtl] .aioseo-seo-checklist .checklist-actions .actions-primary .action-link.has-separator{padding-left:8px;border-left:1px solid #8C8F9A}.aioseo-seo-checklist .checklist-actions .actions-primary .action-link{text-decoration:none;cursor:pointer}.aioseo-seo-checklist .checklist-actions .actions-primary .action-link:hover{text-decoration:underline}.aioseo-seo-checklist .checklist-actions .actions-primary .action-link svg.aioseo-external{width:11px;height:11px;flex-shrink:0}.aioseo-seo-checklist .checklist-actions .actions-secondary{display:flex;align-items:center;font-size:12px}.aioseo-seo-checklist .checklist-actions .actions-secondary .secondary-link{color:#8c8f9a;text-decoration:none;cursor:pointer}.aioseo-seo-checklist .checklist-actions .actions-secondary .secondary-link:hover{text-decoration:underline}[dir=ltr] .aioseo-seo-checklist .checklist-actions .actions-secondary .secondary-link.has-separator{padding-right:8px;margin-right:8px;border-right:1px solid #8C8F9A}[dir=rtl] .aioseo-seo-checklist .checklist-actions .actions-secondary .secondary-link.has-separator{padding-left:8px;margin-left:8px;border-left:1px solid #8C8F9A}.aioseo-seo-checklist .checklist-actions .actions-completed .completed-check{font-size:18px;font-weight:600;color:#005ae0}.aioseo-seo-checklist .checklist-info-panel{padding:8px 16px;border-radius:4px;background-color:#f9f9fa}.aioseo-seo-checklist .checklist-info{font-size:14px;line-height:1.6;color:#434960}.aioseo-seo-checklist .checklist-info h4{margin:0 0 8px;font-size:14px;font-weight:600;color:#141b38}.aioseo-seo-checklist .checklist-info p{margin:0 0 12px}.aioseo-seo-checklist .checklist-info p:last-child{margin-bottom:0}.aioseo-seo-checklist .checklist-info ul{margin:0 0 12px;list-style:disc}[dir=ltr] .aioseo-seo-checklist .checklist-info ul{padding-left:20px}[dir=rtl] .aioseo-seo-checklist .checklist-info ul{padding-right:20px}.aioseo-seo-checklist .checklist-info ul li{margin-bottom:4px}.aioseo-seo-checklist .checklist-info a{color:#005ae0}.aioseo-seo-checklist .checklist-info a:hover{text-decoration:underline}.aioseo-seo-checklist .checklist-info a.no-underline:hover{text-decoration:none}
