.aioseo-app .aioseo-donut-chart,.aioseo-blc-app .aioseo-donut-chart{position:relative;display:flex}.aioseo-app .aioseo-donut-chart svg,.aioseo-blc-app .aioseo-donut-chart svg{width:100%}.aioseo-app .aioseo-donut-chart svg circle,.aioseo-blc-app .aioseo-donut-chart svg circle{transform-origin:center}[dir=ltr] .aioseo-app .aioseo-donut-chart svg circle,[dir=ltr] .aioseo-blc-app .aioseo-donut-chart svg circle{transform:rotate(270deg)}[dir=rtl] .aioseo-app .aioseo-donut-chart svg circle,[dir=rtl] .aioseo-blc-app .aioseo-donut-chart svg circle{transform:rotate(-270deg)}.aioseo-app .aioseo-donut-chart .total-amount-wrapper,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper{position:absolute;inset:0;display:flex;align-items:center;justify-content:center;flex-direction:column;color:#141b38;margin:20px}.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount{text-align:center}.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total{font-size:32px;font-weight:700;line-height:40px}.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container{display:flex;align-items:baseline;justify-content:center;gap:4px}.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container.total-container-large>span,.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container.total-container-large>div,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container.total-container-large>span,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container.total-container-large>div{font-size:32px;font-weight:700}.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container.total-container-large.red,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container.total-container-large.red{color:#df2a4a}.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container.total-container-large.orange,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container.total-container-large.orange{color:#f18200}.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container.total-container-large.green,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container.total-container-large.green{color:#00aa63}.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container .total-max,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount .total-container .total-max{font-size:13px!important;font-weight:600;line-height:150%;color:#8c8f9a}.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount .label,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount .label{margin-top:5px;line-height:150%}.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount .label.red,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount .label.red{color:#df2a4a;font-weight:700}.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount .label.orange,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount .label.orange{color:#f18200;font-weight:700}.aioseo-app .aioseo-donut-chart .total-amount-wrapper .total-amount .label.green,.aioseo-blc-app .aioseo-donut-chart .total-amount-wrapper .total-amount .label.green{color:#00aa63;font-weight:700}
