.aioseo-rss-content svg.aioseo-external{width:14px;height:14px}[dir=ltr] .aioseo-rss-content svg.aioseo-external{margin-right:10px}[dir=rtl] .aioseo-rss-content svg.aioseo-external{margin-left:10px}.aioseo-rss-content .no-access{margin-bottom:30px}.aioseo-rss-content .aioseo-alert{margin-top:10px}.aioseo-rss-content .aioseo-rss-content-advanced .aioseo-settings-row .aioseo-col{padding-top:0}
