<?php

declare (strict_types=1);
namespace WPForms\Vendor\Square\Models;

class PaymentSortField
{
    public const CREATED_AT = 'CREATED_AT';
    public const OFFLINE_CREATED_AT = 'OFFLINE_CREATED_AT';
    public const UPDATED_AT = 'UPDATED_AT';
}
