.aioseo-ai-assistant-block{position:relative}.aioseo-ai-assistant-block__body{padding:5px;position:sticky;bottom:0}.aioseo-ai-assistant-block__input-container{background-color:#fff;border:1px solid #D0D1D7;border-radius:4px;box-shadow:0 4px 8px #2c324c1a;padding:1px}.aioseo-ai-assistant-block__input-container.is-selected{border:1px solid #005AE0}.aioseo-ai-assistant-block__input-row{display:flex;padding:12px;flex-wrap:wrap;justify-content:space-between;gap:8px}.aioseo-ai-assistant-block__input-row--gray{background-color:#f3f4f5;border-radius:4px;padding:6px 12px}.aioseo-ai-assistant-block__input-col--grow{flex:1 1 auto}.aioseo-ai-assistant-block__input-col--disclaimer{color:#434960;font-size:12px}.aioseo-ai-assistant-block__input-col--disclaimer a{text-decoration:none!important}.aioseo-ai-assistant-block__input{background-color:#fff!important;border-radius:0;border:none!important;box-shadow:none!important;color:#141b38;outline:none}.aioseo-ai-assistant-block__input::placeholder{color:#8c8f9a}.aioseo-ai-assistant-block__input{font-size:14px;font-weight:400;line-height:20px;margin:0;max-height:300px;padding:0;resize:none;width:100%}.aioseo-ai-assistant-block__input:focus{background-color:#fff!important;border-radius:0;border:none!important;box-shadow:none!important;color:#141b38;outline:none}.aioseo-ai-assistant-block__input:focus::placeholder{color:#8c8f9a}.aioseo-ai-assistant-block__controls{align-items:center;display:flex;gap:8px}.aioseo-ai-assistant-block__btn:disabled{cursor:not-allowed}.aioseo-ai-assistant-block__content{overflow-x:auto}.aioseo-ai-assistant-block__content :deep(table){border-collapse:collapse;width:100%}.aioseo-ai-assistant-block__content :deep(table) thead{border-bottom:3px solid}.aioseo-ai-assistant-block__content :deep(table) tfoot{border-top:3px solid}.aioseo-ai-assistant-block__content :deep(table) td,.aioseo-ai-assistant-block__content :deep(table) th{border:1px solid;padding:8px}.aioseo-ai-assistant-sidebar .aioseo-ai-assistant-sidebar-cost{margin-top:20px;font-size:13px;color:#141b38}
