<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInitb5bec85f6d156313c218b21150da9560
{
    public static $files = array (
        'def43f6c87e4f8dfd0c9e1b1bab14fe8' => __DIR__ . '/..' . '/symfony/polyfill-iconv/bootstrap.php',
        '0e6d7bf4a5811bfa5cf40c5ccd6fae6a' => __DIR__ . '/..' . '/symfony/polyfill-mbstring/bootstrap.php',
        'a4a119a56e50fbb293281d9a48007e0e' => __DIR__ . '/..' . '/symfony/polyfill-php80/bootstrap.php',
    );

    public static $prefixLengthsPsr4 = array (
        'W' =>
        array (
            'WPForms\\Tests\\Unit\\' => 19,
            'WPForms\\Tests\\Integration\\' => 26,
            'WPForms\\Scoper\\' => 15,
            'WPForms\\' => 8,
        ),
        'S' =>
        array (
            'Symfony\\Polyfill\\Php80\\' => 23,
            'Symfony\\Polyfill\\Mbstring\\' => 26,
            'Symfony\\Polyfill\\Iconv\\' => 23,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'WPForms\\Tests\\Unit\\' =>
        array (
            0 => __DIR__ . '/../..' . '/tests/unit',
        ),
        'WPForms\\Tests\\Integration\\' =>
        array (
            0 => __DIR__ . '/../..' . '/tests/integration',
        ),
        'WPForms\\Scoper\\' =>
        array (
            0 => __DIR__ . '/../..' . '/../.php-scoper',
        ),
        'WPForms\\' =>
        array (
            0 => __DIR__ . '/../..' . '/src',
            1 => __DIR__ . '/../..' . '/src',
        ),
        'Symfony\\Polyfill\\Php80\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-php80',
        ),
        'Symfony\\Polyfill\\Mbstring\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-mbstring',
        ),
        'Symfony\\Polyfill\\Iconv\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-iconv',
        ),
    );

    public static $classMap = array (
        'Attribute' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/Attribute.php',
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
        'PhpToken' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/PhpToken.php',
        'Stringable' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/Stringable.php',
        'UnhandledMatchError' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/UnhandledMatchError.php',
        'ValueError' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/ValueError.php',
        'WPForms\\Vendor\\Address' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/jsonmapper/example/Address.php',
        'WPForms\\Vendor\\Contact' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/jsonmapper/example/Contact.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\Authentication\\AuthGroup' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/Authentication/AuthGroup.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\Authentication\\AuthInterface' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/Authentication/AuthInterface.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\ContextInterface' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/ContextInterface.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\Format' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/Format.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\Logger\\ApiLoggerInterface' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/Logger/ApiLoggerInterface.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\Request\\NonEmptyParamInterface' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/Request/NonEmptyParamInterface.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\Request\\ParamInterface' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/Request/ParamInterface.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\Request\\RequestArraySerialization' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/Request/RequestArraySerialization.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\Request\\RequestInterface' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/Request/RequestInterface.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\Request\\RequestMethod' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/Request/RequestMethod.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\Request\\RequestSetterInterface' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/Request/RequestSetterInterface.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\Request\\TypeValidatorInterface' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/Request/TypeValidatorInterface.php',
        'WPForms\\Vendor\\CoreInterfaces\\Core\\Response\\ResponseInterface' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Core/Response/ResponseInterface.php',
        'WPForms\\Vendor\\CoreInterfaces\\Http\\HttpClientInterface' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Http/HttpClientInterface.php',
        'WPForms\\Vendor\\CoreInterfaces\\Http\\HttpConfigurations' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Http/HttpConfigurations.php',
        'WPForms\\Vendor\\CoreInterfaces\\Http\\RetryOption' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Http/RetryOption.php',
        'WPForms\\Vendor\\CoreInterfaces\\Sdk\\ConverterInterface' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Sdk/ConverterInterface.php',
        'WPForms\\Vendor\\CoreInterfaces\\Sdk\\ExceptionInterface' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core-interfaces/src/Sdk/ExceptionInterface.php',
        'WPForms\\Vendor\\Core\\ApiCall' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/ApiCall.php',
        'WPForms\\Vendor\\Core\\Authentication\\Auth' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Authentication/Auth.php',
        'WPForms\\Vendor\\Core\\Authentication\\CoreAuth' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Authentication/CoreAuth.php',
        'WPForms\\Vendor\\Core\\Client' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Client.php',
        'WPForms\\Vendor\\Core\\ClientBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/ClientBuilder.php',
        'WPForms\\Vendor\\Core\\Exceptions\\AuthValidationException' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Exceptions/AuthValidationException.php',
        'WPForms\\Vendor\\Core\\Logger\\ApiLogger' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Logger/ApiLogger.php',
        'WPForms\\Vendor\\Core\\Logger\\Configuration\\BaseHttpLoggingConfiguration' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Logger/Configuration/BaseHttpLoggingConfiguration.php',
        'WPForms\\Vendor\\Core\\Logger\\Configuration\\LoggingConfiguration' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Logger/Configuration/LoggingConfiguration.php',
        'WPForms\\Vendor\\Core\\Logger\\Configuration\\RequestConfiguration' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Logger/Configuration/RequestConfiguration.php',
        'WPForms\\Vendor\\Core\\Logger\\Configuration\\ResponseConfiguration' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Logger/Configuration/ResponseConfiguration.php',
        'WPForms\\Vendor\\Core\\Logger\\ConsoleLogger' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Logger/ConsoleLogger.php',
        'WPForms\\Vendor\\Core\\Logger\\LoggerConstants' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Logger/LoggerConstants.php',
        'WPForms\\Vendor\\Core\\Logger\\NullApiLogger' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Logger/NullApiLogger.php',
        'WPForms\\Vendor\\Core\\Request\\Parameters\\AdditionalFormParams' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/Parameters/AdditionalFormParams.php',
        'WPForms\\Vendor\\Core\\Request\\Parameters\\AdditionalHeaderParams' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/Parameters/AdditionalHeaderParams.php',
        'WPForms\\Vendor\\Core\\Request\\Parameters\\AdditionalQueryParams' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/Parameters/AdditionalQueryParams.php',
        'WPForms\\Vendor\\Core\\Request\\Parameters\\BodyParam' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/Parameters/BodyParam.php',
        'WPForms\\Vendor\\Core\\Request\\Parameters\\EncodedParam' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/Parameters/EncodedParam.php',
        'WPForms\\Vendor\\Core\\Request\\Parameters\\FormParam' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/Parameters/FormParam.php',
        'WPForms\\Vendor\\Core\\Request\\Parameters\\HeaderParam' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/Parameters/HeaderParam.php',
        'WPForms\\Vendor\\Core\\Request\\Parameters\\MultipleParams' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/Parameters/MultipleParams.php',
        'WPForms\\Vendor\\Core\\Request\\Parameters\\Parameter' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/Parameters/Parameter.php',
        'WPForms\\Vendor\\Core\\Request\\Parameters\\QueryParam' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/Parameters/QueryParam.php',
        'WPForms\\Vendor\\Core\\Request\\Parameters\\TemplateParam' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/Parameters/TemplateParam.php',
        'WPForms\\Vendor\\Core\\Request\\Request' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/Request.php',
        'WPForms\\Vendor\\Core\\Request\\RequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Request/RequestBuilder.php',
        'WPForms\\Vendor\\Core\\Response\\Context' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Response/Context.php',
        'WPForms\\Vendor\\Core\\Response\\ResponseError' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Response/ResponseError.php',
        'WPForms\\Vendor\\Core\\Response\\ResponseHandler' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Response/ResponseHandler.php',
        'WPForms\\Vendor\\Core\\Response\\Types\\DeserializableType' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Response/Types/DeserializableType.php',
        'WPForms\\Vendor\\Core\\Response\\Types\\ErrorType' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Response/Types/ErrorType.php',
        'WPForms\\Vendor\\Core\\Response\\Types\\ResponseMultiType' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Response/Types/ResponseMultiType.php',
        'WPForms\\Vendor\\Core\\Response\\Types\\ResponseType' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Response/Types/ResponseType.php',
        'WPForms\\Vendor\\Core\\TestCase\\BodyMatchers\\BodyComparator' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/TestCase/BodyMatchers/BodyComparator.php',
        'WPForms\\Vendor\\Core\\TestCase\\BodyMatchers\\BodyMatcher' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/TestCase/BodyMatchers/BodyMatcher.php',
        'WPForms\\Vendor\\Core\\TestCase\\BodyMatchers\\KeysAndValuesBodyMatcher' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/TestCase/BodyMatchers/KeysAndValuesBodyMatcher.php',
        'WPForms\\Vendor\\Core\\TestCase\\BodyMatchers\\KeysBodyMatcher' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/TestCase/BodyMatchers/KeysBodyMatcher.php',
        'WPForms\\Vendor\\Core\\TestCase\\BodyMatchers\\NativeBodyMatcher' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/TestCase/BodyMatchers/NativeBodyMatcher.php',
        'WPForms\\Vendor\\Core\\TestCase\\BodyMatchers\\RawBodyMatcher' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/TestCase/BodyMatchers/RawBodyMatcher.php',
        'WPForms\\Vendor\\Core\\TestCase\\CoreTestCase' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/TestCase/CoreTestCase.php',
        'WPForms\\Vendor\\Core\\TestCase\\HeadersMatcher' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/TestCase/HeadersMatcher.php',
        'WPForms\\Vendor\\Core\\TestCase\\StatusCodeMatcher' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/TestCase/StatusCodeMatcher.php',
        'WPForms\\Vendor\\Core\\TestCase\\TestParam' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/TestCase/TestParam.php',
        'WPForms\\Vendor\\Core\\Types\\CallbackCatcher' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Types/CallbackCatcher.php',
        'WPForms\\Vendor\\Core\\Types\\Sdk\\CoreApiResponse' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Types/Sdk/CoreApiResponse.php',
        'WPForms\\Vendor\\Core\\Types\\Sdk\\CoreCallback' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Types/Sdk/CoreCallback.php',
        'WPForms\\Vendor\\Core\\Types\\Sdk\\CoreContext' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Types/Sdk/CoreContext.php',
        'WPForms\\Vendor\\Core\\Types\\Sdk\\CoreFileWrapper' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Types/Sdk/CoreFileWrapper.php',
        'WPForms\\Vendor\\Core\\Types\\Sdk\\CoreRequest' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Types/Sdk/CoreRequest.php',
        'WPForms\\Vendor\\Core\\Types\\Sdk\\CoreResponse' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Types/Sdk/CoreResponse.php',
        'WPForms\\Vendor\\Core\\Utils\\CoreHelper' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Utils/CoreHelper.php',
        'WPForms\\Vendor\\Core\\Utils\\DateHelper' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Utils/DateHelper.php',
        'WPForms\\Vendor\\Core\\Utils\\JsonHelper' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Utils/JsonHelper.php',
        'WPForms\\Vendor\\Core\\Utils\\XmlDeserializer' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Utils/XmlDeserializer.php',
        'WPForms\\Vendor\\Core\\Utils\\XmlSerializer' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/core/src/Utils/XmlSerializer.php',
        'WPForms\\Vendor\\HTML5' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Lexer/PH5P.php',
        'WPForms\\Vendor\\HTML5TreeConstructer' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Lexer/PH5P.php',
        'WPForms\\Vendor\\HTMLPurifier' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier.php',
        'WPForms\\Vendor\\HTMLPurifier_Arborize' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Arborize.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrCollections' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrCollections.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_AlphaValue' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/AlphaValue.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_Background' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Background.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_BackgroundPosition' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/BackgroundPosition.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_Border' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Border.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_Color' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Color.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_Composite' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Composite.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_DenyElementDecorator' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/DenyElementDecorator.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_Filter' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Filter.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_Font' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Font.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_FontFamily' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/FontFamily.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_Ident' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Ident.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_ImportantDecorator' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/ImportantDecorator.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_Length' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Length.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_ListStyle' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/ListStyle.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_Multiple' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Multiple.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_Number' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Number.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_Percentage' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Percentage.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_Ratio' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/Ratio.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_TextDecoration' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/TextDecoration.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_CSS_URI' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/CSS/URI.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_Clone' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/Clone.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_Enum' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/Enum.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_HTML_Bool' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/Bool.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_HTML_Class' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/Class.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_HTML_Color' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/Color.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_HTML_ContentEditable' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/ContentEditable.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_HTML_FrameTarget' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/FrameTarget.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_HTML_ID' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/ID.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_HTML_Length' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/Length.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_HTML_LinkTypes' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/LinkTypes.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_HTML_MultiLength' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/MultiLength.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_HTML_Nmtokens' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/Nmtokens.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_HTML_Pixels' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/HTML/Pixels.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_Integer' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/Integer.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_Lang' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/Lang.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_Switch' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/Switch.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_Text' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/Text.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_URI' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/URI.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_URI_Email' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/URI/Email.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_URI_Email_SimpleCheck' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/URI/Email/SimpleCheck.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_URI_Host' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/URI/Host.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_URI_IPv4' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/URI/IPv4.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrDef_URI_IPv6' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrDef/URI/IPv6.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_Background' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Background.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_BdoDir' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/BdoDir.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_BgColor' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/BgColor.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_BoolToCSS' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/BoolToCSS.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_Border' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Border.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_EnumToCSS' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/EnumToCSS.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_ImgRequired' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/ImgRequired.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_ImgSpace' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/ImgSpace.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_Input' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Input.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_Lang' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Lang.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_Length' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Length.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_Name' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Name.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_NameSync' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/NameSync.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_Nofollow' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Nofollow.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_SafeEmbed' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/SafeEmbed.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_SafeObject' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/SafeObject.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_SafeParam' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/SafeParam.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_ScriptRequired' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/ScriptRequired.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_TargetBlank' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/TargetBlank.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_TargetNoopener' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/TargetNoopener.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_TargetNoreferrer' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/TargetNoreferrer.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTransform_Textarea' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTransform/Textarea.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrTypes' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrTypes.php',
        'WPForms\\Vendor\\HTMLPurifier_AttrValidator' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/AttrValidator.php',
        'WPForms\\Vendor\\HTMLPurifier_Bootstrap' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Bootstrap.php',
        'WPForms\\Vendor\\HTMLPurifier_CSSDefinition' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/CSSDefinition.php',
        'WPForms\\Vendor\\HTMLPurifier_ChildDef' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef.php',
        'WPForms\\Vendor\\HTMLPurifier_ChildDef_Chameleon' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/Chameleon.php',
        'WPForms\\Vendor\\HTMLPurifier_ChildDef_Custom' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/Custom.php',
        'WPForms\\Vendor\\HTMLPurifier_ChildDef_Empty' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/Empty.php',
        'WPForms\\Vendor\\HTMLPurifier_ChildDef_List' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/List.php',
        'WPForms\\Vendor\\HTMLPurifier_ChildDef_Optional' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/Optional.php',
        'WPForms\\Vendor\\HTMLPurifier_ChildDef_Required' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/Required.php',
        'WPForms\\Vendor\\HTMLPurifier_ChildDef_StrictBlockquote' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/StrictBlockquote.php',
        'WPForms\\Vendor\\HTMLPurifier_ChildDef_Table' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ChildDef/Table.php',
        'WPForms\\Vendor\\HTMLPurifier_Config' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Config.php',
        'WPForms\\Vendor\\HTMLPurifier_ConfigSchema' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema.php',
        'WPForms\\Vendor\\HTMLPurifier_ConfigSchema_Builder_ConfigSchema' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Builder/ConfigSchema.php',
        'WPForms\\Vendor\\HTMLPurifier_ConfigSchema_Builder_Xml' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Builder/Xml.php',
        'WPForms\\Vendor\\HTMLPurifier_ConfigSchema_Exception' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Exception.php',
        'WPForms\\Vendor\\HTMLPurifier_ConfigSchema_Interchange' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Interchange.php',
        'WPForms\\Vendor\\HTMLPurifier_ConfigSchema_InterchangeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/InterchangeBuilder.php',
        'WPForms\\Vendor\\HTMLPurifier_ConfigSchema_Interchange_Directive' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Interchange/Directive.php',
        'WPForms\\Vendor\\HTMLPurifier_ConfigSchema_Interchange_Id' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Interchange/Id.php',
        'WPForms\\Vendor\\HTMLPurifier_ConfigSchema_Validator' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/Validator.php',
        'WPForms\\Vendor\\HTMLPurifier_ConfigSchema_ValidatorAtom' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ConfigSchema/ValidatorAtom.php',
        'WPForms\\Vendor\\HTMLPurifier_ContentSets' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ContentSets.php',
        'WPForms\\Vendor\\HTMLPurifier_Context' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Context.php',
        'WPForms\\Vendor\\HTMLPurifier_Definition' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Definition.php',
        'WPForms\\Vendor\\HTMLPurifier_DefinitionCache' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCache.php',
        'WPForms\\Vendor\\HTMLPurifier_DefinitionCacheFactory' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCacheFactory.php',
        'WPForms\\Vendor\\HTMLPurifier_DefinitionCache_Decorator' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCache/Decorator.php',
        'WPForms\\Vendor\\HTMLPurifier_DefinitionCache_Decorator_Cleanup' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCache/Decorator/Cleanup.php',
        'WPForms\\Vendor\\HTMLPurifier_DefinitionCache_Decorator_Memory' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCache/Decorator/Memory.php',
        'WPForms\\Vendor\\HTMLPurifier_DefinitionCache_Null' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCache/Null.php',
        'WPForms\\Vendor\\HTMLPurifier_DefinitionCache_Serializer' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/DefinitionCache/Serializer.php',
        'WPForms\\Vendor\\HTMLPurifier_Doctype' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Doctype.php',
        'WPForms\\Vendor\\HTMLPurifier_DoctypeRegistry' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/DoctypeRegistry.php',
        'WPForms\\Vendor\\HTMLPurifier_ElementDef' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ElementDef.php',
        'WPForms\\Vendor\\HTMLPurifier_Encoder' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Encoder.php',
        'WPForms\\Vendor\\HTMLPurifier_EntityLookup' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/EntityLookup.php',
        'WPForms\\Vendor\\HTMLPurifier_EntityParser' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/EntityParser.php',
        'WPForms\\Vendor\\HTMLPurifier_ErrorCollector' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ErrorCollector.php',
        'WPForms\\Vendor\\HTMLPurifier_ErrorStruct' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/ErrorStruct.php',
        'WPForms\\Vendor\\HTMLPurifier_Exception' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Exception.php',
        'WPForms\\Vendor\\HTMLPurifier_Filter' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Filter.php',
        'WPForms\\Vendor\\HTMLPurifier_Filter_ExtractStyleBlocks' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Filter/ExtractStyleBlocks.php',
        'WPForms\\Vendor\\HTMLPurifier_Filter_YouTube' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Filter/YouTube.php',
        'WPForms\\Vendor\\HTMLPurifier_Generator' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Generator.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLDefinition' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLDefinition.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModuleManager' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModuleManager.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Bdo' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Bdo.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_CommonAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/CommonAttributes.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Edit' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Edit.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Forms' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Forms.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Hypertext' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Hypertext.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Iframe' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Iframe.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Image' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Image.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Legacy' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Legacy.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_List' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/List.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Name' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Name.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Nofollow' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Nofollow.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_NonXMLCommonAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/NonXMLCommonAttributes.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Object' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Object.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Presentation' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Presentation.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Proprietary' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Proprietary.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Ruby' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Ruby.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_SafeEmbed' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/SafeEmbed.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_SafeObject' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/SafeObject.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_SafeScripting' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/SafeScripting.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Scripting' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Scripting.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_StyleAttribute' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/StyleAttribute.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Tables' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tables.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Target' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Target.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_TargetBlank' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/TargetBlank.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_TargetNoopener' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/TargetNoopener.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_TargetNoreferrer' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/TargetNoreferrer.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Text' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Text.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Tidy' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Tidy_Name' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy/Name.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Tidy_Proprietary' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy/Proprietary.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Tidy_Strict' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy/Strict.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Tidy_Transitional' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy/Transitional.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Tidy_XHTML' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy/XHTML.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_Tidy_XHTMLAndHTML4' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/Tidy/XHTMLAndHTML4.php',
        'WPForms\\Vendor\\HTMLPurifier_HTMLModule_XMLCommonAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/HTMLModule/XMLCommonAttributes.php',
        'WPForms\\Vendor\\HTMLPurifier_IDAccumulator' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/IDAccumulator.php',
        'WPForms\\Vendor\\HTMLPurifier_Injector' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Injector.php',
        'WPForms\\Vendor\\HTMLPurifier_Injector_AutoParagraph' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Injector/AutoParagraph.php',
        'WPForms\\Vendor\\HTMLPurifier_Injector_DisplayLinkURI' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Injector/DisplayLinkURI.php',
        'WPForms\\Vendor\\HTMLPurifier_Injector_Linkify' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Injector/Linkify.php',
        'WPForms\\Vendor\\HTMLPurifier_Injector_PurifierLinkify' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Injector/PurifierLinkify.php',
        'WPForms\\Vendor\\HTMLPurifier_Injector_RemoveEmpty' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Injector/RemoveEmpty.php',
        'WPForms\\Vendor\\HTMLPurifier_Injector_RemoveSpansWithoutAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Injector/RemoveSpansWithoutAttributes.php',
        'WPForms\\Vendor\\HTMLPurifier_Injector_SafeObject' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Injector/SafeObject.php',
        'WPForms\\Vendor\\HTMLPurifier_Language' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Language.php',
        'WPForms\\Vendor\\HTMLPurifier_LanguageFactory' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/LanguageFactory.php',
        'WPForms\\Vendor\\HTMLPurifier_Length' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Length.php',
        'WPForms\\Vendor\\HTMLPurifier_Lexer' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Lexer.php',
        'WPForms\\Vendor\\HTMLPurifier_Lexer_DOMLex' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Lexer/DOMLex.php',
        'WPForms\\Vendor\\HTMLPurifier_Lexer_DirectLex' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Lexer/DirectLex.php',
        'WPForms\\Vendor\\HTMLPurifier_Lexer_PH5P' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Lexer/PH5P.php',
        'WPForms\\Vendor\\HTMLPurifier_Node' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Node.php',
        'WPForms\\Vendor\\HTMLPurifier_Node_Comment' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Node/Comment.php',
        'WPForms\\Vendor\\HTMLPurifier_Node_Element' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Node/Element.php',
        'WPForms\\Vendor\\HTMLPurifier_Node_Text' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Node/Text.php',
        'WPForms\\Vendor\\HTMLPurifier_PercentEncoder' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/PercentEncoder.php',
        'WPForms\\Vendor\\HTMLPurifier_Printer' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Printer.php',
        'WPForms\\Vendor\\HTMLPurifier_Printer_CSSDefinition' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Printer/CSSDefinition.php',
        'WPForms\\Vendor\\HTMLPurifier_Printer_ConfigForm' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Printer/ConfigForm.php',
        'WPForms\\Vendor\\HTMLPurifier_Printer_ConfigForm_NullDecorator' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Printer/ConfigForm.php',
        'WPForms\\Vendor\\HTMLPurifier_Printer_ConfigForm_bool' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Printer/ConfigForm.php',
        'WPForms\\Vendor\\HTMLPurifier_Printer_ConfigForm_default' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Printer/ConfigForm.php',
        'WPForms\\Vendor\\HTMLPurifier_Printer_HTMLDefinition' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Printer/HTMLDefinition.php',
        'WPForms\\Vendor\\HTMLPurifier_PropertyList' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/PropertyList.php',
        'WPForms\\Vendor\\HTMLPurifier_PropertyListIterator' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/PropertyListIterator.php',
        'WPForms\\Vendor\\HTMLPurifier_Queue' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Queue.php',
        'WPForms\\Vendor\\HTMLPurifier_Strategy' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Strategy.php',
        'WPForms\\Vendor\\HTMLPurifier_Strategy_Composite' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Strategy/Composite.php',
        'WPForms\\Vendor\\HTMLPurifier_Strategy_Core' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Strategy/Core.php',
        'WPForms\\Vendor\\HTMLPurifier_Strategy_FixNesting' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Strategy/FixNesting.php',
        'WPForms\\Vendor\\HTMLPurifier_Strategy_MakeWellFormed' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Strategy/MakeWellFormed.php',
        'WPForms\\Vendor\\HTMLPurifier_Strategy_RemoveForeignElements' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Strategy/RemoveForeignElements.php',
        'WPForms\\Vendor\\HTMLPurifier_Strategy_ValidateAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Strategy/ValidateAttributes.php',
        'WPForms\\Vendor\\HTMLPurifier_StringHash' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/StringHash.php',
        'WPForms\\Vendor\\HTMLPurifier_StringHashParser' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/StringHashParser.php',
        'WPForms\\Vendor\\HTMLPurifier_TagTransform' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/TagTransform.php',
        'WPForms\\Vendor\\HTMLPurifier_TagTransform_Font' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/TagTransform/Font.php',
        'WPForms\\Vendor\\HTMLPurifier_TagTransform_Simple' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/TagTransform/Simple.php',
        'WPForms\\Vendor\\HTMLPurifier_Token' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Token.php',
        'WPForms\\Vendor\\HTMLPurifier_TokenFactory' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/TokenFactory.php',
        'WPForms\\Vendor\\HTMLPurifier_Token_Comment' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Token/Comment.php',
        'WPForms\\Vendor\\HTMLPurifier_Token_Empty' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Token/Empty.php',
        'WPForms\\Vendor\\HTMLPurifier_Token_End' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Token/End.php',
        'WPForms\\Vendor\\HTMLPurifier_Token_Start' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Token/Start.php',
        'WPForms\\Vendor\\HTMLPurifier_Token_Tag' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Token/Tag.php',
        'WPForms\\Vendor\\HTMLPurifier_Token_Text' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Token/Text.php',
        'WPForms\\Vendor\\HTMLPurifier_URI' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URI.php',
        'WPForms\\Vendor\\HTMLPurifier_URIDefinition' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIDefinition.php',
        'WPForms\\Vendor\\HTMLPurifier_URIFilter' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter.php',
        'WPForms\\Vendor\\HTMLPurifier_URIFilter_DisableExternal' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/DisableExternal.php',
        'WPForms\\Vendor\\HTMLPurifier_URIFilter_DisableExternalResources' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/DisableExternalResources.php',
        'WPForms\\Vendor\\HTMLPurifier_URIFilter_DisableResources' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/DisableResources.php',
        'WPForms\\Vendor\\HTMLPurifier_URIFilter_HostBlacklist' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/HostBlacklist.php',
        'WPForms\\Vendor\\HTMLPurifier_URIFilter_MakeAbsolute' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/MakeAbsolute.php',
        'WPForms\\Vendor\\HTMLPurifier_URIFilter_Munge' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/Munge.php',
        'WPForms\\Vendor\\HTMLPurifier_URIFilter_SafeIframe' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIFilter/SafeIframe.php',
        'WPForms\\Vendor\\HTMLPurifier_URIParser' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIParser.php',
        'WPForms\\Vendor\\HTMLPurifier_URIScheme' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme.php',
        'WPForms\\Vendor\\HTMLPurifier_URISchemeRegistry' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URISchemeRegistry.php',
        'WPForms\\Vendor\\HTMLPurifier_URIScheme_data' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/data.php',
        'WPForms\\Vendor\\HTMLPurifier_URIScheme_file' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/file.php',
        'WPForms\\Vendor\\HTMLPurifier_URIScheme_ftp' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/ftp.php',
        'WPForms\\Vendor\\HTMLPurifier_URIScheme_http' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/http.php',
        'WPForms\\Vendor\\HTMLPurifier_URIScheme_https' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/https.php',
        'WPForms\\Vendor\\HTMLPurifier_URIScheme_mailto' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/mailto.php',
        'WPForms\\Vendor\\HTMLPurifier_URIScheme_news' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/news.php',
        'WPForms\\Vendor\\HTMLPurifier_URIScheme_nntp' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/nntp.php',
        'WPForms\\Vendor\\HTMLPurifier_URIScheme_tel' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/URIScheme/tel.php',
        'WPForms\\Vendor\\HTMLPurifier_UnitConverter' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/UnitConverter.php',
        'WPForms\\Vendor\\HTMLPurifier_VarParser' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/VarParser.php',
        'WPForms\\Vendor\\HTMLPurifier_VarParserException' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/VarParserException.php',
        'WPForms\\Vendor\\HTMLPurifier_VarParser_Flexible' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/VarParser/Flexible.php',
        'WPForms\\Vendor\\HTMLPurifier_VarParser_Native' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/VarParser/Native.php',
        'WPForms\\Vendor\\HTMLPurifier_Zipper' => __DIR__ . '/../..' . '/vendor_prefixed/ezyang/htmlpurifier/library/HTMLPurifier/Zipper.php',
        'WPForms\\Vendor\\Psr\\Log\\AbstractLogger' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/AbstractLogger.php',
        'WPForms\\Vendor\\Psr\\Log\\InvalidArgumentException' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/InvalidArgumentException.php',
        'WPForms\\Vendor\\Psr\\Log\\LogLevel' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/LogLevel.php',
        'WPForms\\Vendor\\Psr\\Log\\LoggerAwareInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/LoggerAwareInterface.php',
        'WPForms\\Vendor\\Psr\\Log\\LoggerAwareTrait' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/LoggerAwareTrait.php',
        'WPForms\\Vendor\\Psr\\Log\\LoggerInterface' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/LoggerInterface.php',
        'WPForms\\Vendor\\Psr\\Log\\LoggerTrait' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/LoggerTrait.php',
        'WPForms\\Vendor\\Psr\\Log\\NullLogger' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/NullLogger.php',
        'WPForms\\Vendor\\Psr\\Log\\Test\\DummyTest' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/Test/DummyTest.php',
        'WPForms\\Vendor\\Psr\\Log\\Test\\LoggerInterfaceTest' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/Test/LoggerInterfaceTest.php',
        'WPForms\\Vendor\\Psr\\Log\\Test\\TestLogger' => __DIR__ . '/../..' . '/vendor_prefixed/psr/log/Psr/Log/Test/TestLogger.php',
        'WPForms\\Vendor\\Rs\\Json\\Pointer' => __DIR__ . '/../..' . '/vendor_prefixed/php-jsonpointer/php-jsonpointer/src/Rs/Json/Pointer.php',
        'WPForms\\Vendor\\Rs\\Json\\Pointer\\InvalidJsonException' => __DIR__ . '/../..' . '/vendor_prefixed/php-jsonpointer/php-jsonpointer/src/Rs/Json/Pointer/InvalidJsonException.php',
        'WPForms\\Vendor\\Rs\\Json\\Pointer\\InvalidPointerException' => __DIR__ . '/../..' . '/vendor_prefixed/php-jsonpointer/php-jsonpointer/src/Rs/Json/Pointer/InvalidPointerException.php',
        'WPForms\\Vendor\\Rs\\Json\\Pointer\\NonWalkableJsonException' => __DIR__ . '/../..' . '/vendor_prefixed/php-jsonpointer/php-jsonpointer/src/Rs/Json/Pointer/NonWalkableJsonException.php',
        'WPForms\\Vendor\\Rs\\Json\\Pointer\\NonexistentValueReferencedException' => __DIR__ . '/../..' . '/vendor_prefixed/php-jsonpointer/php-jsonpointer/src/Rs/Json/Pointer/NonexistentValueReferencedException.php',
        'WPForms\\Vendor\\Square\\ApiHelper' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/ApiHelper.php',
        'WPForms\\Vendor\\Square\\Apis\\ApplePayApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/ApplePayApi.php',
        'WPForms\\Vendor\\Square\\Apis\\BankAccountsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/BankAccountsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\BaseApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/BaseApi.php',
        'WPForms\\Vendor\\Square\\Apis\\BookingCustomAttributesApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/BookingCustomAttributesApi.php',
        'WPForms\\Vendor\\Square\\Apis\\BookingsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/BookingsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\CardsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/CardsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\CashDrawersApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/CashDrawersApi.php',
        'WPForms\\Vendor\\Square\\Apis\\CatalogApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/CatalogApi.php',
        'WPForms\\Vendor\\Square\\Apis\\CheckoutApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/CheckoutApi.php',
        'WPForms\\Vendor\\Square\\Apis\\CustomerCustomAttributesApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/CustomerCustomAttributesApi.php',
        'WPForms\\Vendor\\Square\\Apis\\CustomerGroupsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/CustomerGroupsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\CustomerSegmentsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/CustomerSegmentsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\CustomersApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/CustomersApi.php',
        'WPForms\\Vendor\\Square\\Apis\\DevicesApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/DevicesApi.php',
        'WPForms\\Vendor\\Square\\Apis\\DisputesApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/DisputesApi.php',
        'WPForms\\Vendor\\Square\\Apis\\EmployeesApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/EmployeesApi.php',
        'WPForms\\Vendor\\Square\\Apis\\EventsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/EventsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\GiftCardActivitiesApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/GiftCardActivitiesApi.php',
        'WPForms\\Vendor\\Square\\Apis\\GiftCardsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/GiftCardsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\InventoryApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/InventoryApi.php',
        'WPForms\\Vendor\\Square\\Apis\\InvoicesApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/InvoicesApi.php',
        'WPForms\\Vendor\\Square\\Apis\\LaborApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/LaborApi.php',
        'WPForms\\Vendor\\Square\\Apis\\LocationCustomAttributesApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/LocationCustomAttributesApi.php',
        'WPForms\\Vendor\\Square\\Apis\\LocationsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/LocationsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\LoyaltyApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/LoyaltyApi.php',
        'WPForms\\Vendor\\Square\\Apis\\MerchantCustomAttributesApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/MerchantCustomAttributesApi.php',
        'WPForms\\Vendor\\Square\\Apis\\MerchantsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/MerchantsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\MobileAuthorizationApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/MobileAuthorizationApi.php',
        'WPForms\\Vendor\\Square\\Apis\\OAuthApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/OAuthApi.php',
        'WPForms\\Vendor\\Square\\Apis\\OrderCustomAttributesApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/OrderCustomAttributesApi.php',
        'WPForms\\Vendor\\Square\\Apis\\OrdersApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/OrdersApi.php',
        'WPForms\\Vendor\\Square\\Apis\\PaymentsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/PaymentsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\PayoutsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/PayoutsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\RefundsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/RefundsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\SitesApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/SitesApi.php',
        'WPForms\\Vendor\\Square\\Apis\\SnippetsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/SnippetsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\SubscriptionsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/SubscriptionsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\TeamApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/TeamApi.php',
        'WPForms\\Vendor\\Square\\Apis\\TerminalApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/TerminalApi.php',
        'WPForms\\Vendor\\Square\\Apis\\TransactionsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/TransactionsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\V1TransactionsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/V1TransactionsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\VendorsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/VendorsApi.php',
        'WPForms\\Vendor\\Square\\Apis\\WebhookSubscriptionsApi' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Apis/WebhookSubscriptionsApi.php',
        'WPForms\\Vendor\\Square\\Authentication\\BearerAuthCredentialsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Authentication/BearerAuthCredentialsBuilder.php',
        'WPForms\\Vendor\\Square\\Authentication\\BearerAuthManager' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Authentication/BearerAuthManager.php',
        'WPForms\\Vendor\\Square\\BearerAuthCredentials' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/BearerAuthCredentials.php',
        'WPForms\\Vendor\\Square\\ConfigurationDefaults' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/ConfigurationDefaults.php',
        'WPForms\\Vendor\\Square\\ConfigurationInterface' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/ConfigurationInterface.php',
        'WPForms\\Vendor\\Square\\Environment' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Environment.php',
        'WPForms\\Vendor\\Square\\Exceptions\\ApiException' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Exceptions/ApiException.php',
        'WPForms\\Vendor\\Square\\Http\\ApiResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Http/ApiResponse.php',
        'WPForms\\Vendor\\Square\\Http\\HttpCallBack' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Http/HttpCallBack.php',
        'WPForms\\Vendor\\Square\\Http\\HttpContext' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Http/HttpContext.php',
        'WPForms\\Vendor\\Square\\Http\\HttpMethod' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Http/HttpMethod.php',
        'WPForms\\Vendor\\Square\\Http\\HttpRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Http/HttpRequest.php',
        'WPForms\\Vendor\\Square\\Http\\HttpResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Http/HttpResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ACHDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ACHDetails.php',
        'WPForms\\Vendor\\Square\\Models\\AcceptDisputeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/AcceptDisputeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\AcceptedPaymentMethods' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/AcceptedPaymentMethods.php',
        'WPForms\\Vendor\\Square\\Models\\AccumulateLoyaltyPointsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/AccumulateLoyaltyPointsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\AccumulateLoyaltyPointsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/AccumulateLoyaltyPointsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ActionCancelReason' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ActionCancelReason.php',
        'WPForms\\Vendor\\Square\\Models\\ActivityType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ActivityType.php',
        'WPForms\\Vendor\\Square\\Models\\AddGroupToCustomerResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/AddGroupToCustomerResponse.php',
        'WPForms\\Vendor\\Square\\Models\\AdditionalRecipient' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/AdditionalRecipient.php',
        'WPForms\\Vendor\\Square\\Models\\Address' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Address.php',
        'WPForms\\Vendor\\Square\\Models\\AdjustLoyaltyPointsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/AdjustLoyaltyPointsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\AdjustLoyaltyPointsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/AdjustLoyaltyPointsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\AfterpayDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/AfterpayDetails.php',
        'WPForms\\Vendor\\Square\\Models\\ApplicationDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ApplicationDetails.php',
        'WPForms\\Vendor\\Square\\Models\\ApplicationDetailsExternalSquareProduct' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ApplicationDetailsExternalSquareProduct.php',
        'WPForms\\Vendor\\Square\\Models\\ApplicationType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ApplicationType.php',
        'WPForms\\Vendor\\Square\\Models\\AppointmentSegment' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/AppointmentSegment.php',
        'WPForms\\Vendor\\Square\\Models\\ArchivedState' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ArchivedState.php',
        'WPForms\\Vendor\\Square\\Models\\Availability' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Availability.php',
        'WPForms\\Vendor\\Square\\Models\\BankAccount' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BankAccount.php',
        'WPForms\\Vendor\\Square\\Models\\BankAccountPaymentDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BankAccountPaymentDetails.php',
        'WPForms\\Vendor\\Square\\Models\\BankAccountStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BankAccountStatus.php',
        'WPForms\\Vendor\\Square\\Models\\BankAccountType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BankAccountType.php',
        'WPForms\\Vendor\\Square\\Models\\BatchChangeInventoryRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchChangeInventoryRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BatchChangeInventoryResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchChangeInventoryResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BatchDeleteCatalogObjectsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchDeleteCatalogObjectsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BatchDeleteCatalogObjectsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchDeleteCatalogObjectsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BatchRetrieveCatalogObjectsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchRetrieveCatalogObjectsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BatchRetrieveCatalogObjectsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchRetrieveCatalogObjectsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BatchRetrieveInventoryChangesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchRetrieveInventoryChangesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BatchRetrieveInventoryChangesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchRetrieveInventoryChangesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BatchRetrieveInventoryCountsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchRetrieveInventoryCountsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BatchRetrieveInventoryCountsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchRetrieveInventoryCountsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BatchRetrieveOrdersRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchRetrieveOrdersRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BatchRetrieveOrdersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchRetrieveOrdersResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BatchUpsertCatalogObjectsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchUpsertCatalogObjectsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BatchUpsertCatalogObjectsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BatchUpsertCatalogObjectsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\Booking' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Booking.php',
        'WPForms\\Vendor\\Square\\Models\\BookingBookingSource' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BookingBookingSource.php',
        'WPForms\\Vendor\\Square\\Models\\BookingCreatorDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BookingCreatorDetails.php',
        'WPForms\\Vendor\\Square\\Models\\BookingCreatorDetailsCreatorType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BookingCreatorDetailsCreatorType.php',
        'WPForms\\Vendor\\Square\\Models\\BookingCustomAttributeDeleteRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BookingCustomAttributeDeleteRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BookingCustomAttributeDeleteResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BookingCustomAttributeDeleteResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BookingCustomAttributeUpsertRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BookingCustomAttributeUpsertRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BookingCustomAttributeUpsertResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BookingCustomAttributeUpsertResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BookingStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BookingStatus.php',
        'WPForms\\Vendor\\Square\\Models\\BreakType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BreakType.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ACHDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ACHDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\AcceptDisputeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/AcceptDisputeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\AcceptedPaymentMethodsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/AcceptedPaymentMethodsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\AccumulateLoyaltyPointsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/AccumulateLoyaltyPointsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\AccumulateLoyaltyPointsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/AccumulateLoyaltyPointsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\AddGroupToCustomerResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/AddGroupToCustomerResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\AdditionalRecipientBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/AdditionalRecipientBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\AddressBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/AddressBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\AdjustLoyaltyPointsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/AdjustLoyaltyPointsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\AdjustLoyaltyPointsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/AdjustLoyaltyPointsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\AfterpayDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/AfterpayDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ApplicationDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ApplicationDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\AppointmentSegmentBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/AppointmentSegmentBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\AvailabilityBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/AvailabilityBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BankAccountBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BankAccountBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BankAccountPaymentDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BankAccountPaymentDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchChangeInventoryRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchChangeInventoryRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchChangeInventoryResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchChangeInventoryResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchDeleteCatalogObjectsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchDeleteCatalogObjectsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchDeleteCatalogObjectsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchDeleteCatalogObjectsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchRetrieveCatalogObjectsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchRetrieveCatalogObjectsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchRetrieveCatalogObjectsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchRetrieveCatalogObjectsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchRetrieveInventoryChangesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchRetrieveInventoryChangesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchRetrieveInventoryChangesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchRetrieveInventoryChangesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchRetrieveInventoryCountsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchRetrieveInventoryCountsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchRetrieveInventoryCountsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchRetrieveInventoryCountsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchRetrieveOrdersRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchRetrieveOrdersRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchRetrieveOrdersResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchRetrieveOrdersResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchUpsertCatalogObjectsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchUpsertCatalogObjectsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BatchUpsertCatalogObjectsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BatchUpsertCatalogObjectsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BookingBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BookingBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BookingCreatorDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BookingCreatorDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BookingCustomAttributeDeleteRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BookingCustomAttributeDeleteRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BookingCustomAttributeDeleteResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BookingCustomAttributeDeleteResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BookingCustomAttributeUpsertRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BookingCustomAttributeUpsertRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BookingCustomAttributeUpsertResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BookingCustomAttributeUpsertResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BreakTypeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BreakTypeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkCreateCustomerDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkCreateCustomerDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkCreateCustomersRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkCreateCustomersRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkCreateCustomersResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkCreateCustomersResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkCreateTeamMembersRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkCreateTeamMembersRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkCreateTeamMembersResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkCreateTeamMembersResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkCreateVendorsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkCreateVendorsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkCreateVendorsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkCreateVendorsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteBookingCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteBookingCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteBookingCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteBookingCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteCustomersRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteCustomersRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteCustomersResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteCustomersResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteLocationCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteLocationCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteLocationCustomAttributesRequestLocationCustomAttributeDeleteRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteLocationCustomAttributesRequestLocationCustomAttributeDeleteRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteLocationCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteLocationCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteLocationCustomAttributesResponseLocationCustomAttributeDeleteResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteLocationCustomAttributesResponseLocationCustomAttributeDeleteResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteMerchantCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteMerchantCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteMerchantCustomAttributesRequestMerchantCustomAttributeDeleteRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteMerchantCustomAttributesRequestMerchantCustomAttributeDeleteRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteMerchantCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteMerchantCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteMerchantCustomAttributesResponseMerchantCustomAttributeDeleteResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteMerchantCustomAttributesResponseMerchantCustomAttributeDeleteResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteOrderCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteOrderCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteOrderCustomAttributesRequestDeleteCustomAttributeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteOrderCustomAttributesRequestDeleteCustomAttributeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkDeleteOrderCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkDeleteOrderCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkRetrieveBookingsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkRetrieveBookingsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkRetrieveBookingsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkRetrieveBookingsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkRetrieveCustomersRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkRetrieveCustomersRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkRetrieveCustomersResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkRetrieveCustomersResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkRetrieveTeamMemberBookingProfilesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkRetrieveTeamMemberBookingProfilesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkRetrieveTeamMemberBookingProfilesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkRetrieveTeamMemberBookingProfilesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkRetrieveVendorsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkRetrieveVendorsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkRetrieveVendorsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkRetrieveVendorsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkSwapPlanRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkSwapPlanRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkSwapPlanResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkSwapPlanResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpdateCustomerDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpdateCustomerDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpdateCustomersRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpdateCustomersRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpdateCustomersResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpdateCustomersResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpdateTeamMembersRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpdateTeamMembersRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpdateTeamMembersResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpdateTeamMembersResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpdateVendorsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpdateVendorsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpdateVendorsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpdateVendorsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertBookingCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertBookingCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertBookingCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertBookingCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertCustomerCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertCustomerCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertCustomerCustomAttributesRequestCustomerCustomAttributeUpsertRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertCustomerCustomAttributesRequestCustomerCustomAttributeUpsertRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertCustomerCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertCustomerCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertCustomerCustomAttributesResponseCustomerCustomAttributeUpsertResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertCustomerCustomAttributesResponseCustomerCustomAttributeUpsertResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertLocationCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertLocationCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertLocationCustomAttributesRequestLocationCustomAttributeUpsertRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertLocationCustomAttributesRequestLocationCustomAttributeUpsertRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertLocationCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertLocationCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertLocationCustomAttributesResponseLocationCustomAttributeUpsertResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertLocationCustomAttributesResponseLocationCustomAttributeUpsertResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertMerchantCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertMerchantCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertMerchantCustomAttributesRequestMerchantCustomAttributeUpsertRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertMerchantCustomAttributesRequestMerchantCustomAttributeUpsertRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertMerchantCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertMerchantCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertMerchantCustomAttributesResponseMerchantCustomAttributeUpsertResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertMerchantCustomAttributesResponseMerchantCustomAttributeUpsertResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertOrderCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertOrderCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertOrderCustomAttributesRequestUpsertCustomAttributeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertOrderCustomAttributesRequestUpsertCustomAttributeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BulkUpsertOrderCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BulkUpsertOrderCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BusinessAppointmentSettingsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BusinessAppointmentSettingsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BusinessBookingProfileBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BusinessBookingProfileBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BusinessHoursBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BusinessHoursBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BusinessHoursPeriodBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BusinessHoursPeriodBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\BuyNowPayLaterDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/BuyNowPayLaterDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CalculateLoyaltyPointsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CalculateLoyaltyPointsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CalculateLoyaltyPointsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CalculateLoyaltyPointsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CalculateOrderRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CalculateOrderRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CalculateOrderResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CalculateOrderResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CancelBookingRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CancelBookingRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CancelBookingResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CancelBookingResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CancelInvoiceRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CancelInvoiceRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CancelInvoiceResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CancelInvoiceResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CancelLoyaltyPromotionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CancelLoyaltyPromotionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CancelPaymentByIdempotencyKeyRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CancelPaymentByIdempotencyKeyRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CancelPaymentByIdempotencyKeyResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CancelPaymentByIdempotencyKeyResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CancelPaymentResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CancelPaymentResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CancelSubscriptionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CancelSubscriptionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CancelTerminalActionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CancelTerminalActionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CancelTerminalCheckoutResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CancelTerminalCheckoutResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CancelTerminalRefundResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CancelTerminalRefundResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CaptureTransactionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CaptureTransactionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CardBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CardBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CardPaymentDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CardPaymentDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CardPaymentTimelineBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CardPaymentTimelineBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CashAppDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CashAppDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CashDrawerDeviceBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CashDrawerDeviceBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CashDrawerShiftBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CashDrawerShiftBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CashDrawerShiftEventBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CashDrawerShiftEventBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CashDrawerShiftSummaryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CashDrawerShiftSummaryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CashPaymentDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CashPaymentDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogAvailabilityPeriodBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogAvailabilityPeriodBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogCategoryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogCategoryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogCustomAttributeDefinitionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogCustomAttributeDefinitionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogCustomAttributeDefinitionNumberConfigBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogCustomAttributeDefinitionNumberConfigBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogCustomAttributeDefinitionSelectionConfigBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogCustomAttributeDefinitionSelectionConfigBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogCustomAttributeDefinitionSelectionConfigCustomAttributeSelectionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogCustomAttributeDefinitionSelectionConfigCustomAttributeSelectionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogCustomAttributeDefinitionStringConfigBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogCustomAttributeDefinitionStringConfigBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogCustomAttributeValueBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogCustomAttributeValueBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogDiscountBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogDiscountBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogEcomSeoDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogEcomSeoDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogIdMappingBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogIdMappingBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogImageBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogImageBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogInfoResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogInfoResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogInfoResponseLimitsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogInfoResponseLimitsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogItemBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogItemBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogItemFoodAndBeverageDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogItemFoodAndBeverageDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogItemFoodAndBeverageDetailsDietaryPreferenceBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogItemFoodAndBeverageDetailsDietaryPreferenceBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogItemFoodAndBeverageDetailsIngredientBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogItemFoodAndBeverageDetailsIngredientBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogItemModifierListInfoBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogItemModifierListInfoBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogItemOptionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogItemOptionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogItemOptionForItemBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogItemOptionForItemBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogItemOptionValueBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogItemOptionValueBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogItemOptionValueForItemVariationBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogItemOptionValueForItemVariationBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogItemVariationBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogItemVariationBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogMeasurementUnitBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogMeasurementUnitBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogModifierBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogModifierBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogModifierListBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogModifierListBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogModifierOverrideBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogModifierOverrideBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogObjectBatchBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogObjectBatchBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogObjectBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogObjectBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogObjectCategoryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogObjectCategoryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogObjectReferenceBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogObjectReferenceBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogPricingRuleBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogPricingRuleBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogProductSetBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogProductSetBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQueryExactBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQueryExactBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQueryItemVariationsForItemOptionValuesBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQueryItemVariationsForItemOptionValuesBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQueryItemsForItemOptionsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQueryItemsForItemOptionsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQueryItemsForModifierListBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQueryItemsForModifierListBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQueryItemsForTaxBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQueryItemsForTaxBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQueryPrefixBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQueryPrefixBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQueryRangeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQueryRangeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQuerySetBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQuerySetBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQuerySortedAttributeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQuerySortedAttributeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQueryTextBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQueryTextBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQuickAmountBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQuickAmountBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogQuickAmountsSettingsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogQuickAmountsSettingsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogStockConversionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogStockConversionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogSubscriptionPlanBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogSubscriptionPlanBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogSubscriptionPlanVariationBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogSubscriptionPlanVariationBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogTaxBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogTaxBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogTimePeriodBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogTimePeriodBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CatalogV1IdBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CatalogV1IdBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CategoryPathToRootNodeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CategoryPathToRootNodeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ChangeBillingAnchorDateRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ChangeBillingAnchorDateRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ChangeBillingAnchorDateResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ChangeBillingAnchorDateResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ChargeRequestAdditionalRecipientBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ChargeRequestAdditionalRecipientBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ChargeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ChargeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ChargeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ChargeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CheckoutBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CheckoutBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CheckoutLocationSettingsBrandingBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CheckoutLocationSettingsBrandingBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CheckoutLocationSettingsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CheckoutLocationSettingsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CheckoutLocationSettingsCouponsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CheckoutLocationSettingsCouponsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CheckoutLocationSettingsPolicyBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CheckoutLocationSettingsPolicyBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CheckoutLocationSettingsTippingBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CheckoutLocationSettingsTippingBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CheckoutMerchantSettingsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CheckoutMerchantSettingsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayEligibilityRangeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayEligibilityRangeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CheckoutMerchantSettingsPaymentMethodsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CheckoutMerchantSettingsPaymentMethodsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CheckoutMerchantSettingsPaymentMethodsPaymentMethodBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CheckoutMerchantSettingsPaymentMethodsPaymentMethodBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CheckoutOptionsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CheckoutOptionsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ClearpayDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ClearpayDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CloneOrderRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CloneOrderRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CloneOrderResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CloneOrderResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CollectedDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CollectedDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CompletePaymentRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CompletePaymentRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CompletePaymentResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CompletePaymentResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ComponentBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ComponentBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ConfirmationDecisionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ConfirmationDecisionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ConfirmationOptionsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ConfirmationOptionsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CoordinatesBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CoordinatesBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateBookingCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateBookingCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateBookingCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateBookingCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateBookingRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateBookingRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateBookingResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateBookingResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateBreakTypeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateBreakTypeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateBreakTypeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateBreakTypeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCardRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCardRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCatalogImageRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCatalogImageRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCatalogImageResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCatalogImageResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCheckoutRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCheckoutRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCheckoutResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCheckoutResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCustomerCardRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCustomerCardRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCustomerCardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCustomerCardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCustomerCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCustomerCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCustomerCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCustomerCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCustomerGroupRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCustomerGroupRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCustomerGroupResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCustomerGroupResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCustomerRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCustomerRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateCustomerResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateCustomerResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateDeviceCodeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateDeviceCodeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateDeviceCodeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateDeviceCodeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateDisputeEvidenceFileRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateDisputeEvidenceFileRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateDisputeEvidenceFileResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateDisputeEvidenceFileResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateDisputeEvidenceTextRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateDisputeEvidenceTextRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateDisputeEvidenceTextResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateDisputeEvidenceTextResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateGiftCardActivityRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateGiftCardActivityRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateGiftCardActivityResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateGiftCardActivityResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateGiftCardRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateGiftCardRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateGiftCardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateGiftCardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateInvoiceAttachmentRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateInvoiceAttachmentRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateInvoiceAttachmentResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateInvoiceAttachmentResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateInvoiceRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateInvoiceRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateInvoiceResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateInvoiceResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateJobRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateJobRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateJobResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateJobResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateLocationCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateLocationCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateLocationCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateLocationCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateLocationRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateLocationRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateLocationResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateLocationResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateLoyaltyAccountRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateLoyaltyAccountRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateLoyaltyAccountResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateLoyaltyAccountResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateLoyaltyPromotionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateLoyaltyPromotionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateLoyaltyPromotionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateLoyaltyPromotionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateLoyaltyRewardRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateLoyaltyRewardRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateLoyaltyRewardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateLoyaltyRewardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateMerchantCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateMerchantCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateMerchantCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateMerchantCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateMobileAuthorizationCodeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateMobileAuthorizationCodeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateMobileAuthorizationCodeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateMobileAuthorizationCodeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateOrderCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateOrderCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateOrderCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateOrderCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateOrderRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateOrderRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateOrderResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateOrderResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreatePaymentLinkRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreatePaymentLinkRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreatePaymentLinkResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreatePaymentLinkResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreatePaymentRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreatePaymentRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreatePaymentResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreatePaymentResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateRefundRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateRefundRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateRefundResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateRefundResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateShiftRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateShiftRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateShiftResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateShiftResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateSubscriptionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateSubscriptionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateSubscriptionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateSubscriptionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateTeamMemberRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateTeamMemberRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateTeamMemberResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateTeamMemberResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateTerminalActionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateTerminalActionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateTerminalActionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateTerminalActionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateTerminalCheckoutRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateTerminalCheckoutRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateTerminalCheckoutResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateTerminalCheckoutResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateTerminalRefundRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateTerminalRefundRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateTerminalRefundResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateTerminalRefundResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateVendorRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateVendorRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateVendorResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateVendorResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateWebhookSubscriptionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateWebhookSubscriptionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CreateWebhookSubscriptionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CreateWebhookSubscriptionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomAttributeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomAttributeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomAttributeDefinitionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomAttributeDefinitionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomAttributeFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomAttributeFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomFieldBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomFieldBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerAddressFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerAddressFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerCreationSourceFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerCreationSourceFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerCustomAttributeFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerCustomAttributeFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerCustomAttributeFilterValueBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerCustomAttributeFilterValueBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerCustomAttributeFiltersBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerCustomAttributeFiltersBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerGroupBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerGroupBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerPreferencesBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerPreferencesBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerSegmentBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerSegmentBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerSortBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerSortBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerTaxIdsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerTaxIdsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\CustomerTextFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/CustomerTextFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DataCollectionOptionsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DataCollectionOptionsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DateRangeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DateRangeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteBookingCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteBookingCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteBookingCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteBookingCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteBreakTypeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteBreakTypeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteCatalogObjectResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteCatalogObjectResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteCustomerCardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteCustomerCardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteCustomerCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteCustomerCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteCustomerCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteCustomerCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteCustomerGroupResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteCustomerGroupResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteCustomerRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteCustomerRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteCustomerResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteCustomerResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteDisputeEvidenceResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteDisputeEvidenceResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteInvoiceAttachmentResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteInvoiceAttachmentResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteInvoiceRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteInvoiceRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteInvoiceResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteInvoiceResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteLocationCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteLocationCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteLocationCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteLocationCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteLoyaltyRewardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteLoyaltyRewardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteMerchantCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteMerchantCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteMerchantCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteMerchantCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteOrderCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteOrderCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteOrderCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteOrderCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeletePaymentLinkResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeletePaymentLinkResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteShiftResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteShiftResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteSnippetResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteSnippetResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteSubscriptionActionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteSubscriptionActionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeleteWebhookSubscriptionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeleteWebhookSubscriptionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeprecatedCreateDisputeEvidenceFileRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeprecatedCreateDisputeEvidenceFileRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeprecatedCreateDisputeEvidenceFileResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeprecatedCreateDisputeEvidenceFileResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeprecatedCreateDisputeEvidenceTextRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeprecatedCreateDisputeEvidenceTextRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeprecatedCreateDisputeEvidenceTextResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeprecatedCreateDisputeEvidenceTextResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DestinationBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DestinationBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DestinationDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DestinationDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DestinationDetailsCardRefundDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DestinationDetailsCardRefundDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DestinationDetailsCashRefundDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DestinationDetailsCashRefundDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DestinationDetailsExternalRefundDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DestinationDetailsExternalRefundDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceAttributesBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceAttributesBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceCheckoutOptionsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceCheckoutOptionsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceCodeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceCodeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceComponentDetailsApplicationDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceComponentDetailsApplicationDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceComponentDetailsBatteryDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceComponentDetailsBatteryDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceComponentDetailsCardReaderDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceComponentDetailsCardReaderDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceComponentDetailsEthernetDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceComponentDetailsEthernetDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceComponentDetailsMeasurementBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceComponentDetailsMeasurementBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceComponentDetailsNetworkInterfaceDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceComponentDetailsNetworkInterfaceDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceComponentDetailsWiFiDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceComponentDetailsWiFiDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceMetadataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceMetadataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DeviceStatusBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DeviceStatusBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DigitalWalletDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DigitalWalletDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DisableCardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DisableCardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DisableEventsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DisableEventsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DismissTerminalActionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DismissTerminalActionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DismissTerminalCheckoutResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DismissTerminalCheckoutResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DismissTerminalRefundResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DismissTerminalRefundResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DisputeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DisputeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DisputeEvidenceBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DisputeEvidenceBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DisputeEvidenceFileBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DisputeEvidenceFileBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\DisputedPaymentBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/DisputedPaymentBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\EmployeeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/EmployeeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\EmployeeWageBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/EmployeeWageBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\EnableEventsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/EnableEventsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ErrorBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ErrorBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\EventBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/EventBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\EventDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/EventDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\EventMetadataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/EventMetadataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\EventTypeMetadataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/EventTypeMetadataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ExternalPaymentDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ExternalPaymentDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\FilterValueBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/FilterValueBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\FloatNumberRangeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/FloatNumberRangeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\FulfillmentBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/FulfillmentBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\FulfillmentDeliveryDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/FulfillmentDeliveryDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\FulfillmentFulfillmentEntryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/FulfillmentFulfillmentEntryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\FulfillmentPickupDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/FulfillmentPickupDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\FulfillmentPickupDetailsCurbsidePickupDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/FulfillmentPickupDetailsCurbsidePickupDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\FulfillmentRecipientBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/FulfillmentRecipientBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\FulfillmentShipmentDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/FulfillmentShipmentDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetBankAccountByV1IdResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetBankAccountByV1IdResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetBankAccountResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetBankAccountResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetBreakTypeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetBreakTypeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetDeviceCodeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetDeviceCodeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetDeviceResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetDeviceResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetEmployeeWageResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetEmployeeWageResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetInvoiceResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetInvoiceResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetPaymentRefundResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetPaymentRefundResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetPaymentResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetPaymentResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetPayoutResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetPayoutResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetShiftResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetShiftResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetTeamMemberWageResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetTeamMemberWageResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetTerminalActionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetTerminalActionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetTerminalCheckoutResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetTerminalCheckoutResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GetTerminalRefundResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GetTerminalRefundResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityActivateBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityActivateBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityAdjustDecrementBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityAdjustDecrementBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityAdjustIncrementBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityAdjustIncrementBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityBlockBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityBlockBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityClearBalanceBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityClearBalanceBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityDeactivateBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityDeactivateBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityImportBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityImportBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityImportReversalBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityImportReversalBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityLoadBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityLoadBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityRedeemBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityRedeemBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityRefundBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityRefundBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityTransferBalanceFromBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityTransferBalanceFromBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityTransferBalanceToBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityTransferBalanceToBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityUnblockBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityUnblockBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardActivityUnlinkedActivityRefundBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardActivityUnlinkedActivityRefundBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\GiftCardBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/GiftCardBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InventoryAdjustmentBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InventoryAdjustmentBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InventoryAdjustmentGroupBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InventoryAdjustmentGroupBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InventoryChangeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InventoryChangeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InventoryCountBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InventoryCountBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InventoryPhysicalCountBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InventoryPhysicalCountBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InventoryTransferBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InventoryTransferBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InvoiceAcceptedPaymentMethodsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InvoiceAcceptedPaymentMethodsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InvoiceAttachmentBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InvoiceAttachmentBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InvoiceBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InvoiceBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InvoiceCustomFieldBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InvoiceCustomFieldBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InvoiceFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InvoiceFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InvoicePaymentReminderBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InvoicePaymentReminderBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InvoicePaymentRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InvoicePaymentRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InvoiceQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InvoiceQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InvoiceRecipientBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InvoiceRecipientBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InvoiceRecipientTaxIdsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InvoiceRecipientTaxIdsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\InvoiceSortBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/InvoiceSortBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ItemVariationLocationOverridesBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ItemVariationLocationOverridesBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\JobAssignmentBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/JobAssignmentBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\JobBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/JobBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LinkCustomerToGiftCardRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LinkCustomerToGiftCardRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LinkCustomerToGiftCardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LinkCustomerToGiftCardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListBankAccountsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListBankAccountsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListBankAccountsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListBankAccountsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListBookingCustomAttributeDefinitionsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListBookingCustomAttributeDefinitionsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListBookingCustomAttributeDefinitionsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListBookingCustomAttributeDefinitionsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListBookingCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListBookingCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListBookingCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListBookingCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListBookingsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListBookingsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListBookingsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListBookingsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListBreakTypesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListBreakTypesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListBreakTypesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListBreakTypesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCardsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCardsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCardsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCardsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCashDrawerShiftEventsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCashDrawerShiftEventsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCashDrawerShiftEventsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCashDrawerShiftEventsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCashDrawerShiftsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCashDrawerShiftsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCashDrawerShiftsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCashDrawerShiftsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCatalogRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCatalogRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCatalogResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCatalogResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCustomerCustomAttributeDefinitionsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCustomerCustomAttributeDefinitionsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCustomerCustomAttributeDefinitionsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCustomerCustomAttributeDefinitionsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCustomerCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCustomerCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCustomerCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCustomerCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCustomerGroupsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCustomerGroupsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCustomerGroupsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCustomerGroupsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCustomerSegmentsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCustomerSegmentsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCustomerSegmentsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCustomerSegmentsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCustomersRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCustomersRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListCustomersResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListCustomersResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListDeviceCodesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListDeviceCodesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListDeviceCodesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListDeviceCodesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListDevicesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListDevicesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListDevicesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListDevicesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListDisputeEvidenceRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListDisputeEvidenceRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListDisputeEvidenceResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListDisputeEvidenceResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListDisputesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListDisputesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListDisputesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListDisputesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListEmployeeWagesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListEmployeeWagesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListEmployeeWagesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListEmployeeWagesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListEmployeesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListEmployeesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListEmployeesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListEmployeesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListEventTypesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListEventTypesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListEventTypesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListEventTypesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListGiftCardActivitiesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListGiftCardActivitiesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListGiftCardActivitiesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListGiftCardActivitiesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListGiftCardsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListGiftCardsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListGiftCardsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListGiftCardsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListInvoicesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListInvoicesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListInvoicesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListInvoicesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListJobsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListJobsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListJobsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListJobsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListLocationBookingProfilesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListLocationBookingProfilesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListLocationBookingProfilesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListLocationBookingProfilesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListLocationCustomAttributeDefinitionsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListLocationCustomAttributeDefinitionsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListLocationCustomAttributeDefinitionsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListLocationCustomAttributeDefinitionsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListLocationCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListLocationCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListLocationCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListLocationCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListLocationsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListLocationsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListLoyaltyProgramsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListLoyaltyProgramsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListLoyaltyPromotionsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListLoyaltyPromotionsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListLoyaltyPromotionsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListLoyaltyPromotionsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListMerchantCustomAttributeDefinitionsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListMerchantCustomAttributeDefinitionsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListMerchantCustomAttributeDefinitionsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListMerchantCustomAttributeDefinitionsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListMerchantCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListMerchantCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListMerchantCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListMerchantCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListMerchantsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListMerchantsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListMerchantsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListMerchantsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListOrderCustomAttributeDefinitionsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListOrderCustomAttributeDefinitionsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListOrderCustomAttributeDefinitionsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListOrderCustomAttributeDefinitionsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListOrderCustomAttributesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListOrderCustomAttributesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListOrderCustomAttributesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListOrderCustomAttributesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListPaymentLinksRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListPaymentLinksRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListPaymentLinksResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListPaymentLinksResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListPaymentRefundsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListPaymentRefundsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListPaymentRefundsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListPaymentRefundsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListPaymentsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListPaymentsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListPaymentsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListPaymentsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListPayoutEntriesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListPayoutEntriesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListPayoutEntriesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListPayoutEntriesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListPayoutsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListPayoutsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListPayoutsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListPayoutsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListRefundsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListRefundsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListRefundsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListRefundsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListSitesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListSitesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListSubscriptionEventsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListSubscriptionEventsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListSubscriptionEventsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListSubscriptionEventsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListTeamMemberBookingProfilesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListTeamMemberBookingProfilesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListTeamMemberBookingProfilesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListTeamMemberBookingProfilesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListTeamMemberWagesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListTeamMemberWagesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListTeamMemberWagesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListTeamMemberWagesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListTransactionsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListTransactionsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListTransactionsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListTransactionsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListWebhookEventTypesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListWebhookEventTypesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListWebhookEventTypesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListWebhookEventTypesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListWebhookSubscriptionsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListWebhookSubscriptionsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListWebhookSubscriptionsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListWebhookSubscriptionsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListWorkweekConfigsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListWorkweekConfigsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ListWorkweekConfigsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ListWorkweekConfigsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LocationBookingProfileBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LocationBookingProfileBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LocationBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LocationBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyAccountBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyAccountBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyAccountExpiringPointDeadlineBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyAccountExpiringPointDeadlineBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyAccountMappingBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyAccountMappingBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventAccumulatePointsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventAccumulatePointsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventAccumulatePromotionPointsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventAccumulatePromotionPointsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventAdjustPointsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventAdjustPointsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventCreateRewardBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventCreateRewardBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventDateTimeFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventDateTimeFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventDeleteRewardBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventDeleteRewardBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventExpirePointsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventExpirePointsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventLocationFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventLocationFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventLoyaltyAccountFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventLoyaltyAccountFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventOrderFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventOrderFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventOtherBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventOtherBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventRedeemRewardBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventRedeemRewardBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyEventTypeFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyEventTypeFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyProgramAccrualRuleBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyProgramAccrualRuleBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyProgramAccrualRuleCategoryDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyProgramAccrualRuleCategoryDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyProgramAccrualRuleItemVariationDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyProgramAccrualRuleItemVariationDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyProgramAccrualRuleSpendDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyProgramAccrualRuleSpendDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyProgramAccrualRuleVisitDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyProgramAccrualRuleVisitDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyProgramBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyProgramBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyProgramExpirationPolicyBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyProgramExpirationPolicyBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyProgramRewardDefinitionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyProgramRewardDefinitionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyProgramRewardTierBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyProgramRewardTierBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyProgramTerminologyBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyProgramTerminologyBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyPromotionAvailableTimeDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyPromotionAvailableTimeDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyPromotionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyPromotionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyPromotionIncentiveBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyPromotionIncentiveBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyPromotionIncentivePointsAdditionDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyPromotionIncentivePointsAdditionDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyPromotionIncentivePointsMultiplierDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyPromotionIncentivePointsMultiplierDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyPromotionTriggerLimitBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyPromotionTriggerLimitBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\LoyaltyRewardBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/LoyaltyRewardBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\MBreakBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/MBreakBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\MeasurementUnitBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/MeasurementUnitBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\MeasurementUnitCustomBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/MeasurementUnitCustomBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\MerchantBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/MerchantBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ModifierLocationOverridesBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ModifierLocationOverridesBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\MoneyBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/MoneyBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ObtainTokenRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ObtainTokenRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ObtainTokenResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ObtainTokenResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OfflinePaymentDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OfflinePaymentDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderCreatedBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderCreatedBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderCreatedObjectBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderCreatedObjectBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderEntryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderEntryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderFulfillmentBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderFulfillmentBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderFulfillmentDeliveryDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderFulfillmentDeliveryDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderFulfillmentFulfillmentEntryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderFulfillmentFulfillmentEntryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderFulfillmentPickupDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderFulfillmentPickupDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderFulfillmentPickupDetailsCurbsidePickupDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderFulfillmentPickupDetailsCurbsidePickupDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderFulfillmentRecipientBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderFulfillmentRecipientBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderFulfillmentShipmentDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderFulfillmentShipmentDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderFulfillmentUpdatedBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderFulfillmentUpdatedBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderFulfillmentUpdatedObjectBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderFulfillmentUpdatedObjectBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderFulfillmentUpdatedUpdateBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderFulfillmentUpdatedUpdateBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderLineItemAppliedDiscountBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderLineItemAppliedDiscountBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderLineItemAppliedServiceChargeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderLineItemAppliedServiceChargeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderLineItemAppliedTaxBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderLineItemAppliedTaxBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderLineItemBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderLineItemBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderLineItemDiscountBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderLineItemDiscountBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderLineItemModifierBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderLineItemModifierBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderLineItemPricingBlocklistsBlockedDiscountBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderLineItemPricingBlocklistsBlockedDiscountBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderLineItemPricingBlocklistsBlockedTaxBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderLineItemPricingBlocklistsBlockedTaxBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderLineItemPricingBlocklistsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderLineItemPricingBlocklistsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderLineItemTaxBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderLineItemTaxBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderMoneyAmountsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderMoneyAmountsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderPricingOptionsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderPricingOptionsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderQuantityUnitBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderQuantityUnitBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderReturnBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderReturnBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderReturnDiscountBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderReturnDiscountBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderReturnLineItemBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderReturnLineItemBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderReturnLineItemModifierBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderReturnLineItemModifierBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderReturnServiceChargeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderReturnServiceChargeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderReturnTaxBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderReturnTaxBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderReturnTipBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderReturnTipBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderRewardBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderRewardBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderRoundingAdjustmentBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderRoundingAdjustmentBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderServiceChargeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderServiceChargeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderSourceBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderSourceBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderUpdatedBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderUpdatedBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\OrderUpdatedObjectBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/OrderUpdatedObjectBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaginationCursorBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaginationCursorBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PauseSubscriptionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PauseSubscriptionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PauseSubscriptionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PauseSubscriptionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PayOrderRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PayOrderRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PayOrderResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PayOrderResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityAppFeeRefundDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityAppFeeRefundDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityAppFeeRevenueDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityAppFeeRevenueDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityAutomaticSavingsDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityAutomaticSavingsDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityAutomaticSavingsReversedDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityAutomaticSavingsReversedDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityChargeDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityChargeDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityDepositFeeDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityDepositFeeDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityDepositFeeReversedDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityDepositFeeReversedDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityDisputeDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityDisputeDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityFeeDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityFeeDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityFreeProcessingDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityFreeProcessingDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityHoldAdjustmentDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityHoldAdjustmentDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityOpenDisputeDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityOpenDisputeDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityOtherAdjustmentDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityOtherAdjustmentDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityOtherDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityOtherDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityRefundDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityRefundDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityReleaseAdjustmentDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityReleaseAdjustmentDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityReserveHoldDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityReserveHoldDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityReserveReleaseDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityReserveReleaseDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivitySquareCapitalPaymentDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivitySquareCapitalPaymentDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivitySquareCapitalReversedPaymentDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivitySquareCapitalReversedPaymentDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivitySquarePayrollTransferDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivitySquarePayrollTransferDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivitySquarePayrollTransferReversedDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivitySquarePayrollTransferReversedDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityTaxOnFeeDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityTaxOnFeeDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityThirdPartyFeeDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityThirdPartyFeeDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBalanceActivityThirdPartyFeeRefundDetailBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBalanceActivityThirdPartyFeeRefundDetailBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentLinkBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentLinkBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentLinkRelatedResourcesBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentLinkRelatedResourcesBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentOptionsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentOptionsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PaymentRefundBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PaymentRefundBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PayoutBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PayoutBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PayoutEntryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PayoutEntryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PayoutFeeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PayoutFeeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PhaseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PhaseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PhaseInputBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PhaseInputBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PrePopulatedDataBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PrePopulatedDataBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ProcessingFeeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ProcessingFeeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PublishInvoiceRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PublishInvoiceRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\PublishInvoiceResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/PublishInvoiceResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\QrCodeOptionsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/QrCodeOptionsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\QuantityRatioBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/QuantityRatioBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\QuickPayBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/QuickPayBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RangeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RangeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ReceiptOptionsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ReceiptOptionsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RedeemLoyaltyRewardRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RedeemLoyaltyRewardRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RedeemLoyaltyRewardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RedeemLoyaltyRewardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RefundBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RefundBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RefundPaymentRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RefundPaymentRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RefundPaymentResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RefundPaymentResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RegisterDomainRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RegisterDomainRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RegisterDomainResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RegisterDomainResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RemoveGroupFromCustomerResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RemoveGroupFromCustomerResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ResumeSubscriptionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ResumeSubscriptionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ResumeSubscriptionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ResumeSubscriptionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveBookingCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveBookingCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveBookingCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveBookingCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveBookingCustomAttributeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveBookingCustomAttributeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveBookingCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveBookingCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveBookingResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveBookingResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveBusinessBookingProfileResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveBusinessBookingProfileResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveCardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveCardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveCashDrawerShiftRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveCashDrawerShiftRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveCashDrawerShiftResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveCashDrawerShiftResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveCatalogObjectRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveCatalogObjectRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveCatalogObjectResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveCatalogObjectResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveCustomerCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveCustomerCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveCustomerCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveCustomerCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveCustomerCustomAttributeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveCustomerCustomAttributeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveCustomerCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveCustomerCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveCustomerGroupResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveCustomerGroupResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveCustomerResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveCustomerResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveCustomerSegmentResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveCustomerSegmentResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveDisputeEvidenceResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveDisputeEvidenceResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveDisputeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveDisputeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveEmployeeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveEmployeeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveGiftCardFromGANRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveGiftCardFromGANRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveGiftCardFromGANResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveGiftCardFromGANResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveGiftCardFromNonceRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveGiftCardFromNonceRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveGiftCardFromNonceResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveGiftCardFromNonceResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveGiftCardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveGiftCardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveInventoryAdjustmentResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveInventoryAdjustmentResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveInventoryChangesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveInventoryChangesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveInventoryChangesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveInventoryChangesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveInventoryCountRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveInventoryCountRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveInventoryCountResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveInventoryCountResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveInventoryPhysicalCountResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveInventoryPhysicalCountResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveInventoryTransferResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveInventoryTransferResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveJobResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveJobResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveLocationBookingProfileResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveLocationBookingProfileResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveLocationCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveLocationCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveLocationCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveLocationCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveLocationCustomAttributeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveLocationCustomAttributeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveLocationCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveLocationCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveLocationResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveLocationResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveLocationSettingsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveLocationSettingsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveLoyaltyAccountResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveLoyaltyAccountResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveLoyaltyProgramResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveLoyaltyProgramResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveLoyaltyPromotionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveLoyaltyPromotionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveLoyaltyRewardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveLoyaltyRewardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveMerchantCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveMerchantCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveMerchantCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveMerchantCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveMerchantCustomAttributeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveMerchantCustomAttributeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveMerchantCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveMerchantCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveMerchantResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveMerchantResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveMerchantSettingsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveMerchantSettingsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveOrderCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveOrderCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveOrderCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveOrderCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveOrderCustomAttributeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveOrderCustomAttributeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveOrderCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveOrderCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveOrderResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveOrderResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrievePaymentLinkResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrievePaymentLinkResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveSnippetResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveSnippetResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveSubscriptionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveSubscriptionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveSubscriptionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveSubscriptionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveTeamMemberBookingProfileResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveTeamMemberBookingProfileResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveTeamMemberResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveTeamMemberResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveTokenStatusResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveTokenStatusResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveTransactionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveTransactionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveVendorResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveVendorResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveWageSettingResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveWageSettingResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RetrieveWebhookSubscriptionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RetrieveWebhookSubscriptionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RevokeTokenRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RevokeTokenRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RevokeTokenResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RevokeTokenResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\RiskEvaluationBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/RiskEvaluationBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SaveCardOptionsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SaveCardOptionsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchAvailabilityFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchAvailabilityFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchAvailabilityQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchAvailabilityQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchAvailabilityRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchAvailabilityRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchAvailabilityResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchAvailabilityResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchCatalogItemsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchCatalogItemsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchCatalogItemsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchCatalogItemsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchCatalogObjectsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchCatalogObjectsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchCatalogObjectsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchCatalogObjectsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchCustomersRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchCustomersRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchCustomersResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchCustomersResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchEventsFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchEventsFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchEventsQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchEventsQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchEventsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchEventsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchEventsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchEventsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchEventsSortBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchEventsSortBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchInvoicesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchInvoicesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchInvoicesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchInvoicesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchLoyaltyAccountsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchLoyaltyAccountsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchLoyaltyAccountsRequestLoyaltyAccountQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchLoyaltyAccountsRequestLoyaltyAccountQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchLoyaltyAccountsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchLoyaltyAccountsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchLoyaltyEventsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchLoyaltyEventsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchLoyaltyEventsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchLoyaltyEventsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchLoyaltyRewardsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchLoyaltyRewardsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchLoyaltyRewardsRequestLoyaltyRewardQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchLoyaltyRewardsRequestLoyaltyRewardQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchLoyaltyRewardsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchLoyaltyRewardsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchOrdersCustomerFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchOrdersCustomerFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchOrdersDateTimeFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchOrdersDateTimeFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchOrdersFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchOrdersFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchOrdersFulfillmentFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchOrdersFulfillmentFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchOrdersQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchOrdersQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchOrdersRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchOrdersRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchOrdersResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchOrdersResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchOrdersSortBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchOrdersSortBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchOrdersSourceFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchOrdersSourceFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchOrdersStateFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchOrdersStateFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchShiftsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchShiftsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchShiftsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchShiftsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchSubscriptionsFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchSubscriptionsFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchSubscriptionsQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchSubscriptionsQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchSubscriptionsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchSubscriptionsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchSubscriptionsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchSubscriptionsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchTeamMembersFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchTeamMembersFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchTeamMembersQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchTeamMembersQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchTeamMembersRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchTeamMembersRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchTeamMembersResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchTeamMembersResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchTerminalActionsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchTerminalActionsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchTerminalActionsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchTerminalActionsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchTerminalCheckoutsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchTerminalCheckoutsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchTerminalCheckoutsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchTerminalCheckoutsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchTerminalRefundsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchTerminalRefundsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchTerminalRefundsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchTerminalRefundsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchVendorsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchVendorsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchVendorsRequestFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchVendorsRequestFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchVendorsRequestSortBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchVendorsRequestSortBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SearchVendorsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SearchVendorsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SegmentFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SegmentFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SelectOptionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SelectOptionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SelectOptionsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SelectOptionsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ShiftBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ShiftBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ShiftFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ShiftFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ShiftQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ShiftQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ShiftSortBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ShiftSortBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ShiftWageBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ShiftWageBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ShiftWorkdayBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ShiftWorkdayBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\ShippingFeeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/ShippingFeeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SignatureImageBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SignatureImageBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SignatureOptionsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SignatureOptionsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SiteBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SiteBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SnippetBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SnippetBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SnippetResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SnippetResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SourceApplicationBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SourceApplicationBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SquareAccountDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SquareAccountDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\StandardUnitDescriptionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/StandardUnitDescriptionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\StandardUnitDescriptionGroupBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/StandardUnitDescriptionGroupBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SubmitEvidenceResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SubmitEvidenceResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SubscriptionActionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SubscriptionActionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SubscriptionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SubscriptionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SubscriptionEventBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SubscriptionEventBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SubscriptionEventInfoBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SubscriptionEventInfoBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SubscriptionPhaseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SubscriptionPhaseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SubscriptionPricingBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SubscriptionPricingBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SubscriptionSourceBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SubscriptionSourceBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SubscriptionTestResultBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SubscriptionTestResultBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SwapPlanRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SwapPlanRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\SwapPlanResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/SwapPlanResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TaxIdsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TaxIdsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TeamMemberAssignedLocationsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TeamMemberAssignedLocationsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TeamMemberBookingProfileBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TeamMemberBookingProfileBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TeamMemberBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TeamMemberBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TeamMemberWageBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TeamMemberWageBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TenderBankAccountDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TenderBankAccountDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TenderBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TenderBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TenderBuyNowPayLaterDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TenderBuyNowPayLaterDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TenderCardDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TenderCardDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TenderCashDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TenderCashDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TenderSquareAccountDetailsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TenderSquareAccountDetailsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TerminalActionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TerminalActionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TerminalActionQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TerminalActionQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TerminalActionQueryFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TerminalActionQueryFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TerminalActionQuerySortBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TerminalActionQuerySortBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TerminalCheckoutBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TerminalCheckoutBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TerminalCheckoutQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TerminalCheckoutQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TerminalCheckoutQueryFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TerminalCheckoutQueryFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TerminalCheckoutQuerySortBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TerminalCheckoutQuerySortBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TerminalRefundBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TerminalRefundBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TerminalRefundQueryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TerminalRefundQueryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TerminalRefundQueryFilterBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TerminalRefundQueryFilterBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TerminalRefundQuerySortBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TerminalRefundQuerySortBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TestWebhookSubscriptionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TestWebhookSubscriptionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TestWebhookSubscriptionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TestWebhookSubscriptionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TimeRangeBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TimeRangeBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TipSettingsBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TipSettingsBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\TransactionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/TransactionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UnlinkCustomerFromGiftCardRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UnlinkCustomerFromGiftCardRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UnlinkCustomerFromGiftCardResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UnlinkCustomerFromGiftCardResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateBookingCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateBookingCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateBookingCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateBookingCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateBookingRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateBookingRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateBookingResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateBookingResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateBreakTypeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateBreakTypeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateBreakTypeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateBreakTypeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateCatalogImageRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateCatalogImageRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateCatalogImageResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateCatalogImageResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateCustomerCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateCustomerCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateCustomerCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateCustomerCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateCustomerGroupRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateCustomerGroupRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateCustomerGroupResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateCustomerGroupResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateCustomerRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateCustomerRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateCustomerResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateCustomerResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateInvoiceRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateInvoiceRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateInvoiceResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateInvoiceResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateItemModifierListsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateItemModifierListsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateItemModifierListsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateItemModifierListsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateItemTaxesRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateItemTaxesRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateItemTaxesResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateItemTaxesResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateJobRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateJobRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateJobResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateJobResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateLocationCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateLocationCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateLocationCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateLocationCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateLocationRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateLocationRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateLocationResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateLocationResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateLocationSettingsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateLocationSettingsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateLocationSettingsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateLocationSettingsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateMerchantCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateMerchantCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateMerchantCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateMerchantCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateMerchantSettingsRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateMerchantSettingsRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateMerchantSettingsResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateMerchantSettingsResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateOrderCustomAttributeDefinitionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateOrderCustomAttributeDefinitionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateOrderCustomAttributeDefinitionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateOrderCustomAttributeDefinitionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateOrderRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateOrderRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateOrderResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateOrderResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdatePaymentLinkRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdatePaymentLinkRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdatePaymentLinkResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdatePaymentLinkResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdatePaymentRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdatePaymentRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdatePaymentResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdatePaymentResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateShiftRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateShiftRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateShiftResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateShiftResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateSubscriptionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateSubscriptionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateSubscriptionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateSubscriptionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateTeamMemberRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateTeamMemberRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateTeamMemberResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateTeamMemberResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateVendorRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateVendorRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateVendorResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateVendorResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateWageSettingRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateWageSettingRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateWageSettingResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateWageSettingResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateWebhookSubscriptionRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateWebhookSubscriptionRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateWebhookSubscriptionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateWebhookSubscriptionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateWebhookSubscriptionSignatureKeyRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateWebhookSubscriptionSignatureKeyRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateWebhookSubscriptionSignatureKeyResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateWebhookSubscriptionSignatureKeyResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateWorkweekConfigRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateWorkweekConfigRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpdateWorkweekConfigResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpdateWorkweekConfigResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertBookingCustomAttributeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertBookingCustomAttributeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertBookingCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertBookingCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertCatalogObjectRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertCatalogObjectRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertCatalogObjectResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertCatalogObjectResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertCustomerCustomAttributeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertCustomerCustomAttributeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertCustomerCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertCustomerCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertLocationCustomAttributeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertLocationCustomAttributeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertLocationCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertLocationCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertMerchantCustomAttributeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertMerchantCustomAttributeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertMerchantCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertMerchantCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertOrderCustomAttributeRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertOrderCustomAttributeRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertOrderCustomAttributeResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertOrderCustomAttributeResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertSnippetRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertSnippetRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\UpsertSnippetResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/UpsertSnippetResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\V1DeviceBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/V1DeviceBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\V1ListOrdersRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/V1ListOrdersRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\V1ListOrdersResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/V1ListOrdersResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\V1MoneyBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/V1MoneyBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\V1OrderBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/V1OrderBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\V1OrderHistoryEntryBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/V1OrderHistoryEntryBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\V1PhoneNumberBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/V1PhoneNumberBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\V1TenderBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/V1TenderBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\V1UpdateOrderRequestBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/V1UpdateOrderRequestBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\VendorBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/VendorBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\VendorContactBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/VendorContactBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\VoidTransactionResponseBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/VoidTransactionResponseBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\WageSettingBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/WageSettingBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\WebhookSubscriptionBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/WebhookSubscriptionBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\Builders\\WorkweekConfigBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Builders/WorkweekConfigBuilder.php',
        'WPForms\\Vendor\\Square\\Models\\BulkCreateCustomerData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkCreateCustomerData.php',
        'WPForms\\Vendor\\Square\\Models\\BulkCreateCustomersRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkCreateCustomersRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkCreateCustomersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkCreateCustomersResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkCreateTeamMembersRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkCreateTeamMembersRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkCreateTeamMembersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkCreateTeamMembersResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkCreateVendorsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkCreateVendorsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkCreateVendorsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkCreateVendorsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteBookingCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteBookingCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteBookingCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteBookingCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteCustomersRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteCustomersRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteCustomersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteCustomersResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteLocationCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteLocationCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteLocationCustomAttributesRequestLocationCustomAttributeDeleteRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteLocationCustomAttributesRequestLocationCustomAttributeDeleteRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteLocationCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteLocationCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteLocationCustomAttributesResponseLocationCustomAttributeDeleteResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteLocationCustomAttributesResponseLocationCustomAttributeDeleteResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteMerchantCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteMerchantCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteMerchantCustomAttributesRequestMerchantCustomAttributeDeleteRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteMerchantCustomAttributesRequestMerchantCustomAttributeDeleteRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteMerchantCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteMerchantCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteMerchantCustomAttributesResponseMerchantCustomAttributeDeleteResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteMerchantCustomAttributesResponseMerchantCustomAttributeDeleteResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteOrderCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteOrderCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteOrderCustomAttributesRequestDeleteCustomAttribute' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteOrderCustomAttributesRequestDeleteCustomAttribute.php',
        'WPForms\\Vendor\\Square\\Models\\BulkDeleteOrderCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkDeleteOrderCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkRetrieveBookingsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkRetrieveBookingsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkRetrieveBookingsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkRetrieveBookingsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkRetrieveCustomersRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkRetrieveCustomersRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkRetrieveCustomersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkRetrieveCustomersResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkRetrieveTeamMemberBookingProfilesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkRetrieveTeamMemberBookingProfilesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkRetrieveTeamMemberBookingProfilesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkRetrieveTeamMemberBookingProfilesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkRetrieveVendorsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkRetrieveVendorsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkRetrieveVendorsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkRetrieveVendorsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkSwapPlanRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkSwapPlanRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkSwapPlanResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkSwapPlanResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpdateCustomerData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpdateCustomerData.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpdateCustomersRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpdateCustomersRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpdateCustomersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpdateCustomersResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpdateTeamMembersRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpdateTeamMembersRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpdateTeamMembersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpdateTeamMembersResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpdateVendorsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpdateVendorsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpdateVendorsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpdateVendorsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertBookingCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertBookingCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertBookingCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertBookingCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertCustomerCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertCustomerCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertCustomerCustomAttributesRequestCustomerCustomAttributeUpsertRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertCustomerCustomAttributesRequestCustomerCustomAttributeUpsertRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertCustomerCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertCustomerCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertCustomerCustomAttributesResponseCustomerCustomAttributeUpsertResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertCustomerCustomAttributesResponseCustomerCustomAttributeUpsertResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertLocationCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertLocationCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertLocationCustomAttributesRequestLocationCustomAttributeUpsertRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertLocationCustomAttributesRequestLocationCustomAttributeUpsertRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertLocationCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertLocationCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertLocationCustomAttributesResponseLocationCustomAttributeUpsertResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertLocationCustomAttributesResponseLocationCustomAttributeUpsertResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertMerchantCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertMerchantCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertMerchantCustomAttributesRequestMerchantCustomAttributeUpsertRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertMerchantCustomAttributesRequestMerchantCustomAttributeUpsertRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertMerchantCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertMerchantCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertMerchantCustomAttributesResponseMerchantCustomAttributeUpsertResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertMerchantCustomAttributesResponseMerchantCustomAttributeUpsertResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertOrderCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertOrderCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertOrderCustomAttributesRequestUpsertCustomAttribute' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertOrderCustomAttributesRequestUpsertCustomAttribute.php',
        'WPForms\\Vendor\\Square\\Models\\BulkUpsertOrderCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BulkUpsertOrderCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\BusinessAppointmentSettings' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BusinessAppointmentSettings.php',
        'WPForms\\Vendor\\Square\\Models\\BusinessAppointmentSettingsAlignmentTime' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BusinessAppointmentSettingsAlignmentTime.php',
        'WPForms\\Vendor\\Square\\Models\\BusinessAppointmentSettingsBookingLocationType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BusinessAppointmentSettingsBookingLocationType.php',
        'WPForms\\Vendor\\Square\\Models\\BusinessAppointmentSettingsCancellationPolicy' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BusinessAppointmentSettingsCancellationPolicy.php',
        'WPForms\\Vendor\\Square\\Models\\BusinessAppointmentSettingsMaxAppointmentsPerDayLimitType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BusinessAppointmentSettingsMaxAppointmentsPerDayLimitType.php',
        'WPForms\\Vendor\\Square\\Models\\BusinessBookingProfile' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BusinessBookingProfile.php',
        'WPForms\\Vendor\\Square\\Models\\BusinessBookingProfileBookingPolicy' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BusinessBookingProfileBookingPolicy.php',
        'WPForms\\Vendor\\Square\\Models\\BusinessBookingProfileCustomerTimezoneChoice' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BusinessBookingProfileCustomerTimezoneChoice.php',
        'WPForms\\Vendor\\Square\\Models\\BusinessHours' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BusinessHours.php',
        'WPForms\\Vendor\\Square\\Models\\BusinessHoursPeriod' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BusinessHoursPeriod.php',
        'WPForms\\Vendor\\Square\\Models\\BuyNowPayLaterDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/BuyNowPayLaterDetails.php',
        'WPForms\\Vendor\\Square\\Models\\CalculateLoyaltyPointsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CalculateLoyaltyPointsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CalculateLoyaltyPointsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CalculateLoyaltyPointsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CalculateOrderRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CalculateOrderRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CalculateOrderResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CalculateOrderResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CancelBookingRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CancelBookingRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CancelBookingResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CancelBookingResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CancelInvoiceRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CancelInvoiceRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CancelInvoiceResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CancelInvoiceResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CancelLoyaltyPromotionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CancelLoyaltyPromotionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CancelPaymentByIdempotencyKeyRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CancelPaymentByIdempotencyKeyRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CancelPaymentByIdempotencyKeyResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CancelPaymentByIdempotencyKeyResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CancelPaymentResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CancelPaymentResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CancelSubscriptionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CancelSubscriptionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CancelTerminalActionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CancelTerminalActionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CancelTerminalCheckoutResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CancelTerminalCheckoutResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CancelTerminalRefundResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CancelTerminalRefundResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CaptureTransactionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CaptureTransactionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\Card' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Card.php',
        'WPForms\\Vendor\\Square\\Models\\CardBrand' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CardBrand.php',
        'WPForms\\Vendor\\Square\\Models\\CardCoBrand' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CardCoBrand.php',
        'WPForms\\Vendor\\Square\\Models\\CardPaymentDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CardPaymentDetails.php',
        'WPForms\\Vendor\\Square\\Models\\CardPaymentTimeline' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CardPaymentTimeline.php',
        'WPForms\\Vendor\\Square\\Models\\CardPrepaidType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CardPrepaidType.php',
        'WPForms\\Vendor\\Square\\Models\\CardType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CardType.php',
        'WPForms\\Vendor\\Square\\Models\\CashAppDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CashAppDetails.php',
        'WPForms\\Vendor\\Square\\Models\\CashDrawerDevice' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CashDrawerDevice.php',
        'WPForms\\Vendor\\Square\\Models\\CashDrawerEventType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CashDrawerEventType.php',
        'WPForms\\Vendor\\Square\\Models\\CashDrawerShift' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CashDrawerShift.php',
        'WPForms\\Vendor\\Square\\Models\\CashDrawerShiftEvent' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CashDrawerShiftEvent.php',
        'WPForms\\Vendor\\Square\\Models\\CashDrawerShiftState' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CashDrawerShiftState.php',
        'WPForms\\Vendor\\Square\\Models\\CashDrawerShiftSummary' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CashDrawerShiftSummary.php',
        'WPForms\\Vendor\\Square\\Models\\CashPaymentDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CashPaymentDetails.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogAvailabilityPeriod' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogAvailabilityPeriod.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogCategory' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogCategory.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogCategoryType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogCategoryType.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogCustomAttributeDefinition' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogCustomAttributeDefinition.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogCustomAttributeDefinitionAppVisibility' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogCustomAttributeDefinitionAppVisibility.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogCustomAttributeDefinitionNumberConfig' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogCustomAttributeDefinitionNumberConfig.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogCustomAttributeDefinitionSelectionConfig' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogCustomAttributeDefinitionSelectionConfig.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogCustomAttributeDefinitionSelectionConfigCustomAttributeSelection' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogCustomAttributeDefinitionSelectionConfigCustomAttributeSelection.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogCustomAttributeDefinitionSellerVisibility' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogCustomAttributeDefinitionSellerVisibility.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogCustomAttributeDefinitionStringConfig' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogCustomAttributeDefinitionStringConfig.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogCustomAttributeDefinitionType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogCustomAttributeDefinitionType.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogCustomAttributeValue' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogCustomAttributeValue.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogDiscount' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogDiscount.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogDiscountModifyTaxBasis' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogDiscountModifyTaxBasis.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogDiscountType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogDiscountType.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogEcomSeoData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogEcomSeoData.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogIdMapping' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogIdMapping.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogImage' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogImage.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogInfoResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogInfoResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogInfoResponseLimits' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogInfoResponseLimits.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItem' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItem.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemFoodAndBeverageDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemFoodAndBeverageDetails.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemFoodAndBeverageDetailsDietaryPreference' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemFoodAndBeverageDetailsDietaryPreference.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemFoodAndBeverageDetailsDietaryPreferenceStandardDietaryPreference' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemFoodAndBeverageDetailsDietaryPreferenceStandardDietaryPreference.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemFoodAndBeverageDetailsDietaryPreferenceType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemFoodAndBeverageDetailsDietaryPreferenceType.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemFoodAndBeverageDetailsIngredient' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemFoodAndBeverageDetailsIngredient.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemFoodAndBeverageDetailsIngredientStandardIngredient' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemFoodAndBeverageDetailsIngredientStandardIngredient.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemModifierListInfo' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemModifierListInfo.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemOption' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemOption.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemOptionForItem' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemOptionForItem.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemOptionValue' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemOptionValue.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemOptionValueForItemVariation' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemOptionValueForItemVariation.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemProductType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemProductType.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogItemVariation' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogItemVariation.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogMeasurementUnit' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogMeasurementUnit.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogModifier' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogModifier.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogModifierList' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogModifierList.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogModifierListModifierType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogModifierListModifierType.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogModifierListSelectionType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogModifierListSelectionType.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogModifierOverride' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogModifierOverride.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogObject' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogObject.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogObjectBatch' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogObjectBatch.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogObjectCategory' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogObjectCategory.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogObjectReference' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogObjectReference.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogObjectType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogObjectType.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogPricingRule' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogPricingRule.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogPricingType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogPricingType.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogProductSet' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogProductSet.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQuery.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQueryExact' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQueryExact.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQueryItemVariationsForItemOptionValues' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQueryItemVariationsForItemOptionValues.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQueryItemsForItemOptions' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQueryItemsForItemOptions.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQueryItemsForModifierList' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQueryItemsForModifierList.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQueryItemsForTax' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQueryItemsForTax.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQueryPrefix' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQueryPrefix.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQueryRange' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQueryRange.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQuerySet' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQuerySet.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQuerySortedAttribute' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQuerySortedAttribute.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQueryText' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQueryText.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQuickAmount' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQuickAmount.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQuickAmountType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQuickAmountType.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQuickAmountsSettings' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQuickAmountsSettings.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogQuickAmountsSettingsOption' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogQuickAmountsSettingsOption.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogStockConversion' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogStockConversion.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogSubscriptionPlan' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogSubscriptionPlan.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogSubscriptionPlanVariation' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogSubscriptionPlanVariation.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogTax' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogTax.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogTimePeriod' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogTimePeriod.php',
        'WPForms\\Vendor\\Square\\Models\\CatalogV1Id' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CatalogV1Id.php',
        'WPForms\\Vendor\\Square\\Models\\CategoryPathToRootNode' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CategoryPathToRootNode.php',
        'WPForms\\Vendor\\Square\\Models\\ChangeBillingAnchorDateRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ChangeBillingAnchorDateRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ChangeBillingAnchorDateResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ChangeBillingAnchorDateResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ChangeTiming' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ChangeTiming.php',
        'WPForms\\Vendor\\Square\\Models\\ChargeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ChargeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ChargeRequestAdditionalRecipient' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ChargeRequestAdditionalRecipient.php',
        'WPForms\\Vendor\\Square\\Models\\ChargeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ChargeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\Checkout' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Checkout.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutLocationSettings' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutLocationSettings.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutLocationSettingsBranding' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutLocationSettingsBranding.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutLocationSettingsBrandingButtonShape' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutLocationSettingsBrandingButtonShape.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutLocationSettingsBrandingHeaderType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutLocationSettingsBrandingHeaderType.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutLocationSettingsCoupons' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutLocationSettingsCoupons.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutLocationSettingsPolicy' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutLocationSettingsPolicy.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutLocationSettingsTipping' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutLocationSettingsTipping.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutMerchantSettings' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutMerchantSettings.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutMerchantSettingsPaymentMethods' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutMerchantSettingsPaymentMethods.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutMerchantSettingsPaymentMethodsAfterpayClearpay' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutMerchantSettingsPaymentMethodsAfterpayClearpay.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayEligibilityRange' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayEligibilityRange.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutMerchantSettingsPaymentMethodsPaymentMethod' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutMerchantSettingsPaymentMethodsPaymentMethod.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutOptions' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutOptions.php',
        'WPForms\\Vendor\\Square\\Models\\CheckoutOptionsPaymentType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CheckoutOptionsPaymentType.php',
        'WPForms\\Vendor\\Square\\Models\\ClearpayDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ClearpayDetails.php',
        'WPForms\\Vendor\\Square\\Models\\CloneOrderRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CloneOrderRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CloneOrderResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CloneOrderResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CollectedData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CollectedData.php',
        'WPForms\\Vendor\\Square\\Models\\CompletePaymentRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CompletePaymentRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CompletePaymentResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CompletePaymentResponse.php',
        'WPForms\\Vendor\\Square\\Models\\Component' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Component.php',
        'WPForms\\Vendor\\Square\\Models\\ComponentComponentType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ComponentComponentType.php',
        'WPForms\\Vendor\\Square\\Models\\ConfirmationDecision' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ConfirmationDecision.php',
        'WPForms\\Vendor\\Square\\Models\\ConfirmationOptions' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ConfirmationOptions.php',
        'WPForms\\Vendor\\Square\\Models\\Coordinates' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Coordinates.php',
        'WPForms\\Vendor\\Square\\Models\\Country' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Country.php',
        'WPForms\\Vendor\\Square\\Models\\CreateBookingCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateBookingCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateBookingCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateBookingCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateBookingRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateBookingRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateBookingResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateBookingResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateBreakTypeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateBreakTypeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateBreakTypeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateBreakTypeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCardRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCardRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCatalogImageRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCatalogImageRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCatalogImageResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCatalogImageResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCheckoutRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCheckoutRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCheckoutResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCheckoutResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCustomerCardRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCustomerCardRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCustomerCardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCustomerCardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCustomerCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCustomerCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCustomerCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCustomerCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCustomerGroupRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCustomerGroupRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCustomerGroupResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCustomerGroupResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCustomerRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCustomerRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateCustomerResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateCustomerResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateDeviceCodeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateDeviceCodeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateDeviceCodeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateDeviceCodeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateDisputeEvidenceFileRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateDisputeEvidenceFileRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateDisputeEvidenceFileResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateDisputeEvidenceFileResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateDisputeEvidenceTextRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateDisputeEvidenceTextRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateDisputeEvidenceTextResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateDisputeEvidenceTextResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateGiftCardActivityRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateGiftCardActivityRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateGiftCardActivityResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateGiftCardActivityResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateGiftCardRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateGiftCardRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateGiftCardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateGiftCardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateInvoiceAttachmentRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateInvoiceAttachmentRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateInvoiceAttachmentResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateInvoiceAttachmentResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateInvoiceRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateInvoiceRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateInvoiceResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateInvoiceResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateJobRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateJobRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateJobResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateJobResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateLocationCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateLocationCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateLocationCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateLocationCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateLocationRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateLocationRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateLocationResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateLocationResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateLoyaltyAccountRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateLoyaltyAccountRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateLoyaltyAccountResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateLoyaltyAccountResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateLoyaltyPromotionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateLoyaltyPromotionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateLoyaltyPromotionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateLoyaltyPromotionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateLoyaltyRewardRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateLoyaltyRewardRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateLoyaltyRewardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateLoyaltyRewardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateMerchantCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateMerchantCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateMerchantCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateMerchantCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateMobileAuthorizationCodeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateMobileAuthorizationCodeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateMobileAuthorizationCodeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateMobileAuthorizationCodeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateOrderCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateOrderCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateOrderCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateOrderCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateOrderRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateOrderRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateOrderResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateOrderResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreatePaymentLinkRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreatePaymentLinkRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreatePaymentLinkResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreatePaymentLinkResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreatePaymentRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreatePaymentRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreatePaymentResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreatePaymentResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateRefundRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateRefundRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateRefundResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateRefundResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateShiftRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateShiftRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateShiftResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateShiftResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateSubscriptionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateSubscriptionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateSubscriptionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateSubscriptionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateTeamMemberRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateTeamMemberRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateTeamMemberResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateTeamMemberResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateTerminalActionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateTerminalActionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateTerminalActionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateTerminalActionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateTerminalCheckoutRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateTerminalCheckoutRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateTerminalCheckoutResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateTerminalCheckoutResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateTerminalRefundRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateTerminalRefundRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateTerminalRefundResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateTerminalRefundResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateVendorRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateVendorRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateVendorResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateVendorResponse.php',
        'WPForms\\Vendor\\Square\\Models\\CreateWebhookSubscriptionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateWebhookSubscriptionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\CreateWebhookSubscriptionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CreateWebhookSubscriptionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\Currency' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Currency.php',
        'WPForms\\Vendor\\Square\\Models\\CustomAttribute' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomAttribute.php',
        'WPForms\\Vendor\\Square\\Models\\CustomAttributeDefinition' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomAttributeDefinition.php',
        'WPForms\\Vendor\\Square\\Models\\CustomAttributeDefinitionVisibility' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomAttributeDefinitionVisibility.php',
        'WPForms\\Vendor\\Square\\Models\\CustomAttributeFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomAttributeFilter.php',
        'WPForms\\Vendor\\Square\\Models\\CustomField' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomField.php',
        'WPForms\\Vendor\\Square\\Models\\Customer' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Customer.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerAddressFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerAddressFilter.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerCreationSource' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerCreationSource.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerCreationSourceFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerCreationSourceFilter.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerCustomAttributeFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerCustomAttributeFilter.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerCustomAttributeFilterValue' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerCustomAttributeFilterValue.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerCustomAttributeFilters' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerCustomAttributeFilters.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerDetails.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerFilter.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerGroup' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerGroup.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerInclusionExclusion' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerInclusionExclusion.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerPreferences' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerPreferences.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerQuery.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerSegment' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerSegment.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerSort' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerSort.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerSortField' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerSortField.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerTaxIds' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerTaxIds.php',
        'WPForms\\Vendor\\Square\\Models\\CustomerTextFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/CustomerTextFilter.php',
        'WPForms\\Vendor\\Square\\Models\\DataCollectionOptions' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DataCollectionOptions.php',
        'WPForms\\Vendor\\Square\\Models\\DataCollectionOptionsInputType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DataCollectionOptionsInputType.php',
        'WPForms\\Vendor\\Square\\Models\\DateRange' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DateRange.php',
        'WPForms\\Vendor\\Square\\Models\\DayOfWeek' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DayOfWeek.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteBookingCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteBookingCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteBookingCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteBookingCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteBreakTypeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteBreakTypeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteCatalogObjectResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteCatalogObjectResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteCustomerCardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteCustomerCardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteCustomerCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteCustomerCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteCustomerCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteCustomerCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteCustomerGroupResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteCustomerGroupResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteCustomerRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteCustomerRequest.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteCustomerResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteCustomerResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteDisputeEvidenceResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteDisputeEvidenceResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteInvoiceAttachmentResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteInvoiceAttachmentResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteInvoiceRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteInvoiceRequest.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteInvoiceResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteInvoiceResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteLocationCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteLocationCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteLocationCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteLocationCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteLoyaltyRewardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteLoyaltyRewardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteMerchantCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteMerchantCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteMerchantCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteMerchantCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteOrderCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteOrderCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteOrderCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteOrderCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeletePaymentLinkResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeletePaymentLinkResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteShiftResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteShiftResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteSnippetResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteSnippetResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteSubscriptionActionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteSubscriptionActionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeleteWebhookSubscriptionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeleteWebhookSubscriptionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeprecatedCreateDisputeEvidenceFileRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeprecatedCreateDisputeEvidenceFileRequest.php',
        'WPForms\\Vendor\\Square\\Models\\DeprecatedCreateDisputeEvidenceFileResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeprecatedCreateDisputeEvidenceFileResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DeprecatedCreateDisputeEvidenceTextRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeprecatedCreateDisputeEvidenceTextRequest.php',
        'WPForms\\Vendor\\Square\\Models\\DeprecatedCreateDisputeEvidenceTextResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeprecatedCreateDisputeEvidenceTextResponse.php',
        'WPForms\\Vendor\\Square\\Models\\Destination' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Destination.php',
        'WPForms\\Vendor\\Square\\Models\\DestinationDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DestinationDetails.php',
        'WPForms\\Vendor\\Square\\Models\\DestinationDetailsCardRefundDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DestinationDetailsCardRefundDetails.php',
        'WPForms\\Vendor\\Square\\Models\\DestinationDetailsCashRefundDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DestinationDetailsCashRefundDetails.php',
        'WPForms\\Vendor\\Square\\Models\\DestinationDetailsExternalRefundDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DestinationDetailsExternalRefundDetails.php',
        'WPForms\\Vendor\\Square\\Models\\DestinationType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DestinationType.php',
        'WPForms\\Vendor\\Square\\Models\\Device' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Device.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceAttributes.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceAttributesDeviceType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceAttributesDeviceType.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceCheckoutOptions' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceCheckoutOptions.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceCode' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceCode.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceCodeStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceCodeStatus.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceComponentDetailsApplicationDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceComponentDetailsApplicationDetails.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceComponentDetailsBatteryDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceComponentDetailsBatteryDetails.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceComponentDetailsCardReaderDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceComponentDetailsCardReaderDetails.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceComponentDetailsEthernetDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceComponentDetailsEthernetDetails.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceComponentDetailsExternalPower' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceComponentDetailsExternalPower.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceComponentDetailsMeasurement' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceComponentDetailsMeasurement.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceComponentDetailsNetworkInterfaceDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceComponentDetailsNetworkInterfaceDetails.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceComponentDetailsWiFiDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceComponentDetailsWiFiDetails.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceDetails.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceMetadata' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceMetadata.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceStatus.php',
        'WPForms\\Vendor\\Square\\Models\\DeviceStatusCategory' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DeviceStatusCategory.php',
        'WPForms\\Vendor\\Square\\Models\\DigitalWalletDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DigitalWalletDetails.php',
        'WPForms\\Vendor\\Square\\Models\\DisableCardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DisableCardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DisableEventsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DisableEventsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DismissTerminalActionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DismissTerminalActionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DismissTerminalCheckoutResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DismissTerminalCheckoutResponse.php',
        'WPForms\\Vendor\\Square\\Models\\DismissTerminalRefundResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DismissTerminalRefundResponse.php',
        'WPForms\\Vendor\\Square\\Models\\Dispute' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Dispute.php',
        'WPForms\\Vendor\\Square\\Models\\DisputeEvidence' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DisputeEvidence.php',
        'WPForms\\Vendor\\Square\\Models\\DisputeEvidenceFile' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DisputeEvidenceFile.php',
        'WPForms\\Vendor\\Square\\Models\\DisputeEvidenceType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DisputeEvidenceType.php',
        'WPForms\\Vendor\\Square\\Models\\DisputeReason' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DisputeReason.php',
        'WPForms\\Vendor\\Square\\Models\\DisputeState' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DisputeState.php',
        'WPForms\\Vendor\\Square\\Models\\DisputedPayment' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/DisputedPayment.php',
        'WPForms\\Vendor\\Square\\Models\\EcomVisibility' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/EcomVisibility.php',
        'WPForms\\Vendor\\Square\\Models\\Employee' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Employee.php',
        'WPForms\\Vendor\\Square\\Models\\EmployeeStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/EmployeeStatus.php',
        'WPForms\\Vendor\\Square\\Models\\EmployeeWage' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/EmployeeWage.php',
        'WPForms\\Vendor\\Square\\Models\\EnableEventsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/EnableEventsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\Error' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Error.php',
        'WPForms\\Vendor\\Square\\Models\\ErrorCategory' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ErrorCategory.php',
        'WPForms\\Vendor\\Square\\Models\\ErrorCode' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ErrorCode.php',
        'WPForms\\Vendor\\Square\\Models\\Event' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Event.php',
        'WPForms\\Vendor\\Square\\Models\\EventData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/EventData.php',
        'WPForms\\Vendor\\Square\\Models\\EventMetadata' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/EventMetadata.php',
        'WPForms\\Vendor\\Square\\Models\\EventTypeMetadata' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/EventTypeMetadata.php',
        'WPForms\\Vendor\\Square\\Models\\ExcludeStrategy' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ExcludeStrategy.php',
        'WPForms\\Vendor\\Square\\Models\\ExternalPaymentDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ExternalPaymentDetails.php',
        'WPForms\\Vendor\\Square\\Models\\FilterValue' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FilterValue.php',
        'WPForms\\Vendor\\Square\\Models\\FloatNumberRange' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FloatNumberRange.php',
        'WPForms\\Vendor\\Square\\Models\\Fulfillment' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Fulfillment.php',
        'WPForms\\Vendor\\Square\\Models\\FulfillmentDeliveryDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FulfillmentDeliveryDetails.php',
        'WPForms\\Vendor\\Square\\Models\\FulfillmentDeliveryDetailsOrderFulfillmentDeliveryDetailsScheduleType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FulfillmentDeliveryDetailsOrderFulfillmentDeliveryDetailsScheduleType.php',
        'WPForms\\Vendor\\Square\\Models\\FulfillmentFulfillmentEntry' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FulfillmentFulfillmentEntry.php',
        'WPForms\\Vendor\\Square\\Models\\FulfillmentFulfillmentLineItemApplication' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FulfillmentFulfillmentLineItemApplication.php',
        'WPForms\\Vendor\\Square\\Models\\FulfillmentPickupDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FulfillmentPickupDetails.php',
        'WPForms\\Vendor\\Square\\Models\\FulfillmentPickupDetailsCurbsidePickupDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FulfillmentPickupDetailsCurbsidePickupDetails.php',
        'WPForms\\Vendor\\Square\\Models\\FulfillmentPickupDetailsScheduleType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FulfillmentPickupDetailsScheduleType.php',
        'WPForms\\Vendor\\Square\\Models\\FulfillmentRecipient' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FulfillmentRecipient.php',
        'WPForms\\Vendor\\Square\\Models\\FulfillmentShipmentDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FulfillmentShipmentDetails.php',
        'WPForms\\Vendor\\Square\\Models\\FulfillmentState' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FulfillmentState.php',
        'WPForms\\Vendor\\Square\\Models\\FulfillmentType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/FulfillmentType.php',
        'WPForms\\Vendor\\Square\\Models\\GetBankAccountByV1IdResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetBankAccountByV1IdResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetBankAccountResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetBankAccountResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetBreakTypeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetBreakTypeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetDeviceCodeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetDeviceCodeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetDeviceResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetDeviceResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetEmployeeWageResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetEmployeeWageResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetInvoiceResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetInvoiceResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetPaymentRefundResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetPaymentRefundResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetPaymentResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetPaymentResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetPayoutResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetPayoutResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetShiftResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetShiftResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetTeamMemberWageResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetTeamMemberWageResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetTerminalActionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetTerminalActionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetTerminalCheckoutResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetTerminalCheckoutResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GetTerminalRefundResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GetTerminalRefundResponse.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCard' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCard.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivity' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivity.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityActivate' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityActivate.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityAdjustDecrement' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityAdjustDecrement.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityAdjustDecrementReason' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityAdjustDecrementReason.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityAdjustIncrement' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityAdjustIncrement.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityAdjustIncrementReason' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityAdjustIncrementReason.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityBlock' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityBlock.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityBlockReason' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityBlockReason.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityClearBalance' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityClearBalance.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityClearBalanceReason' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityClearBalanceReason.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityDeactivate' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityDeactivate.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityDeactivateReason' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityDeactivateReason.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityImport' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityImport.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityImportReversal' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityImportReversal.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityLoad' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityLoad.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityRedeem' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityRedeem.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityRedeemStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityRedeemStatus.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityRefund' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityRefund.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityTransferBalanceFrom' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityTransferBalanceFrom.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityTransferBalanceTo' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityTransferBalanceTo.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityType.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityUnblock' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityUnblock.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityUnblockReason' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityUnblockReason.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardActivityUnlinkedActivityRefund' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardActivityUnlinkedActivityRefund.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardGANSource' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardGANSource.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardStatus.php',
        'WPForms\\Vendor\\Square\\Models\\GiftCardType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/GiftCardType.php',
        'WPForms\\Vendor\\Square\\Models\\InventoryAdjustment' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InventoryAdjustment.php',
        'WPForms\\Vendor\\Square\\Models\\InventoryAdjustmentGroup' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InventoryAdjustmentGroup.php',
        'WPForms\\Vendor\\Square\\Models\\InventoryAlertType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InventoryAlertType.php',
        'WPForms\\Vendor\\Square\\Models\\InventoryChange' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InventoryChange.php',
        'WPForms\\Vendor\\Square\\Models\\InventoryChangeType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InventoryChangeType.php',
        'WPForms\\Vendor\\Square\\Models\\InventoryCount' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InventoryCount.php',
        'WPForms\\Vendor\\Square\\Models\\InventoryPhysicalCount' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InventoryPhysicalCount.php',
        'WPForms\\Vendor\\Square\\Models\\InventoryState' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InventoryState.php',
        'WPForms\\Vendor\\Square\\Models\\InventoryTransfer' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InventoryTransfer.php',
        'WPForms\\Vendor\\Square\\Models\\Invoice' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Invoice.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceAcceptedPaymentMethods' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceAcceptedPaymentMethods.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceAttachment' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceAttachment.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceAutomaticPaymentSource' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceAutomaticPaymentSource.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceCustomField' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceCustomField.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceCustomFieldPlacement' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceCustomFieldPlacement.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceDeliveryMethod' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceDeliveryMethod.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceFilter.php',
        'WPForms\\Vendor\\Square\\Models\\InvoicePaymentReminder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoicePaymentReminder.php',
        'WPForms\\Vendor\\Square\\Models\\InvoicePaymentReminderStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoicePaymentReminderStatus.php',
        'WPForms\\Vendor\\Square\\Models\\InvoicePaymentRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoicePaymentRequest.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceQuery.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceRecipient' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceRecipient.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceRecipientTaxIds' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceRecipientTaxIds.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceRequestMethod' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceRequestMethod.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceRequestType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceRequestType.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceSort' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceSort.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceSortField' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceSortField.php',
        'WPForms\\Vendor\\Square\\Models\\InvoiceStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/InvoiceStatus.php',
        'WPForms\\Vendor\\Square\\Models\\ItemVariationLocationOverrides' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ItemVariationLocationOverrides.php',
        'WPForms\\Vendor\\Square\\Models\\Job' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Job.php',
        'WPForms\\Vendor\\Square\\Models\\JobAssignment' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/JobAssignment.php',
        'WPForms\\Vendor\\Square\\Models\\JobAssignmentPayType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/JobAssignmentPayType.php',
        'WPForms\\Vendor\\Square\\Models\\LinkCustomerToGiftCardRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LinkCustomerToGiftCardRequest.php',
        'WPForms\\Vendor\\Square\\Models\\LinkCustomerToGiftCardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LinkCustomerToGiftCardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListBankAccountsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListBankAccountsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListBankAccountsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListBankAccountsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListBookingCustomAttributeDefinitionsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListBookingCustomAttributeDefinitionsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListBookingCustomAttributeDefinitionsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListBookingCustomAttributeDefinitionsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListBookingCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListBookingCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListBookingCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListBookingCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListBookingsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListBookingsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListBookingsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListBookingsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListBreakTypesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListBreakTypesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListBreakTypesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListBreakTypesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListCardsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCardsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListCardsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCardsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListCashDrawerShiftEventsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCashDrawerShiftEventsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListCashDrawerShiftEventsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCashDrawerShiftEventsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListCashDrawerShiftsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCashDrawerShiftsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListCashDrawerShiftsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCashDrawerShiftsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListCatalogRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCatalogRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListCatalogResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCatalogResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListCustomerCustomAttributeDefinitionsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCustomerCustomAttributeDefinitionsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListCustomerCustomAttributeDefinitionsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCustomerCustomAttributeDefinitionsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListCustomerCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCustomerCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListCustomerCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCustomerCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListCustomerGroupsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCustomerGroupsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListCustomerGroupsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCustomerGroupsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListCustomerSegmentsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCustomerSegmentsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListCustomerSegmentsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCustomerSegmentsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListCustomersRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCustomersRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListCustomersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListCustomersResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListDeviceCodesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListDeviceCodesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListDeviceCodesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListDeviceCodesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListDevicesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListDevicesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListDevicesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListDevicesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListDisputeEvidenceRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListDisputeEvidenceRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListDisputeEvidenceResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListDisputeEvidenceResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListDisputesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListDisputesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListDisputesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListDisputesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListEmployeeWagesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListEmployeeWagesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListEmployeeWagesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListEmployeeWagesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListEmployeesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListEmployeesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListEmployeesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListEmployeesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListEventTypesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListEventTypesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListEventTypesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListEventTypesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListGiftCardActivitiesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListGiftCardActivitiesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListGiftCardActivitiesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListGiftCardActivitiesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListGiftCardsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListGiftCardsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListGiftCardsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListGiftCardsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListInvoicesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListInvoicesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListInvoicesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListInvoicesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListJobsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListJobsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListJobsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListJobsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListLocationBookingProfilesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListLocationBookingProfilesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListLocationBookingProfilesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListLocationBookingProfilesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListLocationCustomAttributeDefinitionsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListLocationCustomAttributeDefinitionsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListLocationCustomAttributeDefinitionsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListLocationCustomAttributeDefinitionsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListLocationCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListLocationCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListLocationCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListLocationCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListLocationsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListLocationsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListLoyaltyProgramsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListLoyaltyProgramsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListLoyaltyPromotionsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListLoyaltyPromotionsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListLoyaltyPromotionsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListLoyaltyPromotionsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListMerchantCustomAttributeDefinitionsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListMerchantCustomAttributeDefinitionsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListMerchantCustomAttributeDefinitionsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListMerchantCustomAttributeDefinitionsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListMerchantCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListMerchantCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListMerchantCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListMerchantCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListMerchantsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListMerchantsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListMerchantsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListMerchantsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListOrderCustomAttributeDefinitionsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListOrderCustomAttributeDefinitionsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListOrderCustomAttributeDefinitionsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListOrderCustomAttributeDefinitionsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListOrderCustomAttributesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListOrderCustomAttributesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListOrderCustomAttributesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListOrderCustomAttributesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListPaymentLinksRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListPaymentLinksRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListPaymentLinksResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListPaymentLinksResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListPaymentRefundsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListPaymentRefundsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListPaymentRefundsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListPaymentRefundsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListPaymentsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListPaymentsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListPaymentsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListPaymentsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListPayoutEntriesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListPayoutEntriesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListPayoutEntriesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListPayoutEntriesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListPayoutsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListPayoutsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListPayoutsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListPayoutsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListRefundsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListRefundsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListRefundsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListRefundsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListSitesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListSitesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListSubscriptionEventsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListSubscriptionEventsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListSubscriptionEventsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListSubscriptionEventsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListTeamMemberBookingProfilesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListTeamMemberBookingProfilesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListTeamMemberBookingProfilesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListTeamMemberBookingProfilesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListTeamMemberWagesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListTeamMemberWagesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListTeamMemberWagesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListTeamMemberWagesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListTransactionsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListTransactionsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListTransactionsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListTransactionsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListWebhookEventTypesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListWebhookEventTypesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListWebhookEventTypesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListWebhookEventTypesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListWebhookSubscriptionsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListWebhookSubscriptionsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListWebhookSubscriptionsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListWebhookSubscriptionsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ListWorkweekConfigsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListWorkweekConfigsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ListWorkweekConfigsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ListWorkweekConfigsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\Location' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Location.php',
        'WPForms\\Vendor\\Square\\Models\\LocationBookingProfile' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LocationBookingProfile.php',
        'WPForms\\Vendor\\Square\\Models\\LocationCapability' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LocationCapability.php',
        'WPForms\\Vendor\\Square\\Models\\LocationStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LocationStatus.php',
        'WPForms\\Vendor\\Square\\Models\\LocationType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LocationType.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyAccount' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyAccount.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyAccountExpiringPointDeadline' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyAccountExpiringPointDeadline.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyAccountMapping' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyAccountMapping.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyAccountMappingType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyAccountMappingType.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEvent' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEvent.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventAccumulatePoints' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventAccumulatePoints.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventAccumulatePromotionPoints' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventAccumulatePromotionPoints.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventAdjustPoints' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventAdjustPoints.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventCreateReward' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventCreateReward.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventDateTimeFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventDateTimeFilter.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventDeleteReward' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventDeleteReward.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventExpirePoints' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventExpirePoints.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventFilter.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventLocationFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventLocationFilter.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventLoyaltyAccountFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventLoyaltyAccountFilter.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventOrderFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventOrderFilter.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventOther' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventOther.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventQuery.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventRedeemReward' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventRedeemReward.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventSource' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventSource.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventType.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyEventTypeFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyEventTypeFilter.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgram' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgram.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramAccrualRule' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramAccrualRule.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramAccrualRuleCategoryData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramAccrualRuleCategoryData.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramAccrualRuleItemVariationData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramAccrualRuleItemVariationData.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramAccrualRuleSpendData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramAccrualRuleSpendData.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramAccrualRuleTaxMode' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramAccrualRuleTaxMode.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramAccrualRuleType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramAccrualRuleType.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramAccrualRuleVisitData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramAccrualRuleVisitData.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramExpirationPolicy' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramExpirationPolicy.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramRewardDefinition' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramRewardDefinition.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramRewardDefinitionScope' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramRewardDefinitionScope.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramRewardDefinitionType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramRewardDefinitionType.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramRewardTier' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramRewardTier.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramStatus.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyProgramTerminology' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyProgramTerminology.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyPromotion' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyPromotion.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyPromotionAvailableTimeData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyPromotionAvailableTimeData.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyPromotionIncentive' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyPromotionIncentive.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyPromotionIncentivePointsAdditionData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyPromotionIncentivePointsAdditionData.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyPromotionIncentivePointsMultiplierData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyPromotionIncentivePointsMultiplierData.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyPromotionIncentiveType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyPromotionIncentiveType.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyPromotionStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyPromotionStatus.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyPromotionTriggerLimit' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyPromotionTriggerLimit.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyPromotionTriggerLimitInterval' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyPromotionTriggerLimitInterval.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyReward' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyReward.php',
        'WPForms\\Vendor\\Square\\Models\\LoyaltyRewardStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/LoyaltyRewardStatus.php',
        'WPForms\\Vendor\\Square\\Models\\MBreak' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/MBreak.php',
        'WPForms\\Vendor\\Square\\Models\\MeasurementUnit' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/MeasurementUnit.php',
        'WPForms\\Vendor\\Square\\Models\\MeasurementUnitArea' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/MeasurementUnitArea.php',
        'WPForms\\Vendor\\Square\\Models\\MeasurementUnitCustom' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/MeasurementUnitCustom.php',
        'WPForms\\Vendor\\Square\\Models\\MeasurementUnitGeneric' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/MeasurementUnitGeneric.php',
        'WPForms\\Vendor\\Square\\Models\\MeasurementUnitLength' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/MeasurementUnitLength.php',
        'WPForms\\Vendor\\Square\\Models\\MeasurementUnitTime' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/MeasurementUnitTime.php',
        'WPForms\\Vendor\\Square\\Models\\MeasurementUnitUnitType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/MeasurementUnitUnitType.php',
        'WPForms\\Vendor\\Square\\Models\\MeasurementUnitVolume' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/MeasurementUnitVolume.php',
        'WPForms\\Vendor\\Square\\Models\\MeasurementUnitWeight' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/MeasurementUnitWeight.php',
        'WPForms\\Vendor\\Square\\Models\\Merchant' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Merchant.php',
        'WPForms\\Vendor\\Square\\Models\\MerchantStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/MerchantStatus.php',
        'WPForms\\Vendor\\Square\\Models\\ModifierLocationOverrides' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ModifierLocationOverrides.php',
        'WPForms\\Vendor\\Square\\Models\\Money' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Money.php',
        'WPForms\\Vendor\\Square\\Models\\ObtainTokenRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ObtainTokenRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ObtainTokenResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ObtainTokenResponse.php',
        'WPForms\\Vendor\\Square\\Models\\OfflinePaymentDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OfflinePaymentDetails.php',
        'WPForms\\Vendor\\Square\\Models\\Order' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Order.php',
        'WPForms\\Vendor\\Square\\Models\\OrderCreated' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderCreated.php',
        'WPForms\\Vendor\\Square\\Models\\OrderCreatedObject' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderCreatedObject.php',
        'WPForms\\Vendor\\Square\\Models\\OrderEntry' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderEntry.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillment' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillment.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentDeliveryDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentDeliveryDetails.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentDeliveryDetailsScheduleType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentDeliveryDetailsScheduleType.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentFulfillmentEntry' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentFulfillmentEntry.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentFulfillmentLineItemApplication' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentFulfillmentLineItemApplication.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentPickupDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentPickupDetails.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentPickupDetailsCurbsidePickupDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentPickupDetailsCurbsidePickupDetails.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentPickupDetailsScheduleType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentPickupDetailsScheduleType.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentRecipient' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentRecipient.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentShipmentDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentShipmentDetails.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentState' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentState.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentType.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentUpdated' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentUpdated.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentUpdatedObject' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentUpdatedObject.php',
        'WPForms\\Vendor\\Square\\Models\\OrderFulfillmentUpdatedUpdate' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderFulfillmentUpdatedUpdate.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItem' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItem.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemAppliedDiscount' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemAppliedDiscount.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemAppliedServiceCharge' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemAppliedServiceCharge.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemAppliedTax' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemAppliedTax.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemDiscount' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemDiscount.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemDiscountScope' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemDiscountScope.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemDiscountType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemDiscountType.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemItemType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemItemType.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemModifier' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemModifier.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemPricingBlocklists' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemPricingBlocklists.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemPricingBlocklistsBlockedDiscount' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemPricingBlocklistsBlockedDiscount.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemPricingBlocklistsBlockedTax' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemPricingBlocklistsBlockedTax.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemTax' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemTax.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemTaxScope' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemTaxScope.php',
        'WPForms\\Vendor\\Square\\Models\\OrderLineItemTaxType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderLineItemTaxType.php',
        'WPForms\\Vendor\\Square\\Models\\OrderMoneyAmounts' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderMoneyAmounts.php',
        'WPForms\\Vendor\\Square\\Models\\OrderPricingOptions' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderPricingOptions.php',
        'WPForms\\Vendor\\Square\\Models\\OrderQuantityUnit' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderQuantityUnit.php',
        'WPForms\\Vendor\\Square\\Models\\OrderReturn' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderReturn.php',
        'WPForms\\Vendor\\Square\\Models\\OrderReturnDiscount' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderReturnDiscount.php',
        'WPForms\\Vendor\\Square\\Models\\OrderReturnLineItem' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderReturnLineItem.php',
        'WPForms\\Vendor\\Square\\Models\\OrderReturnLineItemModifier' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderReturnLineItemModifier.php',
        'WPForms\\Vendor\\Square\\Models\\OrderReturnServiceCharge' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderReturnServiceCharge.php',
        'WPForms\\Vendor\\Square\\Models\\OrderReturnTax' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderReturnTax.php',
        'WPForms\\Vendor\\Square\\Models\\OrderReturnTip' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderReturnTip.php',
        'WPForms\\Vendor\\Square\\Models\\OrderReward' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderReward.php',
        'WPForms\\Vendor\\Square\\Models\\OrderRoundingAdjustment' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderRoundingAdjustment.php',
        'WPForms\\Vendor\\Square\\Models\\OrderServiceCharge' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderServiceCharge.php',
        'WPForms\\Vendor\\Square\\Models\\OrderServiceChargeCalculationPhase' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderServiceChargeCalculationPhase.php',
        'WPForms\\Vendor\\Square\\Models\\OrderServiceChargeScope' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderServiceChargeScope.php',
        'WPForms\\Vendor\\Square\\Models\\OrderServiceChargeTreatmentType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderServiceChargeTreatmentType.php',
        'WPForms\\Vendor\\Square\\Models\\OrderServiceChargeType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderServiceChargeType.php',
        'WPForms\\Vendor\\Square\\Models\\OrderSource' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderSource.php',
        'WPForms\\Vendor\\Square\\Models\\OrderState' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderState.php',
        'WPForms\\Vendor\\Square\\Models\\OrderUpdated' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderUpdated.php',
        'WPForms\\Vendor\\Square\\Models\\OrderUpdatedObject' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/OrderUpdatedObject.php',
        'WPForms\\Vendor\\Square\\Models\\PaginationCursor' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaginationCursor.php',
        'WPForms\\Vendor\\Square\\Models\\PauseSubscriptionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PauseSubscriptionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\PauseSubscriptionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PauseSubscriptionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\PayOrderRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PayOrderRequest.php',
        'WPForms\\Vendor\\Square\\Models\\PayOrderResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PayOrderResponse.php',
        'WPForms\\Vendor\\Square\\Models\\Payment' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Payment.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityAppFeeRefundDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityAppFeeRefundDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityAppFeeRevenueDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityAppFeeRevenueDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityAutomaticSavingsDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityAutomaticSavingsDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityAutomaticSavingsReversedDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityAutomaticSavingsReversedDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityChargeDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityChargeDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityDepositFeeDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityDepositFeeDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityDepositFeeReversedDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityDepositFeeReversedDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityDisputeDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityDisputeDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityFeeDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityFeeDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityFreeProcessingDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityFreeProcessingDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityHoldAdjustmentDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityHoldAdjustmentDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityOpenDisputeDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityOpenDisputeDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityOtherAdjustmentDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityOtherAdjustmentDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityOtherDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityOtherDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityRefundDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityRefundDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityReleaseAdjustmentDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityReleaseAdjustmentDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityReserveHoldDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityReserveHoldDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityReserveReleaseDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityReserveReleaseDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivitySquareCapitalPaymentDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivitySquareCapitalPaymentDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivitySquareCapitalReversedPaymentDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivitySquareCapitalReversedPaymentDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivitySquarePayrollTransferDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivitySquarePayrollTransferDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivitySquarePayrollTransferReversedDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivitySquarePayrollTransferReversedDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityTaxOnFeeDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityTaxOnFeeDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityThirdPartyFeeDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityThirdPartyFeeDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentBalanceActivityThirdPartyFeeRefundDetail' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentBalanceActivityThirdPartyFeeRefundDetail.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentLink' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentLink.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentLinkRelatedResources' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentLinkRelatedResources.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentOptions' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentOptions.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentOptionsDelayAction' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentOptionsDelayAction.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentRefund' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentRefund.php',
        'WPForms\\Vendor\\Square\\Models\\PaymentSortField' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PaymentSortField.php',
        'WPForms\\Vendor\\Square\\Models\\Payout' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Payout.php',
        'WPForms\\Vendor\\Square\\Models\\PayoutEntry' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PayoutEntry.php',
        'WPForms\\Vendor\\Square\\Models\\PayoutFee' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PayoutFee.php',
        'WPForms\\Vendor\\Square\\Models\\PayoutFeeType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PayoutFeeType.php',
        'WPForms\\Vendor\\Square\\Models\\PayoutStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PayoutStatus.php',
        'WPForms\\Vendor\\Square\\Models\\PayoutType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PayoutType.php',
        'WPForms\\Vendor\\Square\\Models\\Phase' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Phase.php',
        'WPForms\\Vendor\\Square\\Models\\PhaseInput' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PhaseInput.php',
        'WPForms\\Vendor\\Square\\Models\\PrePopulatedData' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PrePopulatedData.php',
        'WPForms\\Vendor\\Square\\Models\\ProcessingFee' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ProcessingFee.php',
        'WPForms\\Vendor\\Square\\Models\\Product' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Product.php',
        'WPForms\\Vendor\\Square\\Models\\ProductType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ProductType.php',
        'WPForms\\Vendor\\Square\\Models\\PublishInvoiceRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PublishInvoiceRequest.php',
        'WPForms\\Vendor\\Square\\Models\\PublishInvoiceResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/PublishInvoiceResponse.php',
        'WPForms\\Vendor\\Square\\Models\\QrCodeOptions' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/QrCodeOptions.php',
        'WPForms\\Vendor\\Square\\Models\\QuantityRatio' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/QuantityRatio.php',
        'WPForms\\Vendor\\Square\\Models\\QuickPay' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/QuickPay.php',
        'WPForms\\Vendor\\Square\\Models\\Range' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Range.php',
        'WPForms\\Vendor\\Square\\Models\\ReceiptOptions' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ReceiptOptions.php',
        'WPForms\\Vendor\\Square\\Models\\RedeemLoyaltyRewardRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RedeemLoyaltyRewardRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RedeemLoyaltyRewardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RedeemLoyaltyRewardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\Refund' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Refund.php',
        'WPForms\\Vendor\\Square\\Models\\RefundPaymentRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RefundPaymentRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RefundPaymentResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RefundPaymentResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RefundStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RefundStatus.php',
        'WPForms\\Vendor\\Square\\Models\\RegisterDomainRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RegisterDomainRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RegisterDomainResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RegisterDomainResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RegisterDomainResponseStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RegisterDomainResponseStatus.php',
        'WPForms\\Vendor\\Square\\Models\\RemoveGroupFromCustomerResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RemoveGroupFromCustomerResponse.php',
        'WPForms\\Vendor\\Square\\Models\\ResumeSubscriptionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ResumeSubscriptionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\ResumeSubscriptionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ResumeSubscriptionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveBookingCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveBookingCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveBookingCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveBookingCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveBookingCustomAttributeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveBookingCustomAttributeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveBookingCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveBookingCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveBookingResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveBookingResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveBusinessBookingProfileResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveBusinessBookingProfileResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveCardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveCardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveCashDrawerShiftRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveCashDrawerShiftRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveCashDrawerShiftResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveCashDrawerShiftResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveCatalogObjectRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveCatalogObjectRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveCatalogObjectResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveCatalogObjectResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveCustomerCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveCustomerCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveCustomerCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveCustomerCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveCustomerCustomAttributeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveCustomerCustomAttributeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveCustomerCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveCustomerCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveCustomerGroupResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveCustomerGroupResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveCustomerResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveCustomerResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveCustomerSegmentResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveCustomerSegmentResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveDisputeEvidenceResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveDisputeEvidenceResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveDisputeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveDisputeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveEmployeeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveEmployeeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveGiftCardFromGANRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveGiftCardFromGANRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveGiftCardFromGANResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveGiftCardFromGANResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveGiftCardFromNonceRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveGiftCardFromNonceRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveGiftCardFromNonceResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveGiftCardFromNonceResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveGiftCardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveGiftCardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveInventoryAdjustmentResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveInventoryAdjustmentResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveInventoryChangesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveInventoryChangesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveInventoryChangesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveInventoryChangesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveInventoryCountRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveInventoryCountRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveInventoryCountResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveInventoryCountResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveInventoryPhysicalCountResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveInventoryPhysicalCountResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveInventoryTransferResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveInventoryTransferResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveJobResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveJobResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveLocationBookingProfileResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveLocationBookingProfileResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveLocationCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveLocationCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveLocationCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveLocationCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveLocationCustomAttributeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveLocationCustomAttributeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveLocationCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveLocationCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveLocationResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveLocationResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveLocationSettingsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveLocationSettingsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveLoyaltyAccountResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveLoyaltyAccountResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveLoyaltyProgramResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveLoyaltyProgramResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveLoyaltyPromotionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveLoyaltyPromotionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveLoyaltyRewardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveLoyaltyRewardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveMerchantCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveMerchantCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveMerchantCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveMerchantCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveMerchantCustomAttributeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveMerchantCustomAttributeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveMerchantCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveMerchantCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveMerchantResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveMerchantResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveMerchantSettingsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveMerchantSettingsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveOrderCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveOrderCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveOrderCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveOrderCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveOrderCustomAttributeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveOrderCustomAttributeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveOrderCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveOrderCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveOrderResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveOrderResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrievePaymentLinkResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrievePaymentLinkResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveSnippetResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveSnippetResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveSubscriptionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveSubscriptionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveSubscriptionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveSubscriptionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveTeamMemberBookingProfileResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveTeamMemberBookingProfileResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveTeamMemberResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveTeamMemberResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveTokenStatusResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveTokenStatusResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveTransactionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveTransactionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveVendorResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveVendorResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveWageSettingResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveWageSettingResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RetrieveWebhookSubscriptionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RetrieveWebhookSubscriptionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RevokeTokenRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RevokeTokenRequest.php',
        'WPForms\\Vendor\\Square\\Models\\RevokeTokenResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RevokeTokenResponse.php',
        'WPForms\\Vendor\\Square\\Models\\RiskEvaluation' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RiskEvaluation.php',
        'WPForms\\Vendor\\Square\\Models\\RiskEvaluationRiskLevel' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/RiskEvaluationRiskLevel.php',
        'WPForms\\Vendor\\Square\\Models\\SaveCardOptions' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SaveCardOptions.php',
        'WPForms\\Vendor\\Square\\Models\\SearchAvailabilityFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchAvailabilityFilter.php',
        'WPForms\\Vendor\\Square\\Models\\SearchAvailabilityQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchAvailabilityQuery.php',
        'WPForms\\Vendor\\Square\\Models\\SearchAvailabilityRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchAvailabilityRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchAvailabilityResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchAvailabilityResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchCatalogItemsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchCatalogItemsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchCatalogItemsRequestStockLevel' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchCatalogItemsRequestStockLevel.php',
        'WPForms\\Vendor\\Square\\Models\\SearchCatalogItemsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchCatalogItemsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchCatalogObjectsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchCatalogObjectsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchCatalogObjectsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchCatalogObjectsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchCustomersRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchCustomersRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchCustomersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchCustomersResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchEventsFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchEventsFilter.php',
        'WPForms\\Vendor\\Square\\Models\\SearchEventsQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchEventsQuery.php',
        'WPForms\\Vendor\\Square\\Models\\SearchEventsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchEventsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchEventsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchEventsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchEventsSort' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchEventsSort.php',
        'WPForms\\Vendor\\Square\\Models\\SearchEventsSortField' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchEventsSortField.php',
        'WPForms\\Vendor\\Square\\Models\\SearchInvoicesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchInvoicesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchInvoicesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchInvoicesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchLoyaltyAccountsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchLoyaltyAccountsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchLoyaltyAccountsRequestLoyaltyAccountQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchLoyaltyAccountsRequestLoyaltyAccountQuery.php',
        'WPForms\\Vendor\\Square\\Models\\SearchLoyaltyAccountsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchLoyaltyAccountsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchLoyaltyEventsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchLoyaltyEventsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchLoyaltyEventsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchLoyaltyEventsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchLoyaltyRewardsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchLoyaltyRewardsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchLoyaltyRewardsRequestLoyaltyRewardQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchLoyaltyRewardsRequestLoyaltyRewardQuery.php',
        'WPForms\\Vendor\\Square\\Models\\SearchLoyaltyRewardsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchLoyaltyRewardsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchOrdersCustomerFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchOrdersCustomerFilter.php',
        'WPForms\\Vendor\\Square\\Models\\SearchOrdersDateTimeFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchOrdersDateTimeFilter.php',
        'WPForms\\Vendor\\Square\\Models\\SearchOrdersFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchOrdersFilter.php',
        'WPForms\\Vendor\\Square\\Models\\SearchOrdersFulfillmentFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchOrdersFulfillmentFilter.php',
        'WPForms\\Vendor\\Square\\Models\\SearchOrdersQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchOrdersQuery.php',
        'WPForms\\Vendor\\Square\\Models\\SearchOrdersRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchOrdersRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchOrdersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchOrdersResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchOrdersSort' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchOrdersSort.php',
        'WPForms\\Vendor\\Square\\Models\\SearchOrdersSortField' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchOrdersSortField.php',
        'WPForms\\Vendor\\Square\\Models\\SearchOrdersSourceFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchOrdersSourceFilter.php',
        'WPForms\\Vendor\\Square\\Models\\SearchOrdersStateFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchOrdersStateFilter.php',
        'WPForms\\Vendor\\Square\\Models\\SearchShiftsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchShiftsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchShiftsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchShiftsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchSubscriptionsFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchSubscriptionsFilter.php',
        'WPForms\\Vendor\\Square\\Models\\SearchSubscriptionsQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchSubscriptionsQuery.php',
        'WPForms\\Vendor\\Square\\Models\\SearchSubscriptionsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchSubscriptionsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchSubscriptionsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchSubscriptionsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchTeamMembersFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchTeamMembersFilter.php',
        'WPForms\\Vendor\\Square\\Models\\SearchTeamMembersQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchTeamMembersQuery.php',
        'WPForms\\Vendor\\Square\\Models\\SearchTeamMembersRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchTeamMembersRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchTeamMembersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchTeamMembersResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchTerminalActionsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchTerminalActionsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchTerminalActionsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchTerminalActionsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchTerminalCheckoutsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchTerminalCheckoutsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchTerminalCheckoutsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchTerminalCheckoutsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchTerminalRefundsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchTerminalRefundsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchTerminalRefundsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchTerminalRefundsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SearchVendorsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchVendorsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SearchVendorsRequestFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchVendorsRequestFilter.php',
        'WPForms\\Vendor\\Square\\Models\\SearchVendorsRequestSort' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchVendorsRequestSort.php',
        'WPForms\\Vendor\\Square\\Models\\SearchVendorsRequestSortField' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchVendorsRequestSortField.php',
        'WPForms\\Vendor\\Square\\Models\\SearchVendorsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SearchVendorsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SegmentFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SegmentFilter.php',
        'WPForms\\Vendor\\Square\\Models\\SelectOption' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SelectOption.php',
        'WPForms\\Vendor\\Square\\Models\\SelectOptions' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SelectOptions.php',
        'WPForms\\Vendor\\Square\\Models\\Shift' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Shift.php',
        'WPForms\\Vendor\\Square\\Models\\ShiftFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ShiftFilter.php',
        'WPForms\\Vendor\\Square\\Models\\ShiftFilterStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ShiftFilterStatus.php',
        'WPForms\\Vendor\\Square\\Models\\ShiftQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ShiftQuery.php',
        'WPForms\\Vendor\\Square\\Models\\ShiftSort' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ShiftSort.php',
        'WPForms\\Vendor\\Square\\Models\\ShiftSortField' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ShiftSortField.php',
        'WPForms\\Vendor\\Square\\Models\\ShiftStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ShiftStatus.php',
        'WPForms\\Vendor\\Square\\Models\\ShiftWage' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ShiftWage.php',
        'WPForms\\Vendor\\Square\\Models\\ShiftWorkday' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ShiftWorkday.php',
        'WPForms\\Vendor\\Square\\Models\\ShiftWorkdayMatcher' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ShiftWorkdayMatcher.php',
        'WPForms\\Vendor\\Square\\Models\\ShippingFee' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/ShippingFee.php',
        'WPForms\\Vendor\\Square\\Models\\SignatureImage' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SignatureImage.php',
        'WPForms\\Vendor\\Square\\Models\\SignatureOptions' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SignatureOptions.php',
        'WPForms\\Vendor\\Square\\Models\\Site' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Site.php',
        'WPForms\\Vendor\\Square\\Models\\Snippet' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Snippet.php',
        'WPForms\\Vendor\\Square\\Models\\SnippetResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SnippetResponse.php',
        'WPForms\\Vendor\\Square\\Models\\SortOrder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SortOrder.php',
        'WPForms\\Vendor\\Square\\Models\\SourceApplication' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SourceApplication.php',
        'WPForms\\Vendor\\Square\\Models\\SquareAccountDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SquareAccountDetails.php',
        'WPForms\\Vendor\\Square\\Models\\StandardUnitDescription' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/StandardUnitDescription.php',
        'WPForms\\Vendor\\Square\\Models\\StandardUnitDescriptionGroup' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/StandardUnitDescriptionGroup.php',
        'WPForms\\Vendor\\Square\\Models\\SubmitEvidenceResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubmitEvidenceResponse.php',
        'WPForms\\Vendor\\Square\\Models\\Subscription' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Subscription.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionAction' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionAction.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionActionType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionActionType.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionCadence' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionCadence.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionEvent' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionEvent.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionEventInfo' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionEventInfo.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionEventInfoCode' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionEventInfoCode.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionEventSubscriptionEventType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionEventSubscriptionEventType.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionPhase' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionPhase.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionPricing' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionPricing.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionPricingType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionPricingType.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionSource' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionSource.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionStatus.php',
        'WPForms\\Vendor\\Square\\Models\\SubscriptionTestResult' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SubscriptionTestResult.php',
        'WPForms\\Vendor\\Square\\Models\\SwapPlanRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SwapPlanRequest.php',
        'WPForms\\Vendor\\Square\\Models\\SwapPlanResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/SwapPlanResponse.php',
        'WPForms\\Vendor\\Square\\Models\\TaxCalculationPhase' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TaxCalculationPhase.php',
        'WPForms\\Vendor\\Square\\Models\\TaxIds' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TaxIds.php',
        'WPForms\\Vendor\\Square\\Models\\TaxInclusionType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TaxInclusionType.php',
        'WPForms\\Vendor\\Square\\Models\\TeamMember' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TeamMember.php',
        'WPForms\\Vendor\\Square\\Models\\TeamMemberAssignedLocations' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TeamMemberAssignedLocations.php',
        'WPForms\\Vendor\\Square\\Models\\TeamMemberAssignedLocationsAssignmentType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TeamMemberAssignedLocationsAssignmentType.php',
        'WPForms\\Vendor\\Square\\Models\\TeamMemberBookingProfile' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TeamMemberBookingProfile.php',
        'WPForms\\Vendor\\Square\\Models\\TeamMemberInvitationStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TeamMemberInvitationStatus.php',
        'WPForms\\Vendor\\Square\\Models\\TeamMemberStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TeamMemberStatus.php',
        'WPForms\\Vendor\\Square\\Models\\TeamMemberWage' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TeamMemberWage.php',
        'WPForms\\Vendor\\Square\\Models\\Tender' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Tender.php',
        'WPForms\\Vendor\\Square\\Models\\TenderBankAccountDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TenderBankAccountDetails.php',
        'WPForms\\Vendor\\Square\\Models\\TenderBankAccountDetailsStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TenderBankAccountDetailsStatus.php',
        'WPForms\\Vendor\\Square\\Models\\TenderBuyNowPayLaterDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TenderBuyNowPayLaterDetails.php',
        'WPForms\\Vendor\\Square\\Models\\TenderBuyNowPayLaterDetailsBrand' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TenderBuyNowPayLaterDetailsBrand.php',
        'WPForms\\Vendor\\Square\\Models\\TenderBuyNowPayLaterDetailsStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TenderBuyNowPayLaterDetailsStatus.php',
        'WPForms\\Vendor\\Square\\Models\\TenderCardDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TenderCardDetails.php',
        'WPForms\\Vendor\\Square\\Models\\TenderCardDetailsEntryMethod' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TenderCardDetailsEntryMethod.php',
        'WPForms\\Vendor\\Square\\Models\\TenderCardDetailsStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TenderCardDetailsStatus.php',
        'WPForms\\Vendor\\Square\\Models\\TenderCashDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TenderCashDetails.php',
        'WPForms\\Vendor\\Square\\Models\\TenderSquareAccountDetails' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TenderSquareAccountDetails.php',
        'WPForms\\Vendor\\Square\\Models\\TenderSquareAccountDetailsStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TenderSquareAccountDetailsStatus.php',
        'WPForms\\Vendor\\Square\\Models\\TenderType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TenderType.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalAction' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalAction.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalActionActionType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalActionActionType.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalActionQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalActionQuery.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalActionQueryFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalActionQueryFilter.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalActionQuerySort' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalActionQuerySort.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalCheckout' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalCheckout.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalCheckoutQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalCheckoutQuery.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalCheckoutQueryFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalCheckoutQueryFilter.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalCheckoutQuerySort' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalCheckoutQuerySort.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalRefund' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalRefund.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalRefundQuery' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalRefundQuery.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalRefundQueryFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalRefundQueryFilter.php',
        'WPForms\\Vendor\\Square\\Models\\TerminalRefundQuerySort' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TerminalRefundQuerySort.php',
        'WPForms\\Vendor\\Square\\Models\\TestWebhookSubscriptionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TestWebhookSubscriptionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\TestWebhookSubscriptionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TestWebhookSubscriptionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\TimeRange' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TimeRange.php',
        'WPForms\\Vendor\\Square\\Models\\TipSettings' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TipSettings.php',
        'WPForms\\Vendor\\Square\\Models\\Transaction' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Transaction.php',
        'WPForms\\Vendor\\Square\\Models\\TransactionProduct' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TransactionProduct.php',
        'WPForms\\Vendor\\Square\\Models\\TransactionType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/TransactionType.php',
        'WPForms\\Vendor\\Square\\Models\\UnlinkCustomerFromGiftCardRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UnlinkCustomerFromGiftCardRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UnlinkCustomerFromGiftCardResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UnlinkCustomerFromGiftCardResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateBookingCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateBookingCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateBookingCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateBookingCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateBookingRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateBookingRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateBookingResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateBookingResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateBreakTypeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateBreakTypeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateBreakTypeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateBreakTypeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateCatalogImageRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateCatalogImageRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateCatalogImageResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateCatalogImageResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateCustomerCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateCustomerCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateCustomerCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateCustomerCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateCustomerGroupRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateCustomerGroupRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateCustomerGroupResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateCustomerGroupResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateCustomerRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateCustomerRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateCustomerResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateCustomerResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateInvoiceRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateInvoiceRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateInvoiceResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateInvoiceResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateItemModifierListsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateItemModifierListsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateItemModifierListsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateItemModifierListsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateItemTaxesRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateItemTaxesRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateItemTaxesResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateItemTaxesResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateJobRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateJobRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateJobResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateJobResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateLocationCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateLocationCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateLocationCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateLocationCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateLocationRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateLocationRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateLocationResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateLocationResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateLocationSettingsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateLocationSettingsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateLocationSettingsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateLocationSettingsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateMerchantCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateMerchantCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateMerchantCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateMerchantCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateMerchantSettingsRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateMerchantSettingsRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateMerchantSettingsResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateMerchantSettingsResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateOrderCustomAttributeDefinitionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateOrderCustomAttributeDefinitionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateOrderCustomAttributeDefinitionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateOrderCustomAttributeDefinitionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateOrderRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateOrderRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateOrderResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateOrderResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdatePaymentLinkRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdatePaymentLinkRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdatePaymentLinkResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdatePaymentLinkResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdatePaymentRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdatePaymentRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdatePaymentResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdatePaymentResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateShiftRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateShiftRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateShiftResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateShiftResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateSubscriptionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateSubscriptionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateSubscriptionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateSubscriptionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateTeamMemberRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateTeamMemberRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateTeamMemberResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateTeamMemberResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateVendorRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateVendorRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateVendorResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateVendorResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateWageSettingRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateWageSettingRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateWageSettingResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateWageSettingResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateWebhookSubscriptionRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateWebhookSubscriptionRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateWebhookSubscriptionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateWebhookSubscriptionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateWebhookSubscriptionSignatureKeyRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateWebhookSubscriptionSignatureKeyRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateWebhookSubscriptionSignatureKeyResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateWebhookSubscriptionSignatureKeyResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateWorkweekConfigRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateWorkweekConfigRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpdateWorkweekConfigResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpdateWorkweekConfigResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertBookingCustomAttributeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertBookingCustomAttributeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertBookingCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertBookingCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertCatalogObjectRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertCatalogObjectRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertCatalogObjectResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertCatalogObjectResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertCustomerCustomAttributeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertCustomerCustomAttributeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertCustomerCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertCustomerCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertLocationCustomAttributeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertLocationCustomAttributeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertLocationCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertLocationCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertMerchantCustomAttributeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertMerchantCustomAttributeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertMerchantCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertMerchantCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertOrderCustomAttributeRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertOrderCustomAttributeRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertOrderCustomAttributeResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertOrderCustomAttributeResponse.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertSnippetRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertSnippetRequest.php',
        'WPForms\\Vendor\\Square\\Models\\UpsertSnippetResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/UpsertSnippetResponse.php',
        'WPForms\\Vendor\\Square\\Models\\V1Device' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1Device.php',
        'WPForms\\Vendor\\Square\\Models\\V1ListOrdersRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1ListOrdersRequest.php',
        'WPForms\\Vendor\\Square\\Models\\V1ListOrdersResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1ListOrdersResponse.php',
        'WPForms\\Vendor\\Square\\Models\\V1Money' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1Money.php',
        'WPForms\\Vendor\\Square\\Models\\V1Order' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1Order.php',
        'WPForms\\Vendor\\Square\\Models\\V1OrderHistoryEntry' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1OrderHistoryEntry.php',
        'WPForms\\Vendor\\Square\\Models\\V1OrderHistoryEntryAction' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1OrderHistoryEntryAction.php',
        'WPForms\\Vendor\\Square\\Models\\V1OrderState' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1OrderState.php',
        'WPForms\\Vendor\\Square\\Models\\V1PhoneNumber' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1PhoneNumber.php',
        'WPForms\\Vendor\\Square\\Models\\V1Tender' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1Tender.php',
        'WPForms\\Vendor\\Square\\Models\\V1TenderCardBrand' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1TenderCardBrand.php',
        'WPForms\\Vendor\\Square\\Models\\V1TenderEntryMethod' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1TenderEntryMethod.php',
        'WPForms\\Vendor\\Square\\Models\\V1TenderType' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1TenderType.php',
        'WPForms\\Vendor\\Square\\Models\\V1UpdateOrderRequest' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1UpdateOrderRequest.php',
        'WPForms\\Vendor\\Square\\Models\\V1UpdateOrderRequestAction' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/V1UpdateOrderRequestAction.php',
        'WPForms\\Vendor\\Square\\Models\\Vendor' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Vendor.php',
        'WPForms\\Vendor\\Square\\Models\\VendorContact' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/VendorContact.php',
        'WPForms\\Vendor\\Square\\Models\\VendorStatus' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/VendorStatus.php',
        'WPForms\\Vendor\\Square\\Models\\VisibilityFilter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/VisibilityFilter.php',
        'WPForms\\Vendor\\Square\\Models\\VoidTransactionResponse' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/VoidTransactionResponse.php',
        'WPForms\\Vendor\\Square\\Models\\WageSetting' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/WageSetting.php',
        'WPForms\\Vendor\\Square\\Models\\WebhookSubscription' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/WebhookSubscription.php',
        'WPForms\\Vendor\\Square\\Models\\Weekday' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/Weekday.php',
        'WPForms\\Vendor\\Square\\Models\\WorkweekConfig' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Models/WorkweekConfig.php',
        'WPForms\\Vendor\\Square\\Server' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Server.php',
        'WPForms\\Vendor\\Square\\SquareClient' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/SquareClient.php',
        'WPForms\\Vendor\\Square\\SquareClientBuilder' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/SquareClientBuilder.php',
        'WPForms\\Vendor\\Square\\Utils\\CompatibilityConverter' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Utils/CompatibilityConverter.php',
        'WPForms\\Vendor\\Square\\Utils\\FileWrapper' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Utils/FileWrapper.php',
        'WPForms\\Vendor\\Square\\Utils\\WebhooksHelper' => __DIR__ . '/../..' . '/vendor_prefixed/square/square/src/Utils/WebhooksHelper.php',
        'WPForms\\Vendor\\Stripe\\Account' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Account.php',
        'WPForms\\Vendor\\Stripe\\AccountLink' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/AccountLink.php',
        'WPForms\\Vendor\\Stripe\\AccountSession' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/AccountSession.php',
        'WPForms\\Vendor\\Stripe\\ApiOperations\\All' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApiOperations/All.php',
        'WPForms\\Vendor\\Stripe\\ApiOperations\\Create' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApiOperations/Create.php',
        'WPForms\\Vendor\\Stripe\\ApiOperations\\Delete' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApiOperations/Delete.php',
        'WPForms\\Vendor\\Stripe\\ApiOperations\\NestedResource' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApiOperations/NestedResource.php',
        'WPForms\\Vendor\\Stripe\\ApiOperations\\Request' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApiOperations/Request.php',
        'WPForms\\Vendor\\Stripe\\ApiOperations\\Retrieve' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApiOperations/Retrieve.php',
        'WPForms\\Vendor\\Stripe\\ApiOperations\\Search' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApiOperations/Search.php',
        'WPForms\\Vendor\\Stripe\\ApiOperations\\SingletonRetrieve' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApiOperations/SingletonRetrieve.php',
        'WPForms\\Vendor\\Stripe\\ApiOperations\\Update' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApiOperations/Update.php',
        'WPForms\\Vendor\\Stripe\\ApiRequestor' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApiRequestor.php',
        'WPForms\\Vendor\\Stripe\\ApiResource' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApiResource.php',
        'WPForms\\Vendor\\Stripe\\ApiResponse' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApiResponse.php',
        'WPForms\\Vendor\\Stripe\\ApplePayDomain' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApplePayDomain.php',
        'WPForms\\Vendor\\Stripe\\Application' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Application.php',
        'WPForms\\Vendor\\Stripe\\ApplicationFee' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApplicationFee.php',
        'WPForms\\Vendor\\Stripe\\ApplicationFeeRefund' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ApplicationFeeRefund.php',
        'WPForms\\Vendor\\Stripe\\Apps\\Secret' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Apps/Secret.php',
        'WPForms\\Vendor\\Stripe\\Balance' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Balance.php',
        'WPForms\\Vendor\\Stripe\\BalanceTransaction' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/BalanceTransaction.php',
        'WPForms\\Vendor\\Stripe\\BankAccount' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/BankAccount.php',
        'WPForms\\Vendor\\Stripe\\BaseStripeClient' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/BaseStripeClient.php',
        'WPForms\\Vendor\\Stripe\\BaseStripeClientInterface' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/BaseStripeClientInterface.php',
        'WPForms\\Vendor\\Stripe\\BillingPortal\\Configuration' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/BillingPortal/Configuration.php',
        'WPForms\\Vendor\\Stripe\\BillingPortal\\Session' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/BillingPortal/Session.php',
        'WPForms\\Vendor\\Stripe\\Billing\\Alert' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Billing/Alert.php',
        'WPForms\\Vendor\\Stripe\\Billing\\AlertTriggered' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Billing/AlertTriggered.php',
        'WPForms\\Vendor\\Stripe\\Billing\\CreditBalanceSummary' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Billing/CreditBalanceSummary.php',
        'WPForms\\Vendor\\Stripe\\Billing\\CreditBalanceTransaction' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Billing/CreditBalanceTransaction.php',
        'WPForms\\Vendor\\Stripe\\Billing\\CreditGrant' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Billing/CreditGrant.php',
        'WPForms\\Vendor\\Stripe\\Billing\\Meter' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Billing/Meter.php',
        'WPForms\\Vendor\\Stripe\\Billing\\MeterEvent' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Billing/MeterEvent.php',
        'WPForms\\Vendor\\Stripe\\Billing\\MeterEventAdjustment' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Billing/MeterEventAdjustment.php',
        'WPForms\\Vendor\\Stripe\\Billing\\MeterEventSummary' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Billing/MeterEventSummary.php',
        'WPForms\\Vendor\\Stripe\\Capability' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Capability.php',
        'WPForms\\Vendor\\Stripe\\Card' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Card.php',
        'WPForms\\Vendor\\Stripe\\CashBalance' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/CashBalance.php',
        'WPForms\\Vendor\\Stripe\\Charge' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Charge.php',
        'WPForms\\Vendor\\Stripe\\Checkout\\Session' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Checkout/Session.php',
        'WPForms\\Vendor\\Stripe\\Climate\\Order' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Climate/Order.php',
        'WPForms\\Vendor\\Stripe\\Climate\\Product' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Climate/Product.php',
        'WPForms\\Vendor\\Stripe\\Climate\\Supplier' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Climate/Supplier.php',
        'WPForms\\Vendor\\Stripe\\Collection' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Collection.php',
        'WPForms\\Vendor\\Stripe\\ConfirmationToken' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ConfirmationToken.php',
        'WPForms\\Vendor\\Stripe\\ConnectCollectionTransfer' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ConnectCollectionTransfer.php',
        'WPForms\\Vendor\\Stripe\\CountrySpec' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/CountrySpec.php',
        'WPForms\\Vendor\\Stripe\\Coupon' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Coupon.php',
        'WPForms\\Vendor\\Stripe\\CreditNote' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/CreditNote.php',
        'WPForms\\Vendor\\Stripe\\CreditNoteLineItem' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/CreditNoteLineItem.php',
        'WPForms\\Vendor\\Stripe\\Customer' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Customer.php',
        'WPForms\\Vendor\\Stripe\\CustomerBalanceTransaction' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/CustomerBalanceTransaction.php',
        'WPForms\\Vendor\\Stripe\\CustomerCashBalanceTransaction' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/CustomerCashBalanceTransaction.php',
        'WPForms\\Vendor\\Stripe\\CustomerSession' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/CustomerSession.php',
        'WPForms\\Vendor\\Stripe\\Discount' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Discount.php',
        'WPForms\\Vendor\\Stripe\\Dispute' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Dispute.php',
        'WPForms\\Vendor\\Stripe\\Entitlements\\ActiveEntitlement' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Entitlements/ActiveEntitlement.php',
        'WPForms\\Vendor\\Stripe\\Entitlements\\ActiveEntitlementSummary' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Entitlements/ActiveEntitlementSummary.php',
        'WPForms\\Vendor\\Stripe\\Entitlements\\Feature' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Entitlements/Feature.php',
        'WPForms\\Vendor\\Stripe\\EphemeralKey' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/EphemeralKey.php',
        'WPForms\\Vendor\\Stripe\\ErrorObject' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ErrorObject.php',
        'WPForms\\Vendor\\Stripe\\Event' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Event.php',
        'WPForms\\Vendor\\Stripe\\EventData\\V1BillingMeterErrorReportTriggeredEventData' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/EventData/V1BillingMeterErrorReportTriggeredEventData.php',
        'WPForms\\Vendor\\Stripe\\EventData\\V1BillingMeterNoMeterFoundEventData' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/EventData/V1BillingMeterNoMeterFoundEventData.php',
        'WPForms\\Vendor\\Stripe\\Events\\V1BillingMeterErrorReportTriggeredEvent' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Events/V1BillingMeterErrorReportTriggeredEvent.php',
        'WPForms\\Vendor\\Stripe\\Events\\V1BillingMeterNoMeterFoundEvent' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Events/V1BillingMeterNoMeterFoundEvent.php',
        'WPForms\\Vendor\\Stripe\\Exception\\ApiConnectionException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/ApiConnectionException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\ApiErrorException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/ApiErrorException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\AuthenticationException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/AuthenticationException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\BadMethodCallException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/BadMethodCallException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\CardException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/CardException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\ExceptionInterface' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/ExceptionInterface.php',
        'WPForms\\Vendor\\Stripe\\Exception\\IdempotencyException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/IdempotencyException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\InvalidArgumentException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/InvalidArgumentException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\InvalidRequestException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/InvalidRequestException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\OAuth\\ExceptionInterface' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/OAuth/ExceptionInterface.php',
        'WPForms\\Vendor\\Stripe\\Exception\\OAuth\\InvalidClientException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/OAuth/InvalidClientException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\OAuth\\InvalidGrantException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/OAuth/InvalidGrantException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\OAuth\\InvalidRequestException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/OAuth/InvalidRequestException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\OAuth\\InvalidScopeException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/OAuth/InvalidScopeException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\OAuth\\OAuthErrorException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/OAuth/OAuthErrorException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\OAuth\\UnknownOAuthErrorException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/OAuth/UnknownOAuthErrorException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\OAuth\\UnsupportedGrantTypeException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/OAuth/UnsupportedGrantTypeException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\OAuth\\UnsupportedResponseTypeException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/OAuth/UnsupportedResponseTypeException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\PermissionException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/PermissionException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\RateLimitException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/RateLimitException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\SignatureVerificationException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/SignatureVerificationException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\TemporarySessionExpiredException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/TemporarySessionExpiredException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\UnexpectedValueException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/UnexpectedValueException.php',
        'WPForms\\Vendor\\Stripe\\Exception\\UnknownApiErrorException' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Exception/UnknownApiErrorException.php',
        'WPForms\\Vendor\\Stripe\\ExchangeRate' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ExchangeRate.php',
        'WPForms\\Vendor\\Stripe\\File' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/File.php',
        'WPForms\\Vendor\\Stripe\\FileLink' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/FileLink.php',
        'WPForms\\Vendor\\Stripe\\FinancialConnections\\Account' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/FinancialConnections/Account.php',
        'WPForms\\Vendor\\Stripe\\FinancialConnections\\AccountOwner' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/FinancialConnections/AccountOwner.php',
        'WPForms\\Vendor\\Stripe\\FinancialConnections\\AccountOwnership' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/FinancialConnections/AccountOwnership.php',
        'WPForms\\Vendor\\Stripe\\FinancialConnections\\Session' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/FinancialConnections/Session.php',
        'WPForms\\Vendor\\Stripe\\FinancialConnections\\Transaction' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/FinancialConnections/Transaction.php',
        'WPForms\\Vendor\\Stripe\\Forwarding\\Request' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Forwarding/Request.php',
        'WPForms\\Vendor\\Stripe\\FundingInstructions' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/FundingInstructions.php',
        'WPForms\\Vendor\\Stripe\\HttpClient\\ClientInterface' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/HttpClient/ClientInterface.php',
        'WPForms\\Vendor\\Stripe\\HttpClient\\CurlClient' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/HttpClient/CurlClient.php',
        'WPForms\\Vendor\\Stripe\\HttpClient\\StreamingClientInterface' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/HttpClient/StreamingClientInterface.php',
        'WPForms\\Vendor\\Stripe\\Identity\\VerificationReport' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Identity/VerificationReport.php',
        'WPForms\\Vendor\\Stripe\\Identity\\VerificationSession' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Identity/VerificationSession.php',
        'WPForms\\Vendor\\Stripe\\Invoice' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Invoice.php',
        'WPForms\\Vendor\\Stripe\\InvoiceItem' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/InvoiceItem.php',
        'WPForms\\Vendor\\Stripe\\InvoiceLineItem' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/InvoiceLineItem.php',
        'WPForms\\Vendor\\Stripe\\InvoiceRenderingTemplate' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/InvoiceRenderingTemplate.php',
        'WPForms\\Vendor\\Stripe\\Issuing\\Authorization' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Issuing/Authorization.php',
        'WPForms\\Vendor\\Stripe\\Issuing\\Card' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Issuing/Card.php',
        'WPForms\\Vendor\\Stripe\\Issuing\\CardDetails' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Issuing/CardDetails.php',
        'WPForms\\Vendor\\Stripe\\Issuing\\Cardholder' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Issuing/Cardholder.php',
        'WPForms\\Vendor\\Stripe\\Issuing\\Dispute' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Issuing/Dispute.php',
        'WPForms\\Vendor\\Stripe\\Issuing\\PersonalizationDesign' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Issuing/PersonalizationDesign.php',
        'WPForms\\Vendor\\Stripe\\Issuing\\PhysicalBundle' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Issuing/PhysicalBundle.php',
        'WPForms\\Vendor\\Stripe\\Issuing\\Token' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Issuing/Token.php',
        'WPForms\\Vendor\\Stripe\\Issuing\\Transaction' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Issuing/Transaction.php',
        'WPForms\\Vendor\\Stripe\\LineItem' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/LineItem.php',
        'WPForms\\Vendor\\Stripe\\LoginLink' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/LoginLink.php',
        'WPForms\\Vendor\\Stripe\\Mandate' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Mandate.php',
        'WPForms\\Vendor\\Stripe\\OAuth' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/OAuth.php',
        'WPForms\\Vendor\\Stripe\\OAuthErrorObject' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/OAuthErrorObject.php',
        'WPForms\\Vendor\\Stripe\\PaymentIntent' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/PaymentIntent.php',
        'WPForms\\Vendor\\Stripe\\PaymentLink' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/PaymentLink.php',
        'WPForms\\Vendor\\Stripe\\PaymentMethod' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/PaymentMethod.php',
        'WPForms\\Vendor\\Stripe\\PaymentMethodConfiguration' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/PaymentMethodConfiguration.php',
        'WPForms\\Vendor\\Stripe\\PaymentMethodDomain' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/PaymentMethodDomain.php',
        'WPForms\\Vendor\\Stripe\\Payout' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Payout.php',
        'WPForms\\Vendor\\Stripe\\Person' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Person.php',
        'WPForms\\Vendor\\Stripe\\Plan' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Plan.php',
        'WPForms\\Vendor\\Stripe\\Price' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Price.php',
        'WPForms\\Vendor\\Stripe\\Product' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Product.php',
        'WPForms\\Vendor\\Stripe\\ProductFeature' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ProductFeature.php',
        'WPForms\\Vendor\\Stripe\\PromotionCode' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/PromotionCode.php',
        'WPForms\\Vendor\\Stripe\\Quote' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Quote.php',
        'WPForms\\Vendor\\Stripe\\Radar\\EarlyFraudWarning' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Radar/EarlyFraudWarning.php',
        'WPForms\\Vendor\\Stripe\\Radar\\ValueList' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Radar/ValueList.php',
        'WPForms\\Vendor\\Stripe\\Radar\\ValueListItem' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Radar/ValueListItem.php',
        'WPForms\\Vendor\\Stripe\\Reason' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Reason.php',
        'WPForms\\Vendor\\Stripe\\RecipientTransfer' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/RecipientTransfer.php',
        'WPForms\\Vendor\\Stripe\\Refund' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Refund.php',
        'WPForms\\Vendor\\Stripe\\RelatedObject' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/RelatedObject.php',
        'WPForms\\Vendor\\Stripe\\Reporting\\ReportRun' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Reporting/ReportRun.php',
        'WPForms\\Vendor\\Stripe\\Reporting\\ReportType' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Reporting/ReportType.php',
        'WPForms\\Vendor\\Stripe\\RequestTelemetry' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/RequestTelemetry.php',
        'WPForms\\Vendor\\Stripe\\ReserveTransaction' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ReserveTransaction.php',
        'WPForms\\Vendor\\Stripe\\Review' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Review.php',
        'WPForms\\Vendor\\Stripe\\SearchResult' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/SearchResult.php',
        'WPForms\\Vendor\\Stripe\\Service\\AbstractService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/AbstractService.php',
        'WPForms\\Vendor\\Stripe\\Service\\AbstractServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/AbstractServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\AccountLinkService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/AccountLinkService.php',
        'WPForms\\Vendor\\Stripe\\Service\\AccountService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/AccountService.php',
        'WPForms\\Vendor\\Stripe\\Service\\AccountSessionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/AccountSessionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\ApplePayDomainService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/ApplePayDomainService.php',
        'WPForms\\Vendor\\Stripe\\Service\\ApplicationFeeService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/ApplicationFeeService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Apps\\AppsServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Apps/AppsServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\Apps\\SecretService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Apps/SecretService.php',
        'WPForms\\Vendor\\Stripe\\Service\\BalanceService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/BalanceService.php',
        'WPForms\\Vendor\\Stripe\\Service\\BalanceTransactionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/BalanceTransactionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\BillingPortal\\BillingPortalServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/BillingPortal/BillingPortalServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\BillingPortal\\ConfigurationService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/BillingPortal/ConfigurationService.php',
        'WPForms\\Vendor\\Stripe\\Service\\BillingPortal\\SessionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/BillingPortal/SessionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Billing\\AlertService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Billing/AlertService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Billing\\BillingServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Billing/BillingServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\Billing\\CreditBalanceSummaryService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Billing/CreditBalanceSummaryService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Billing\\CreditBalanceTransactionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Billing/CreditBalanceTransactionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Billing\\CreditGrantService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Billing/CreditGrantService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Billing\\MeterEventAdjustmentService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Billing/MeterEventAdjustmentService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Billing\\MeterEventService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Billing/MeterEventService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Billing\\MeterService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Billing/MeterService.php',
        'WPForms\\Vendor\\Stripe\\Service\\ChargeService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/ChargeService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Checkout\\CheckoutServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Checkout/CheckoutServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\Checkout\\SessionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Checkout/SessionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Climate\\ClimateServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Climate/ClimateServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\Climate\\OrderService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Climate/OrderService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Climate\\ProductService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Climate/ProductService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Climate\\SupplierService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Climate/SupplierService.php',
        'WPForms\\Vendor\\Stripe\\Service\\ConfirmationTokenService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/ConfirmationTokenService.php',
        'WPForms\\Vendor\\Stripe\\Service\\CoreServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/CoreServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\CountrySpecService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/CountrySpecService.php',
        'WPForms\\Vendor\\Stripe\\Service\\CouponService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/CouponService.php',
        'WPForms\\Vendor\\Stripe\\Service\\CreditNoteService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/CreditNoteService.php',
        'WPForms\\Vendor\\Stripe\\Service\\CustomerService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/CustomerService.php',
        'WPForms\\Vendor\\Stripe\\Service\\CustomerSessionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/CustomerSessionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\DisputeService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/DisputeService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Entitlements\\ActiveEntitlementService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Entitlements/ActiveEntitlementService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Entitlements\\EntitlementsServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Entitlements/EntitlementsServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\Entitlements\\FeatureService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Entitlements/FeatureService.php',
        'WPForms\\Vendor\\Stripe\\Service\\EphemeralKeyService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/EphemeralKeyService.php',
        'WPForms\\Vendor\\Stripe\\Service\\EventService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/EventService.php',
        'WPForms\\Vendor\\Stripe\\Service\\ExchangeRateService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/ExchangeRateService.php',
        'WPForms\\Vendor\\Stripe\\Service\\FileLinkService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/FileLinkService.php',
        'WPForms\\Vendor\\Stripe\\Service\\FileService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/FileService.php',
        'WPForms\\Vendor\\Stripe\\Service\\FinancialConnections\\AccountService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/FinancialConnections/AccountService.php',
        'WPForms\\Vendor\\Stripe\\Service\\FinancialConnections\\FinancialConnectionsServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/FinancialConnections/FinancialConnectionsServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\FinancialConnections\\SessionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/FinancialConnections/SessionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\FinancialConnections\\TransactionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/FinancialConnections/TransactionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Forwarding\\ForwardingServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Forwarding/ForwardingServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\Forwarding\\RequestService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Forwarding/RequestService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Identity\\IdentityServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Identity/IdentityServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\Identity\\VerificationReportService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Identity/VerificationReportService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Identity\\VerificationSessionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Identity/VerificationSessionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\InvoiceItemService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/InvoiceItemService.php',
        'WPForms\\Vendor\\Stripe\\Service\\InvoiceRenderingTemplateService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/InvoiceRenderingTemplateService.php',
        'WPForms\\Vendor\\Stripe\\Service\\InvoiceService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/InvoiceService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Issuing\\AuthorizationService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Issuing/AuthorizationService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Issuing\\CardService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Issuing/CardService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Issuing\\CardholderService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Issuing/CardholderService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Issuing\\DisputeService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Issuing/DisputeService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Issuing\\IssuingServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Issuing/IssuingServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\Issuing\\PersonalizationDesignService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Issuing/PersonalizationDesignService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Issuing\\PhysicalBundleService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Issuing/PhysicalBundleService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Issuing\\TokenService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Issuing/TokenService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Issuing\\TransactionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Issuing/TransactionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\MandateService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/MandateService.php',
        'WPForms\\Vendor\\Stripe\\Service\\OAuthService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/OAuthService.php',
        'WPForms\\Vendor\\Stripe\\Service\\PaymentIntentService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/PaymentIntentService.php',
        'WPForms\\Vendor\\Stripe\\Service\\PaymentLinkService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/PaymentLinkService.php',
        'WPForms\\Vendor\\Stripe\\Service\\PaymentMethodConfigurationService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/PaymentMethodConfigurationService.php',
        'WPForms\\Vendor\\Stripe\\Service\\PaymentMethodDomainService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/PaymentMethodDomainService.php',
        'WPForms\\Vendor\\Stripe\\Service\\PaymentMethodService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/PaymentMethodService.php',
        'WPForms\\Vendor\\Stripe\\Service\\PayoutService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/PayoutService.php',
        'WPForms\\Vendor\\Stripe\\Service\\PlanService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/PlanService.php',
        'WPForms\\Vendor\\Stripe\\Service\\PriceService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/PriceService.php',
        'WPForms\\Vendor\\Stripe\\Service\\ProductService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/ProductService.php',
        'WPForms\\Vendor\\Stripe\\Service\\PromotionCodeService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/PromotionCodeService.php',
        'WPForms\\Vendor\\Stripe\\Service\\QuoteService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/QuoteService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Radar\\EarlyFraudWarningService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Radar/EarlyFraudWarningService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Radar\\RadarServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Radar/RadarServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\Radar\\ValueListItemService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Radar/ValueListItemService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Radar\\ValueListService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Radar/ValueListService.php',
        'WPForms\\Vendor\\Stripe\\Service\\RefundService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/RefundService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Reporting\\ReportRunService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Reporting/ReportRunService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Reporting\\ReportTypeService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Reporting/ReportTypeService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Reporting\\ReportingServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Reporting/ReportingServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\ReviewService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/ReviewService.php',
        'WPForms\\Vendor\\Stripe\\Service\\ServiceNavigatorTrait' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/ServiceNavigatorTrait.php',
        'WPForms\\Vendor\\Stripe\\Service\\SetupAttemptService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/SetupAttemptService.php',
        'WPForms\\Vendor\\Stripe\\Service\\SetupIntentService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/SetupIntentService.php',
        'WPForms\\Vendor\\Stripe\\Service\\ShippingRateService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/ShippingRateService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Sigma\\ScheduledQueryRunService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Sigma/ScheduledQueryRunService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Sigma\\SigmaServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Sigma/SigmaServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\SourceService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/SourceService.php',
        'WPForms\\Vendor\\Stripe\\Service\\SubscriptionItemService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/SubscriptionItemService.php',
        'WPForms\\Vendor\\Stripe\\Service\\SubscriptionScheduleService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/SubscriptionScheduleService.php',
        'WPForms\\Vendor\\Stripe\\Service\\SubscriptionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/SubscriptionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TaxCodeService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TaxCodeService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TaxIdService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TaxIdService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TaxRateService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TaxRateService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Tax\\CalculationService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Tax/CalculationService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Tax\\RegistrationService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Tax/RegistrationService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Tax\\SettingsService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Tax/SettingsService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Tax\\TaxServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Tax/TaxServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\Tax\\TransactionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Tax/TransactionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Terminal\\ConfigurationService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Terminal/ConfigurationService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Terminal\\ConnectionTokenService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Terminal/ConnectionTokenService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Terminal\\LocationService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Terminal/LocationService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Terminal\\ReaderService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Terminal/ReaderService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Terminal\\TerminalServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Terminal/TerminalServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\ConfirmationTokenService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/ConfirmationTokenService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\CustomerService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/CustomerService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Issuing\\AuthorizationService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Issuing/AuthorizationService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Issuing\\CardService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Issuing/CardService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Issuing\\IssuingServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Issuing/IssuingServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Issuing\\PersonalizationDesignService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Issuing/PersonalizationDesignService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Issuing\\TransactionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Issuing/TransactionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\RefundService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/RefundService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Terminal\\ReaderService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Terminal/ReaderService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Terminal\\TerminalServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Terminal/TerminalServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\TestClockService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/TestClockService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\TestHelpersServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/TestHelpersServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Treasury\\InboundTransferService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Treasury/InboundTransferService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Treasury\\OutboundPaymentService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Treasury/OutboundPaymentService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Treasury\\OutboundTransferService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Treasury/OutboundTransferService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Treasury\\ReceivedCreditService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Treasury/ReceivedCreditService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Treasury\\ReceivedDebitService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Treasury/ReceivedDebitService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TestHelpers\\Treasury\\TreasuryServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TestHelpers/Treasury/TreasuryServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\TokenService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TokenService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TopupService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TopupService.php',
        'WPForms\\Vendor\\Stripe\\Service\\TransferService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/TransferService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Treasury\\CreditReversalService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Treasury/CreditReversalService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Treasury\\DebitReversalService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Treasury/DebitReversalService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Treasury\\FinancialAccountService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Treasury/FinancialAccountService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Treasury\\InboundTransferService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Treasury/InboundTransferService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Treasury\\OutboundPaymentService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Treasury/OutboundPaymentService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Treasury\\OutboundTransferService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Treasury/OutboundTransferService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Treasury\\ReceivedCreditService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Treasury/ReceivedCreditService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Treasury\\ReceivedDebitService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Treasury/ReceivedDebitService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Treasury\\TransactionEntryService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Treasury/TransactionEntryService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Treasury\\TransactionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Treasury/TransactionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\Treasury\\TreasuryServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/Treasury/TreasuryServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\V2\\Billing\\BillingServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/V2/Billing/BillingServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\V2\\Billing\\MeterEventAdjustmentService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/V2/Billing/MeterEventAdjustmentService.php',
        'WPForms\\Vendor\\Stripe\\Service\\V2\\Billing\\MeterEventService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/V2/Billing/MeterEventService.php',
        'WPForms\\Vendor\\Stripe\\Service\\V2\\Billing\\MeterEventSessionService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/V2/Billing/MeterEventSessionService.php',
        'WPForms\\Vendor\\Stripe\\Service\\V2\\Billing\\MeterEventStreamService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/V2/Billing/MeterEventStreamService.php',
        'WPForms\\Vendor\\Stripe\\Service\\V2\\Core\\CoreServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/V2/Core/CoreServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\V2\\Core\\EventDestinationService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/V2/Core/EventDestinationService.php',
        'WPForms\\Vendor\\Stripe\\Service\\V2\\Core\\EventService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/V2/Core/EventService.php',
        'WPForms\\Vendor\\Stripe\\Service\\V2\\V2ServiceFactory' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/V2/V2ServiceFactory.php',
        'WPForms\\Vendor\\Stripe\\Service\\WebhookEndpointService' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Service/WebhookEndpointService.php',
        'WPForms\\Vendor\\Stripe\\SetupAttempt' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/SetupAttempt.php',
        'WPForms\\Vendor\\Stripe\\SetupIntent' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/SetupIntent.php',
        'WPForms\\Vendor\\Stripe\\ShippingRate' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ShippingRate.php',
        'WPForms\\Vendor\\Stripe\\Sigma\\ScheduledQueryRun' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Sigma/ScheduledQueryRun.php',
        'WPForms\\Vendor\\Stripe\\SingletonApiResource' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/SingletonApiResource.php',
        'WPForms\\Vendor\\Stripe\\Source' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Source.php',
        'WPForms\\Vendor\\Stripe\\SourceMandateNotification' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/SourceMandateNotification.php',
        'WPForms\\Vendor\\Stripe\\SourceTransaction' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/SourceTransaction.php',
        'WPForms\\Vendor\\Stripe\\Stripe' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Stripe.php',
        'WPForms\\Vendor\\Stripe\\StripeClient' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/StripeClient.php',
        'WPForms\\Vendor\\Stripe\\StripeClientInterface' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/StripeClientInterface.php',
        'WPForms\\Vendor\\Stripe\\StripeObject' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/StripeObject.php',
        'WPForms\\Vendor\\Stripe\\StripeStreamingClientInterface' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/StripeStreamingClientInterface.php',
        'WPForms\\Vendor\\Stripe\\Subscription' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Subscription.php',
        'WPForms\\Vendor\\Stripe\\SubscriptionItem' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/SubscriptionItem.php',
        'WPForms\\Vendor\\Stripe\\SubscriptionSchedule' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/SubscriptionSchedule.php',
        'WPForms\\Vendor\\Stripe\\TaxCode' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/TaxCode.php',
        'WPForms\\Vendor\\Stripe\\TaxDeductedAtSource' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/TaxDeductedAtSource.php',
        'WPForms\\Vendor\\Stripe\\TaxId' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/TaxId.php',
        'WPForms\\Vendor\\Stripe\\TaxRate' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/TaxRate.php',
        'WPForms\\Vendor\\Stripe\\Tax\\Calculation' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Tax/Calculation.php',
        'WPForms\\Vendor\\Stripe\\Tax\\CalculationLineItem' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Tax/CalculationLineItem.php',
        'WPForms\\Vendor\\Stripe\\Tax\\Registration' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Tax/Registration.php',
        'WPForms\\Vendor\\Stripe\\Tax\\Settings' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Tax/Settings.php',
        'WPForms\\Vendor\\Stripe\\Tax\\Transaction' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Tax/Transaction.php',
        'WPForms\\Vendor\\Stripe\\Tax\\TransactionLineItem' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Tax/TransactionLineItem.php',
        'WPForms\\Vendor\\Stripe\\Terminal\\Configuration' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Terminal/Configuration.php',
        'WPForms\\Vendor\\Stripe\\Terminal\\ConnectionToken' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Terminal/ConnectionToken.php',
        'WPForms\\Vendor\\Stripe\\Terminal\\Location' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Terminal/Location.php',
        'WPForms\\Vendor\\Stripe\\Terminal\\Reader' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Terminal/Reader.php',
        'WPForms\\Vendor\\Stripe\\TestHelpers\\TestClock' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/TestHelpers/TestClock.php',
        'WPForms\\Vendor\\Stripe\\ThinEvent' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/ThinEvent.php',
        'WPForms\\Vendor\\Stripe\\Token' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Token.php',
        'WPForms\\Vendor\\Stripe\\Topup' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Topup.php',
        'WPForms\\Vendor\\Stripe\\Transfer' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Transfer.php',
        'WPForms\\Vendor\\Stripe\\TransferReversal' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/TransferReversal.php',
        'WPForms\\Vendor\\Stripe\\Treasury\\CreditReversal' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Treasury/CreditReversal.php',
        'WPForms\\Vendor\\Stripe\\Treasury\\DebitReversal' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Treasury/DebitReversal.php',
        'WPForms\\Vendor\\Stripe\\Treasury\\FinancialAccount' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Treasury/FinancialAccount.php',
        'WPForms\\Vendor\\Stripe\\Treasury\\FinancialAccountFeatures' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Treasury/FinancialAccountFeatures.php',
        'WPForms\\Vendor\\Stripe\\Treasury\\InboundTransfer' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Treasury/InboundTransfer.php',
        'WPForms\\Vendor\\Stripe\\Treasury\\OutboundPayment' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Treasury/OutboundPayment.php',
        'WPForms\\Vendor\\Stripe\\Treasury\\OutboundTransfer' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Treasury/OutboundTransfer.php',
        'WPForms\\Vendor\\Stripe\\Treasury\\ReceivedCredit' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Treasury/ReceivedCredit.php',
        'WPForms\\Vendor\\Stripe\\Treasury\\ReceivedDebit' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Treasury/ReceivedDebit.php',
        'WPForms\\Vendor\\Stripe\\Treasury\\Transaction' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Treasury/Transaction.php',
        'WPForms\\Vendor\\Stripe\\Treasury\\TransactionEntry' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Treasury/TransactionEntry.php',
        'WPForms\\Vendor\\Stripe\\UsageRecord' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/UsageRecord.php',
        'WPForms\\Vendor\\Stripe\\UsageRecordSummary' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/UsageRecordSummary.php',
        'WPForms\\Vendor\\Stripe\\Util\\ApiVersion' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Util/ApiVersion.php',
        'WPForms\\Vendor\\Stripe\\Util\\CaseInsensitiveArray' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Util/CaseInsensitiveArray.php',
        'WPForms\\Vendor\\Stripe\\Util\\DefaultLogger' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Util/DefaultLogger.php',
        'WPForms\\Vendor\\Stripe\\Util\\EventTypes' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Util/EventTypes.php',
        'WPForms\\Vendor\\Stripe\\Util\\LoggerInterface' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Util/LoggerInterface.php',
        'WPForms\\Vendor\\Stripe\\Util\\ObjectTypes' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Util/ObjectTypes.php',
        'WPForms\\Vendor\\Stripe\\Util\\RandomGenerator' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Util/RandomGenerator.php',
        'WPForms\\Vendor\\Stripe\\Util\\RequestOptions' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Util/RequestOptions.php',
        'WPForms\\Vendor\\Stripe\\Util\\Set' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Util/Set.php',
        'WPForms\\Vendor\\Stripe\\Util\\Util' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Util/Util.php',
        'WPForms\\Vendor\\Stripe\\V2\\Billing\\MeterEvent' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/V2/Billing/MeterEvent.php',
        'WPForms\\Vendor\\Stripe\\V2\\Billing\\MeterEventAdjustment' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/V2/Billing/MeterEventAdjustment.php',
        'WPForms\\Vendor\\Stripe\\V2\\Billing\\MeterEventSession' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/V2/Billing/MeterEventSession.php',
        'WPForms\\Vendor\\Stripe\\V2\\Collection' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/V2/Collection.php',
        'WPForms\\Vendor\\Stripe\\V2\\Event' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/V2/Event.php',
        'WPForms\\Vendor\\Stripe\\V2\\EventDestination' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/V2/EventDestination.php',
        'WPForms\\Vendor\\Stripe\\Webhook' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/Webhook.php',
        'WPForms\\Vendor\\Stripe\\WebhookEndpoint' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/WebhookEndpoint.php',
        'WPForms\\Vendor\\Stripe\\WebhookSignature' => __DIR__ . '/../..' . '/vendor_prefixed/stripe/stripe-php/lib/WebhookSignature.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\CssSelectorConverter' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/CssSelectorConverter.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Exception\\ExceptionInterface' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Exception/ExceptionInterface.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Exception\\ExpressionErrorException' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Exception/ExpressionErrorException.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Exception\\InternalErrorException' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Exception/InternalErrorException.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Exception\\ParseException' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Exception/ParseException.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Exception\\SyntaxErrorException' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Exception/SyntaxErrorException.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Node\\AbstractNode' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Node/AbstractNode.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Node\\AttributeNode' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Node/AttributeNode.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Node\\ClassNode' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Node/ClassNode.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Node\\CombinedSelectorNode' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Node/CombinedSelectorNode.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Node\\ElementNode' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Node/ElementNode.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Node\\FunctionNode' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Node/FunctionNode.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Node\\HashNode' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Node/HashNode.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Node\\NegationNode' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Node/NegationNode.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Node\\NodeInterface' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Node/NodeInterface.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Node\\PseudoNode' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Node/PseudoNode.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Node\\SelectorNode' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Node/SelectorNode.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Node\\Specificity' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Node/Specificity.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Handler\\CommentHandler' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Handler/CommentHandler.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Handler\\HandlerInterface' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Handler/HandlerInterface.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Handler\\HashHandler' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Handler/HashHandler.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Handler\\IdentifierHandler' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Handler/IdentifierHandler.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Handler\\NumberHandler' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Handler/NumberHandler.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Handler\\StringHandler' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Handler/StringHandler.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Handler\\WhitespaceHandler' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Handler/WhitespaceHandler.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Parser' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Parser.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\ParserInterface' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/ParserInterface.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Reader' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Reader.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Shortcut\\ClassParser' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Shortcut/ClassParser.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Shortcut\\ElementParser' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Shortcut/ElementParser.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Shortcut\\EmptyStringParser' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Shortcut/EmptyStringParser.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Shortcut\\HashParser' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Shortcut/HashParser.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Token' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Token.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\TokenStream' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/TokenStream.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Tokenizer\\Tokenizer' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Tokenizer/Tokenizer.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Tokenizer\\TokenizerEscaping' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Tokenizer/TokenizerEscaping.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\Parser\\Tokenizer\\TokenizerPatterns' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/Parser/Tokenizer/TokenizerPatterns.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\XPath\\Extension\\AbstractExtension' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/XPath/Extension/AbstractExtension.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\XPath\\Extension\\AttributeMatchingExtension' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/XPath/Extension/AttributeMatchingExtension.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\XPath\\Extension\\CombinationExtension' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/XPath/Extension/CombinationExtension.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\XPath\\Extension\\ExtensionInterface' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/XPath/Extension/ExtensionInterface.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\XPath\\Extension\\FunctionExtension' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/XPath/Extension/FunctionExtension.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\XPath\\Extension\\HtmlExtension' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/XPath/Extension/HtmlExtension.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\XPath\\Extension\\NodeExtension' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/XPath/Extension/NodeExtension.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\XPath\\Extension\\PseudoClassExtension' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/XPath/Extension/PseudoClassExtension.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\XPath\\Translator' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/XPath/Translator.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\XPath\\TranslatorInterface' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/XPath/TranslatorInterface.php',
        'WPForms\\Vendor\\Symfony\\Component\\CssSelector\\XPath\\XPathExpr' => __DIR__ . '/../..' . '/vendor_prefixed/symfony/css-selector/XPath/XPathExpr.php',
        'WPForms\\Vendor\\TijsVerkoyen\\CssToInlineStyles\\CssToInlineStyles' => __DIR__ . '/../..' . '/vendor_prefixed/tijsverkoyen/css-to-inline-styles/src/CssToInlineStyles.php',
        'WPForms\\Vendor\\TijsVerkoyen\\CssToInlineStyles\\Css\\Processor' => __DIR__ . '/../..' . '/vendor_prefixed/tijsverkoyen/css-to-inline-styles/src/Css/Processor.php',
        'WPForms\\Vendor\\TijsVerkoyen\\CssToInlineStyles\\Css\\Property\\Processor' => __DIR__ . '/../..' . '/vendor_prefixed/tijsverkoyen/css-to-inline-styles/src/Css/Property/Processor.php',
        'WPForms\\Vendor\\TijsVerkoyen\\CssToInlineStyles\\Css\\Property\\Property' => __DIR__ . '/../..' . '/vendor_prefixed/tijsverkoyen/css-to-inline-styles/src/Css/Property/Property.php',
        'WPForms\\Vendor\\TijsVerkoyen\\CssToInlineStyles\\Css\\Rule\\Processor' => __DIR__ . '/../..' . '/vendor_prefixed/tijsverkoyen/css-to-inline-styles/src/Css/Rule/Processor.php',
        'WPForms\\Vendor\\TijsVerkoyen\\CssToInlineStyles\\Css\\Rule\\Rule' => __DIR__ . '/../..' . '/vendor_prefixed/tijsverkoyen/css-to-inline-styles/src/Css/Rule/Rule.php',
        'WPForms\\Vendor\\TrueBV\\Exception\\DomainOutOfBoundsException' => __DIR__ . '/../..' . '/vendor_prefixed/true/punycode/src/Exception/DomainOutOfBoundsException.php',
        'WPForms\\Vendor\\TrueBV\\Exception\\LabelOutOfBoundsException' => __DIR__ . '/../..' . '/vendor_prefixed/true/punycode/src/Exception/LabelOutOfBoundsException.php',
        'WPForms\\Vendor\\TrueBV\\Exception\\OutOfBoundsException' => __DIR__ . '/../..' . '/vendor_prefixed/true/punycode/src/Exception/OutOfBoundsException.php',
        'WPForms\\Vendor\\TrueBV\\Punycode' => __DIR__ . '/../..' . '/vendor_prefixed/true/punycode/src/Punycode.php',
        'WPForms\\Vendor\\Unirest\\Configuration' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/unirest-php/src/Configuration.php',
        'WPForms\\Vendor\\Unirest\\HttpClient' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/unirest-php/src/HttpClient.php',
        'WPForms\\Vendor\\Unirest\\Request\\Body' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/unirest-php/src/Request/Body.php',
        'WPForms\\Vendor\\Unirest\\Request\\Request' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/unirest-php/src/Request/Request.php',
        'WPForms\\Vendor\\Unirest\\Response' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/unirest-php/src/Response.php',
        'WPForms\\Vendor\\apimatic\\jsonmapper\\AnyOfValidationException' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/jsonmapper/src/AnyOfValidationException.php',
        'WPForms\\Vendor\\apimatic\\jsonmapper\\JsonMapper' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/jsonmapper/src/JsonMapper.php',
        'WPForms\\Vendor\\apimatic\\jsonmapper\\JsonMapperException' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/jsonmapper/src/JsonMapperException.php',
        'WPForms\\Vendor\\apimatic\\jsonmapper\\OneOfValidationException' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/jsonmapper/src/OneOfValidationException.php',
        'WPForms\\Vendor\\apimatic\\jsonmapper\\TypeCombination' => __DIR__ . '/../..' . '/vendor_prefixed/apimatic/jsonmapper/src/TypeCombination.php',
        'WPForms\\Vendor\\enshrined\\svgSanitize\\ElementReference\\Resolver' => __DIR__ . '/../..' . '/vendor_prefixed/enshrined/svg-sanitize/src/ElementReference/Resolver.php',
        'WPForms\\Vendor\\enshrined\\svgSanitize\\ElementReference\\Subject' => __DIR__ . '/../..' . '/vendor_prefixed/enshrined/svg-sanitize/src/ElementReference/Subject.php',
        'WPForms\\Vendor\\enshrined\\svgSanitize\\ElementReference\\Usage' => __DIR__ . '/../..' . '/vendor_prefixed/enshrined/svg-sanitize/src/ElementReference/Usage.php',
        'WPForms\\Vendor\\enshrined\\svgSanitize\\Exceptions\\NestingException' => __DIR__ . '/../..' . '/vendor_prefixed/enshrined/svg-sanitize/src/Exceptions/NestingException.php',
        'WPForms\\Vendor\\enshrined\\svgSanitize\\Helper' => __DIR__ . '/../..' . '/vendor_prefixed/enshrined/svg-sanitize/src/Helper.php',
        'WPForms\\Vendor\\enshrined\\svgSanitize\\Sanitizer' => __DIR__ . '/../..' . '/vendor_prefixed/enshrined/svg-sanitize/src/Sanitizer.php',
        'WPForms\\Vendor\\enshrined\\svgSanitize\\data\\AllowedAttributes' => __DIR__ . '/../..' . '/vendor_prefixed/enshrined/svg-sanitize/src/data/AllowedAttributes.php',
        'WPForms\\Vendor\\enshrined\\svgSanitize\\data\\AllowedTags' => __DIR__ . '/../..' . '/vendor_prefixed/enshrined/svg-sanitize/src/data/AllowedTags.php',
        'WPForms\\Vendor\\enshrined\\svgSanitize\\data\\AttributeInterface' => __DIR__ . '/../..' . '/vendor_prefixed/enshrined/svg-sanitize/src/data/AttributeInterface.php',
        'WPForms\\Vendor\\enshrined\\svgSanitize\\data\\TagInterface' => __DIR__ . '/../..' . '/vendor_prefixed/enshrined/svg-sanitize/src/data/TagInterface.php',
        'WPForms\\Vendor\\enshrined\\svgSanitize\\data\\XPath' => __DIR__ . '/../..' . '/vendor_prefixed/enshrined/svg-sanitize/src/data/XPath.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInitb5bec85f6d156313c218b21150da9560::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInitb5bec85f6d156313c218b21150da9560::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInitb5bec85f6d156313c218b21150da9560::$classMap;

        }, null, ClassLoader::class);
    }
}
